=== modified file '.bzrignore'
--- .bzrignore	2009-07-31 19:56:19 +0000
+++ .bzrignore	2009-10-07 15:48:32 +0000
@@ -5,10 +5,21 @@
 ./.bzr.log
 # Generated files
 CHANGELOG
+# generated documents
 bzr.1
 ./doc/*.html
-./doc/_build/
+./doc/*/_build/
+./doc/*/Makefile
+./doc/*/make.bat
 ./tutorial.html
+./build_doc_website
+./html_docs
+./pretty_docs
+./api
+./doc/**/*.html
+./doc/developers/performance.png
+./doc/en/user-reference/*.txt
+./doc/en/release-notes/*.txt
 BRANCH-INFO
 # setup.py working directory
 ./build
@@ -35,11 +46,7 @@
 ./dist
 # performance history data file
 ./.perf_history
-./html_docs
-./pretty_docs
-./api
-doc/**/*.html
-doc/developers/performance.png
+# Pyrex
 bzrlib/_annotator_pyx.c
 bzrlib/_bencode_pyx.c
 bzrlib/_btree_serializer_pyx.c
@@ -51,16 +58,12 @@
 bzrlib/_known_graph_pyx.c
 bzrlib/_readdir_pyx.c
 bzrlib/_rio_pyx.c
+bzrlib/_simple_set_pyx.c
+bzrlib/_simple_set_pyx.h
+bzrlib/_simple_set_pyx_api.h
 bzrlib/_walkdirs_win32.c
-doc/en/release-notes/NEWS.txt
-doc/en/developer-guide/HACKING.txt
-doc/en/user-reference/bzr_man.txt
 # built extension modules
 bzrlib/_*.dll
 bzrlib/_*.so
 bzrlib/_*.pyd
-# generated help topics
-doc/en/user-reference/*.txt
-./doc/en/user-guide/latex_prepared
-./doc/en/user-guide/*.pdf
 ./.ccache

=== modified file 'Makefile'
--- Makefile	2009-08-03 20:38:39 +0000
+++ Makefile	2009-11-18 06:18:14 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2008 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,8 +40,6 @@
 
 check-nodocs: extensions
 	$(PYTHON) -Werror -O ./bzr selftest -1v $(tests)
-	@echo "Running all tests with no locale."
-	LC_CTYPE= LANG=C LC_ALL= ./bzr selftest -1v $(tests) 2>&1 | sed -e 's/^/[ascii] /'
 
 # Run Python style checker (apt-get install pyflakes)
 #
@@ -77,44 +75,172 @@
 # these are treated as phony so they'll always be rebuilt - it's pretty quick
 .PHONY: TAGS tags
 
+
 ### Documentation ###
 
-# set PRETTY to get docs that look like the Bazaar web site
-ifdef PRETTY
-rst2html := $(PYTHON) tools/rst2prettyhtml.py doc/bazaar-vcs.org.kid 
-else
-rst2html := $(PYTHON) tools/rst2html.py --link-stylesheet --footnote-references=superscript --halt=warning
-endif
+# Default to plain documentation for maximum backwards compatibility.
+# (Post 2.0, the defaults will most likely be Sphinx-style instead.)
+
+docs: docs-plain
+
+clean-docs: clean-plain
+
+html-docs: html-plain
+
+
+### Man-page Documentation ###
+
+MAN_DEPENDENCIES = bzrlib/builtins.py \
+	$(wildcard bzrlib/*.py) \
+	$(wildcard bzrlib/*/*.py) \
+	tools/generate_docs.py \
+	$(wildcard $(addsuffix /*.txt, bzrlib/help_topics/en)) 
+
+MAN_PAGES = man1/bzr.1
+man1/bzr.1: $(MAN_DEPENDENCIES)
+	$(PYTHON) tools/generate_docs.py -o $@ man
+
+
+### Sphinx-style Documentation ###
+
+# Build the documentation. To keep the dependencies down to a minimum
+# for distro packagers, we only build the html documentation by default.
+# Sphinx 0.6 or later is preferred for the best rendering, though
+# Sphinx 0.4 or later should work. See http://sphinx.pocoo.org/index.html
+# for installation instructions.
+docs-sphinx: html-sphinx
+
+# Clean out generated documentation
+clean-sphinx:
+	cd doc/en && make clean
+	cd doc/es && make clean
+	cd doc/ja && make clean
+	cd doc/ru && make clean
+	cd doc/developers && make clean
+
+SPHINX_DEPENDENCIES = \
+        doc/en/release-notes/index.txt \
+        doc/en/user-reference/index.txt \
+	doc/es/Makefile \
+	doc/es/make.bat \
+	doc/ja/Makefile \
+	doc/ja/make.bat \
+	doc/ru/Makefile \
+	doc/ru/make.bat \
+	doc/developers/Makefile \
+	doc/developers/make.bat
+
+doc/en/user-reference/index.txt: $(MAN_DEPENDENCIES)
+	$(PYTHON) tools/generate_docs.py -o $@ rstx
+
+doc/en/release-notes/index.txt: NEWS tools/generate_release_notes.py
+	$(PYTHON) tools/generate_release_notes.py NEWS $@
+
+doc/%/Makefile: doc/en/Makefile
+	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
+
+doc/%/make.bat: doc/en/make.bat
+	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
+
+# Build the html docs using Sphinx.
+html-sphinx: $(SPHINX_DEPENDENCIES)
+	cd doc/en && make html
+	cd doc/es && make html
+	cd doc/ru && make html
+	cd doc/ja && make html
+	cd doc/developers && make html
+
+# Build the PDF docs using Sphinx. This requires numerous LaTeX
+# packages. See http://sphinx.pocoo.org/builders.html for details.
+# Note: We don't currently build PDFs for the Russian docs because
+# they require additional packages to be installed (to handle
+# Russian hyphenation rules, etc.)
+pdf-sphinx: $(SPHINX_DEPENDENCIES)
+	cd doc/en && make latex
+	cd doc/es && make latex
+	cd doc/ja && make latex
+	cd doc/developers && make latex
+	cd doc/en/_build/latex && make all-pdf
+	cd doc/es/_build/latex && make all-pdf
+	cd doc/developers/_build/latex && make all-pdf
+
+# Build the CHM (Windows Help) docs using Sphinx.
+# Note: HtmlHelp Workshop needs to be used on the generated hhp files
+# to generate the final chm files.
+chm-sphinx: $(SPHINX_DEPENDENCIES)
+	cd doc/en && make htmlhelp
+	cd doc/es && make htmlhelp
+	cd doc/ru && make htmlhelp
+	cd doc/ja && make htmlhelp
+	cd doc/developers && make htmlhelp
+
+
+### Documentation Website ###
+
+# Where to build the website
+DOC_WEBSITE_BUILD = build_doc_website
+
+# Build and package docs into a website, complete with downloads.
+doc-website: html-sphinx pdf-sphinx
+	$(PYTHON) tools/package_docs.py doc/en $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/es $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/ru $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/ja $(DOC_WEBSITE_BUILD)
+	$(PYTHON) tools/package_docs.py doc/developers $(DOC_WEBSITE_BUILD)
+
+
+### Plain Documentation ###
+
+# While Sphinx is the preferred tool for building documentation, we still
+# support our "plain" html documentation so that Sphinx is not a hard
+# dependency for packagers on older platforms.
+
+rst2html = $(PYTHON) tools/rst2html.py --link-stylesheet --footnote-references=superscript --halt=warning
 
 # translate txt docs to html
-derived_txt_files := \
+derived_txt_files = \
 	doc/en/user-reference/bzr_man.txt \
 	doc/en/release-notes/NEWS.txt
-txt_files := \
+txt_all = \
 	doc/en/tutorials/tutorial.txt \
 	doc/en/tutorials/using_bazaar_with_launchpad.txt \
 	doc/en/tutorials/centralized_workflow.txt \
-        $(wildcard doc/ru/tutorials/*.txt) \
+        $(wildcard doc/es/tutorials/*.txt) \
+		$(wildcard doc/ru/tutorials/*.txt) \
+	doc/ja/tutorials/tutorial.txt \
+	doc/ja/tutorials/using_bazaar_with_launchpad.txt \
+	doc/ja/tutorials/centralized_workflow.txt \
 	$(wildcard doc/*/mini-tutorial/index.txt) \
-	$(wildcard doc/*/user-guide/index.txt) \
+	$(wildcard doc/*/user-guide/index-plain.txt) \
+	$(wildcard doc/es/guia-usario/*.txt) \
 	$(derived_txt_files) \
-	doc/en/developer-guide/HACKING.txt \
 	doc/en/upgrade-guide/index.txt \
-	$(wildcard doc/es/guia-usario/*.txt) \
-	doc/es/mini-tutorial/index.txt \
 	doc/index.txt \
 	$(wildcard doc/index.*.txt)
-non_txt_files := \
+txt_nohtml = \
+	doc/en/user-guide/index.txt \
+	doc/es/user-guide/index.txt \
+	doc/ja/user-guide/index.txt \
+	doc/ru/user-guide/index.txt
+txt_files = $(filter-out $(txt_nohtml), $(txt_all))
+htm_files = $(patsubst %.txt, %.html, $(txt_files)) 
+
+non_txt_files = \
        doc/default.css \
-       $(wildcard doc/*/quick-reference/bzr-quick-reference.svg) \
-       $(wildcard doc/*/quick-reference/bzr-quick-reference.png) \
-       $(wildcard doc/*/quick-reference/bzr-quick-reference.pdf) \
+       $(wildcard doc/*/bzr-en-quick-reference.svg) \
+       $(wildcard doc/*/bzr-en-quick-reference.png) \
+       $(wildcard doc/*/bzr-en-quick-reference.pdf) \
+       $(wildcard doc/*/bzr-es-quick-reference.svg) \
+       $(wildcard doc/*/bzr-es-quick-reference.png) \
+       $(wildcard doc/*/bzr-es-quick-reference.pdf) \
+       $(wildcard doc/*/bzr-ru-quick-reference.svg) \
+       $(wildcard doc/*/bzr-ru-quick-reference.png) \
+       $(wildcard doc/*/bzr-ru-quick-reference.pdf) \
        $(wildcard doc/*/user-guide/images/*.png)
-htm_files := $(patsubst %.txt, %.html, $(txt_files)) 
 
 # doc/developers/*.txt files that should *not* be individually
 # converted to HTML
-dev_txt_nohtml := \
+dev_txt_nohtml = \
 	doc/developers/add.txt \
 	doc/developers/annotate.txt \
 	doc/developers/bundle-creation.txt \
@@ -122,46 +248,37 @@
 	doc/developers/diff.txt \
 	doc/developers/directory-fingerprints.txt \
 	doc/developers/gc.txt \
+	doc/developers/implementation-notes.txt \
 	doc/developers/incremental-push-pull.txt \
+	doc/developers/index.txt \
 	doc/developers/initial-push-pull.txt \
 	doc/developers/merge-scaling.txt \
+	doc/developers/miscellaneous-notes.txt \
 	doc/developers/missing.txt \
 	doc/developers/performance-roadmap-rationale.txt \
 	doc/developers/performance-use-case-analysis.txt \
 	doc/developers/planned-change-integration.txt \
 	doc/developers/planned-performance-changes.txt \
+	doc/developers/plans.txt \
+	doc/developers/process.txt \
 	doc/developers/revert.txt \
+	doc/developers/specifications.txt \
 	doc/developers/status.txt \
 	doc/developers/uncommit.txt
 
-dev_txt_all := $(wildcard $(addsuffix /*.txt, doc/developers))
-dev_txt_files := $(filter-out $(dev_txt_nohtml), $(dev_txt_all))
-dev_htm_files := $(patsubst %.txt, %.html, $(dev_txt_files)) 
-
-doc/%/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/%/user-guide)) 
-	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
-
-# Set the paper size for PDF files.
-# Options:  'a4' (ISO A4 size), 'letter' (US Letter size)
-PAPERSIZE = a4
-# TODO: Add generation for Russian PDF
-PDF_DOCS := doc/en/user-guide/user-guide.$(PAPERSIZE).pdf
-
-# Copy and modify the RST sources, and convert SVG images to PDF
-# files for use a images in the LaTeX-generated PDF.
-# Then generate the PDF output from the modified RST sources.
-doc/en/user-guide/user-guide.$(PAPERSIZE).pdf: $(wildcard $(addsuffix /*.txt, doc/en/user-guide))
-	mkdir -p doc/en/user-guide/latex_prepared
-	$(PYTHON) tools/prepare_for_latex.py \
-	    --out-dir=doc/en/user-guide/latex_prepared \
-	    --in-dir=doc/en/user-guide
-	cd doc/en/user-guide/latex_prepared && \
-	    $(PYTHON) ../../../../tools/rst2pdf.py \
-	        --documentoptions=10pt,$(PAPERSIZE)paper \
-	        --input-encoding=UTF-8:strict --output-encoding=UTF-8:strict \
-	        --strict --title="Bazaar User Guide" \
-	        index.txt ../user-guide.$(PAPERSIZE).pdf
-
+dev_txt_all = $(wildcard $(addsuffix /*.txt, doc/developers))
+dev_txt_files = $(filter-out $(dev_txt_nohtml), $(dev_txt_all))
+dev_htm_files = $(patsubst %.txt, %.html, $(dev_txt_files)) 
+
+doc/en/user-guide/index-plain.html: $(wildcard $(addsuffix /*.txt, doc/en/user-guide)) 
+	$(rst2html) --stylesheet=../../default.css $(dir $@)index-plain.txt $@
+
+#doc/es/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/es/user-guide)) 
+#	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
+#
+#doc/ru/user-guide/index.html: $(wildcard $(addsuffix /*.txt, doc/ru/user-guide)) 
+#	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
+#
 doc/developers/%.html: doc/developers/%.txt
 	$(rst2html) --stylesheet=../default.css $< $@
 
@@ -174,55 +291,42 @@
 %.html: %.txt
 	$(rst2html) --stylesheet=../../default.css $< $@
 
-MAN_DEPENDENCIES = bzrlib/builtins.py \
-	$(wildcard bzrlib/*.py) \
-	$(wildcard bzrlib/*/*.py) \
-	tools/generate_docs.py \
-	$(wildcard $(addsuffix /*.txt, bzrlib/help_topics/en)) 
-
 doc/en/user-reference/bzr_man.txt: $(MAN_DEPENDENCIES)
 	$(PYTHON) tools/generate_docs.py -o $@ rstx
 
 doc/en/release-notes/NEWS.txt: NEWS
 	$(PYTHON) -c "import shutil; shutil.copyfile('$<', '$@')"
 
-MAN_PAGES = man1/bzr.1
-man1/bzr.1: $(MAN_DEPENDENCIES)
-	$(PYTHON) tools/generate_docs.py -o $@ man
-
 upgrade_guide_dependencies =  $(wildcard $(addsuffix /*.txt, doc/en/upgrade-guide)) 
 
 doc/en/upgrade-guide/index.html: $(upgrade_guide_dependencies)
 	$(rst2html) --stylesheet=../../default.css $(dir $@)index.txt $@
 
-# build a png of our performance task list
-# 
-# this is no longer built by default; you can build it if you want to look at it
-doc/developers/performance.png: doc/developers/performance.dot
-	@echo Generating $@
-	@dot -Tpng $< -o$@ || echo "Dot not installed; skipping generation of $@"
-
 derived_web_docs = $(htm_files) $(dev_htm_files) 
 WEB_DOCS = $(derived_web_docs) $(non_txt_files)
 ALL_DOCS = $(derived_web_docs) $(MAN_PAGES)
 
 # the main target to build all the docs
-docs: $(ALL_DOCS)
+docs-plain: $(ALL_DOCS)
 
 # produce a tree containing just the final docs, ready for uploading to the web
-HTMLDIR := html_docs
-html-docs: docs
+HTMLDIR = html_docs
+html-plain: docs-plain
 	$(PYTHON) tools/win32/ostools.py copytree $(WEB_DOCS) $(HTMLDIR)
 
-# Produce PDF documents.  Requires pdfLaTeX, rubber, and Inkscape.
-pdf-docs: $(PDF_DOCS)
-
 # clean produced docs
-clean-docs:
+clean-plain:
 	$(PYTHON) tools/win32/ostools.py remove $(ALL_DOCS) \
 	    $(HTMLDIR) $(derived_txt_files)
-	rm -f doc/*/user-guide/*.pdf
-	rm -rf doc/*/user-guide/latex_prepared
+
+
+### Miscellaneous Documentation Targets ###
+
+# build a png of our performance task list
+# this is no longer built by default; you can build it if you want to look at it
+doc/developers/performance.png: doc/developers/performance.dot
+	@echo Generating $@
+	@dot -Tpng $< -o$@ || echo "Dot not installed; skipping generation of $@"
 
 
 ### Windows Support ###
@@ -232,7 +336,7 @@
 # These are files that need to be copied into the build location to boostrap
 # the build process.
 # Note that the path is relative to tools/win32
-BUILDOUT_FILES := buildout.cfg \
+BUILDOUT_FILES = buildout.cfg \
 	buildout-templates/bin/build-installer.bat.in \
 	ostools.py bootstrap.py
 
@@ -298,9 +402,12 @@
 	$(PYTHON) tools/win32/ostools.py remove bzr-*win32.exe
 	$(PYTHON) tools/win32/ostools.py remove dist
 
+
+### Packaging Targets ###
+
 .PHONY: dist dist-upload-escudero check-dist-tarball
 
-# build a distribution tarball and zip file.
+# build a distribution source tarball
 #
 # this method of copying the pyrex generated files is a bit ugly; it would be
 # nicer to generate it from distutils.
@@ -310,15 +417,12 @@
 	expbasedir=`mktemp -t -d tmp_bzr_dist.XXXXXXXXXX` && \
 	expdir=$$expbasedir/bzr-$$version && \
 	tarball=$$PWD/../bzr-$$version.tar.gz && \
-	zipball=$$PWD/../bzr-$$version.zip && \
 	$(MAKE) clean && \
 	$(MAKE) && \
 	bzr export $$expdir && \
-	cp bzrlib/*.c $$expdir/bzrlib/. && \
+	cp bzrlib/*.c bzrlib/*.h $$expdir/bzrlib/. && \
 	tar cfz $$tarball -C $$expbasedir bzr-$$version && \
-	(cd $$expbasedir && zip -r $$zipball bzr-$$version) && \
 	gpg --detach-sign $$tarball && \
-	gpg --detach-sign $$zipball && \
 	rm -rf $$expbasedir
 
 # run all tests in a previously built tarball
@@ -336,15 +440,10 @@
 dist-upload-escudero:
 	version=`./bzr version --short` && \
 	tarball=../bzr-$$version.tar.gz && \
-	zipball=../bzr-$$version.zip && \
-	scp $$zipball $$zipball.sig $$tarball $$tarball.sig \
+	scp $$tarball $$tarball.sig \
 	    escudero.ubuntu.com:/srv/bazaar.canonical.com/www/releases/src \
 		&& \
 	echo verifying over http... && \
-	curl http://bazaar-vcs.org/releases/src/bzr-$$version.zip \
-		| diff -s - $$zipball && \
-	curl http://bazaar-vcs.org/releases/src/bzr-$$version.zip.sig \
-		| diff -s - $$zipball.sig 
 	curl http://bazaar-vcs.org/releases/src/bzr-$$version.tar.gz \
 		| diff -s - $$tarball && \
 	curl http://bazaar-vcs.org/releases/src/bzr-$$version.tar.gz.sig \

=== modified file 'NEWS'
--- NEWS	2009-08-31 00:25:33 +0000
+++ NEWS	2009-12-03 02:24:54 +0000
@@ -2,50 +2,833 @@
 Bazaar Release Notes
 ####################
 
-
 .. contents:: List of Releases
    :depth: 1
 
-bzr 2.0rc2
-##########
-
-Bug Fixes
-*********
+bzr 2.1.0b4 (not released yet)
+##############################
+
+:Codename: san francisco airport
+:2.1.0b4: ???
+
+Compatibility Breaks
+********************
+
+* The BZR_SSH environmental variable may now be set to the path of a secure
+  shell client. If currently set to the value ``ssh`` it will now guess the
+  vendor of the program with that name, to restore the old behaviour that
+  indicated the SSH Corporation client use ``sshcorp`` instead as the magic
+  string. (Martin <gzlist@googlemail.com>, #176292)
+
+New Features
+************
+
+* ``bzr commit`` now has a ``--commit-time`` option.
+  (Alexander Sack, #459276)
+
+Bug Fixes
+*********
+
+* After renaming a file, the dirstate could accidentally reference
+  ``source\\path`` rather than ``source/path`` on Windows. This might be a
+  source of some dirstate-related failures. (John Arbash Meinel)
+
+* ``bzr ignore /`` no longer causes an IndexError. (Gorder Tyler, #456036)
+
+* ``bzr mv --quiet`` really is quiet now.  (Gordon Tyler, #271790)
+
+* ``bzr serve`` is more clear about the risk of supplying --allow-writes.
+  (Robert Collins, #84659)
+
+* ``bzr serve --quiet`` really is quiet now.  (Gordon Tyler, #252834)
+
+* Lots of bugfixes for the test suite on Windows. We should once again
+  have a test suite with no failures on Windows. (John Arbash Meinel)
+
+* Terminate ssh subprocesses when no references to them remain, fixing
+  subprocess and file descriptor leaks.  (Andrew Bennetts, #426662)
+  
+* The new glob expansion on Windows would replace all ``\`` characters
+  with ``/`` even if it there wasn't a glob to expand, the arg was quoted,
+  etc. Now only change slashes if there is something being glob expanded.
+  (John Arbash Meinel, #485771)
+
+* Use our faster ``KnownGraph.heads()`` functionality when computing the
+  new rich-root heads. This can cut a conversion time in half (mysql from
+  13.5h => 6.2h) (John Arbash Meinel, #487632)
+
+Improvements
+************
+
+* ``bzr log`` is now faster. (Ian Clatworthy)
+
+* ``bzrlib.urlutils.local_path_from_url`` now accepts
+  'file://localhost/' as well as 'file:///' URLs on POSIX.  (Michael
+  Hudson)
+
+Documentation
+*************
+
+API Changes
+***********
+
+* ``bzrlib.textui`` (vestigial module) removed.  (Martin Pool)
+
+Internals
+*********
+
+* Several code paths that were calling ``Transport.get().read()`` have
+  been changed to the equalivent ``Transport.get_bytes()``. The main
+  difference is that the latter will explicitly call ``file.close()``,
+  rather than expecting the garbage collector to handle it. This helps
+  with some race conditions on Windows during the test suite and sftp
+  tests. (John Arbash Meinel)
+
+Testing
+*******
+
+* TestCaseWithMemoryTransport no longer sets $HOME and $BZR_HOME to
+  unicode strings. (Michael Hudson, #464174)
+
+bzr 2.0.3 (not released yet)
+############################
+
+:Codename: 
+:2.0.3: ???
+
+Compatibility Breaks
+********************
+
+New Features
+************
+
+Bug Fixes
+*********
+
+* ``bzr push --use-existing-dir`` no longer crashes if the directory
+  exists but contains an invalid ``.bzr`` directory.
+  (Andrew Bennetts, #423563)
+
+* Content filters are now applied correctly after pull, merge and switch.
+  (Ian Clatworthy, #385879)
+
+* Improve "Binary files differ" hunk handling.  (Aaron Bentley, #436325)
+
+Improvements
+************
+
+Documentation
+*************
+* Include Japanese translations for documentation (Inada Naoki)
+
+API Changes
+***********
+
+Internals
+*********
+
+Testing
+*******
+
+
+
+bzr 2.1.0b3
+###########
+
+:Codename: after sprint recovery
+:2.1.0b3: 2009-11-16
+
+This release was pushed up from its normal release cycle due to a
+regression in python 2.4 compatibility in 2.1.0b2.  Since this regression
+was caught before 2.1.0b2 was officially announced, the full changelog
+includes both 2.1.0b3 and 2.1.0b2 changes.
+
+Highlights of 2.1.0b3 are: new globbing code for all commands on Windows,
+the test suite now conforms to python's trunk enhanced semantics (skip,
+etc.), and ``bzr info -v`` will now report the correct branch and repo
+formats for Remote objects.
+
+
+New Features
+************
+
+* Users can define a shelve editor to provide shelf functionality at a
+  granularity finer than per-patch-hunk. (Aaron Bentley)
+
+Bug Fixes
+*********
+
+* Fix for shell completion and short options.  (Benoît PIERRE)
+
+* Hooks daughter classes should always call the base constructor.
+  (Alexander Belchenko, Vincent Ladeuil, #389648) 
+
+* Improve "Binary files differ" hunk handling.  (Aaron Bentley, #436325)
+
+* On Windows, do glob expansion at the command-line level (as is usually
+  done in bash, etc.) This means that *all* commands get glob expansion
+  (bzr status, bzr add, bzr mv, etc). It uses a custom command line
+  parser, which allows us to know if a given section was quoted. It means
+  you can now do ``bzr ignore "*.py"``.
+  (John Arbash Meinel, #425510, #426410, #194450)
+
+* Sanitize commit messages that come in from the '-m' flag. We translate
+  '\r\n' => '\n' and a plain '\r' => '\n'. The storage layer doesn't
+  allow those because XML store silently translate it anyway. (The parser
+  auto-translates \r\n => \n in ways that are hard for us to catch.)
+
+* Show correct branch and repository format descriptions in 
+  ``bzr info -v`` on a smart server location.  (Andrew Bennetts, #196080)
+
+* The fix for bug #186920 accidentally broke compatibility with python
+  2.4.  (Vincent Ladeuil, #475585)
+
+* Using ``Repository.get_commit_builder().record_iter_changes()`` now
+  correctly sets ``self.inv_sha1`` to a sha1 string and
+  ``self.new_inventory`` to an Inventory instance after calling
+  ``self.finish_inventory()``. (Previously it accidently set both values
+  as a tuple on ``self.inv_sha1``. This was missed because
+  ``repo.add_revision`` ignores the supplied inventory sha1 and recomputes
+  the sha1 from the repo directly. (John Arbash Meinel)
+
+
+* Shelve command refuse to run if there is no real terminal.
+  (Alexander Belchenko)
+
+* Avoid unnecessarily flushing of trace file; it's now unbuffered at the
+  Python level.  (Martin Pool)
+
+Documentation
+*************
+
+* Include Japanese translations for documentation (Inada Naoki)
+
+Internals
+*********
+
+* Some of the core groupcompress functionality now releases the GIL before
+  operation. Similar to how zlib and bz2 operate without the GIL in the
+  core compression and decompression routines. (John Arbash Meinel)
+
+Testing
+*******
+
+* -Dhpssvfs will now trigger on ``RemoteBzrDir._ensure_real``, providing
+  more debugging of VFS access triggers. (Robert Collins)
+
+* KnownFailure is now signalled to ``ExtendedTestResult`` using the same
+  method that Python 2.7 uses - ``addExpectedFailure``. (Robert Collins)
+
+* ``--parallel=fork`` is now compatible with --subunit.
+  (Robert Collins, Vincent Ladeuil, #419776)
+
+* TestNotApplicable is now handled within the TestCase.run method rather
+  than being looked for within ``ExtendedTestResult.addError``. This
+  provides better handling with other ``TestResult`` objects, degrading to
+  sucess rather than error. (Robert Collins)
+
+* The private method ``_testConcluded`` on ``ExtendedTestResult`` has been
+  removed - it was empty and unused. (Robert Collins)
+
+* UnavailableFeature is now handled within the TestCase.run method rather
+  than being looked for within addError. If the Result object does not
+  have an addNotSupported method, addSkip is attempted instead, and
+  failing that addSuccess. (Robert Collins)
+
+* When a TestResult does not have an addSkip method, skipped tests are now
+  reported as successful tests, rather than as errors. This change is
+  to make it possible to get a clean test run with a less capable
+  TestResult. (Robert Collins)
+
+
+
+bzr 2.1.0b2
+###########
+
+:Codename: a load off my mind
+:2.1.0b2: 2009-11-02
+
+This is our second feature-filled release since 2.0, pushing us down the
+path to a 2.1.0. Once again, all bugfixes in 2.0.2 are present in 2.1.0b2.
+
+Key highlights in this release are: improved handling of
+failures-during-cleanup for commit, fixing a long-standing bug with
+``bzr+http`` and shared repositories, all ``lp:`` urls to be resolved
+behind proxies, and a new StaticTuple datatype, allowing us to reduce
+memory consumption (50%) and garbage collector overhead (40% faster) for
+many operations.
+
+* A new ``--concurrency`` option has been added as well as an associated
+  BZR_CONCURRENCY environment variable to specify the number of
+  processes that can be run concurrently when running ``bzr selftest``. The
+  command-line option overrides the environment variable if both are
+  specified. If none is specified. the number of processes is obtained
+  from the OS as before.  (Matt Nordhoff, Vincent Ladeuil)
+
+Bug Fixes
+*********
+
+* ``bzr+http`` servers no longer give spurious jail break errors when
+  serving branches inside a shared repository.  (Andrew Bennetts, #348308)
+
+* Errors during commit are handled more robustly so that knock-on errors
+  are less likely to occur, and will not obscure the original error if
+  they do occur.  This fixes some causes of ``TooManyConcurrentRequests``
+  and similar errors.  (Andrew Bennetts, #429747, #243391)
+
+* Launchpad urls can now be resolved from behind proxies.
+  (Gordon Tyler, Vincent Ladeuil, #186920)
+
+* Reduce the strictness for StaticTuple, instead add a debug flag
+  ``-Dstatic_tuple`` which will change apis to be strict and raise errors.
+  This way, most users won't see failures, but developers can improve
+  internals. (John Arbash Meinel, #471193)
+
+* TreeTransform.adjust_path updates the limbo paths of descendants of adjusted
+  files.  (Aaron Bentley)
+
+* Unicode paths are now handled correctly and consistently by the smart
+  server.  (Andrew Bennetts, Michael Hudson, #458762)
+
+Improvements
+************
+
+* When reading index files, we now use a ``StaticTuple`` rather than a
+  plain ``tuple`` object. This generally gives a 20% decrease in peak
+  memory, and can give a performance boost up to 40% on large projects.
+  (John Arbash Meinel)
+
+* Peak memory under certain operations has been reduced significantly.
+  (eg, 'bzr branch launchpad standalone' is cut in half)
+  (John Arbash Meinel)
+
+Documentation
+*************
+
+* Filtered views user documentation upgraded to refer to format 2a
+  instead of pre-2.0 formats. (Ian Clatworthy)
+
+API Changes
+***********
+
+* Remove deprecated ``CLIUIFactory``.  (Martin Pool)
+
+* ``UIFactory`` now has new ``show_error``, ``show_message`` and
+  ``show_warning`` methods, which can be hooked by non-text UIs.  
+  (Martin Pool)
+
+Internals
+*********
+
+* Added ``bzrlib._simple_set_pyx``. This is a hybrid between a Set and a
+  Dict (it only holds keys, but you can lookup the object located at a
+  given key). It has significantly reduced memory consumption versus the
+  builtin objects (1/2 the size of Set, 1/3rd the size of Dict). This is
+  used as the interning structure for StaticTuple objects.
+  (John Arbash Meinel)
+
+* ``bzrlib._static_tuple_c.StaticTuple`` is now available and used by
+  the btree index parser and the chk map parser. This class functions
+  similarly to ``tuple`` objects. However, it can only point to a limited
+  collection of types.  (Currently StaticTuple, str, unicode, None, bool,
+  int, long, float, but not subclasses).  This allows us to remove it from
+  the garbage collector (it cannot be in a cycle), it also allows us to
+  intern the objects. In testing, this can reduce peak memory by 20-40%,
+  and significantly improve performance by removing objects from being
+  inspected by the garbage collector.  (John Arbash Meinel)
+
+* ``GroupCompressBlock._ensure_content()`` will now release the
+  ``zlib.decompressobj()`` when the first request is for all of the
+  content. (Previously it would only be released if you made a request for
+  part of the content, and then all of it later.) This turns out to be a
+  significant memory savings, as a ``zstream`` carries around approx 260kB
+  of internal state and buffers. (For branching bzr.dev this drops peak
+  memory from 382MB => 345MB.) (John Arbash Meinel)
+
+* When streaming content between ``2a`` format repositories, we now clear
+  caches from earlier versioned files. (So 'revisions' is cleared when we
+  start reading 'inventories', etc.) This can have a significant impact on
+  peak memory for initial copies (~200MB). (John Arbash Meinel)
+
+Improvements
+************
+
+Documentation
+*************
+
+API Changes
+***********
+
+Internals
+*********
+
+Testing
+*******
+
+
+bzr 2.0.2
+#########
+
+:Codename: after the scare
+:2.0.2: 2009-11-02
+
+The second in our "let's keep the stable bugfixes flowing" series. As
+expected this has a few (~9) bugfixes relative to 2.0.1, and no major api
+changes or features.
+
+Bug Fixes
+*********
+
+* Avoid "NoneType has no attribute st_mode" error when files disappear
+  from a directory while it's being read.  (Martin Pool, #446033)
+
+* Content filters are now applied correctly after revert.
+  (Ian Clatworthy)
+
+* Diff parsing handles "Binary files differ" hunks.  (Aaron Bentley, #436325)
+
+* Fetching from stacked pre-2a repository via a smart server no longer
+  fails intermittently with "second push failed to complete".
+  (Andrew Bennetts, #437626)
+
+* Fix typos left after test_selftest refactoring.
+  (Vincent Ladeuil, Matt Nordhoff, #461149)
+
+* Fixed ``ObjectNotLocked`` errors during ``bzr log -r NNN somefile``.
+  (Andrew Bennetts, #445171)
+  
+* PreviewTree file names are not limited by the encoding of the temp
+  directory's filesystem. (Aaron Bentley, #436794)
+
+Improvements
+************
+
+* ``bzr log`` now read-locks branches exactly once, so makes better use of
+  data caches.  (Andrew Bennetts)
+
+Documentation
+*************
+
+* Filtered views user documentation upgraded to refer to format 2a
+  instead of pre-2.0 formats. (Ian Clatworthy)
+
+
+bzr 2.1.0b1
+###########
+
+:Codename: While the cat is away
+:2.1.0b1: 2009-10-14
+
+This is the first development release in the new split "stable" and
+"development" series. As such, the release is a snapshot of bzr.dev
+without creating a release candidate first. This release includes a
+fair amount of internal changes, with deprecated code being removed,
+and several new feature developments. People looking for a stable code
+base with only bugfixes should focus on the 2.0.1 release. All bugfixes
+present in 2.0.1 are present in 2.1.0b1.
+
+Highlights include support for ``bzr+ssh://host/~/homedir`` style urls,
+finer control over the plugin search path via extended BZR_PLUGIN_PATH
+syntax, visible warnings when extension modules fail to load, and improved
+error handling during unlocking.
+
+
+New Features
+************
+
+* Bazaar can now send mail through Apple OS X Mail.app. 
+  (Brian de Alwis)
+
+* ``bzr+ssh`` and ``bzr`` paths can now be relative to home directories
+  specified in the URL.  Paths starting with a path segment of ``~`` are
+  relative to the home directory of the user running the server, and paths
+  starting with ``~user`` are relative to the home directory of the named
+  user.  For example, for a user "bob" with a home directory of
+  ``/home/bob``, these URLs are all equivalent:
+
+  * ``bzr+ssh://bob@host/~/repo``
+  * ``bzr+ssh://bob@host/~bob/repo``
+  * ``bzr+ssh://bob@host/home/bob/repo``
+
+  If ``bzr serve`` was invoked with a ``--directory`` argument, then no
+  home directories outside that directory will be accessible via this
+  method.
+
+  This is a feature of ``bzr serve``, so pre-2.1 clients will
+  automatically benefit from this feature when ``bzr`` on the server is
+  upgraded.  (Andrew Bennetts, #109143)
+
+* Extensions can now be compiled if either Cython or Pyrex is available.
+  Currently Pyrex is preferred, but that may change in the future.
+  (Arkanes)
+
+* Give more control on BZR_PLUGIN_PATH by providing a way to refer to or
+  disable the user, site and core plugin directories.
+  (Vincent Ladeuil, #412930, #316192, #145612)
+
+Bug Fixes
+*********
+
+* Bazaar's native protocol code now correctly handles EINTR, which most
+  noticeably occurs if you break in to the debugger while connected to a
+  bzr+ssh server.  You can now can continue from the debugger (by typing
+  'c') and the process continues.  However, note that pressing C-\ in the
+  shell may still kill the SSH process, which is bug 162509, so you must
+  sent a signal to the bzr process specifically, for example by typing
+  ``kill -QUIT PID`` in another shell.  (Martin Pool, #341535)
+
+* ``bzr add`` in a tree that has files with ``\r`` or ``\n`` in the
+  filename will issue a warning and skip over those files.
+  (Robert Collins, #3918)
+
+* ``bzr dpush`` now aborts if uncommitted changes (including pending merges)
+  are present in the working tree. The configuration option ``dpush_strict``
+  can be used to set the default for this behavior.
+  (Vincent Ladeuil, #438158)
+
+* ``bzr merge`` and ``bzr remove-tree`` now requires --force if pending
+  merges are present in the working tree.
+  (Vincent Ladeuil, #426344)
+
+* Clearer message when Bazaar runs out of memory, instead of a ``MemoryError``
+  traceback.  (Martin Pool, #109115)
+
+* Don't give a warning on Windows when failing to import ``_readdir_pyx``
+  as it is never built. (John Arbash Meinel, #430645)
+
+* Don't restrict the command name used to run the test suite.
+  (Vincent Ladeuil, #419950)
+
+* ftp transports were built differently when the kerberos python module was
+  present leading to obscure failures related to ASCII/BINARY modes.
+  (Vincent Ladeuil, #443041)
+
+* Network streams now decode adjacent records of the same type into a
+  single stream, reducing layering churn. (Robert Collins)
+
+* PreviewTree behaves correctly when get_file_mtime is invoked on an unmodified
+  file. (Aaron Bentley, #251532)
+
+* Registry objects should not use iteritems() when asked to use items().
+  (Vincent Ladeuil, #430510)
+
+* Weave based repositories couldn't be cloned when committers were using
+  domains or user ids embedding '.sig'. Now they can.
+  (Matthew Fuller, Vincent Ladeuil, #430868)
+
+Improvements
+************
+
+* Revision specifiers can now be given in a more DWIM form, without
+  needing explicit prefixes for specifiers like tags or revision id's.
+  See ``bzr help revisionspec`` for full details.  (Matthew Fuller)
+
+* Bazaar gives a warning before exiting, and writes into ``.bzr.log``, if 
+  compiled extensions can't be loaded.  This typically indicates a
+  packaging or installation problem.  In this case Bazaar will keep
+  running using pure-Python versions, but this may be substantially
+  slower.  The warning can be disabled by setting
+  ``ignore_missing_extensions = True`` in ``bazaar.conf``.
+  See also <https://answers.launchpad.net/bzr/+faq/703>.
+  (Martin Pool, #406113, #430529)
+
+* Secondary errors that occur during Branch.unlock and Repository.unlock
+  no longer obscure the original error.  These methods now use a new
+  decorator, ``only_raises``.  This fixes many causes of
+  ``TooManyConcurrentRequests`` and similar errors.
+  (Andrew Bennetts, #429747)
+
+Documentation
+*************
+
+* Describe the new shell-like test feature. (Vincent Ladeuil)
+
+* Help on hooks no longer says 'Not deprecated' for hooks that are
+  currently supported. (Ian Clatworthy, #422415)
+
+API Changes
+***********
+
+* ``bzrlib.user_encoding`` has been removed; use
+  ``bzrlib.osutils.get_user_encoding`` instead.  (Martin Pool)
+
+* ``bzrlib.tests`` now uses ``stopTestRun`` for its ``TestResult``
+  subclasses - the same as python's unittest module. (Robert Collins)
+  
+* ``diff._get_trees_to_diff`` has been renamed to 
+  ``diff.get_trees_and_branches_to_diff``. It is now a public API, and it 
+  returns the old and new branches. (Gary van der Merwe)
+
+* ``bzrlib.trace.log_error``, ``error`` and ``info`` have been deprecated.
+  (Martin Pool)
+
+* ``MutableTree.has_changes()`` does not require a tree parameter anymore. It
+  now defaults to comparing to the basis tree. It now checks for pending
+  merges too.  ``Merger.check_basis`` has been deprecated and replaced by the
+  corresponding has_changes() calls. ``Merge.compare_basis``,
+  ``Merger.file_revisions`` and ``Merger.ensure_revision_trees`` have also
+  been deprecated.
+  (Vincent Ladeuil, #440631)
+
+* ``ProgressTask.note`` is deprecated.
+  (Martin Pool)
+
+Internals
+*********
+
+* Added ``-Drelock`` debug flag.  It will ``note`` a message every time a
+  repository or branch object is unlocked then relocked the same way.
+  (Andrew Bennetts)
+  
+* ``BTreeLeafParser.extract_key`` has been tweaked slightly to reduce
+  mallocs while parsing the index (approx 3=>1 mallocs per key read).
+  This results in a 10% speedup while reading an index.
+  (John Arbash Meinel)
+
+* The ``bzrlib.lsprof`` module has a new class ``BzrProfiler`` which makes
+  profiling in some situations like callbacks and generators easier.
+  (Robert Collins)
+
+Testing
+*******
+
+* Passing ``--lsprof-tests -v`` to bzr selftest will cause lsprof output to
+  be output for every test. Note that this is very verbose! (Robert Collins)
+
+* Setting ``BZR_TEST_PDB=1`` when running selftest will cause a pdb
+  post_mortem to be triggered when a test failure occurs. (Robert Collins)
+
+* Shell-like tests can now be written. Code in ``bzrlib/tests/script.py`` ,
+  documentation in ``developers/testing.txt`` for details.
+  (Vincent Ladeuil)
+
+* Some tests could end up with the same id, that was dormant for
+  a long time.
+  (Vincent Ladeuil, #442980)
+
+* Stop showing the number of tests due to missing features in the test
+  progress bar.  (Martin Pool)
+
+* Test parameterisation now does a shallow copy, not a deep copy of the test
+  to be parameterised. This is not expected to break external use of test
+  parameterisation, and is substantially faster. (Robert Collins)
+
+* Tests that try to open a bzr dir on an arbitrary transport will now
+  fail unless they have explicitly permitted the transport via
+  ``self.permit_url``. The standard test factories such as ``self.get_url``
+  will permit the urls they provide automatically, so only exceptional
+  tests should need to do this. (Robert Collins)
+
+* The break-in test no longer cares about clean shutdown of the child,
+  instead it is happy if the debugger starts up. (Robert  Collins)
+
+* The full test suite is expected to pass when the C extensions are not
+  present. (Vincent Ladeuil, #430749)
+
+
+bzr 2.0.1
+#########
+
+:Codename: Stability First
+:2.0.1: 2009-10-14
+
+The first of our new ongoing bugfix-only stable releases has arrived. It
+includes a collection of 12 bugfixes applied to bzr 2.0.0, but does not
+include any of the feature development in the 2.1.0 series.
+
+
+Bug Fixes
+*********
+
+* ``bzr add`` in a tree that has files with ``\r`` or ``\n`` in the
+  filename will issue a warning and skip over those files.
+  (Robert Collins, #3918)
+
+* bzr will attempt to authenticate with SSH servers that support
+  ``keyboard-interactive`` auth but not ``password`` auth when using
+  Paramiko.   (Andrew Bennetts, #433846)
+
+* Fixed fetches from a stacked branch on a smart server that were failing
+  with some combinations of remote and local formats.  This was causing
+  "unknown object type identifier 60" errors.  (Andrew Bennetts, #427736)
+
+* Fixed ``ObjectNotLocked`` errors when doing some log and diff operations
+  on branches via a smart server.  (Andrew Bennetts, #389413)
+
+* Handle things like ``bzr add foo`` and ``bzr rm foo`` when the tree is
+  at the root of a drive. ``osutils._cicp_canonical_relpath`` always
+  assumed that ``abspath()`` returned a path that did not have a trailing
+  ``/``, but that is not true when working at the root of the filesystem.
+  (John Arbash Meinel, Jason Spashett, #322807)
+
+* Hide deprecation warnings for 'final' releases for python2.6.
+  (John Arbash Meinel, #440062)
+
+* Improve the time for ``bzr log DIR`` for 2a format repositories.
+  We had been using the same code path as for <2a formats, which required
+  iterating over all objects in all revisions.
+  (John Arbash Meinel, #374730)
+
+* Make sure that we unlock the tree if we fail to create a TreeTransform
+  object when doing a merge, and there is limbo, or pending-deletions
+  directory.  (Gary van der Merwe, #427773)
+
+* Occasional IndexError on renamed files have been fixed. Operations that
+  set a full inventory in the working tree will now go via the
+  apply_inventory_delta code path which is simpler and easier to
+  understand than dirstates set_state_from_inventory method. This may
+  have a small performance impact on operations built on _write_inventory,
+  but such operations are already doing full tree scans, so no radical
+  performance change should be observed. (Robert Collins, #403322)
+
+* Retrieving file text or mtime from a _PreviewTree has good performance when
+  there are many changes.  (Aaron Bentley)
+
+* The CHK index pages now use an unlimited cache size. With a limited
+  cache and a large project, the random access of chk pages could cause us
+  to download the entire cix file many times.
+  (John Arbash Meinel, #402623)
+
+* When a file kind becomes unversionable after being added, a sensible
+  error will be shown instead of a traceback. (Robert Collins, #438569)
+
+Documentation
+*************
+
+* Improved README. (Ian Clatworthy)
+
+* Improved upgrade documentation for Launchpad branches.
+  (Barry Warsaw)
+
+
+bzr 2.0.0
+#########
+
+:2.0.0: 2009-09-22
+:Codename: Instant Karma
+
+This release of Bazaar makes the 2a (previously 'brisbane-core') format
+the default when new branches or repositories are created.  This format is
+substantially smaller and faster for many operations.  Most of the work in
+this release focuses on bug fixes and stabilization, covering both 2a and
+previous formats.  (See the Upgrade Guide for information on migrating
+existing projects.)
+
+This release also improves the documentation content and presentation,
+including adding Windows HtmlHelp manuals.
+
+The Bazaar team decided that 2.0 will be a long-term supported release,
+with bugfix-only 2.0.x releases based on it, continuing for at least six
+months or until the following stable release.
+
+Changes from 2.0.0rc2 to final
+******************************
+
+* Officially branded as 2.0.0 rather than 2.0 to clarify between things
+  that "want to happen on the 2.0.x stable series" versus things that want
+  to "land in 2.0.0". (Changes how bzrlib._format_version_tuple() handles
+  micro = 0.) (John Arbash Meinel)
+
+
+bzr 2.0.0rc2
+############
+
+:2.0.0rc2: 2009-09-10
+
+New Features
+************
+
+* Added post_commit hook for mutable trees. This allows the keywords
+  plugin to expand keywords on files changed by the commit.
+  (Ian Clatworthy, #408841)
+
+Bug Fixes
+*********
+
+* Bazaar's native protocol code now correctly handles EINTR, which most
+  noticeably occurs if you break in to the debugger while connected to a
+  bzr+ssh server.  You can now can continue from the debugger (by typing
+  'c') and the process continues.  However, note that pressing C-\ in the
+  shell may still kill the SSH process, which is bug 162509, so you must
+  sent a signal to the bzr process specifically, for example by typing
+  ``kill -QUIT PID`` in another shell.  (Martin Pool, #341535)
 
 * ``bzr check`` in pack-0.92, 1.6 and 1.9 format repositories will no
   longer report incorrect errors about ``Missing inventory ('TREE_ROOT', ...)``
   (Robert Collins, #416732)
 
+* ``bzr info -v`` on a 2a format still claimed that it was a "Development
+  format" (John Arbash Meinel, #424392)
+
 * ``bzr log stacked-branch`` shows the full log including
   revisions that are in the fallback repository. (Regressed in 2.0rc1).
   (John Arbash Meinel, #419241)
 
-* Fix a segmentation fault when computing the ``merge_sort`` of a graph
-  that has a ghost in the mainline ancestry.
+* Clearer message when Bazaar runs out of memory, instead of a ``MemoryError``
+  traceback.  (Martin Pool, #109115)
+
+* Conversion to 2a will create a single pack for all the new revisions (as
+  long as it ran without interruption). This improves both ``bzr upgrade``
+  and ``bzr pull`` or ``bzr merge`` from local branches in older formats.
+  The autopack logic that occurs every 100 revisions during local
+  conversions was not returning that pack's identifier, which resulted in
+  the partial packs created during the conversion not being consolidated
+  at the end of the conversion process. (Robert Collins, #423818)
+
+* Fetches from 2a to 2a are now again requested in 'groupcompress' order.
+  Groups that are seen as 'underutilized' will be repacked on-the-fly.
+  This means that when the source is fully packed, there is minimal
+  overhead during the fetch, but if the source is poorly packed the result
+  is a fairly well packed repository (not as good as 'bzr pack' but
+  good-enough.) (Robert Collins, John Arbash Meinel, #402652)
+
+* Fix a potential segmentation fault when doing 'log' of a branch that had
+  ghosts in its mainline.  (Evaluating None as a tuple is bad.)
   (John Arbash Meinel, #419241)
 
+* ``groupcompress`` sort order is now more stable, rather than relying on
+  ``topo_sort`` ordering. The implementation is now
+  ``KnownGraph.gc_sort``. (John Arbash Meinel)
+
+* Local data conversion will generate correct deltas. This is a critical
+  bugfix vs 2.0rc1, and all 2.0rc1 users should upgrade to 2.0rc2 before
+  converting repositories. (Robert Collins, #422849)
+
+* Network streams now decode adjacent records of the same type into a
+  single stream, reducing layering churn. (Robert Collins)
+
+* Prevent some kinds of incomplete data from being committed to a 2a
+  repository, such as revisions without inventories, a missing chk_bytes
+  record for an inventory, or a missing text referenced by an inventory.
+  (Andrew Bennetts, #423506, #406687)
+  
 Documentation
 *************
 
+* Fix assertion error about "_remember_remote_is_before" when pushing to
+  older smart servers.
+  (Andrew Bennetts, #418931)
+
+* Help on hooks no longer says 'Not deprecated' for hooks that are
+  currently supported. (Ian Clatworthy, #422415)
+
+* PDF and CHM (Windows HtmlHelp) formats are now supported for the
+  user documentation. The HTML documentation is better broken up into
+  topics. (Ian Clatworthy)
+
+* The developer and foreign language documents are now separated
+  out so that searching in the HTML and CHM files produces more
+  useful results. (Ian Clatworthy)
+
 * The main table of contents now provides links to the new Migration Docs
   and Plugins Guide. (Ian Clatworthy)
 
 
-bzr 2.0rc1
-##########
-
+bzr 2.0.0rc1
+############
 
 :Codename: no worries
-:2.0rc1: 2009-08-26
-
-This release of Bazaar makes 2a 'brisbane-core' format the
-default.  Most of the work in this release now focuses on bug
-fixes and stabilization, covering both 2a and previous formats.
-
-The Bazaar team decided that 2.0 will be a long-term supported
-release, with bugfix-only releases based on it continuing for at
-least six months or until the following stable release (we said
-that previously, but that's worth repeating).
+:2.0.0rc1: 2009-08-26
 
 Compatibility Breaks
 ********************
@@ -53,7 +836,7 @@
 * The default format for bzr is now ``2a``. This format brings many
   significant performance and size improvements. bzr can pull from
   any existing repository into a ``2a`` one, but can only transfer
-  into ``rich-root`` repositories from ``2a``. The Upgrade guide
+  from ``2a`` into ``rich-root`` repositories. The Upgrade guide
   has more information about this change. (Robert Collins)
 
 * On Windows auto-detection of Putty's plink.exe is disabled.
@@ -70,6 +853,9 @@
 Bug Fixes
 *********
 
+* Further tweaks to handling of ``bzr add`` messages about ignored files.
+  (Jason Spashett, #76616)
+
 * Fetches were being requested in 'groupcompress' order, but weren't
   recombining the groups. Thus they would 'fragment' to get the correct
   order, but not 'recombine' to actually benefit from it. Until we get
@@ -115,7 +901,7 @@
 * ``bzr shelve`` and ``bzr unshelve`` now work on windows.
   (Robert Collins, #305006)
 
-* Commit of specific files no longer prevents using the the iter_changes
+* Commit of specific files no longer prevents using the iter_changes
   codepath. On 2a repositories, commit of specific files should now be as
   fast, or slightly faster, than a full commit. (Robert Collins)
 
@@ -139,14 +925,20 @@
   classes changed to manage lock lifetime of the trees they open in a way
   consistent with reader-exclusive locks. (Robert Collins, #305006)
 
-Internals
-*********
-
 Testing
 *******
 
-bzr 1.18.1 NOT RELEASED YET
-###########################
+bzr 1.18.1
+##########
+
+:Codename:     nein nein nein!
+:1.18.1:       2009-09-09
+
+This release fixes two small but worthwhile bugs relevant to users on
+Microsoft Windows: some commands that failed on with locking errors will
+now work, and a bug that caused poor performance after committing a file
+with line-ending conversion has now been fixed.  It also fixes a bug in
+pushing to older servers.
 
 Bug Fixes
 *********
@@ -155,13 +947,33 @@
   conversion will commit too many copies a file.
   (Martin Pool, #415508)
 
+* Fix assertion error about ``_remember_remote_is_before`` in
+  ``set_tags_bytes`` when pushing to older smart servers.  
+  (Andrew Bennetts, Alexander Belchenko, #418931)
+
+Improvements
+************
+
+* ``bzr push`` locally on Windows will no longer give a locking error with
+  dirstate based formats. (Robert Collins)
+
+* ``bzr shelve`` and ``bzr unshelve`` now work on Windows.
+  (Robert Collins, #305006)
+
 API Changes
 ***********
 
+* ``bzrlib.shelf_ui`` has had the ``from_args`` convenience methods of its
+  classes changed to manage lock lifetime of the trees they open in a way
+  consistent with reader-exclusive locks. (Robert Collins, #305006)
+
 * ``Tree.path_content_summary`` may return a size of None, when called on
   a tree with content filtering where the size of the canonical form
   cannot be cheaply determined.  (Martin Pool)
 
+* When manually creating transport servers in test cases, a new helper
+  ``TestCase.start_server`` that registers a cleanup and starts the server
+  should be used. (Robert Collins)
 
 bzr 1.18
 ########
@@ -499,8 +1311,19 @@
   ``countTestsCases``. (Robert Collins)
 
 
-bzr 1.17 "So late it's brunch" 2009-07-20
-#########################################
+bzr 1.17.1 (unreleased)
+#######################
+
+Bug Fixes
+*********
+
+* The optional ``_knit_load_data_pyx`` C extension was never being
+  imported.  This caused significant slowdowns when reading data from
+  knit format repositories.  (Andrew Bennetts, #405653)
+  
+
+bzr 1.17
+########
 :Codename: so-late-its-brunch
 :1.17rc1: 2009-07-13
 :1.17: 2009-07-20
@@ -749,8 +1572,10 @@
   this class and the UI.  (Martin Pool)
 
 
-bzr 1.16.1 2009-06-26
-#####################
+bzr 1.16.1
+##########
+
+:Released: 2009-06-26
 
 End user testing of the 2a format revealed two serious bugs. The first,
 #365615, caused bzr to raise AbsentContentFactory errors when autopacking.
@@ -805,8 +1630,8 @@
   (Robert Collins, #376748)
 
 
-bzr 1.16 "It's yesterday in California" 2009-06-18
-##################################################
+bzr 1.16
+########
 :Codename: yesterday-in-california
 :1.16rc1: 2009-06-11
 :1.16: 2009-06-18
@@ -845,7 +1670,7 @@
 ************
 
 * A new repository format ``2a`` has been added.  This is a beta release
-  of the the brisbane-core (aka group-compress) project.  This format now
+  of the brisbane-core (aka group-compress) project.  This format now
   suitable for wider testing by advanced users willing to deal with some
   bugs.  We would appreciate test reports, either positive or negative.
   Format 2a is substantially smaller and faster for many operations on
@@ -997,6 +1822,9 @@
 Testing
 *******
 
+* ``make check`` no longer repeats the test run in ``LANG=C``.
+  (Martin Pool, #386180)
+
 * The number of cores is now correctly detected on OSX. (John Szakmeister)
 
 * The number of cores is also detected on Solaris and win32. (Vincent Ladeuil)
@@ -1571,7 +2399,7 @@
 
 * Added ``bzrlib.inventory_delta`` module.  This will be used for
   serializing and deserializing inventory deltas for more efficient
-  streaming on the the network.  (Robert Collins, Andrew Bennetts)
+  streaming on the network.  (Robert Collins, Andrew Bennetts)
 
 * ``Branch._get_config`` has been added, which splits out access to the
   specific config file from the branch. This is used to let RemoteBranch
@@ -2280,8 +3108,11 @@
   (Vincent Ladeuil)
 
 
-bzr 1.11 "Eyes up!" 2009-01-19
-##############################
+bzr 1.11
+########
+
+:Codename: "Eyes up!"
+:Released: 2009-01-19
 
 This first monthly release of Bazaar for 2009 improves Bazaar's operation
 in Windows, Mac OS X, and other situations where file names are matched
@@ -2307,8 +3138,11 @@
 
 
 
-bzr 1.11rc1 "Eyes up!" 2009-01-09
-#################################
+bzr 1.11rc1
+###########
+
+:Codename: "Eyes up!"
+:Released: 2009-01-09
 
 Changes
 *******
@@ -2544,8 +3378,10 @@
 
 
 
-bzr 1.10 2008-12-05
-###################
+bzr 1.10
+########
+
+:Released: 2008-12-05
 
 Bazaar 1.10 has several performance improvements for copying revisions
 (especially for small updates to large projects).  There has also been a
@@ -2570,8 +3406,10 @@
   topologically. (John Arbash Meinel, #304841)
 
 
-bzr 1.10rc1 2008-11-28
-######################
+bzr 1.10rc1
+###########
+
+:Released: 2008-11-28
 
 This release of Bazaar focuses on performance improvements when pushing
 and pulling revisions, both locally and to remote networks.  The popular
@@ -2691,8 +3529,10 @@
 * Doctests now only report the first failure.  (Martin Pool)
 
 
-bzr 1.9 2008-11-07
-##################
+bzr 1.9
+#######
+
+:Released: 2008-11-07
 
 This release of Bazaar adds a new repository format, ``1.9``, with smaller
 and more efficient index files.  This format can be specified when
@@ -2714,8 +3554,10 @@
   (John Arbash Meinel, #293746)
 
 
-bzr 1.9rc1 2008-10-31
-#####################
+bzr 1.9rc1
+##########
+
+:Released: 2008-10-31
 
 New Features
 ************
@@ -2832,8 +3674,10 @@
   configuration of authetication credentials.
 
 
-bzr 1.8 2008-10-16
-##################
+bzr 1.8
+#######
+
+:Released: 2008-10-16
 
 Bazaar 1.8 includes several fixes that improve working tree performance,
 display of revision logs, and merges.  The bzr testsuite now passes on OS
@@ -2854,8 +3698,10 @@
   that platform.  (Alexander Belchenko, Martin Pool, #277481)
 
 
-bzr 1.8rc1 2008-10-07
-#####################
+bzr 1.8rc1
+##########
+
+:Released: 2008-10-07
 
 Changes
 *******
@@ -3053,14 +3899,18 @@
   (Vincent Ladeuil)
 
 
-bzr 1.7.1 2008-10-01
-####################
+bzr 1.7.1
+#########
+
+:Released:  2008-10-01
 
 No changes from 1.7.1rc1.
 
 
-bzr 1.7.1rc1 2008-09-24
-#######################
+bzr 1.7.1rc1
+############
+
+:Released: 2008-09-24
 
 This release just includes an update to how the merge algorithm handles
 file paths when we encounter complex history.
@@ -3075,8 +3925,10 @@
   (John Arbash Meinel)
 
 
-bzr 1.7 2008-09-23
-##################
+bzr 1.7
+#######
+
+:Released: 2008-09-23
 
 This release includes many bug fixes and a few performance and feature
 improvements.  ``bzr rm`` will now scan for missing files and remove them,
@@ -3093,8 +3945,10 @@
   packaging qbzr. (Mark Hammond)
 
 
-bzr 1.7rc2 2008-09-17
-#####################
+bzr 1.7rc2
+##########
+
+:Released: 2008-09-17
 
 A few bug fixes from 1.7rc1. The biggest change is a new
 ``RemoteBranch.get_stacked_on_url`` rpc. This allows clients that are
@@ -3118,8 +3972,10 @@
   (Andrew Bennetts)
 
 
-bzr 1.7rc1 2008-09-09
-#####################
+bzr 1.7rc1
+##########
+
+:Released: 2008-09-09
 
 This release candidate for bzr 1.7 has several bug fixes and a few
 performance and feature improvements.  ``bzr rm`` will now scan for
@@ -3316,16 +4172,20 @@
   clients now use this mechanism.  (Neil Martinsen-Burrell)
 
 
-bzr 1.6.1 2008-09-05
-####################
+bzr 1.6.1
+#########
+
+:Released: 2008-09-05
 
 A couple regressions were found in the 1.6 release. There was a
 performance issue when using ``bzr+ssh`` to branch large repositories,
 and some problems with stacking and ``rich-root`` capable repositories.
 
 
-bzr 1.6.1rc2 2008-09-03
-#######################
+bzr 1.6.1rc2
+############
+
+:Released: 2008-09-03
 
 Bug Fixes
 *********
@@ -3336,8 +4196,10 @@
   (John Arbash Meinel, #264321)
 
 
-bzr 1.6.1rc1 2008-08-29
-#######################
+bzr 1.6.1rc1
+############
+
+:Released: 2008-08-29
 
 This release fixes a few regressions found in the 1.6 client. Fetching
 changes was using an O(N^2) buffering algorithm, so for large projects it
@@ -3377,8 +4239,10 @@
   (John Arbash Meinel, #262333)
 
 
-bzr 1.6 2008-08-25
-##################
+bzr 1.6
+#######
+
+:Released: 2008-08-25
 
 Finally, the long awaited bzr 1.6 has been released. This release includes
 new features like Stacked Branches, improved weave merge, and an updated
@@ -3391,8 +4255,10 @@
 TortoiseBzr in the standalone Windows installer.
 
 
-bzr 1.6rc5 2008-08-19
-#####################
+bzr 1.6rc5
+##########
+
+:Released: 2008-08-19
 
 Bug Fixes
 *********
@@ -3404,8 +4270,10 @@
   (This change was reverted when merged to bzr.dev)
 
 
-bzr 1.6rc4 2008-08-18
-#####################
+bzr 1.6rc4
+##########
+
+:Released: 2008-08-18
 
 Bug Fixes
 *********
@@ -3415,8 +4283,10 @@
   rather than preserving deltas.  (John Arbash Meinel, #256757)
 
 
-bzr 1.6rc3 2008-08-14
-#####################
+bzr 1.6rc3
+##########
+
+:Released: 2008-08-14
 
 Changes
 *******
@@ -3449,8 +4319,10 @@
   development which is substantially faster. (Robert Collins)
 
 
-bzr 1.6rc2 2008-08-13
-#####################
+bzr 1.6rc2
+##########
+
+:Released: 2008-08-13
 
 This release candidate has a few minor bug fixes, and some regression
 fixes for Windows.
@@ -3488,8 +4360,10 @@
   will get the same results.  (John Arbash Meinel, #232188)
 
 
-bzr 1.6rc1 2008-08-06
-#####################
+bzr 1.6rc1
+##########
+
+:Released: 2008-08-06
 
 This release candidate for bzr 1.6 solidifies the new branch stacking
 feature.  Bazaar now recommends that users upgrade all knit repositories,
@@ -3625,8 +4499,10 @@
   (Ian Clatworthy)
 
 
-bzr 1.6beta3 2008-07-17
-#######################
+bzr 1.6beta3
+############
+
+:Released: 2008-07-17
 
 This release adds a new 'stacked branches' feature allowing branches to
 share storage without being in the same repository or on the same machine.
@@ -3798,8 +4674,10 @@
   (Robert Collins)
 
 
-bzr 1.6beta2 2008-06-10
-#######################
+bzr 1.6beta2
+############
+
+:Released: 2008-06-10
 
 This release contains further progress towards our 1.6 goals of shallow
 repositories, and contains a fix for some user-affecting bugs in the
@@ -3882,9 +4760,10 @@
 * Knit record serialisation is now stricter on what it will accept, to
   guard against potential internal bugs, or broken input. (Robert Collins)
 
-bzr 1.6beta1 2008-06-02
-#######################
+bzr 1.6beta1
+############
 
+:Released: 2008-06-02
 
 Commands that work on the revision history such as push, pull, missing,
 uncommit and log are now substantially faster.  This release adds a
@@ -4102,8 +4981,10 @@
   (Martin Pool)
 
 
-bzr 1.5 2008-05-16
-##################
+bzr 1.5
+#######
+
+:Released: 2008-05-16
 
 This release of Bazaar includes several updates to the documentation, and fixes
 to prepare for making rich root support the default format. Many bugs have been
@@ -4124,8 +5005,10 @@
   (Ian Clatworthy)
 
 
-bzr 1.5rc1 2008-05-09
-#####################
+bzr 1.5rc1
+##########
+
+:Released: 2008-05-09
 
 Changes
 *******
@@ -4240,7 +5123,7 @@
   exception. (Andrew Bennetts)
 
 * New ``--debugflag``/``-E`` option to ``bzr selftest`` for setting
-  options for debugging tests, these are complementary to the the -D
+  options for debugging tests, these are complementary to the -D
   options.  The ``-Dselftest_debug`` global option has been replaced by the
   ``-E=allow_debug`` option for selftest. (Andrew Bennetts)
 
@@ -4295,8 +5178,10 @@
   (Martin Pool)
 
 
-bzr 1.4 2008-04-28
-##################
+bzr 1.4 
+#######
+
+:Released: 2008-04-28
 
 This release of Bazaar includes handy improvements to the speed of log and
 status, new options for several commands, improved documentation, and better
@@ -4315,8 +5200,10 @@
   (John Arbash Meinel, Andrew Bennetts, #214894)
 
 
-bzr 1.4rc2 2008-04-21
-#####################
+bzr 1.4rc2
+##########
+
+:Released: 2008-04-21
 
 Bug Fixes
 *********
@@ -4339,8 +5226,10 @@
   (Robert Collins, John Arbash Meinel)
 
 
-bzr 1.4rc1 2008-04-11
-#####################
+bzr 1.4rc1
+##########
+
+:Released: 2008-04-11
 
 Changes
 *******
@@ -4627,14 +5516,18 @@
   ``Graph.get_parent_map`` returns a dict of key:parents. (Robert Collins)
 
 
-bzr 1.3.1 2008-04-09
-####################
+bzr 1.3.1
+#########
+
+:Released: 2008-04-09
 
 No changes from 1.3.1rc1.
 
 
-bzr 1.3.1rc1 2008-04-04
-#######################
+bzr 1.3.1rc1
+############
+
+:Released: 2008-04-04
 
 Bug Fixes
 *********
@@ -4645,8 +5538,10 @@
   (#208418, Andrew Bennetts, Martin Pool, Robert Collins)
 
 
-bzr 1.3 2008-03-20
-##################
+bzr 1.3
+#######
+
+:Released: 2008-03-20
 
 Bazaar has become part of the GNU project <http://www.gnu.org>
 
@@ -4662,8 +5557,10 @@
   (#202778, Martin Pool)
 
 
-bzr 1.3rc1 2008-03-16
-#####################
+bzr 1.3rc1
+##########
+
+:Released: 2008-03-16
 
 Notes When Upgrading
 ********************
@@ -4849,8 +5746,10 @@
   format. (Robert Collins)
 
 
-bzr 1.2 2008-02-15
-##################
+bzr 1.2
+#######
+
+:Released: 2008-02-15
 
 Bug Fixes
 *********
@@ -4858,8 +5757,10 @@
 * Fix failing test in Launchpad plugin. (Martin Pool)
 
 
-bzr 1.2rc1 2008-02-13
-#####################
+bzr 1.2rc1
+##########
+
+:Released: 2008-02-13
 
 Notes When Upgrading
 ********************
@@ -4977,7 +5878,7 @@
   checkouts.  (Aaron Bentley, #182040)
 
 * Stop polluting /tmp when running selftest.
-  (Vincent Ladeuil, #123623)
+  (Vincent Ladeuil, #123363)
 
 * Switch from NFKC => NFC for normalization checks. NFC allows a few
   more characters which should be considered valid.
@@ -5060,13 +5961,17 @@
   revision names etc. (Robert Collins)
 
 
-bzr 1.1 2008-01-15
-##################
+bzr 1.1
+#######
+
+:Released: 2008-01-15
 
 (no changes from 1.1rc1)
 
-bzr 1.1rc1 2008-01-05
-#####################
+bzr 1.1rc1
+##########
+
+:Released: 2008-01-05
 
 Changes
 *******
@@ -5276,8 +6181,10 @@
   replaced by the new helper methods added in this release. (Robert Collins)
 
 
-bzr 1.0 2007-12-14
-##################
+bzr 1.0
+#######
+
+:Released: 2007-12-14
 
 Documentation
 *************
@@ -5294,8 +6201,10 @@
   (Ian Clatworthy)
 
 
-bzr 1.0rc3 2007-12-11
-#####################
+bzr 1.0rc3
+##########
+
+:Released: 2007-12-11
 
 Changes
 *******
@@ -5336,8 +6245,10 @@
   (Vincent Ladeuil)
 
 
-bzr 1.0rc2 2007-12-07
-#####################
+bzr 1.0rc2
+##########
+
+:Released: 2007-12-07
 
 Improvements
 ************
@@ -5411,8 +6322,10 @@
   ``started`` methods. (Matt Nordhoff)
 
 
-bzr 1.0rc1 2007-11-30
-#####################
+bzr 1.0rc1
+##########
+
+:Released: 2007-11-30
 
 Notes When Upgrading
 ********************
@@ -5688,8 +6601,10 @@
 * InventoryEntry.diff is now deprecated.  Please use diff.DiffTree instead.
 
 
-bzr 0.92 2007-11-05
-###################
+bzr 0.92
+########
+
+:Released: 2007-11-05
 
 Changes
 *******
@@ -5697,8 +6612,10 @@
   * New uninstaller on Win32.  (Alexander Belchenko)
 
 
-bzr 0.92rc1 2007-10-29
-######################
+bzr 0.92rc1
+###########
+
+:Released: 2007-10-29
 
 Changes
 *******
@@ -6017,8 +6934,10 @@
   raises a Python warning.  (Martin Pool)
 
 
-bzr 0.91 2007-09-26
-###################
+bzr 0.91
+########
+
+:Released: 2007-09-26
 
 Bug Fixes
 *********
@@ -6039,15 +6958,19 @@
   (Andrew Bennetts)
 
 
-bzr 0.91rc2 2007-09-11
-######################
+bzr 0.91rc2
+###########
+
+:Released: 2007-09-11
 
 * Replaced incorrect tarball for previous release; a debug statement was left
   in bzrlib/remote.py.
 
 
-bzr 0.91rc1 2007-09-11
-######################
+bzr 0.91rc1
+###########
+
+:Released: 2007-09-11
 
 Changes
 *******
@@ -6374,8 +7297,10 @@
   [] to revert all files is deprecated.  (Aaron Bentley)
 
 
-bzr 0.90 2007-08-28
-###################
+bzr 0.90
+########
+
+:Released: 2007-08-28
 
 Improvements
 ************
@@ -6398,8 +7323,10 @@
   and call ``create_repository`` on that.  (Martin Pool)
 
 
-bzr 0.90rc1 2007-08-14
-######################
+bzr 0.90rc1
+###########
+
+:Released: 2007-08-14
 
 Bugfixes
 ********
@@ -6671,8 +7598,10 @@
   parameter.  Varargs-style parameters are deprecated. (Aaron Bentley)
 
 
-bzr 0.18  2007-07-17
-####################
+bzr 0.18
+########
+
+:Released:  2007-07-17
 
 Bugfixes
 ********
@@ -6680,8 +7609,10 @@
 * Fix 'bzr add' crash under Win32 (Kuno Meyer)
 
 
-bzr 0.18rc1  2007-07-10
-#######################
+bzr 0.18rc1
+###########
+
+:Released:  2007-07-10
 
 Bugfixes
 ********
@@ -6932,8 +7863,10 @@
   (Vincent Ladeuil, #110448)
 
 
-bzr 0.17  2007-06-18
-####################
+bzr 0.17
+########
+
+:Released:  2007-06-18
 
 Bugfixes
 ********
@@ -6945,8 +7878,10 @@
   (Aaron Bentley, Ian Clatworthy, #120930)
 
 
-bzr 0.17rc1  2007-06-12
-#######################
+bzr 0.17rc1
+###########
+
+:Released:  2007-06-12
 
 Notes When Upgrading
 ********************
@@ -7047,8 +7982,10 @@
   your repository. (Previously Branch6 only supported revisions in your
   mainline). (John Arbash Meinel, #115343)
 
-bzr 0.16  2007-05-07
-####################
+bzr 0.16
+########
+
+:Released:  2007-05-07
 
 Bugfixes
 ********
@@ -7078,8 +8015,10 @@
   diff`` and ``bzr status`` significantly improving the speed of
   both. (John Arbash Meinel)
 
-bzr 0.16rc2  2007-04-30
-#######################
+bzr 0.16rc2
+###########
+
+:Released:  2007-04-30
 
 Bugfixes
 ********
@@ -7102,8 +8041,10 @@
 * ``WorkingTree4._iter_changes`` should not descend into unversioned
   directories. (John Arbash Meinel, #110399)
 
-bzr 0.16rc1  2007-04-26
-#######################
+bzr 0.16rc1
+###########
+
+:Released:  2007-04-26
 
 Notes When Upgrading
 ********************
@@ -7410,8 +8351,10 @@
   implementation of new auth schemes for both http and proxy.
   (Vincent Ladeuil)
 
-bzr 0.15 2007-04-01
-###################
+bzr 0.15
+########
+
+:Released: 2007-04-01
 
 Bugfixes
 ********
@@ -7423,8 +8366,10 @@
   checking out a branch that contains an old-format working tree.
   (Martin Pool)
 
-bzr 0.15rc3  2007-03-26
-#######################
+bzr 0.15rc3
+###########
+
+:Released:  2007-03-26
 
 Changes
 *******
@@ -7499,8 +8444,10 @@
 * Correctly handles mutiple permanent http redirections.
   (vila, #88780)
 
-bzr 0.15rc2  2007-03-14
-#######################
+bzr 0.15rc2
+###########
+
+:Released:  2007-03-14
 
 Notes When Upgrading
 ********************
@@ -7553,8 +8500,10 @@
   (Wouter van Heyst, #53483)
 
 
-bzr 0.15rc1  2007-03-07
-#######################
+bzr 0.15rc1
+###########
+
+:Released:  2007-03-07
 
 Surprises
 *********
@@ -7784,8 +8733,10 @@
   before the rest of the suite.  (Martin Pool)
 
 
-bzr 0.14  2007-01-23
-####################
+bzr 0.14
+########
+
+:Released:  2007-01-23
 
 Improvements
 ************
@@ -7804,8 +8755,10 @@
   it is in is below a repository. (James Westby, #77306)
 
 
-bzr 0.14rc1  2007-01-16
-#######################
+bzr 0.14rc1
+###########
+
+:Released:  2007-01-16
 
 Improvements
 ************
@@ -7939,14 +8892,18 @@
   (Alexander Belchenko, #68124)
 
 
-bzr 0.13  2006-12-05
-####################
+bzr 0.13
+########
+
+:Released:  2006-12-05
 
 No changes from 0.13rc
 
 
-bzr 0.13rc1  2006-11-27
-#######################
+bzr 0.13rc1
+###########
+
+:Released:  2006-11-27
 
 Improvements
 ************
@@ -8071,8 +9028,10 @@
 * TestingHTTPRequestHandler really handles the Range header
   (previously it was ignoring it and returning the whole file,).
 
-bzr 0.12  2006-10-30
-####################
+bzr 0.12
+########
+
+:Released:  2006-10-30
 
 Internals
 *********
@@ -8081,8 +9040,10 @@
   and remove benchmarks that take longer than 10min to run.
   (John Arbash Meinel)
 
-bzr 0.12rc1  2006-10-23
-#######################
+bzr 0.12rc1
+###########
+
+:Released:  2006-10-23
 
 Improvements
 ************
@@ -8203,13 +9164,17 @@
   option to set the BzrDir, Repository and Branch formats of the
   created objects. (Robert Collins, John Arbash Meinel)
 
-bzr 0.11  2006-10-02
-####################
+bzr 0.11
+########
+
+:Released:  2006-10-02
 
 * Smart server transport test failures on windows fixed. (Lukáš Lalinský).
 
-bzr 0.11rc2  2006-09-27
-#######################
+bzr 0.11rc2
+###########
+
+:Released:  2006-09-27
 
 Bug Fixes
 *********
@@ -8219,8 +9184,10 @@
 * Commit performance regression fixed. (Aaron Bentley, Robert Collins, John
   Arbash Meinel).
 
-bzr 0.11rc1  2006-09-25
-#######################
+bzr 0.11rc1
+###########
+
+:Released:  2006-09-25
 
 Improvements
 ************
@@ -8413,8 +9380,10 @@
   allow upgrades to a richer interface than the VFS one provided by
   Transport. (Andrew Bennetts, Martin Pool)
 
-bzr 0.10  2006-08-29
-####################
+bzr 0.10
+########
+
+:Released:  2006-08-29
 
 Improvements
 ************
@@ -8491,8 +9460,10 @@
   need to be installed. This should help make the life of packagers
   easier. (John Arbash Meinel)
 
-bzr 0.9.0  2006-08-11
-#####################
+bzr 0.9.0
+#########
+
+:Released:  2006-08-11
 
 Surprises
 *********
@@ -8759,16 +9730,20 @@
 
 * "RevisionTree" is now in bzrlib/revisiontree.py. (Robert Collins)
 
-bzr 0.8.2  2006-05-17
-#####################
+bzr 0.8.2
+#########
+
+:Released:  2006-05-17
 
 Bug Fixes
 *********
 
 * setup.py failed to install launchpad plugin.  (Martin Pool)
 
-bzr 0.8.1  2006-05-16
-#####################
+bzr 0.8.1
+#########
+
+:Released:  2006-05-16
 
 Bug Fixes
 *********
@@ -8821,8 +9796,10 @@
 * Fix test case for bzr info in upgrading a standalone branch to metadir,
   uses bzrlib api now. (Olaf Conradi)
 
-bzr 0.8  2006-05-08
-###################
+bzr 0.8
+#######
+
+:Released:  2006-05-08
 
 Notes When Upgrading
 ********************
@@ -9083,8 +10060,10 @@
 * ``run_bzr`` and ``run_bzr_captured`` now accept a 'stdin="foo"'
   parameter which will provide String("foo") to the command as its stdin.
 
-bzr 0.7 2006-01-09
-##################
+bzr 0.7
+#######
+
+:Released: 2006-01-09
 
 Changes
 *******
@@ -9379,8 +10358,10 @@
 * ``bzrlib.osutils.safe_unicode`` now exists to provide parameter coercion
   for functions that need unicode strings. (Robert Collins)
 
-bzr 0.6 2005-10-28
-##################
+bzr 0.6
+#######
+
+:Released: 2005-10-28
 
 Improvements
 ************
@@ -9595,8 +10576,10 @@
   [-1] in the revision-history. (Andres Salomon)
 
 
-bzr 0.1.1 2005-10-12
-####################
+bzr 0.1.1
+#########
+
+:Released: 2005-10-12
 
 Bug Fixes
 *********
@@ -9613,8 +10596,10 @@
 * Avoid some unnecessary http operations in branch and pull.
 
 
-bzr 0.1 2005-10-11
-##################
+bzr 0.1
+#######
+
+:Released: 2005-10-11
 
 Notes
 *****
@@ -9743,8 +10728,10 @@
   of tests to run, e.g. ``bzr selftest test_weave``
 
 
-bzr 0.0.9 2005-09-23
-####################
+bzr 0.0.9
+#########
+
+:Released: 2005-09-23
 
 Bug Fixes
 *********
@@ -9785,8 +10772,11 @@
   another (used by pull, merged, etc.)
 
 
-bzr 0.0.8 2005-09-20
-####################
+bzr 0.0.8
+#########
+
+:Released: 2005-09-20
+
 
 Improvements
 ************
@@ -9836,8 +10826,10 @@
 * Quieten warnings about locking; patch from Matt Lavin.
 
 
-bzr-0.0.7 2005-09-02
-####################
+bzr-0.0.7
+#########
+
+:Released: 2005-09-02
 
 New Features
 ************
@@ -9891,8 +10883,10 @@
 
 
 
-bzr-0.0.6 2005-08-18
-####################
+bzr-0.0.6
+#########
+
+:Released: 2005-08-18
 
 New Features
 ************
@@ -9977,8 +10971,10 @@
 * Fix bugs in committing only selected files or within a subdirectory.
 
 
-bzr-0.0.5  2005-06-15
-#####################
+bzr-0.0.5
+#########
+
+:Released:  2005-06-15
 
 Changes
 *******
@@ -10119,8 +11115,10 @@
   2.4 is now only recommended.
 
 
-bzr-0.0.4  2005-04-22
-#####################
+bzr-0.0.4
+#########
+
+:Released:  2005-04-22
 
 Enhancements
 ************
@@ -10188,8 +11186,10 @@
   from QuantumG.
 
 
-bzr-0.0.3  2005-04-06
-#####################
+bzr-0.0.3
+#########
+
+:Released:  2005-04-06
 
 Enhancements
 ************
@@ -10243,8 +11243,11 @@
 * Win32 fixes from Steve Brown.
 
 
-bzr-0.0.2  "black cube"  2005-03-31
-###################################
+bzr-0.0.2
+#########
+
+:Codename: "black cube"
+:Released: 2005-03-31
 
 Enhancements
 ************
@@ -10272,8 +11275,10 @@
   the root directory only.
 
 
-bzr-0.0.1  2005-03-26
-#####################
+bzr-0.0.1
+#########
+
+:Released:  2005-03-26
 
 Enhancements
 ************
@@ -10302,8 +11307,10 @@
   supported).
 
 
-bzr-0.0.0.69  2005-03-22
-########################
+bzr-0.0.0.69
+############
+
+:Released:  2005-03-22
 
 Enhancements
 ************
@@ -10313,5 +11320,38 @@
 * Storage of local versions: init, add, remove, rm, info, log,
   diff, status, etc.
 
+
+bzr ?.?.? (not released yet)
+############################
+
+:Codename: template
+:2.0.2: ???
+
+Compatibility Breaks
+********************
+
+New Features
+************
+
+Bug Fixes
+*********
+
+Improvements
+************
+
+Documentation
+*************
+
+API Changes
+***********
+
+Internals
+*********
+
+Testing
+*******
+
+
+
 ..
    vim: tw=74 ft=rst ff=unix

=== modified file 'README'
--- README	2008-03-16 14:01:20 +0000
+++ README	2009-10-06 07:41:02 +0000
@@ -3,72 +3,44 @@
 =================
 
 Bazaar (``bzr``) is a decentralized revision control system, designed to be
-easy for developers and end users alike.  Bazaar is part of the GNU project to
-develop a complete free operating system.
-
-To install Bazaar from source, follow the instructions in the INSTALL
-file. Otherwise, you may want to check your distribution package manager
-for ready-to-install packages, or http://bazaar-vcs.org/DistroDownloads.
-
-To learn how to use Bazaar, check the documentation in the doc/ directory.
-Once installed, you can also run 'bzr help'. An always up-to-date and more
-complete set of documents can be found in the Bazaar website, at:
-
-    http://bazaar-vcs.org/Documentation
+easy for developers and end users alike.  Bazaar is part of the GNU project
+to develop a complete free operating system.
+
+To install Bazaar, follow the instructions given at
+http://bazaar-vcs.org/Download. Ready-to-install packages are available
+for most popular operating systems or you can install from source.
+
+To learn how to use Bazaar, see the official documentation at:
+
+    http://doc.bazaar-vcs.org/en/
+
+For additional training materials including screencasts and slides,
+visit our community wiki documentation page at:
+
+    http://bazaar-vcs.org/Documentation/
 
 Bazaar is written in Python, and is sponsored by Canonical Limited, the
 founders of Ubuntu and Launchpad. Bazaar is Free Software, and is released
 under the GNU General Public License.
 
-Bazaar was formerly known as Bazaar-NG.  It's the successor to ``baz``, a fork
-of GNU arch, but shares no code.  (To upgrade from Baz, use the ``baz-import``
-command in the bzrtools plugin.)
-
 Bazaar highlights
 =================
 
-* Easy to use and intuitive.
-
-  Only five commands are needed to do all basic operations, and all
-  commands have documentation accessible via 'bzr help command'.
-  Bazaar's interface is also easy to learn for CVS and Subversion users.
-
-* Robust and reliable.
-
-  Bazaar is developed under an extensive test suite. Branches can be
-  checked and verified for integrity at any time, and revisions can be
-  signed with PGP/GnuPG.
-
-* Publish branches with HTTP.
-
-  Branches can be hosted on an HTTP server with no need for special
-  software on the server side. Branches can be uploaded by bzr itself
-  over SSH (SFTP), or with rsync.
-
-* Adapts to multiple environments.
-
-  Bazaar runs on Linux and Windows, fully supports Unicode filenames,
-  and suits different development models, including centralized.
-
-* Easily extended and customized.
-
-  A rich Python interface is provided for extending and embedding,
-  including a plugin interface. There are already many available plugins,
-  most of them registered at http://bazaar-vcs.org/PluginRegistry.
-
-* Smart merging.
-
-  Changes will never be merged more than once, conflicts will be
-  minimized, and identical changes are dealt with well.
-
-* Vibrant and active community.
-
-  Help with Bazaar is obtained easily, via the mailing list, or the IRC
-  channel.
-
-
-Registration and Feedback
-=========================
+Bazaar directly supports both central version control (like cvs/svn) and
+distributed version control (like git/hg). Developers can organize their
+workspace in whichever way they want on a per project basis including:
+
+* checkouts (like svn)
+* feature branches (like hg)
+* shared working tree (like git).
+
+It also directly supports and encourages a large number of development best
+practices like refactoring and pre-commit regression testing. Users can
+choose between our command line tool and our cross-platform GUI application.
+For further details, see our website at http://bazaar-vcs.org/en.
+
+Feedback
+========
 
 If you encounter any problems with Bazaar, need help understanding it, or would
 like to offer suggestions or feedback, please get in touch with us:
@@ -76,7 +48,7 @@
 * Ask a question through our web support interface, at 
   https://answers.launchpad.net/bzr/
 
-* Report bugs at https://bugs.edge.launchpad.net/bzr/+filebug
+* Report bugs at https://bugs.launchpad.net/bzr/+filebug
 
 * Write to us at bazaar@lists.canonical.com 
   You can join the list at <https://lists.ubuntu.com/mailman/listinfo/bazaar>.
@@ -85,12 +57,8 @@
 
 * Talk to us in irc://irc.ubuntu.com/bzr
 
-* And see http://bazaar-vcs.org/BzrSupport for more.
-
-If you would like to help us improve Bazaar by telling us about yourself and
-what we could do better, please register and complete the online survey here:
-http://www.surveymonkey.com/s.aspx?sm=L94RvLswhKdktrxiHWiX3g_3d_3d.  
-Registration is completely optional. 
-
-Enjoy,
+Our mission is to make a version control tool that developers LOVE to use
+and that casual contributors feel confident with. Please let us know how
+we're going.
+
 The Bazaar Team

=== modified file 'bzr'
--- bzr	2009-08-11 03:02:56 +0000
+++ bzr	2009-10-30 16:13:05 +0000
@@ -23,7 +23,7 @@
 import warnings
 
 # update this on each release
-_script_version = (2, 0, 0)
+_script_version = (2, 1, 0)
 
 if __doc__ is None:
     print "bzr does not support python -OO."

=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2009-08-27 07:49:53 +0000
+++ bzrlib/__init__.py	2009-11-16 19:45:47 +0000
@@ -31,16 +31,10 @@
     import bzrlib.lazy_regex
     bzrlib.lazy_regex.install_lazy_compile()
 
-from bzrlib.osutils import get_user_encoding
-
 
 IGNORE_FILENAME = ".bzrignore"
 
 
-# XXX: Deprecated as of bzr-1.17 use osutils.get_user_encoding() directly
-user_encoding = get_user_encoding()
-
-
 __copyright__ = "Copyright 2005, 2006, 2007, 2008, 2009 Canonical Ltd."
 
 # same format as sys.version_info: "A tuple containing the five components of
@@ -50,10 +44,11 @@
 # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
 # releaselevel of 'dev' for unreleased under-development code.
 
-version_info = (2, 0, 0, 'candidate', 1)
+version_info = (2, 1, 0, 'dev', 4)
 
 # API compatibility version: bzrlib is currently API compatible with 1.15.
-api_minimum_version = (1, 17, 0)
+api_minimum_version = (2, 1, 0)
+
 
 def _format_version_tuple(version_info):
     """Turn a version number 2, 3 or 5-tuple into a short string.
@@ -65,23 +60,29 @@
     zero for final releases.
 
     >>> print _format_version_tuple((1, 0, 0, 'final', 0))
-    1.0
+    1.0.0
     >>> print _format_version_tuple((1, 2, 0, 'dev', 0))
-    1.2dev
+    1.2.0dev
+    >>> print bzrlib._format_version_tuple((1, 2, 0, 'dev', 1))
+    1.2.0dev1
     >>> print _format_version_tuple((1, 1, 1, 'candidate', 2))
     1.1.1rc2
     >>> print bzrlib._format_version_tuple((2, 1, 0, 'beta', 1))
-    2.1b1
+    2.1.0b1
     >>> print _format_version_tuple((1, 4, 0))
-    1.4
+    1.4.0
     >>> print _format_version_tuple((1, 4))
     1.4
+    >>> print bzrlib._format_version_tuple((2, 1, 0, 'final', 1))
+    Traceback (most recent call last):
+    ...
+    ValueError: version_info (2, 1, 0, 'final', 1) not valid
     >>> print _format_version_tuple((1, 4, 0, 'wibble', 0))
     Traceback (most recent call last):
     ...
     ValueError: version_info (1, 4, 0, 'wibble', 0) not valid
     """
-    if len(version_info) == 2 or version_info[2] == 0:
+    if len(version_info) == 2:
         main_version = '%d.%d' % version_info[:2]
     else:
         main_version = '%d.%d.%d' % version_info[:3]
@@ -96,6 +97,8 @@
         sub_string = ''
     elif release_type == 'dev' and sub == 0:
         sub_string = 'dev'
+    elif release_type == 'dev':
+        sub_string = 'dev' + str(sub)
     elif release_type in ('alpha', 'beta'):
         sub_string = release_type[0] + str(sub)
     elif release_type == 'candidate':
@@ -103,7 +106,6 @@
     else:
         raise ValueError("version_info %r not valid" % (version_info,))
 
-    version_string = '%d.%d.%d.%s.%d' % tuple(version_info)
     return main_version + sub_string
 
 

=== modified file 'bzrlib/_bencode_pyx.pyx'
--- bzrlib/_bencode_pyx.pyx	2009-06-05 01:48:32 +0000
+++ bzrlib/_bencode_pyx.pyx	2009-10-15 18:28:14 +0000
@@ -58,6 +58,13 @@
     void D_UPDATE_TAIL(Decoder, int n)
     void E_UPDATE_TAIL(Encoder, int n)
 
+# To maintain compatibility with older versions of pyrex, we have to use the
+# relative import here, rather than 'bzrlib._static_tuple_c'
+from _static_tuple_c cimport StaticTuple, StaticTuple_CheckExact, \
+    import_static_tuple_c
+
+import_static_tuple_c()
+
 
 cdef class Decoder:
     """Bencode decoder"""
@@ -371,7 +378,8 @@
                 self._encode_int(x)
             elif PyLong_CheckExact(x):
                 self._encode_long(x)
-            elif PyList_CheckExact(x) or PyTuple_CheckExact(x):
+            elif (PyList_CheckExact(x) or PyTuple_CheckExact(x)
+                  or StaticTuple_CheckExact(x)):
                 self._encode_list(x)
             elif PyDict_CheckExact(x):
                 self._encode_dict(x)

=== modified file 'bzrlib/_btree_serializer_py.py'
--- bzrlib/_btree_serializer_py.py	2009-03-23 14:59:43 +0000
+++ bzrlib/_btree_serializer_py.py	2009-11-07 00:28:26 +0000
@@ -17,27 +17,33 @@
 
 """B+Tree index parsing."""
 
+from bzrlib import static_tuple
+
+
 def _parse_leaf_lines(bytes, key_length, ref_list_length):
     lines = bytes.split('\n')
     nodes = []
+    as_st = static_tuple.StaticTuple.from_sequence
+    stuple = static_tuple.StaticTuple
     for line in lines[1:]:
         if line == '':
             return nodes
         elements = line.split('\0', key_length)
         # keys are tuples
-        key = tuple(elements[:key_length])
+        key = as_st(elements[:key_length]).intern()
         line = elements[-1]
         references, value = line.rsplit('\0', 1)
         if ref_list_length:
             ref_lists = []
             for ref_string in references.split('\t'):
-                ref_lists.append(tuple([
-                    tuple(ref.split('\0')) for ref in ref_string.split('\r') if ref
-                    ]))
-            ref_lists = tuple(ref_lists)
-            node_value = (value, ref_lists)
+                ref_list = as_st([as_st(ref.split('\0')).intern()
+                                  for ref in ref_string.split('\r') if ref])
+                ref_lists.append(ref_list)
+            ref_lists = as_st(ref_lists)
+            node_value = stuple(value, ref_lists)
         else:
-            node_value = (value, ())
+            node_value = stuple(value, stuple())
+        # No need for StaticTuple here as it is put into a dict
         nodes.append((key, node_value))
     return nodes
 

=== modified file 'bzrlib/_btree_serializer_pyx.pyx'
--- bzrlib/_btree_serializer_pyx.pyx	2009-06-22 12:52:39 +0000
+++ bzrlib/_btree_serializer_pyx.pyx	2009-10-12 20:07:09 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Canonical Ltd
+# Copyright (C) 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,11 +38,16 @@
     Py_ssize_t PyString_Size(object p)
     Py_ssize_t PyString_GET_SIZE_ptr "PyString_GET_SIZE" (PyObject *)
     char * PyString_AS_STRING_ptr "PyString_AS_STRING" (PyObject *)
+    char * PyString_AS_STRING(object)
+    Py_ssize_t PyString_GET_SIZE(object)
     int PyString_AsStringAndSize_ptr(PyObject *, char **buf, Py_ssize_t *len)
     void PyString_InternInPlace(PyObject **)
     int PyTuple_CheckExact(object t)
+    object PyTuple_New(Py_ssize_t n_entries)
+    void PyTuple_SET_ITEM(object, Py_ssize_t offset, object) # steals the ref
     Py_ssize_t PyTuple_GET_SIZE(object t)
     PyObject *PyTuple_GET_ITEM_ptr_object "PyTuple_GET_ITEM" (object tpl, int index)
+    void Py_INCREF(object)
     void Py_DECREF_ptr "Py_DECREF" (PyObject *)
 
 cdef extern from "string.h":
@@ -52,6 +57,12 @@
     # void *memrchr(void *s, int c, size_t n)
     int strncmp(char *s1, char *s2, size_t n)
 
+# It seems we need to import the definitions so that the pyrex compiler has
+# local names to access them.
+from _static_tuple_c cimport StaticTuple, \
+    import_static_tuple_c, StaticTuple_New, \
+    StaticTuple_Intern, StaticTuple_SET_ITEM, StaticTuple_CheckExact
+
 
 # TODO: Find some way to import this from _dirstate_helpers
 cdef void* _my_memrchr(void *s, int c, size_t n):
@@ -68,6 +79,7 @@
         pos = pos - 1
     return NULL
 
+
 # TODO: Import this from _dirstate_helpers when it is merged
 cdef object safe_string_from_size(char *s, Py_ssize_t size):
     if size < 0:
@@ -91,6 +103,10 @@
     Py_DECREF_ptr(py_str)
     return result
 
+from bzrlib import _static_tuple_c
+# This sets up the StaticTuple C_API functionality
+import_static_tuple_c()
+
 
 cdef class BTreeLeafParser:
     """Parse the leaf nodes of a BTree index.
@@ -130,6 +146,7 @@
         self._cur_str = NULL
         self._end_str = NULL
         self._header_found = 0
+        # keys are tuples
 
     cdef extract_key(self, char * last):
         """Extract a key.
@@ -139,15 +156,14 @@
         """
         cdef char *temp_ptr
         cdef int loop_counter
-        # keys are tuples
-        loop_counter = 0
-        key_segments = []
-        while loop_counter < self.key_length:
-            loop_counter = loop_counter + 1
+        cdef StaticTuple key
+
+        key = StaticTuple_New(self.key_length)
+        for loop_counter from 0 <= loop_counter < self.key_length:
             # grab a key segment
             temp_ptr = <char*>memchr(self._start, c'\0', last - self._start)
             if temp_ptr == NULL:
-                if loop_counter == self.key_length:
+                if loop_counter + 1 == self.key_length:
                     # capture to last
                     temp_ptr = last
                 else:
@@ -157,15 +173,20 @@
                                                    last - self._start)))
                     raise AssertionError(failure_string)
             # capture the key string
-            # TODO: Consider using PyIntern_FromString, the only caveat is that
-            # it assumes a NULL-terminated string, so we have to check if
-            # temp_ptr[0] == c'\0' or some other char.
-            key_element = safe_interned_string_from_size(self._start,
+            if (self.key_length == 1
+                and (temp_ptr - self._start) == 45
+                and strncmp(self._start, 'sha1:', 5) == 0):
+                key_element = safe_string_from_size(self._start,
+                                                    temp_ptr - self._start)
+            else:
+                key_element = safe_interned_string_from_size(self._start,
                                                          temp_ptr - self._start)
             # advance our pointer
             self._start = temp_ptr + 1
-            PyList_Append(key_segments, key_element)
-        return tuple(key_segments)
+            Py_INCREF(key_element)
+            StaticTuple_SET_ITEM(key, loop_counter, key_element)
+        key = StaticTuple_Intern(key)
+        return key
 
     cdef int process_line(self) except -1:
         """Process a line in the bytes."""
@@ -174,6 +195,7 @@
         cdef char *ref_ptr
         cdef char *next_start
         cdef int loop_counter
+        cdef Py_ssize_t str_len
 
         self._start = self._cur_str
         # Find the next newline
@@ -186,14 +208,13 @@
             # And the next string is right after it
             self._cur_str = last + 1
             # The last character is right before the '\n'
-            last = last
 
         if last == self._start:
             # parsed it all.
             return 0
         if last < self._start:
             # Unexpected error condition - fail
-            return -1
+            raise AssertionError("last < self._start")
         if 0 == self._header_found:
             # The first line in a leaf node is the header "type=leaf\n"
             if strncmp("type=leaf", self._start, last - self._start) == 0:
@@ -202,36 +223,48 @@
             else:
                 raise AssertionError('Node did not start with "type=leaf": %r'
                     % (safe_string_from_size(self._start, last - self._start)))
-                return -1
 
         key = self.extract_key(last)
         # find the value area
         temp_ptr = <char*>_my_memrchr(self._start, c'\0', last - self._start)
         if temp_ptr == NULL:
             # Invalid line
-            return -1
+            raise AssertionError("Failed to find the value area")
         else:
-            # capture the value string
-            value = safe_string_from_size(temp_ptr + 1, last - temp_ptr - 1)
+            # Because of how conversions were done, we ended up with *lots* of
+            # values that are identical. These are all of the 0-length nodes
+            # that are referred to by the TREE_ROOT (and likely some other
+            # directory nodes.) For example, bzr has 25k references to
+            # something like '12607215 328306 0 0', which ends up consuming 1MB
+            # of memory, just for those strings.
+            str_len = last - temp_ptr - 1
+            if (str_len > 4
+                and strncmp(" 0 0", last - 4, 4) == 0):
+                # This drops peak mem for bzr.dev from 87.4MB => 86.2MB
+                # For Launchpad 236MB => 232MB
+                value = safe_interned_string_from_size(temp_ptr + 1, str_len)
+            else:
+                value = safe_string_from_size(temp_ptr + 1, str_len)
             # shrink the references end point
             last = temp_ptr
+
         if self.ref_list_length:
-            ref_lists = []
+            ref_lists = StaticTuple_New(self.ref_list_length)
             loop_counter = 0
             while loop_counter < self.ref_list_length:
                 ref_list = []
                 # extract a reference list
                 loop_counter = loop_counter + 1
                 if last < self._start:
-                    return -1
+                    raise AssertionError("last < self._start")
                 # find the next reference list end point:
                 temp_ptr = <char*>memchr(self._start, c'\t', last - self._start)
                 if temp_ptr == NULL:
                     # Only valid for the last list
                     if loop_counter != self.ref_list_length:
                         # Invalid line
-                        return -1
-                        raise AssertionError("invalid key")
+                        raise AssertionError(
+                            "invalid key, loop_counter != self.ref_list_length")
                     else:
                         # scan to the end of the ref list area
                         ref_ptr = last
@@ -248,18 +281,20 @@
                     if temp_ptr == NULL:
                         # key runs to the end
                         temp_ptr = ref_ptr
+
                     PyList_Append(ref_list, self.extract_key(temp_ptr))
-                PyList_Append(ref_lists, tuple(ref_list))
+                ref_list = StaticTuple_Intern(StaticTuple(*ref_list))
+                Py_INCREF(ref_list)
+                StaticTuple_SET_ITEM(ref_lists, loop_counter - 1, ref_list)
                 # prepare for the next reference list
                 self._start = next_start
-            ref_lists = tuple(ref_lists)
-            node_value = (value, ref_lists)
+            node_value = StaticTuple(value, ref_lists)
         else:
             if last != self._start:
                 # unexpected reference data present
-                return -1
-            node_value = (value, ())
-        PyList_Append(self.keys, (key, node_value))
+                raise AssertionError("unexpected reference data present")
+            node_value = StaticTuple(value, StaticTuple())
+        PyList_Append(self.keys, StaticTuple(key, node_value))
         return 0
 
     def parse(self):
@@ -294,7 +329,6 @@
     cdef Py_ssize_t flat_len
     cdef Py_ssize_t key_len
     cdef Py_ssize_t node_len
-    cdef PyObject * val
     cdef char * value
     cdef Py_ssize_t value_len
     cdef char * out
@@ -303,13 +337,12 @@
     cdef int first_ref_list
     cdef int first_reference
     cdef int i
-    cdef PyObject *ref_bit
     cdef Py_ssize_t ref_bit_len
 
-    if not PyTuple_CheckExact(node):
-        raise TypeError('We expected a tuple() for node not: %s'
+    if not PyTuple_CheckExact(node) and not StaticTuple_CheckExact(node):
+        raise TypeError('We expected a tuple() or StaticTuple() for node not: %s'
             % type(node))
-    node_len = PyTuple_GET_SIZE(node)
+    node_len = len(node)
     have_reference_lists = reference_lists
     if have_reference_lists:
         if node_len != 4:
@@ -318,8 +351,17 @@
     elif node_len < 3:
         raise ValueError('Without ref_lists, we need at least 3 entries not: %s'
             % len(node))
-    # I don't expect that we can do faster than string.join()
-    string_key = '\0'.join(<object>PyTuple_GET_ITEM_ptr_object(node, 1))
+    # TODO: We can probably do better than string.join(), namely
+    #       when key has only 1 item, we can just grab that string
+    #       And when there are 2 items, we could do a single malloc + len() + 1
+    #       also, doing .join() requires a PyObject_GetAttrString call, which
+    #       we could also avoid.
+    # TODO: Note that pyrex 0.9.6 generates fairly crummy code here, using the
+    #       python object interface, versus 0.9.8+ which uses a helper that
+    #       checks if this supports the sequence interface.
+    #       We *could* do more work on our own, and grab the actual items
+    #       lists. For now, just ask people to use a better compiler. :)
+    string_key = '\0'.join(node[1])
 
     # TODO: instead of using string joins, precompute the final string length,
     #       and then malloc a single string and copy everything in.
@@ -336,7 +378,7 @@
     refs_len = 0
     if have_reference_lists:
         # Figure out how many bytes it will take to store the references
-        ref_lists = <object>PyTuple_GET_ITEM_ptr_object(node, 3)
+        ref_lists = node[3]
         next_len = len(ref_lists) # TODO: use a Py function
         if next_len > 0:
             # If there are no nodes, we don't need to do any work
@@ -350,31 +392,31 @@
                     # references
                     refs_len = refs_len + (next_len - 1)
                     for reference in ref_list:
-                        if not PyTuple_CheckExact(reference):
+                        if (not PyTuple_CheckExact(reference)
+                            and not StaticTuple_CheckExact(reference)):
                             raise TypeError(
                                 'We expect references to be tuples not: %s'
                                 % type(reference))
-                        next_len = PyTuple_GET_SIZE(reference)
+                        next_len = len(reference)
                         if next_len > 0:
                             # We will need (len - 1) '\x00' characters to
                             # separate the reference key
                             refs_len = refs_len + (next_len - 1)
-                            for i from 0 <= i < next_len:
-                                ref_bit = PyTuple_GET_ITEM_ptr_object(reference, i)
-                                if not PyString_CheckExact_ptr(ref_bit):
+                            for ref_bit in reference:
+                                if not PyString_CheckExact(ref_bit):
                                     raise TypeError('We expect reference bits'
                                         ' to be strings not: %s'
                                         % type(<object>ref_bit))
-                                refs_len = refs_len + PyString_GET_SIZE_ptr(ref_bit)
+                                refs_len = refs_len + PyString_GET_SIZE(ref_bit)
 
     # So we have the (key NULL refs NULL value LF)
     key_len = PyString_Size(string_key)
-    val = PyTuple_GET_ITEM_ptr_object(node, 2)
-    if not PyString_CheckExact_ptr(val):
+    val = node[2]
+    if not PyString_CheckExact(val):
         raise TypeError('Expected a plain str for value not: %s'
-                        % type(<object>val))
-    value = PyString_AS_STRING_ptr(val)
-    value_len = PyString_GET_SIZE_ptr(val)
+                        % type(val))
+    value = PyString_AS_STRING(val)
+    value_len = PyString_GET_SIZE(val)
     flat_len = (key_len + 1 + refs_len + 1 + value_len + 1)
     line = PyString_FromStringAndSize(NULL, flat_len)
     # Get a pointer to the new buffer
@@ -396,14 +438,14 @@
                     out[0] = c'\r'
                     out = out + 1
                 first_reference = 0
-                next_len = PyTuple_GET_SIZE(reference)
+                next_len = len(reference)
                 for i from 0 <= i < next_len:
                     if i != 0:
                         out[0] = c'\x00'
                         out = out + 1
-                    ref_bit = PyTuple_GET_ITEM_ptr_object(reference, i)
-                    ref_bit_len = PyString_GET_SIZE_ptr(ref_bit)
-                    memcpy(out, PyString_AS_STRING_ptr(ref_bit), ref_bit_len)
+                    ref_bit = reference[i]
+                    ref_bit_len = PyString_GET_SIZE(ref_bit)
+                    memcpy(out, PyString_AS_STRING(ref_bit), ref_bit_len)
                     out = out + ref_bit_len
     out[0] = c'\0'
     out = out  + 1

=== modified file 'bzrlib/_chk_map_py.py'
--- bzrlib/_chk_map_py.py	2009-04-09 20:23:07 +0000
+++ bzrlib/_chk_map_py.py	2009-10-21 21:27:19 +0000
@@ -19,6 +19,8 @@
 import zlib
 import struct
 
+from bzrlib.static_tuple import StaticTuple
+
 _LeafNode = None
 _InternalNode = None
 _unknown = None
@@ -93,7 +95,7 @@
         value_lines = lines[pos:pos+num_value_lines]
         pos += num_value_lines
         value = '\n'.join(value_lines)
-        items[tuple(elements[:-1])] = value
+        items[StaticTuple.from_sequence(elements[:-1])] = value
     if len(items) != length:
         raise AssertionError("item count (%d) mismatch for key %s,"
             " bytes %r" % (length, key, bytes))
@@ -141,7 +143,7 @@
     for line in lines[5:]:
         line = common_prefix + line
         prefix, flat_key = line.rsplit('\x00', 1)
-        items[prefix] = (flat_key,)
+        items[prefix] = StaticTuple(flat_key,)
     if len(items) == 0:
         raise AssertionError("We didn't find any item for %s" % key)
     result._items = items
@@ -155,4 +157,3 @@
     result._node_width = len(prefix)
     result._search_prefix = common_prefix
     return result
-

=== modified file 'bzrlib/_chk_map_pyx.pyx'
--- bzrlib/_chk_map_pyx.pyx	2009-06-22 12:52:39 +0000
+++ bzrlib/_chk_map_pyx.pyx	2009-10-21 21:27:19 +0000
@@ -29,9 +29,8 @@
 
 cdef extern from "Python.h":
     ctypedef int Py_ssize_t # Required for older pyrex versions
-    struct _PyObject:
+    ctypedef struct PyObject:
         pass
-    ctypedef _PyObject PyObject
     int PyTuple_CheckExact(object p)
     Py_ssize_t PyTuple_GET_SIZE(object t)
     int PyString_CheckExact(object)
@@ -52,6 +51,18 @@
     char *PyString_AS_STRING_ptr "PyString_AS_STRING" (PyObject *s)
     object PyString_FromStringAndSize(char*, Py_ssize_t)
 
+# cimport all of the definitions we will need to access
+from _static_tuple_c cimport StaticTuple,\
+    import_static_tuple_c, StaticTuple_New, \
+    StaticTuple_Intern, StaticTuple_SET_ITEM, StaticTuple_CheckExact
+
+cdef extern from "_static_tuple_c.h":
+    # Defined explicitly rather than cimport-ing. Trying to use cimport, the
+    # type for PyObject is a different class that happens to have the same
+    # name...
+    PyObject * StaticTuple_GET_ITEM_ptr "StaticTuple_GET_ITEM" (StaticTuple,
+                                                                Py_ssize_t)
+
 cdef extern from "zlib.h":
     ctypedef unsigned long uLong
     ctypedef unsigned int uInt
@@ -60,8 +71,14 @@
     uLong crc32(uLong crc, Bytef *buf, uInt len)
 
 
+# Set up the StaticTuple C_API functionality
+import_static_tuple_c()
+
+cdef object _LeafNode
 _LeafNode = None
+cdef object _InternalNode
 _InternalNode = None
+cdef object _unknown
 _unknown = None
 
 # We shouldn't just copy this from _dirstate_helpers_pyx
@@ -91,9 +108,9 @@
     cdef char *c_out
     cdef PyObject *bit
 
-    if not PyTuple_CheckExact(key):
-        raise TypeError('key %r is not a tuple' % (key,))
-    num_bits = PyTuple_GET_SIZE(key)
+    if not StaticTuple_CheckExact(key):
+        raise TypeError('key %r is not a StaticTuple' % (key,))
+    num_bits = len(key)
     # 4 bytes per crc32, and another 1 byte between bits
     num_out_bytes = (9 * num_bits) - 1
     out = PyString_FromStringAndSize(NULL, num_out_bytes)
@@ -105,7 +122,7 @@
         # We use the _ptr variant, because GET_ITEM returns a borrowed
         # reference, and Pyrex assumes that returned 'object' are a new
         # reference
-        bit = PyTuple_GET_ITEM_ptr(key, i)
+        bit = StaticTuple_GET_ITEM_ptr(key, i)
         if not PyString_CheckExact_ptr(bit):
             raise TypeError('Bit %d of %r is not a string' % (i, key))
         c_bit = <Bytef *>PyString_AS_STRING_ptr(bit)
@@ -129,9 +146,9 @@
     cdef char *c_out
     cdef PyObject *bit
 
-    if not PyTuple_CheckExact(key):
-        raise TypeError('key %r is not a tuple' % (key,))
-    num_bits = PyTuple_GET_SIZE(key)
+    if not StaticTuple_CheckExact(key):
+        raise TypeError('key %r is not a StaticTuple' % (key,))
+    num_bits = len(key)
     # 4 bytes per crc32, and another 1 byte between bits
     num_out_bytes = (5 * num_bits) - 1
     out = PyString_FromStringAndSize(NULL, num_out_bytes)
@@ -140,10 +157,10 @@
         if i > 0:
             c_out[0] = c'\x00'
             c_out = c_out + 1
-        bit = PyTuple_GET_ITEM_ptr(key, i)
+        bit = StaticTuple_GET_ITEM_ptr(key, i)
         if not PyString_CheckExact_ptr(bit):
-            raise TypeError('Bit %d of %r is not a string: %r' % (i, key,
-            <object>bit))
+            raise TypeError('Bit %d of %r is not a string: %r'
+                            % (i, key, <object>bit))
         c_bit = <Bytef *>PyString_AS_STRING_ptr(bit)
         c_len = PyString_GET_SIZE_ptr(bit)
         crc_val = crc32(0, c_bit, c_len)
@@ -195,6 +212,7 @@
     cdef char *prefix, *value_start, *prefix_tail
     cdef char *next_null, *last_null, *line_start
     cdef char *c_entry, *entry_start
+    cdef StaticTuple entry_bits
 
     if _LeafNode is None:
         from bzrlib import chk_map
@@ -265,12 +283,14 @@
             if next_line == NULL:
                 raise ValueError('missing trailing newline')
             cur = next_line + 1
-        entry_bits = PyTuple_New(width)
+        entry_bits = StaticTuple_New(width)
         for i from 0 <= i < num_prefix_bits:
+            # TODO: Use PyList_GetItem, or turn prefix_bits into a
+            #       tuple/StaticTuple
             entry = prefix_bits[i]
             # SET_ITEM 'steals' a reference
             Py_INCREF(entry)
-            PyTuple_SET_ITEM(entry_bits, i, entry)
+            StaticTuple_SET_ITEM(entry_bits, i, entry)
         value = PyString_FromStringAndSize(value_start, next_line - value_start)
         # The next entry bit needs the 'tail' from the prefix, and first part
         # of the line
@@ -288,7 +308,7 @@
             memcpy(c_entry + prefix_tail_len, line_start, next_null - line_start)
         Py_INCREF(entry)
         i = num_prefix_bits
-        PyTuple_SET_ITEM(entry_bits, i, entry)
+        StaticTuple_SET_ITEM(entry_bits, i, entry)
         while next_null != last_null: # We have remaining bits
             i = i + 1
             if i > width:
@@ -301,11 +321,12 @@
             entry = PyString_FromStringAndSize(entry_start,
                                                next_null - entry_start)
             Py_INCREF(entry)
-            PyTuple_SET_ITEM(entry_bits, i, entry)
+            StaticTuple_SET_ITEM(entry_bits, i, entry)
         if len(entry_bits) != width:
             raise AssertionError(
                 'Incorrect number of elements (%d vs %d)'
                 % (len(entry_bits)+1, width + 1))
+        entry_bits = StaticTuple_Intern(entry_bits)
         PyDict_SetItem(items, entry_bits, value)
     if len(items) != length:
         raise ValueError("item count (%d) mismatch for key %s,"
@@ -343,6 +364,8 @@
         _unknown = chk_map._unknown
     result = _InternalNode(search_key_func=search_key_func)
 
+    if not StaticTuple_CheckExact(key):
+        raise TypeError('key %r is not a StaticTuple' % (key,))
     if not PyString_CheckExact(bytes):
         raise TypeError('bytes must be a plain string not %s' % (type(bytes),))
 
@@ -384,7 +407,8 @@
         memcpy(c_item_prefix + prefix_length, cur, next_null - cur)
         flat_key = PyString_FromStringAndSize(next_null + 1,
                                               next_line - next_null - 1)
-        PyDict_SetItem(items, item_prefix, (flat_key,))
+        flat_key = StaticTuple(flat_key).intern()
+        PyDict_SetItem(items, item_prefix, flat_key)
         cur = next_line + 1
     assert len(items) > 0
     result._items = items
@@ -398,4 +422,3 @@
     result._node_width = len(item_prefix)
     result._search_prefix = PyString_FromStringAndSize(prefix, prefix_length)
     return result
-

=== modified file 'bzrlib/_dirstate_helpers_pyx.pyx'
--- bzrlib/_dirstate_helpers_pyx.pyx	2009-08-26 03:20:32 +0000
+++ bzrlib/_dirstate_helpers_pyx.pyx	2009-10-02 05:43:41 +0000
@@ -1202,7 +1202,9 @@
                         content_change = 0
                     target_exec = False
                 else:
-                    raise Exception, "unknown kind %s" % path_info[2]
+                    if path is None:
+                        path = self.pathjoin(old_dirname, old_basename)
+                    raise errors.BadFileKindError(path, path_info[2])
             if source_minikind == c'd':
                 if path is None:
                     old_path = path = self.pathjoin(old_dirname, old_basename)

=== added file 'bzrlib/_export_c_api.h'
--- bzrlib/_export_c_api.h	1970-01-01 00:00:00 +0000
+++ bzrlib/_export_c_api.h	2009-10-12 21:44:27 +0000
@@ -0,0 +1,104 @@
+/* Copyright (C) 2009 Canonical Ltd
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+
+/* This file contains helper functions for exporting a C API for a CPython
+ * extension module.
+ */
+
+#ifndef _EXPORT_C_API_H_
+#define _EXPORT_C_API_H_
+
+static const char *_C_API_NAME = "_C_API";
+
+/**
+ * Add a C function to the modules _C_API
+ * This wraps the function in a PyCObject, and inserts that into a dict.
+ * The key of the dict is the function name, and the description is the
+ * signature of the function.
+ * This is generally called during a modules init_MODULE function.
+ *
+ * @param   module  A Python module (the one being initialized)
+ * @param   funcname The name of the function being exported
+ * @param   func    A pointer to the function
+ * @param   signature The C signature of the function
+ * @return  0 if everything is successful, -1 if there is a problem. An
+ *          exception should also be set
+ */
+static int
+_export_function(PyObject *module, char *funcname, void *func, char *signature)
+{
+    PyObject *d = NULL;
+    PyObject *c_obj = NULL;
+
+    /* (char *) is because python2.4 declares this api as 'char *' rather than
+     * const char* which it really is.
+     */
+    d = PyObject_GetAttrString(module, (char *)_C_API_NAME);
+    if (!d) {
+        PyErr_Clear();
+        d = PyDict_New();
+        if (!d)
+            goto bad;
+        Py_INCREF(d);
+        if (PyModule_AddObject(module, (char *)_C_API_NAME, d) < 0)
+            goto bad;
+    }
+    c_obj = PyCObject_FromVoidPtrAndDesc(func, signature, 0);
+    if (!c_obj)
+        goto bad;
+    if (PyDict_SetItemString(d, funcname, c_obj) < 0)
+        goto bad;
+    Py_DECREF(d);
+    return 0;
+bad:
+    Py_XDECREF(c_obj);
+    Py_XDECREF(d);
+    return -1;
+}
+
+/* Note:
+ *  It feels like more could be done here. Specifically, if you look at
+ *  _static_tuple_c.h you can see some boilerplate where we have:
+ * #ifdef STATIC_TUPLE_MODULE  // are we exporting or importing
+ * static RETVAL FUNCNAME PROTO;
+ * #else
+ * static RETVAL (*FUNCNAME) PROTO;
+ * #endif
+ * 
+ * And then in _static_tuple_c.c we have
+ * int setup_c_api()
+ * {
+ *   _export_function(module, #FUNCNAME, FUNCNAME, #PROTO);
+ * }
+ *
+ * And then in _static_tuple_c.h import_##MODULE
+ * struct function_definition functions[] = {
+ *   {#FUNCNAME, (void **)&FUNCNAME, #RETVAL #PROTO},
+ *   ...
+ *   {NULL}};
+ *
+ * And some similar stuff for types. However, this would mean that we would
+ * need a way for the C preprocessor to build up a list of definitions to be
+ * generated, and then expand that list at the appropriate time.
+ * I would guess there would be a way to do this, but probably not without a
+ * lot of magic, and the end result probably wouldn't be very pretty to
+ * maintain. Perhaps python's dynamic nature has left me jaded about writing
+ * boilerplate....
+ */
+
+#endif // _EXPORT_C_API_H_

=== modified file 'bzrlib/_groupcompress_pyx.pyx'
--- bzrlib/_groupcompress_pyx.pyx	2009-06-10 03:56:49 +0000
+++ bzrlib/_groupcompress_pyx.pyx	2009-11-06 18:05:03 +0000
@@ -31,10 +31,10 @@
 
 cdef extern from *:
     ctypedef unsigned long size_t
-    void * malloc(size_t)
-    void * realloc(void *, size_t)
-    void free(void *)
-    void memcpy(void *, void *, size_t)
+    void * malloc(size_t) nogil
+    void * realloc(void *, size_t) nogil
+    void free(void *) nogil
+    void memcpy(void *, void *, size_t) nogil
 
 
 cdef extern from "delta.h":
@@ -44,19 +44,16 @@
         unsigned long agg_offset
     struct delta_index:
         pass
-    delta_index * create_delta_index(source_info *src, delta_index *old)
+    delta_index * create_delta_index(source_info *src, delta_index *old) nogil
     delta_index * create_delta_index_from_delta(source_info *delta,
-                                                delta_index *old)
-    void free_delta_index(delta_index *index)
+                                                delta_index *old) nogil
+    void free_delta_index(delta_index *index) nogil
     void *create_delta(delta_index *indexes,
              void *buf, unsigned long bufsize,
-             unsigned long *delta_size, unsigned long max_delta_size)
+             unsigned long *delta_size, unsigned long max_delta_size) nogil
     unsigned long get_delta_hdr_size(unsigned char **datap,
-                                     unsigned char *top)
+                                     unsigned char *top) nogil
     Py_ssize_t DELTA_SIZE_MIN
-    void *patch_delta(void *src_buf, unsigned long src_size,
-                      void *delta_buf, unsigned long delta_size,
-                      unsigned long *dst_size)
 
 
 cdef void *safe_malloc(size_t count) except NULL:
@@ -148,7 +145,8 @@
         src.buf = c_delta
         src.size = c_delta_size
         src.agg_offset = self._source_offset + unadded_bytes
-        index = create_delta_index_from_delta(src, self._index)
+        with nogil:
+            index = create_delta_index_from_delta(src, self._index)
         self._source_offset = src.agg_offset + src.size
         if index != NULL:
             free_delta_index(self._index)
@@ -188,7 +186,8 @@
         self._source_offset = src.agg_offset + src.size
         # We delay creating the index on the first insert
         if source_location != 0:
-            index = create_delta_index(src, self._index)
+            with nogil:
+                index = create_delta_index(src, self._index)
             if index != NULL:
                 free_delta_index(self._index)
                 self._index = index
@@ -201,7 +200,8 @@
 
         # We know that self._index is already NULL, so whatever
         # create_delta_index returns is fine
-        self._index = create_delta_index(&self._source_infos[0], NULL)
+        with nogil:
+            self._index = create_delta_index(&self._source_infos[0], NULL)
         assert self._index != NULL
 
     cdef _expand_sources(self):
@@ -218,6 +218,7 @@
         cdef Py_ssize_t target_size
         cdef void * delta
         cdef unsigned long delta_size
+        cdef unsigned long c_max_delta_size
 
         if self._index == NULL:
             if len(self._sources) == 0:
@@ -234,9 +235,11 @@
         # TODO: inline some of create_delta so we at least don't have to double
         #       malloc, and can instead use PyString_FromStringAndSize, to
         #       allocate the bytes into the final string
-        delta = create_delta(self._index,
-                             target, target_size,
-                             &delta_size, max_delta_size)
+        c_max_delta_size = max_delta_size
+        with nogil:
+            delta = create_delta(self._index,
+                                 target, target_size,
+                                 &delta_size, c_max_delta_size)
         result = None
         if delta:
             result = PyString_FromStringAndSize(<char *>delta, delta_size)
@@ -276,7 +279,7 @@
 
 
 cdef unsigned char *_decode_copy_instruction(unsigned char *bytes,
-    unsigned char cmd, unsigned int *offset, unsigned int *length):
+    unsigned char cmd, unsigned int *offset, unsigned int *length) nogil:
     """Decode a copy instruction from the next few bytes.
 
     A copy instruction is a variable number of bytes, so we will parse the
@@ -326,6 +329,7 @@
     cdef unsigned char *dst_buf, *out, cmd
     cdef Py_ssize_t size
     cdef unsigned int cp_off, cp_size
+    cdef int failed
 
     data = <unsigned char *>delta
     top = data + delta_size
@@ -335,37 +339,49 @@
     result = PyString_FromStringAndSize(NULL, size)
     dst_buf = <unsigned char*>PyString_AS_STRING(result)
 
-    out = dst_buf
-    while (data < top):
-        cmd = data[0]
-        data = data + 1
-        if (cmd & 0x80):
-            # Copy instruction
-            data = _decode_copy_instruction(data, cmd, &cp_off, &cp_size)
-            if (cp_off + cp_size < cp_size or
-                cp_off + cp_size > source_size or
-                cp_size > size):
-                raise RuntimeError('Something wrong with:'
-                    ' cp_off = %s, cp_size = %s'
-                    ' source_size = %s, size = %s'
-                    % (cp_off, cp_size, source_size, size))
-            memcpy(out, source + cp_off, cp_size)
-            out = out + cp_size
-            size = size - cp_size
-        else:
-            # Insert instruction
-            if cmd == 0:
-                # cmd == 0 is reserved for future encoding
-                # extensions. In the mean time we must fail when
-                # encountering them (might be data corruption).
-                raise RuntimeError('Got delta opcode: 0, not supported')
-            if (cmd > size):
-                raise RuntimeError('Insert instruction longer than remaining'
-                    ' bytes: %d > %d' % (cmd, size))
-            memcpy(out, data, cmd)
-            out = out + cmd
-            data = data + cmd
-            size = size - cmd
+    failed = 0
+    with nogil:
+        out = dst_buf
+        while (data < top):
+            cmd = data[0]
+            data = data + 1
+            if (cmd & 0x80):
+                # Copy instruction
+                data = _decode_copy_instruction(data, cmd, &cp_off, &cp_size)
+                if (cp_off + cp_size < cp_size or
+                    cp_off + cp_size > source_size or
+                    cp_size > size):
+                    failed = 1
+                    break
+                memcpy(out, source + cp_off, cp_size)
+                out = out + cp_size
+                size = size - cp_size
+            else:
+                # Insert instruction
+                if cmd == 0:
+                    # cmd == 0 is reserved for future encoding
+                    # extensions. In the mean time we must fail when
+                    # encountering them (might be data corruption).
+                    failed = 2
+                    break
+                if cmd > size:
+                    failed = 3
+                    break
+                memcpy(out, data, cmd)
+                out = out + cmd
+                data = data + cmd
+                size = size - cmd
+    if failed:
+        if failed == 1:
+            raise ValueError('Something wrong with:'
+                ' cp_off = %s, cp_size = %s'
+                ' source_size = %s, size = %s'
+                % (cp_off, cp_size, source_size, size))
+        elif failed == 2:
+            raise ValueError('Got delta opcode: 0, not supported')
+        elif failed == 3:
+            raise ValueError('Insert instruction longer than remaining'
+                ' bytes: %d > %d' % (cmd, size))
 
     # sanity check
     if (data != top or size != 0):

=== added file 'bzrlib/_import_c_api.h'
--- bzrlib/_import_c_api.h	1970-01-01 00:00:00 +0000
+++ bzrlib/_import_c_api.h	2009-10-12 21:44:27 +0000
@@ -0,0 +1,189 @@
+/* Copyright (C) 2009 Canonical Ltd
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+#ifndef _IMPORT_C_API_H_
+#define _IMPORT_C_API_H_
+
+/**
+ * Helper functions to eliminate some of the boilerplate when importing a C API
+ * from a CPython extension module.
+ *
+ * For more information see _export_c_api.h
+ */
+
+static const char *_C_API_NAME = "_C_API";
+
+/**
+ * Import a function from the _C_API_NAME dict that is part of module.
+ *
+ * @param   module  The Python module we are importing from
+ *                  the attribute _C_API_NAME will be used as a dictionary
+ *                  containing the function pointer we are looking for.
+ * @param   funcname    Name of the function we want to import
+ * @param   func    A pointer to the function handle where we will store the
+ *                  function.
+ * @param   signature   The C signature of the function. This is validated
+ *                      against the signature stored in the C api, to make sure
+ *                      there is no versioning skew.
+ */
+static int _import_function(PyObject *module, const char *funcname,
+                            void **func, const char *signature)
+{
+    PyObject *d = NULL;
+    PyObject *c_obj = NULL;
+    const char *desc = NULL;
+
+    /* (char *) because Python2.4 defines this as (char *) rather than
+     * (const char *)
+     */
+    d = PyObject_GetAttrString(module, (char *)_C_API_NAME);
+    if (!d) {
+        // PyObject_GetAttrString sets an appropriate exception
+        goto bad;
+    }
+    c_obj = PyDict_GetItemString(d, funcname);
+    if (!c_obj) {
+        // PyDict_GetItemString does not set an exception
+        PyErr_Format(PyExc_AttributeError,
+            "Module %s did not export a function named %s\n",
+            PyModule_GetName(module), funcname);
+        goto bad;
+    }
+    desc = (char *)PyCObject_GetDesc(c_obj);
+    if (!desc || strcmp(desc, signature) != 0) {
+        if (desc == NULL) {
+            desc = "<null>";
+        }
+        PyErr_Format(PyExc_TypeError,
+            "C function %s.%s has wrong signature (expected %s, got %s)",
+                PyModule_GetName(module), funcname, signature, desc);
+        goto bad;
+    }
+    *func = PyCObject_AsVoidPtr(c_obj);
+    Py_DECREF(d);
+    return 0;
+bad:
+    Py_XDECREF(d);
+    return -1;
+}
+
+
+/**
+ * Get a pointer to an exported PyTypeObject.
+ *
+ * @param   module        The Python module we are importing from
+ * @param   class_name    Attribute of the module that should reference the
+ *                        Type object. Note that a PyTypeObject is the python
+ *                        description of the type, not the raw C structure.
+ * @return  A Pointer to the requested type object. On error NULL will be
+ *          returned and an exception will be set.
+ */
+static PyTypeObject *
+_import_type(PyObject *module, const char *class_name)
+{
+    PyObject *type = NULL;
+
+    type = PyObject_GetAttrString(module, (char *)class_name);
+    if (!type) {
+        goto bad;
+    }
+    if (!PyType_Check(type)) {
+        PyErr_Format(PyExc_TypeError,
+            "%s.%s is not a type object",
+            PyModule_GetName(module), class_name);
+        goto bad;
+    }
+    return (PyTypeObject *)type;
+bad:
+    Py_XDECREF(type);
+    return NULL;
+}
+
+
+struct function_description
+{
+    const char *name;
+    void **pointer;
+    const char *signature;
+};
+
+struct type_description
+{
+    const char *name;
+    PyTypeObject **pointer;
+};
+
+/**
+ * Helper for importing several functions and types in a data-driven manner.
+ *
+ * @param   module  The name of the module we will be importing
+ * @param   functions   A list of function_description objects, describing the
+ *                      functions being imported.
+ *                      The list should be terminated with {NULL} to indicate
+ *                      there are no more functions to import.
+ * @param   types       A list of type_description objects describing type
+ *                      objects that we want to import. The list should be
+ *                      terminated with {NULL} to indicate there are no more
+ *                      types to import.
+ * @return  0 on success, -1 on error and an exception should be set.
+ */
+
+static int
+_import_extension_module(const char *module_name,
+                         struct function_description *functions,
+                         struct type_description *types)
+{
+    PyObject *module = NULL;
+    struct function_description *cur_func;
+    struct type_description *cur_type;
+    int ret_code;
+    
+    module = PyImport_ImportModule((char *)module_name);
+    if (!module)
+        goto bad;
+    if (functions != NULL) {
+        cur_func = functions;
+        while (cur_func->name != NULL) {
+            ret_code = _import_function(module, cur_func->name,
+                                        cur_func->pointer,
+                                        cur_func->signature);
+            if (ret_code < 0)
+                goto bad;
+            cur_func++;
+        }
+    }
+    if (types != NULL) {
+        PyTypeObject *type_p = NULL;
+        cur_type = types;
+        while (cur_type->name != NULL)  {
+            type_p = _import_type(module, cur_type->name);
+            if (type_p == NULL)
+                goto bad;
+            *(cur_type->pointer) = type_p;
+            cur_type++;
+        }
+    }
+    
+    Py_XDECREF(module);
+    return 0;
+bad:
+    Py_XDECREF(module);
+    return -1;
+}
+
+
+#endif // _IMPORT_C_API_H_

=== modified file 'bzrlib/_known_graph_py.py'
--- bzrlib/_known_graph_py.py	2009-08-17 20:41:26 +0000
+++ bzrlib/_known_graph_py.py	2009-11-30 17:25:22 +0000
@@ -17,6 +17,7 @@
 """Implementation of Graph algorithms when we have already loaded everything.
 """
 
+from collections import deque
 from bzrlib import (
     errors,
     revision,
@@ -62,7 +63,7 @@
         :param parent_map: A dictionary mapping key => parent_keys
         """
         self._nodes = {}
-        # Maps {sorted(revision_id, revision_id): heads}
+        # Maps {frozenset(revision_id, revision_id): heads}
         self._known_heads = {}
         self.do_cache = do_cache
         self._initialize_nodes(parent_map)
@@ -97,6 +98,10 @@
         return [node for node in self._nodes.itervalues()
                 if not node.parent_keys]
 
+    def _find_tips(self):
+        return [node for node in self._nodes.itervalues()
+                      if not node.child_keys]
+
     def _find_gdfo(self):
         nodes = self._nodes
         known_parent_gdfos = {}
@@ -128,6 +133,71 @@
                     # Update known_parent_gdfos for a key we couldn't process
                     known_parent_gdfos[child_key] = known_gdfo
 
+    def add_node(self, key, parent_keys):
+        """Add a new node to the graph.
+
+        If this fills in a ghost, then the gdfos of all children will be
+        updated accordingly.
+        
+        :param key: The node being added. If this is a duplicate, this is a
+            no-op.
+        :param parent_keys: The parents of the given node.
+        :return: None (should we return if this was a ghost, etc?)
+        """
+        nodes = self._nodes
+        if key in nodes:
+            node = nodes[key]
+            if node.parent_keys is None:
+                node.parent_keys = parent_keys
+                # A ghost is being added, we can no-longer trust the heads
+                # cache, so clear it
+                self._known_heads.clear()
+            else:
+                # Make sure we compare a list to a list, as tuple != list.
+                parent_keys = list(parent_keys)
+                existing_parent_keys = list(node.parent_keys)
+                if parent_keys == existing_parent_keys:
+                    return # Identical content
+                else:
+                    raise ValueError('Parent key mismatch, existing node %s'
+                        ' has parents of %s not %s'
+                        % (key, existing_parent_keys, parent_keys))
+        else:
+            node = _KnownGraphNode(key, parent_keys)
+            nodes[key] = node
+        parent_gdfo = 0
+        for parent_key in parent_keys:
+            try:
+                parent_node = nodes[parent_key]
+            except KeyError:
+                parent_node = _KnownGraphNode(parent_key, None)
+                # Ghosts and roots have gdfo 1
+                parent_node.gdfo = 1
+                nodes[parent_key] = parent_node
+            if parent_gdfo < parent_node.gdfo:
+                parent_gdfo = parent_node.gdfo
+            parent_node.child_keys.append(key)
+        node.gdfo = parent_gdfo + 1
+        # Now fill the gdfo to all children
+        # Note that this loop is slightly inefficient, in that we may visit the
+        # same child (and its decendents) more than once, however, it is
+        # 'efficient' in that we only walk to nodes that would be updated,
+        # rather than all nodes
+        # We use a deque rather than a simple list stack, to go for BFD rather
+        # than DFD. So that if a longer path is possible, we walk it before we
+        # get to the final child
+        pending = deque([node])
+        while pending:
+            node = pending.popleft()
+            next_gdfo = node.gdfo + 1
+            for child_key in node.child_keys:
+                child = nodes[child_key]
+                if child.gdfo < next_gdfo:
+                    # This child is being updated, we need to check its
+                    # children
+                    child.gdfo = next_gdfo
+                    pending.append(child)
+
     def heads(self, keys):
         """Return the heads from amongst keys.
 
@@ -218,6 +288,51 @@
         # We started from the parents, so we don't need to do anymore work
         return topo_order
 
+    def gc_sort(self):
+        """Return a reverse topological ordering which is 'stable'.
+
+        There are a few constraints:
+          1) Reverse topological (all children before all parents)
+          2) Grouped by prefix
+          3) 'stable' sorting, so that we get the same result, independent of
+             machine, or extra data.
+        To do this, we use the same basic algorithm as topo_sort, but when we
+        aren't sure what node to access next, we sort them lexicographically.
+        """
+        tips = self._find_tips()
+        # Split the tips based on prefix
+        prefix_tips = {}
+        for node in tips:
+            if node.key.__class__ is str or len(node.key) == 1:
+                prefix = ''
+            else:
+                prefix = node.key[0]
+            prefix_tips.setdefault(prefix, []).append(node)
+
+        num_seen_children = dict.fromkeys(self._nodes, 0)
+
+        result = []
+        for prefix in sorted(prefix_tips):
+            pending = sorted(prefix_tips[prefix], key=lambda n:n.key,
+                             reverse=True)
+            while pending:
+                node = pending.pop()
+                if node.parent_keys is None:
+                    # Ghost node, skip it
+                    continue
+                result.append(node.key)
+                for parent_key in sorted(node.parent_keys, reverse=True):
+                    parent_node = self._nodes[parent_key]
+                    seen_children = num_seen_children[parent_key] + 1
+                    if seen_children == len(parent_node.child_keys):
+                        # All children have been processed, enqueue this parent
+                        pending.append(parent_node)
+                        # This has been queued up, stop tracking it
+                        del num_seen_children[parent_key]
+                    else:
+                        num_seen_children[parent_key] = seen_children
+        return result
+
     def merge_sort(self, tip_key):
         """Compute the merge sorted graph output."""
         from bzrlib import tsort
@@ -232,3 +347,26 @@
                  in tsort.merge_sort(as_parent_map, tip_key,
                                      mainline_revisions=None,
                                      generate_revno=True)]
+    
+    def get_parent_keys(self, key):
+        """Get the parents for a key
+        
+        Returns a list containg the parents keys. If the key is a ghost,
+        None is returned. A KeyError will be raised if the key is not in
+        the graph.
+        
+        :param keys: Key to check (eg revision_id)
+        :return: A list of parents
+        """
+        return self._nodes[key].parent_keys
+
+    def get_child_keys(self, key):
+        """Get the children for a key
+        
+        Returns a list containg the children keys. A KeyError will be raised
+        if the key is not in the graph.
+        
+        :param keys: Key to check (eg revision_id)
+        :return: A list of children
+        """
+        return self._nodes[key].child_keys

=== modified file 'bzrlib/_known_graph_pyx.pyx'
--- bzrlib/_known_graph_pyx.pyx	2009-08-26 16:03:59 +0000
+++ bzrlib/_known_graph_pyx.pyx	2009-11-30 17:25:22 +0000
@@ -25,11 +25,18 @@
     ctypedef struct PyObject:
         pass
 
+    int PyString_CheckExact(object)
+
+    int PyObject_RichCompareBool(object, object, int)
+    int Py_LT
+
+    int PyTuple_CheckExact(object)
     object PyTuple_New(Py_ssize_t n)
     Py_ssize_t PyTuple_GET_SIZE(object t)
     PyObject * PyTuple_GET_ITEM(object t, Py_ssize_t o)
     void PyTuple_SET_ITEM(object t, Py_ssize_t o, object v)
 
+    int PyList_CheckExact(object)
     Py_ssize_t PyList_GET_SIZE(object l)
     PyObject * PyList_GET_ITEM(object l, Py_ssize_t o)
     int PyList_SetItem(object l, Py_ssize_t o, object l) except -1
@@ -44,6 +51,7 @@
 
     void Py_INCREF(object)
 
+from collections import deque
 import gc
 
 from bzrlib import errors, revision
@@ -81,6 +89,18 @@
                 PyList_Append(keys, child.key)
             return keys
 
+    property parent_keys:
+        def __get__(self):
+            if self.parents is None:
+                return None
+            
+            cdef _KnownGraphNode parent
+
+            keys = []
+            for parent in self.parents:
+                PyList_Append(keys, parent.key)
+            return keys
+    
     cdef clear_references(self):
         self.parents = None
         self.children = None
@@ -108,21 +128,72 @@
     return <_KnownGraphNode>temp_node
 
 
-cdef _KnownGraphNode _get_parent(parents, Py_ssize_t pos):
+cdef _KnownGraphNode _get_tuple_node(tpl, Py_ssize_t pos):
     cdef PyObject *temp_node
-    cdef _KnownGraphNode node
 
-    temp_node = PyTuple_GET_ITEM(parents, pos)
+    temp_node = PyTuple_GET_ITEM(tpl, pos)
     return <_KnownGraphNode>temp_node
 
 
+def get_key(node):
+    cdef _KnownGraphNode real_node
+    real_node = node
+    return real_node.key
+
+
+cdef object _sort_list_nodes(object lst_or_tpl, int reverse):
+    """Sort a list of _KnownGraphNode objects.
+
+    If lst_or_tpl is a list, it is allowed to mutate in place. It may also
+    just return the input list if everything is already sorted.
+    """
+    cdef _KnownGraphNode node1, node2
+    cdef int do_swap, is_tuple
+    cdef Py_ssize_t length
+
+    is_tuple = PyTuple_CheckExact(lst_or_tpl)
+    if not (is_tuple or PyList_CheckExact(lst_or_tpl)):
+        raise TypeError('lst_or_tpl must be a list or tuple.')
+    length = len(lst_or_tpl)
+    if length == 0 or length == 1:
+        return lst_or_tpl
+    if length == 2:
+        if is_tuple:
+            node1 = _get_tuple_node(lst_or_tpl, 0)
+            node2 = _get_tuple_node(lst_or_tpl, 1)
+        else:
+            node1 = _get_list_node(lst_or_tpl, 0)
+            node2 = _get_list_node(lst_or_tpl, 1)
+        if reverse:
+            do_swap = PyObject_RichCompareBool(node1.key, node2.key, Py_LT)
+        else:
+            do_swap = PyObject_RichCompareBool(node2.key, node1.key, Py_LT)
+        if not do_swap:
+            return lst_or_tpl
+        if is_tuple:
+            return (node2, node1)
+        else:
+            # Swap 'in-place', since lists are mutable
+            Py_INCREF(node1)
+            PyList_SetItem(lst_or_tpl, 1, node1)
+            Py_INCREF(node2)
+            PyList_SetItem(lst_or_tpl, 0, node2)
+            return lst_or_tpl
+    # For all other sizes, we just use 'sorted()'
+    if is_tuple:
+        # Note that sorted() is just list(iterable).sort()
+        lst_or_tpl = list(lst_or_tpl)
+    lst_or_tpl.sort(key=get_key, reverse=reverse)
+    return lst_or_tpl
+
+
 cdef class _MergeSorter
 
 cdef class KnownGraph:
     """This is a class which assumes we already know the full graph."""
 
     cdef public object _nodes
-    cdef object _known_heads
+    cdef public object _known_heads
     cdef public int do_cache
 
     def __init__(self, parent_map, do_cache=True):
@@ -162,6 +233,28 @@
             node = <_KnownGraphNode>temp_node
         return node
 
+    cdef _populate_parents(self, _KnownGraphNode node, parent_keys):
+        cdef Py_ssize_t num_parent_keys, pos
+        cdef _KnownGraphNode parent_node
+
+        num_parent_keys = len(parent_keys)
+        # We know how many parents, so we pre allocate the tuple
+        parent_nodes = PyTuple_New(num_parent_keys)
+        for pos from 0 <= pos < num_parent_keys:
+            # Note: it costs us 10ms out of 40ms to lookup all of these
+            #       parents, it doesn't seem to be an allocation overhead,
+            #       but rather a lookup overhead. There doesn't seem to be
+            #       a way around it, and that is one reason why
+            #       KnownGraphNode maintains a direct pointer to the parent
+            #       node.
+            # We use [] because parent_keys may be a tuple or list
+            parent_node = self._get_or_create_node(parent_keys[pos])
+            # PyTuple_SET_ITEM will steal a reference, so INCREF first
+            Py_INCREF(parent_node)
+            PyTuple_SET_ITEM(parent_nodes, pos, parent_node)
+            PyList_Append(parent_node.children, node)
+        node.parents = parent_nodes
+
     def _initialize_nodes(self, parent_map):
         """Populate self._nodes.
 
@@ -172,7 +265,7 @@
           child keys,
         """
         cdef PyObject *temp_key, *temp_parent_keys, *temp_node
-        cdef Py_ssize_t pos, pos2, num_parent_keys
+        cdef Py_ssize_t pos
         cdef _KnownGraphNode node
         cdef _KnownGraphNode parent_node
 
@@ -183,24 +276,8 @@
         while PyDict_Next(parent_map, &pos, &temp_key, &temp_parent_keys):
             key = <object>temp_key
             parent_keys = <object>temp_parent_keys
-            num_parent_keys = len(parent_keys)
             node = self._get_or_create_node(key)
-            # We know how many parents, so we pre allocate the tuple
-            parent_nodes = PyTuple_New(num_parent_keys)
-            for pos2 from 0 <= pos2 < num_parent_keys:
-                # Note: it costs us 10ms out of 40ms to lookup all of these
-                #       parents, it doesn't seem to be an allocation overhead,
-                #       but rather a lookup overhead. There doesn't seem to be
-                #       a way around it, and that is one reason why
-                #       KnownGraphNode maintains a direct pointer to the parent
-                #       node.
-                # We use [] because parent_keys may be a tuple or list
-                parent_node = self._get_or_create_node(parent_keys[pos2])
-                # PyTuple_SET_ITEM will steal a reference, so INCREF first
-                Py_INCREF(parent_node)
-                PyTuple_SET_ITEM(parent_nodes, pos2, parent_node)
-                PyList_Append(parent_node.children, node)
-            node.parents = parent_nodes
+            self._populate_parents(node, parent_keys)
 
     def _find_tails(self):
         cdef PyObject *temp_node
@@ -216,6 +293,19 @@
                 PyList_Append(tails, node)
         return tails
 
+    def _find_tips(self):
+        cdef PyObject *temp_node
+        cdef _KnownGraphNode node
+        cdef Py_ssize_t pos
+
+        tips = []
+        pos = 0
+        while PyDict_Next(self._nodes, &pos, NULL, &temp_node):
+            node = <_KnownGraphNode>temp_node
+            if PyList_GET_SIZE(node.children) == 0:
+                PyList_Append(tips, node)
+        return tips
+
     def _find_gdfo(self):
         cdef _KnownGraphNode node
         cdef _KnownGraphNode child
@@ -251,6 +341,76 @@
                     # anymore
                     child.seen = 0
 
+    def add_node(self, key, parent_keys):
+        """Add a new node to the graph.
+
+        If this fills in a ghost, then the gdfos of all children will be
+        updated accordingly.
+        
+        :param key: The node being added. If this is a duplicate, this is a
+            no-op.
+        :param parent_keys: The parents of the given node.
+        :return: None (should we return if this was a ghost, etc?)
+        """
+        cdef PyObject *maybe_node
+        cdef _KnownGraphNode node, parent_node, child_node
+        cdef long parent_gdfo, next_gdfo
+
+        maybe_node = PyDict_GetItem(self._nodes, key)
+        if maybe_node != NULL:
+            node = <_KnownGraphNode>maybe_node
+            if node.parents is None:
+                # We are filling in a ghost
+                self._populate_parents(node, parent_keys)
+                # We can't trust cached heads anymore
+                self._known_heads.clear()
+            else: # Ensure that the parent_key list matches
+                existing_parent_keys = []
+                for parent_node in node.parents:
+                    existing_parent_keys.append(parent_node.key)
+                # Make sure we use a list for the comparison, in case it was a
+                # tuple, etc
+                parent_keys = list(parent_keys)
+                if existing_parent_keys == parent_keys:
+                    # Exact match, nothing more to do
+                    return
+                else:
+                    raise ValueError('Parent key mismatch, existing node %s'
+                        ' has parents of %s not %s'
+                        % (key, existing_parent_keys, parent_keys))
+        else:
+            node = _KnownGraphNode(key)
+            PyDict_SetItem(self._nodes, key, node)
+            self._populate_parents(node, parent_keys)
+        parent_gdfo = 0
+        for parent_node in node.parents:
+            if parent_node.gdfo == -1:
+                # This is a newly introduced ghost, so it gets gdfo of 1
+                parent_node.gdfo = 1
+            if parent_gdfo < parent_node.gdfo:
+                parent_gdfo = parent_node.gdfo
+        node.gdfo = parent_gdfo + 1
+        # Now fill the gdfo to all children
+        # Note that this loop is slightly inefficient, in that we may visit the
+        # same child (and its decendents) more than once, however, it is
+        # 'efficient' in that we only walk to nodes that would be updated,
+        # rather than all nodes
+        # We use a deque rather than a simple list stack, to go for BFD rather
+        # than DFD. So that if a longer path is possible, we walk it before we
+        # get to the final child
+        pending = deque([node])
+        pending_popleft = pending.popleft
+        pending_append = pending.append
+        while pending:
+            node = pending_popleft()
+            next_gdfo = node.gdfo + 1
+            for child_node in node.children:
+                if child_node.gdfo < next_gdfo:
+                    # This child is being updated, we need to check its
+                    # children
+                    child_node.gdfo = next_gdfo
+                    pending_append(child_node)
+
     def heads(self, keys):
         """Return the heads from amongst keys.
 
@@ -322,7 +482,7 @@
                 continue
             if node.parents is not None and PyTuple_GET_SIZE(node.parents) > 0:
                 for pos from 0 <= pos < PyTuple_GET_SIZE(node.parents):
-                    parent_node = _get_parent(node.parents, pos)
+                    parent_node = _get_tuple_node(node.parents, pos)
                     last_item = last_item + 1
                     if last_item < PyList_GET_SIZE(pending):
                         Py_INCREF(parent_node) # SetItem steals a ref
@@ -397,6 +557,77 @@
         # We started from the parents, so we don't need to do anymore work
         return topo_order
 
+    def gc_sort(self):
+        """Return a reverse topological ordering which is 'stable'.
+
+        There are a few constraints:
+          1) Reverse topological (all children before all parents)
+          2) Grouped by prefix
+          3) 'stable' sorting, so that we get the same result, independent of
+             machine, or extra data.
+        To do this, we use the same basic algorithm as topo_sort, but when we
+        aren't sure what node to access next, we sort them lexicographically.
+        """
+        cdef PyObject *temp
+        cdef Py_ssize_t pos, last_item
+        cdef _KnownGraphNode node, node2, parent_node
+
+        tips = self._find_tips()
+        # Split the tips based on prefix
+        prefix_tips = {}
+        for pos from 0 <= pos < PyList_GET_SIZE(tips):
+            node = _get_list_node(tips, pos)
+            if PyString_CheckExact(node.key) or len(node.key) == 1:
+                prefix = ''
+            else:
+                prefix = node.key[0]
+            temp = PyDict_GetItem(prefix_tips, prefix)
+            if temp == NULL:
+                prefix_tips[prefix] = [node]
+            else:
+                tip_nodes = <object>temp
+                PyList_Append(tip_nodes, node)
+
+        result = []
+        for prefix in sorted(prefix_tips):
+            temp = PyDict_GetItem(prefix_tips, prefix)
+            assert temp != NULL
+            tip_nodes = <object>temp
+            pending = _sort_list_nodes(tip_nodes, 1)
+            last_item = PyList_GET_SIZE(pending) - 1
+            while last_item >= 0:
+                node = _get_list_node(pending, last_item)
+                last_item = last_item - 1
+                if node.parents is None:
+                    # Ghost
+                    continue
+                PyList_Append(result, node.key)
+                # Sorting the parent keys isn't strictly necessary for stable
+                # sorting of a given graph. But it does help minimize the
+                # differences between graphs
+                # For bzr.dev ancestry:
+                #   4.73ms  no sort
+                #   7.73ms  RichCompareBool sort
+                parents = _sort_list_nodes(node.parents, 1)
+                for pos from 0 <= pos < len(parents):
+                    if PyTuple_CheckExact(parents):
+                        parent_node = _get_tuple_node(parents, pos)
+                    else:
+                        parent_node = _get_list_node(parents, pos)
+                    # TODO: GraphCycle detection
+                    parent_node.seen = parent_node.seen + 1
+                    if (parent_node.seen
+                        == PyList_GET_SIZE(parent_node.children)):
+                        # All children have been processed, queue up this
+                        # parent
+                        last_item = last_item + 1
+                        if last_item < PyList_GET_SIZE(pending):
+                            Py_INCREF(parent_node) # SetItem steals a ref
+                            PyList_SetItem(pending, last_item, parent_node)
+                        else:
+                            PyList_Append(pending, parent_node)
+                        parent_node.seen = 0
+        return result
 
     def merge_sort(self, tip_key):
         """Compute the merge sorted graph output."""
@@ -407,6 +638,29 @@
         #       shown a specific impact, yet.
         sorter = _MergeSorter(self, tip_key)
         return sorter.topo_order()
+    
+    def get_parent_keys(self, key):
+        """Get the parents for a key
+        
+        Returns a list containg the parents keys. If the key is a ghost,
+        None is returned. A KeyError will be raised if the key is not in
+        the graph.
+        
+        :param keys: Key to check (eg revision_id)
+        :return: A list of parents
+        """
+        return self._nodes[key].parent_keys 
+
+    def get_child_keys(self, key):
+        """Get the children for a key
+        
+        Returns a list containg the children keys. A KeyError will be raised
+        if the key is not in the graph.
+        
+        :param keys: Key to check (eg revision_id)
+        :return: A list of children
+        """
+        return self._nodes[key].child_keys    
 
 
 cdef class _MergeSortNode:
@@ -522,7 +776,7 @@
             raise RuntimeError('ghost nodes should not be pushed'
                                ' onto the stack: %s' % (node,))
         if PyTuple_GET_SIZE(node.parents) > 0:
-            parent_node = _get_parent(node.parents, 0)
+            parent_node = _get_tuple_node(node.parents, 0)
             ms_node.left_parent = parent_node
             if parent_node.parents is None: # left-hand ghost
                 ms_node.left_pending_parent = None
@@ -532,7 +786,7 @@
         if PyTuple_GET_SIZE(node.parents) > 1:
             ms_node.pending_parents = []
             for pos from 1 <= pos < PyTuple_GET_SIZE(node.parents):
-                parent_node = _get_parent(node.parents, pos)
+                parent_node = _get_tuple_node(node.parents, pos)
                 if parent_node.parents is None: # ghost
                     continue
                 PyList_Append(ms_node.pending_parents, parent_node)

=== modified file 'bzrlib/_patiencediff_c.c'
--- bzrlib/_patiencediff_c.c	2009-03-23 14:59:43 +0000
+++ bzrlib/_patiencediff_c.c	2009-10-29 06:11:23 +0000
@@ -298,7 +298,7 @@
         apos = SENTINEL;
         /* loop through all lines in the linked list */
         for (i = h[equiv].a_pos; i != SENTINEL; i = lines_a[i].next) {
-            /* the index is lower than alo, the the next line */
+            /* the index is lower than alo, continue to the next line */
             if (i < alo) {
                 h[equiv].a_pos = i;
                 continue;
@@ -319,7 +319,7 @@
         /* check for duplicates of this line in lines_b[blo:bhi] */
         /* loop through all lines in the linked list */
         for (i = h[equiv].b_pos; i != SENTINEL; i = lines_b[i].next) {
-            /* the index is lower than blo, the the next line */
+            /* the index is lower than blo, continue to the next line */
             if (i < blo) {
                 h[equiv].b_pos = i;
                 continue;

=== modified file 'bzrlib/_readdir_pyx.pyx'
--- bzrlib/_readdir_pyx.pyx	2009-07-27 04:24:36 +0000
+++ bzrlib/_readdir_pyx.pyx	2009-10-08 07:03:05 +0000
@@ -343,8 +343,10 @@
                             raise OSError(errno, "lstat: " + strerror(errno),
                                 path + "/" + entry.d_name)
                         else:
-                            kind = _missing
-                            statvalue = None
+                            # the file seems to have disappeared after being
+                            # seen by readdir - perhaps a transient temporary
+                            # file.  there's no point returning it.
+                            continue
                     # We append a 5-tuple that can be modified in-place by the C
                     # api:
                     # inode to sort on (to replace with top_path)

=== added file 'bzrlib/_simple_set_pyx.pxd'
--- bzrlib/_simple_set_pyx.pxd	1970-01-01 00:00:00 +0000
+++ bzrlib/_simple_set_pyx.pxd	2009-10-09 16:49:45 +0000
@@ -0,0 +1,91 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Interface definition of a class like PySet but without caching the hash.
+
+This is generally useful when you want to 'intern' objects, etc. Note that this
+differs from Set in that we:
+  1) Don't have all of the .intersection, .difference, etc functions
+  2) Do return the object from the set via queries
+     eg. SimpleSet.add(key) => saved_key and SimpleSet[key] => saved_key
+"""
+
+cdef extern from "Python.h":
+    ctypedef struct PyObject:
+        pass
+
+
+cdef public api class SimpleSet [object SimpleSetObject, type SimpleSet_Type]:
+    """A class similar to PySet, but with simpler implementation.
+
+    The main advantage is that this class uses only 2N memory to store N
+    objects rather than 4N memory. The main trade-off is that we do not cache
+    the hash value of saved objects. As such, it is assumed that computing the
+    hash will be cheap (such as strings or tuples of strings, etc.)
+
+    This also differs in that you can get back the objects that are stored
+    (like a dict), but we also don't implement the complete list of 'set'
+    operations (difference, intersection, etc).
+    """
+    # Data structure definition:
+    #   This is a basic hash table using open addressing.
+    #       http://en.wikipedia.org/wiki/Open_addressing
+    #   Basically that means we keep an array of pointers to Python objects
+    #   (called a table). Each location in the array is called a 'slot'.
+    #
+    #   An empty slot holds a NULL pointer, a slot where there was an item
+    #   which was then deleted will hold a pointer to _dummy, and a filled slot
+    #   points at the actual object which fills that slot.
+    #
+    #   The table is always a power of two, and the default location where an
+    #   object is inserted is at hash(object) & (table_size - 1)
+    #
+    #   If there is a collision, then we search for another location. The
+    #   specific algorithm is in _lookup. We search until we:
+    #       find the object
+    #       find an equivalent object (by tp_richcompare(obj1, obj2, Py_EQ))
+    #       find a NULL slot
+    #
+    #   When an object is deleted, we set its slot to _dummy. this way we don't
+    #   have to track whether there was a collision, and find the corresponding
+    #   keys. (The collision resolution algorithm makes that nearly impossible
+    #   anyway, because it depends on the upper bits of the hash.)
+    #   The main effect of this, is that if we find _dummy, then we can insert
+    #   an object there, but we have to keep searching until we find NULL to
+    #   know that the object is not present elsewhere.
+
+    cdef Py_ssize_t _used   # active
+    cdef Py_ssize_t _fill   # active + dummy
+    cdef Py_ssize_t _mask   # Table contains (mask+1) slots, a power of 2
+    cdef PyObject **_table  # Pyrex/Cython doesn't support arrays to 'object'
+                            # so we manage it manually
+
+    cdef PyObject *_get(self, object key) except? NULL
+    cdef object _add(self, key)
+    cdef int _discard(self, key) except -1
+    cdef int _insert_clean(self, PyObject *key) except -1
+    cdef Py_ssize_t _resize(self, Py_ssize_t min_unused) except -1
+
+
+# TODO: might want to export the C api here, though it is all available from
+#       the class object...
+cdef api SimpleSet SimpleSet_New()
+cdef api object SimpleSet_Add(object self, object key)
+cdef api int SimpleSet_Contains(object self, object key) except -1
+cdef api int SimpleSet_Discard(object self, object key) except -1
+cdef api PyObject *SimpleSet_Get(SimpleSet self, object key) except? NULL
+cdef api Py_ssize_t SimpleSet_Size(object self) except -1
+cdef api int SimpleSet_Next(object self, Py_ssize_t *pos, PyObject **key)

=== added file 'bzrlib/_simple_set_pyx.pyx'
--- bzrlib/_simple_set_pyx.pyx	1970-01-01 00:00:00 +0000
+++ bzrlib/_simple_set_pyx.pyx	2009-10-14 15:57:06 +0000
@@ -0,0 +1,590 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Definition of a class that is similar to Set with some small changes."""
+
+cdef extern from "python-compat.h":
+    pass
+
+cdef extern from "Python.h":
+    ctypedef unsigned long size_t
+    ctypedef long (*hashfunc)(PyObject*) except -1
+    ctypedef object (*richcmpfunc)(PyObject *, PyObject *, int)
+    ctypedef int (*visitproc)(PyObject *, void *)
+    ctypedef int (*traverseproc)(PyObject *, visitproc, void *)
+    int Py_EQ
+    void Py_INCREF(PyObject *)
+    void Py_DECREF(PyObject *)
+    ctypedef struct PyTypeObject:
+        hashfunc tp_hash
+        richcmpfunc tp_richcompare
+        traverseproc tp_traverse
+
+    PyTypeObject *Py_TYPE(PyObject *)
+    # Note: *Don't* use hash(), Pyrex 0.9.8.5 thinks it returns an 'int', and
+    #       thus silently truncates to 32-bits on 64-bit machines.
+    long PyObject_Hash(PyObject *) except -1
+        
+    void *PyMem_Malloc(size_t nbytes)
+    void PyMem_Free(void *)
+    void memset(void *, int, size_t)
+
+
+# Dummy is an object used to mark nodes that have been deleted. Since
+# collisions require us to move a node to an alternative location, if we just
+# set an entry to NULL on delete, we won't find any relocated nodes.
+# We have to use _dummy_obj because we need to keep a refcount to it, but we
+# also use _dummy as a pointer, because it avoids having to put <PyObject*> all
+# over the code base.
+cdef object _dummy_obj
+cdef PyObject *_dummy
+_dummy_obj = object()
+_dummy = <PyObject *>_dummy_obj
+
+
+cdef object _NotImplemented
+_NotImplemented = NotImplemented
+
+
+cdef int _is_equal(PyObject *this, long this_hash, PyObject *other) except -1:
+    cdef long other_hash
+
+    if this == other:
+        return 1
+    other_hash = PyObject_Hash(other)
+    if other_hash != this_hash:
+        return 0
+
+    # This implements a subset of the PyObject_RichCompareBool functionality.
+    # Namely it:
+    #   1) Doesn't try to do anything with old-style classes
+    #   2) Assumes that both objects have a tp_richcompare implementation, and
+    #      that if that is not enough to compare equal, then they are not
+    #      equal. (It doesn't try to cast them both to some intermediate form
+    #      that would compare equal.)
+    res = Py_TYPE(this).tp_richcompare(this, other, Py_EQ)
+    if res is _NotImplemented:
+        res = Py_TYPE(other).tp_richcompare(other, this, Py_EQ)
+        if res is _NotImplemented:
+            return 0
+    if res:
+        return 1
+    return 0
+
+
+cdef public api class SimpleSet [object SimpleSetObject, type SimpleSet_Type]:
+    """This class can be used to track canonical forms for objects.
+
+    It is similar in function to the interned dictionary that is used by
+    strings. However:
+
+      1) It assumes that hash(obj) is cheap, so does not need to inline a copy
+         of it
+      2) It only stores one reference to the object, rather than 2 (key vs
+         key:value)
+
+    As such, it uses 1/3rd the amount of memory to store a pointer to the
+    interned object.
+    """
+    # Attributes are defined in the .pxd file
+    DEF DEFAULT_SIZE=1024
+
+    def __init__(self):
+        cdef Py_ssize_t size, n_bytes
+
+        size = DEFAULT_SIZE
+        self._mask = size - 1
+        self._used = 0
+        self._fill = 0
+        n_bytes = sizeof(PyObject*) * size;
+        self._table = <PyObject **>PyMem_Malloc(n_bytes)
+        if self._table == NULL:
+            raise MemoryError()
+        memset(self._table, 0, n_bytes)
+
+    def __dealloc__(self):
+        if self._table != NULL:
+            PyMem_Free(self._table)
+            self._table = NULL
+
+    property used:
+        def __get__(self):
+            return self._used
+
+    property fill:
+        def __get__(self):
+            return self._fill
+
+    property mask:
+        def __get__(self):
+            return self._mask
+
+    def _memory_size(self):
+        """Return the number of bytes of memory consumed by this class."""
+        return sizeof(self) + (sizeof(PyObject*)*(self._mask + 1))
+
+    def __len__(self):
+        return self._used
+
+    def _test_lookup(self, key):
+        cdef PyObject **slot
+
+        slot = _lookup(self, key)
+        if slot[0] == NULL:
+            res = '<null>'
+        elif slot[0] == _dummy:
+            res = '<dummy>'
+        else:
+            res = <object>slot[0]
+        return <int>(slot - self._table), res
+
+    def __contains__(self, key):
+        """Is key present in this SimpleSet."""
+        cdef PyObject **slot
+
+        slot = _lookup(self, key)
+        if slot[0] == NULL or slot[0] == _dummy:
+            return False
+        return True
+
+    cdef PyObject *_get(self, object key) except? NULL:
+        """Return the object (or nothing) define at the given location."""
+        cdef PyObject **slot
+
+        slot = _lookup(self, key)
+        if slot[0] == NULL or slot[0] == _dummy:
+            return NULL
+        return slot[0]
+
+    def __getitem__(self, key):
+        """Return a stored item that is equivalent to key."""
+        cdef PyObject *py_val
+
+        py_val = self._get(key)
+        if py_val == NULL:
+            raise KeyError("Key %s is not present" % key)
+        val = <object>(py_val)
+        return val
+
+    cdef int _insert_clean(self, PyObject *key) except -1:
+        """Insert a key into self.table.
+
+        This is only meant to be used during times like '_resize',
+        as it makes a lot of assuptions about keys not already being present,
+        and there being no dummy entries.
+        """
+        cdef size_t i, n_lookup
+        cdef long the_hash
+        cdef PyObject **table, **slot
+        cdef Py_ssize_t mask
+
+        mask = self._mask
+        table = self._table
+
+        the_hash = PyObject_Hash(key)
+        i = the_hash
+        for n_lookup from 0 <= n_lookup <= <size_t>mask: # Don't loop forever
+            slot = &table[i & mask]
+            if slot[0] == NULL:
+                slot[0] = key
+                self._fill = self._fill + 1
+                self._used = self._used + 1
+                return 1
+            i = i + 1 + n_lookup
+        raise RuntimeError('ran out of slots.')
+
+    def _py_resize(self, min_used):
+        """Do not use this directly, it is only exposed for testing."""
+        return self._resize(min_used)
+
+    cdef Py_ssize_t _resize(self, Py_ssize_t min_used) except -1:
+        """Resize the internal table.
+
+        The final table will be big enough to hold at least min_used entries.
+        We will copy the data from the existing table over, leaving out dummy
+        entries.
+
+        :return: The new size of the internal table
+        """
+        cdef Py_ssize_t new_size, n_bytes, remaining
+        cdef PyObject **new_table, **old_table, **slot
+
+        new_size = DEFAULT_SIZE
+        while new_size <= min_used and new_size > 0:
+            new_size = new_size << 1
+        # We rolled over our signed size field
+        if new_size <= 0:
+            raise MemoryError()
+        # Even if min_used == self._mask + 1, and we aren't changing the actual
+        # size, we will still run the algorithm so that dummy entries are
+        # removed
+        # TODO: Test this
+        # if new_size < self._used:
+        #     raise RuntimeError('cannot shrink SimpleSet to something'
+        #                        ' smaller than the number of used slots.')
+        n_bytes = sizeof(PyObject*) * new_size;
+        new_table = <PyObject **>PyMem_Malloc(n_bytes)
+        if new_table == NULL:
+            raise MemoryError()
+
+        old_table = self._table
+        self._table = new_table
+        memset(self._table, 0, n_bytes)
+        self._mask = new_size - 1
+        self._used = 0
+        remaining = self._fill
+        self._fill = 0
+
+        # Moving everything to the other table is refcount neutral, so we don't
+        # worry about it.
+        slot = old_table
+        while remaining > 0:
+            if slot[0] == NULL: # unused slot
+                pass 
+            elif slot[0] == _dummy: # dummy slot
+                remaining = remaining - 1
+            else: # active slot
+                remaining = remaining - 1
+                self._insert_clean(slot[0])
+            slot = slot + 1
+        PyMem_Free(old_table)
+        return new_size
+
+    def add(self, key):
+        """Similar to set.add(), start tracking this key.
+        
+        There is one small difference, which is that we return the object that
+        is stored at the given location. (which is closer to the
+        dict.setdefault() functionality.)
+        """
+        return self._add(key)
+
+    cdef object _add(self, key):
+        cdef PyObject **slot, *py_key
+        cdef int added
+
+        py_key = <PyObject *>key
+        if (Py_TYPE(py_key).tp_richcompare == NULL
+            or Py_TYPE(py_key).tp_hash == NULL):
+            raise TypeError('Types added to SimpleSet must implement'
+                            ' both tp_richcompare and tp_hash')
+        added = 0
+        # We need at least one empty slot
+        assert self._used < self._mask
+        slot = _lookup(self, key)
+        if (slot[0] == NULL):
+            Py_INCREF(py_key)
+            self._fill = self._fill + 1
+            self._used = self._used + 1
+            slot[0] = py_key
+            added = 1
+        elif (slot[0] == _dummy):
+            Py_INCREF(py_key)
+            self._used = self._used + 1
+            slot[0] = py_key
+            added = 1
+        # No else: clause. If _lookup returns a pointer to
+        # a live object, then we already have a value at this location.
+        retval = <object>(slot[0])
+        # PySet and PyDict use a 2-3rds full algorithm, we'll follow suit
+        if added and (self._fill * 3) >= ((self._mask + 1) * 2):
+            # However, we always work for a load factor of 2:1
+            self._resize(self._used * 2)
+        # Even if we resized and ended up moving retval into a different slot,
+        # it is still the value that is held at the slot equivalent to 'key',
+        # so we can still return it
+        return retval
+
+    def discard(self, key):
+        """Remove key from the set, whether it exists or not.
+
+        :return: False if the item did not exist, True if it did
+        """
+        if self._discard(key):
+            return True
+        return False
+
+    cdef int _discard(self, key) except -1:
+        cdef PyObject **slot, *py_key
+
+        slot = _lookup(self, key)
+        if slot[0] == NULL or slot[0] == _dummy:
+            return 0
+        self._used = self._used - 1
+        Py_DECREF(slot[0])
+        slot[0] = _dummy
+        # PySet uses the heuristic: If more than 1/5 are dummies, then resize
+        #                           them away
+        #   if ((so->_fill - so->_used) * 5 < so->mask)
+        # However, we are planning on using this as an interning structure, in
+        # which we will be putting a lot of objects. And we expect that large
+        # groups of them are going to have the same lifetime.
+        # Dummy entries hurt a little bit because they cause the lookup to keep
+        # searching, but resizing is also rather expensive
+        # For now, we'll just use their algorithm, but we may want to revisit
+        # it
+        if ((self._fill - self._used) * 5 > self._mask):
+            self._resize(self._used * 2)
+        return 1
+
+    def __iter__(self):
+        return _SimpleSet_iterator(self)
+
+
+cdef class _SimpleSet_iterator:
+    """Iterator over the SimpleSet structure."""
+
+    cdef Py_ssize_t pos
+    cdef SimpleSet set
+    cdef Py_ssize_t _used # track if things have been mutated while iterating
+    cdef Py_ssize_t len # number of entries left
+
+    def __init__(self, obj):
+        self.set = obj
+        self.pos = 0
+        self._used = self.set._used
+        self.len = self.set._used
+
+    def __iter__(self):
+        return self
+
+    def __next__(self):
+        cdef Py_ssize_t mask, i
+        cdef PyObject *key
+
+        if self.set is None:
+            raise StopIteration
+        if self.set._used != self._used:
+            # Force this exception to continue to be raised
+            self._used = -1
+            raise RuntimeError("Set size changed during iteration")
+        if not SimpleSet_Next(self.set, &self.pos, &key):
+            self.set = None
+            raise StopIteration
+        # we found something
+        the_key = <object>key # INCREF
+        self.len = self.len - 1
+        return the_key
+
+    def __length_hint__(self):
+        if self.set is not None and self._used == self.set._used:
+            return self.len
+        return 0
+    
+
+
+cdef api SimpleSet SimpleSet_New():
+    """Create a new SimpleSet object."""
+    return SimpleSet()
+
+
+cdef SimpleSet _check_self(object self):
+    """Check that the parameter is not None.
+
+    Pyrex/Cython will do type checking, but only to ensure that an object is
+    either the right type or None. You can say "object foo not None" for pure
+    python functions, but not for C functions.
+    So this is just a helper for all the apis that need to do the check.
+    """
+    cdef SimpleSet true_self
+    if self is None:
+        raise TypeError('self must not be None')
+    true_self = self
+    return true_self
+
+
+cdef PyObject **_lookup(SimpleSet self, object key) except NULL:
+    """Find the slot where 'key' would fit.
+
+    This is the same as a dicts 'lookup' function.
+
+    :param key: An object we are looking up
+    :param hash: The hash for key
+    :return: The location in self.table where key should be put.
+        location == NULL is an exception, but (*location) == NULL just
+        indicates the slot is empty and can be used.
+    """
+    # This uses Quadratic Probing:
+    #  http://en.wikipedia.org/wiki/Quadratic_probing
+    # with c1 = c2 = 1/2
+    # This leads to probe locations at:
+    #  h0 = hash(k1)
+    #  h1 = h0 + 1
+    #  h2 = h0 + 3 = h1 + 1 + 1
+    #  h3 = h0 + 6 = h2 + 1 + 2
+    #  h4 = h0 + 10 = h2 + 1 + 3
+    # Note that all of these are '& mask', but that is computed *after* the
+    # offset.
+    # This differs from the algorithm used by Set and Dict. Which, effectively,
+    # use double-hashing, and a step size that starts large, but dwindles to
+    # stepping one-by-one.
+    # This gives more 'locality' in that if you have a collision at offset X,
+    # the first fallback is X+1, which is fast to check. However, that means
+    # that an object w/ hash X+1 will also check there, and then X+2 next.
+    # However, for objects with differing hashes, their chains are different.
+    # The former checks X, X+1, X+3, ... the latter checks X+1, X+2, X+4, ...
+    # So different hashes diverge quickly.
+    # A bigger problem is that we *only* ever use the lowest bits of the hash
+    # So all integers (x + SIZE*N) will resolve into the same bucket, and all
+    # use the same collision resolution. We may want to try to find a way to
+    # incorporate the upper bits of the hash with quadratic probing. (For
+    # example, X, X+1, X+3+some_upper_bits, X+6+more_upper_bits, etc.)
+    cdef size_t i, n_lookup
+    cdef Py_ssize_t mask
+    cdef long key_hash
+    cdef PyObject **table, **slot, *cur, **free_slot, *py_key
+
+    py_key = <PyObject *>key
+    # Note: avoid using hash(obj) because of a bug w/ pyrex 0.9.8.5 and 64-bit
+    #       (it treats hash() as returning an 'int' rather than a 'long')
+    key_hash = PyObject_Hash(py_key)
+    i = <size_t>key_hash
+    mask = self._mask
+    table = self._table
+    free_slot = NULL
+    for n_lookup from 0 <= n_lookup <= <size_t>mask: # Don't loop forever
+        slot = &table[i & mask]
+        cur = slot[0]
+        if cur == NULL:
+            # Found a blank spot
+            if free_slot != NULL:
+                # Did we find an earlier _dummy entry?
+                return free_slot
+            else:
+                return slot
+        if cur == py_key:
+            # Found an exact pointer to the key
+            return slot
+        if cur == _dummy:
+            if free_slot == NULL:
+                free_slot = slot
+        elif _is_equal(py_key, key_hash, cur):
+            # Both py_key and cur belong in this slot, return it
+            return slot
+        i = i + 1 + n_lookup
+    raise AssertionError('should never get here')
+
+
+cdef api PyObject **_SimpleSet_Lookup(object self, object key) except NULL:
+    """Find the slot where 'key' would fit.
+
+    This is the same as a dicts 'lookup' function. This is a private
+    api because mutating what you get without maintaing the other invariants
+    is a 'bad thing'.
+
+    :param key: An object we are looking up
+    :param hash: The hash for key
+    :return: The location in self._table where key should be put
+        should never be NULL, but may reference a NULL (PyObject*)
+    """
+    return _lookup(_check_self(self), key)
+
+
+cdef api object SimpleSet_Add(object self, object key):
+    """Add a key to the SimpleSet (set).
+
+    :param self: The SimpleSet to add the key to.
+    :param key: The key to be added. If the key is already present,
+        self will not be modified
+    :return: The current key stored at the location defined by 'key'.
+        This may be the same object, or it may be an equivalent object.
+        (consider dict.setdefault(key, key))
+    """
+    return _check_self(self)._add(key)
+    
+
+cdef api int SimpleSet_Contains(object self, object key) except -1:
+    """Is key present in self?"""
+    return (key in _check_self(self))
+
+
+cdef api int SimpleSet_Discard(object self, object key) except -1:
+    """Remove the object referenced at location 'key'.
+
+    :param self: The SimpleSet being modified
+    :param key: The key we are checking on
+    :return: 1 if there was an object present, 0 if there was not, and -1 on
+        error.
+    """
+    return _check_self(self)._discard(key)
+
+
+cdef api PyObject *SimpleSet_Get(SimpleSet self, object key) except? NULL:
+    """Get a pointer to the object present at location 'key'.
+
+    This returns an object which is equal to key which was previously added to
+    self. This returns a borrowed reference, as it may also return NULL if no
+    value is present at that location.
+
+    :param key: The value we are looking for
+    :return: The object present at that location
+    """
+    return _check_self(self)._get(key)
+
+
+cdef api Py_ssize_t SimpleSet_Size(object self) except -1:
+    """Get the number of active entries in 'self'"""
+    return _check_self(self)._used
+
+
+cdef api int SimpleSet_Next(object self, Py_ssize_t *pos, PyObject **key):
+    """Walk over items in a SimpleSet.
+
+    :param pos: should be initialized to 0 by the caller, and will be updated
+        by this function
+    :param key: Will return a borrowed reference to key
+    :return: 0 if nothing left, 1 if we are returning a new value
+    """
+    cdef Py_ssize_t i, mask
+    cdef SimpleSet true_self
+    cdef PyObject **table
+    true_self = _check_self(self)
+    i = pos[0]
+    if (i < 0):
+        return 0
+    mask = true_self._mask
+    table= true_self._table
+    while (i <= mask and (table[i] == NULL or table[i] == _dummy)):
+        i = i + 1
+    pos[0] = i + 1
+    if (i > mask):
+        return 0 # All done
+    if (key != NULL):
+        key[0] = table[i]
+    return 1
+
+
+cdef int SimpleSet_traverse(SimpleSet self, visitproc visit, void *arg):
+    """This is an implementation of 'tp_traverse' that hits the whole table.
+
+    Cython/Pyrex don't seem to let you define a tp_traverse, and they only
+    define one for you if you have an 'object' attribute. Since they don't
+    support C arrays of objects, we access the PyObject * directly.
+    """
+    cdef Py_ssize_t pos
+    cdef PyObject *next_key
+    cdef int ret
+
+    pos = 0
+    while SimpleSet_Next(self, &pos, &next_key):
+        ret = visit(next_key, arg)
+        if ret:
+            return ret
+    return 0
+
+# It is a little bit ugly to do this, but it works, and means that Meliae can
+# dump the total memory consumed by all child objects.
+(<PyTypeObject *>SimpleSet).tp_traverse = <traverseproc>SimpleSet_traverse

=== added file 'bzrlib/_static_tuple_c.c'
--- bzrlib/_static_tuple_c.c	1970-01-01 00:00:00 +0000
+++ bzrlib/_static_tuple_c.c	2009-10-27 14:07:16 +0000
@@ -0,0 +1,941 @@
+/* Copyright (C) 2009 Canonical Ltd
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+/* Must be defined before importing _static_tuple_c.h so that we get the right
+ * linkage.
+ */
+#define STATIC_TUPLE_MODULE
+
+#include <Python.h>
+#include "python-compat.h"
+
+#include "_static_tuple_c.h"
+#include "_export_c_api.h"
+
+/* Pyrex 0.9.6.4 exports _simple_set_pyx_api as
+ * import__simple_set_pyx(), while Pyrex 0.9.8.5 and Cython 0.11.3 export them
+ * as import_bzrlib___simple_set_pyx(). As such, we just #define one to be
+ * equivalent to the other in our internal code.
+ */
+#define import__simple_set_pyx import_bzrlib___simple_set_pyx
+#include "_simple_set_pyx_api.h"
+
+#if defined(__GNUC__)
+#   define inline __inline__
+#elif defined(_MSC_VER)
+#   define inline __inline
+#else
+#   define inline
+#endif
+
+
+/* The one and only StaticTuple with no values */
+static StaticTuple *_empty_tuple = NULL;
+static PyObject *_interned_tuples = NULL;
+
+
+static inline int
+_StaticTuple_is_interned(StaticTuple *self)
+{
+    return self->flags & STATIC_TUPLE_INTERNED_FLAG;
+}
+
+
+
+static PyObject *
+StaticTuple_as_tuple(StaticTuple *self)
+{
+    PyObject *tpl = NULL, *obj = NULL;
+    int i, len;
+
+    len = self->size;
+    tpl = PyTuple_New(len);
+    if (!tpl) {
+        /* Malloc failure */
+        return NULL;
+    }
+    for (i = 0; i < len; ++i) {
+        obj = (PyObject *)self->items[i];
+        Py_INCREF(obj);
+        PyTuple_SET_ITEM(tpl, i, obj);
+    }
+    return tpl;
+}
+
+
+static char StaticTuple_as_tuple_doc[] = "as_tuple() => tuple";
+
+static StaticTuple *
+StaticTuple_Intern(StaticTuple *self)
+{
+    PyObject *canonical_tuple = NULL;
+
+    if (_interned_tuples == NULL || _StaticTuple_is_interned(self)) {
+        Py_INCREF(self);
+        return self;
+    }
+    /* SimpleSet_Add returns whatever object is present at self
+     * or the new object if it needs to add it.
+     */
+    canonical_tuple = SimpleSet_Add(_interned_tuples, (PyObject *)self);
+    if (!canonical_tuple) {
+        // Some sort of exception, propogate it.
+        return NULL;
+    }
+    if (canonical_tuple != (PyObject *)self) {
+        // There was already a tuple with that value
+        return (StaticTuple *)canonical_tuple;
+    }
+    self->flags |= STATIC_TUPLE_INTERNED_FLAG;
+    // The two references in the dict do not count, so that the StaticTuple
+    // object does not become immortal just because it was interned.
+    Py_REFCNT(self) -= 1;
+    return self;
+}
+
+static char StaticTuple_Intern_doc[] = "intern() => unique StaticTuple\n"
+    "Return a 'canonical' StaticTuple object.\n"
+    "Similar to intern() for strings, this makes sure there\n"
+    "is only one StaticTuple object for a given value\n."
+    "Common usage is:\n"
+    "  key = StaticTuple('foo', 'bar').intern()\n";
+
+
+static void
+StaticTuple_dealloc(StaticTuple *self)
+{
+    int i, len;
+
+    if (_StaticTuple_is_interned(self)) {
+        /* revive dead object temporarily for Discard */
+        Py_REFCNT(self) = 2;
+        if (SimpleSet_Discard(_interned_tuples, (PyObject*)self) != 1)
+            Py_FatalError("deletion of interned StaticTuple failed");
+        self->flags &= ~STATIC_TUPLE_INTERNED_FLAG;
+    }
+    len = self->size;
+    for (i = 0; i < len; ++i) {
+        Py_XDECREF(self->items[i]);
+    }
+    Py_TYPE(self)->tp_free((PyObject *)self);
+}
+
+
+/* Similar to PyTuple_New() */
+static StaticTuple *
+StaticTuple_New(Py_ssize_t size)
+{
+    StaticTuple *stuple;
+    if (size < 0) {
+        PyErr_BadInternalCall();
+        return NULL;
+    }
+
+    if (size < 0 || size > 255) {
+        /* Too big or too small */
+        PyErr_SetString(PyExc_ValueError, "StaticTuple(...)"
+            " takes from 0 to 255 items");
+        return NULL;
+    }
+    if (size == 0 && _empty_tuple != NULL) {
+        Py_INCREF(_empty_tuple);
+        return _empty_tuple;
+    }
+    /* Note that we use PyObject_NewVar because we want to allocate a variable
+     * width entry. However we *aren't* truly a PyVarObject because we don't
+     * use a long for ob_size. Instead we use a plain 'size' that is an int,
+     * and will be overloaded with flags in the future.
+     * As such we do the alloc, and then have to clean up anything it does
+     * incorrectly.
+     */
+    stuple = PyObject_NewVar(StaticTuple, &StaticTuple_Type, size);
+    if (stuple == NULL) {
+        return NULL;
+    }
+    stuple->size = size;
+    stuple->flags = 0;
+    stuple->_unused0 = 0;
+    stuple->_unused1 = 0;
+    if (size > 0) {
+        memset(stuple->items, 0, sizeof(PyObject *) * size);
+    }
+#if STATIC_TUPLE_HAS_HASH
+    stuple->hash = -1;
+#endif
+    return stuple;
+}
+
+
+static StaticTuple *
+StaticTuple_FromSequence(PyObject *sequence)
+{
+    StaticTuple *new = NULL;
+    PyObject *as_tuple = NULL;
+    PyObject *item;
+    Py_ssize_t i, size;
+
+    if (StaticTuple_CheckExact(sequence)) {
+        Py_INCREF(sequence);
+        return (StaticTuple *)sequence;
+    }
+    if (!PySequence_Check(sequence)) {
+        as_tuple = PySequence_Tuple(sequence);
+        if (as_tuple == NULL)
+            goto done;
+        sequence = as_tuple;
+    }
+    size = PySequence_Size(sequence);
+    if (size == -1) {
+        goto done;
+    }
+    new = StaticTuple_New(size);
+    if (new == NULL) {
+        goto done;
+    }
+    for (i = 0; i < size; ++i) {
+        // This returns a new reference, which we then 'steal' with 
+        // StaticTuple_SET_ITEM
+        item = PySequence_GetItem(sequence, i);
+        if (item == NULL) {
+            Py_DECREF(new);
+            new = NULL;
+            goto done;
+        }
+        StaticTuple_SET_ITEM(new, i, item);
+    }
+done:
+    Py_XDECREF(as_tuple);
+    return (StaticTuple *)new;
+}
+
+static StaticTuple *
+StaticTuple_from_sequence(PyObject *self, PyObject *args, PyObject *kwargs)
+{
+    PyObject *sequence;
+    if (!PyArg_ParseTuple(args, "O", &sequence))
+        return NULL;
+    return StaticTuple_FromSequence(sequence);
+}
+
+
+/* Check that all items we point to are 'valid' */
+static int
+StaticTuple_check_items(StaticTuple *self)
+{
+    int i;
+    PyObject *obj;
+
+    for (i = 0; i < self->size; ++i) {
+        obj = self->items[i];
+        if (obj == NULL) {
+            PyErr_SetString(PyExc_RuntimeError, "StaticTuple(...)"
+                " should not have a NULL entry.");
+            return 0;
+        }
+        if (PyString_CheckExact(obj)
+            || StaticTuple_CheckExact(obj)
+            || obj == Py_None
+            || PyBool_Check(obj)
+            || PyInt_CheckExact(obj)
+            || PyLong_CheckExact(obj)
+            || PyFloat_CheckExact(obj)
+            || PyUnicode_CheckExact(obj)
+            ) continue;
+        PyErr_Format(PyExc_TypeError, "StaticTuple(...)"
+            " requires that all items are one of"
+            " str, StaticTuple, None, bool, int, long, float, or unicode"
+            " not %s.", Py_TYPE(obj)->tp_name);
+        return 0;
+    }
+    return 1;
+}
+
+static PyObject *
+StaticTuple_new_constructor(PyTypeObject *type, PyObject *args, PyObject *kwds)
+{
+    StaticTuple *self;
+    PyObject *obj = NULL;
+    Py_ssize_t i, len = 0;
+
+    if (type != &StaticTuple_Type) {
+        PyErr_SetString(PyExc_TypeError, "we only support creating StaticTuple");
+        return NULL;
+    }
+    if (!PyTuple_CheckExact(args)) {
+        PyErr_SetString(PyExc_TypeError, "args must be a tuple");
+        return NULL;
+    }
+    len = PyTuple_GET_SIZE(args);
+    self = (StaticTuple *)StaticTuple_New(len);
+    if (self == NULL) {
+        return NULL;
+    }
+    for (i = 0; i < len; ++i) {
+        obj = PyTuple_GET_ITEM(args, i);
+        Py_INCREF(obj);
+        self->items[i] = obj;
+    }
+    if (!StaticTuple_check_items(self)) {
+        type->tp_dealloc((PyObject *)self);
+        return NULL;
+    }
+    return (PyObject *)self;
+}
+
+static PyObject *
+StaticTuple_repr(StaticTuple *self)
+{
+    PyObject *as_tuple, *tuple_repr, *result;
+
+    as_tuple = StaticTuple_as_tuple(self);
+    if (as_tuple == NULL) {
+        return NULL;
+    }
+    tuple_repr = PyObject_Repr(as_tuple);
+    Py_DECREF(as_tuple);
+    if (tuple_repr == NULL) {
+        return NULL;
+    }
+    result = PyString_FromFormat("StaticTuple%s",
+                                 PyString_AsString(tuple_repr));
+    return result;
+}
+
+static long
+StaticTuple_hash(StaticTuple *self)
+{
+    /* adapted from tuplehash(), is the specific hash value considered
+     * 'stable'?
+     */
+    register long x, y;
+    Py_ssize_t len = self->size;
+    PyObject **p;
+    long mult = 1000003L;
+
+#if STATIC_TUPLE_HAS_HASH
+    if (self->hash != -1) {
+        return self->hash;
+    }
+#endif
+    x = 0x345678L;
+    p = self->items;
+    // TODO: We could set specific flags if we know that, for example, all the
+    //       items are strings. I haven't seen a real-world benefit to that
+    //       yet, though.
+    while (--len >= 0) {
+        y = PyObject_Hash(*p++);
+        if (y == -1) /* failure */
+            return -1;
+        x = (x ^ y) * mult;
+        /* the cast might truncate len; that doesn't change hash stability */
+        mult += (long)(82520L + len + len);
+    }
+    x += 97531L;
+    if (x == -1)
+        x = -2;
+#if STATIC_TUPLE_HAS_HASH
+    self->hash = x;
+#endif
+    return x;
+}
+
+static PyObject *
+StaticTuple_richcompare_to_tuple(StaticTuple *v, PyObject *wt, int op)
+{
+    PyObject *vt;
+    PyObject *result = NULL;
+    
+    vt = StaticTuple_as_tuple((StaticTuple *)v);
+    if (vt == NULL) {
+        goto done;
+    }
+    if (!PyTuple_Check(wt)) {
+        PyErr_BadInternalCall();
+        goto done;
+    }
+    /* Now we have 2 tuples to compare, do it */
+    result = PyTuple_Type.tp_richcompare(vt, wt, op);
+done:
+    Py_XDECREF(vt);
+    return result;
+}
+
+/** Compare two objects to determine if they are equivalent.
+ * The basic flow is as follows
+ *  1) First make sure that both objects are StaticTuple instances. If they
+ *     aren't then cast self to a tuple, and have the tuple do the comparison.
+ *  2) Special case comparison to Py_None, because it happens to occur fairly
+ *     often in the test suite.
+ *  3) Special case when v and w are the same pointer. As we know the answer to
+ *     all queries without walking individual items.
+ *  4) For all operations, we then walk the items to find the first paired
+ *     items that are not equal.
+ *  5) If all items found are equal, we then check the length of self and
+ *     other to determine equality.
+ *  6) If an item differs, then we apply "op" to those last two items. (eg.
+ *     StaticTuple(A, B) > StaticTuple(A, C) iff B > C)
+ */
+
+static PyObject *
+StaticTuple_richcompare(PyObject *v, PyObject *w, int op)
+{
+    StaticTuple *v_st, *w_st;
+    Py_ssize_t vlen, wlen, min_len, i;
+    PyObject *v_obj, *w_obj;
+    richcmpfunc string_richcompare;
+
+    if (!StaticTuple_CheckExact(v)) {
+        /* This has never triggered, according to python-dev it seems this
+         * might trigger if '__op__' is defined but '__rop__' is not, sort of
+         * case. Such as "None == StaticTuple()"
+         */
+        fprintf(stderr, "self is not StaticTuple\n");
+        Py_INCREF(Py_NotImplemented);
+        return Py_NotImplemented;
+    }
+    v_st = (StaticTuple *)v;
+    if (StaticTuple_CheckExact(w)) {
+        /* The most common case */
+        w_st = (StaticTuple*)w;
+    } else if (PyTuple_Check(w)) {
+        /* One of v or w is a tuple, so we go the 'slow' route and cast up to
+         * tuples to compare.
+         */
+        /* TODO: This seems to be triggering more than I thought it would...
+         *       We probably want to optimize comparing self to other when
+         *       other is a tuple.
+         */
+        return StaticTuple_richcompare_to_tuple(v_st, w, op);
+    } else if (w == Py_None) {
+        // None is always less than the object
+        switch (op) {
+        case Py_NE:case Py_GT:case Py_GE:
+            Py_INCREF(Py_True);
+            return Py_True;
+        case Py_EQ:case Py_LT:case Py_LE:
+            Py_INCREF(Py_False);
+            return Py_False;
+    default: // Should never happen
+        return Py_NotImplemented;
+        }
+    } else {
+        /* We don't special case this comparison, we just let python handle
+         * it.
+         */
+         Py_INCREF(Py_NotImplemented);
+         return Py_NotImplemented;
+    }
+    /* Now we know that we have 2 StaticTuple objects, so let's compare them.
+     * This code is inspired from tuplerichcompare, except we know our
+     * objects are limited in scope, so we can inline some comparisons.
+     */
+    if (v == w) {
+        /* Identical pointers, we can shortcut this easily. */
+        switch (op) {
+        case Py_EQ:case Py_LE:case Py_GE:
+            Py_INCREF(Py_True);
+            return Py_True;
+        case Py_NE:case Py_LT:case Py_GT:
+            Py_INCREF(Py_False);
+            return Py_False;
+        }
+    }
+    if (op == Py_EQ
+        && _StaticTuple_is_interned(v_st)
+        && _StaticTuple_is_interned(w_st))
+    {
+        /* If both objects are interned, we know they are different if the
+         * pointer is not the same, which would have been handled by the
+         * previous if. No need to compare the entries.
+         */
+        Py_INCREF(Py_False);
+        return Py_False;
+    }
+
+    /* The only time we are likely to compare items of different lengths is in
+     * something like the interned_keys set. However, the hash is good enough
+     * that it is rare. Note that 'tuple_richcompare' also does not compare
+     * lengths here.
+     */
+    vlen = v_st->size;
+    wlen = w_st->size;
+    min_len = (vlen < wlen) ? vlen : wlen;
+    string_richcompare = PyString_Type.tp_richcompare;
+    for (i = 0; i < min_len; i++) {
+        PyObject *result = NULL;
+        v_obj = StaticTuple_GET_ITEM(v_st, i);
+        w_obj = StaticTuple_GET_ITEM(w_st, i);
+        if (v_obj == w_obj) {
+            /* Shortcut case, these must be identical */
+            continue;
+        }
+        if (PyString_CheckExact(v_obj) && PyString_CheckExact(w_obj)) {
+            result = string_richcompare(v_obj, w_obj, Py_EQ);
+        } else if (StaticTuple_CheckExact(v_obj) &&
+                   StaticTuple_CheckExact(w_obj))
+        {
+            /* Both are StaticTuple types, so recurse */
+            result = StaticTuple_richcompare(v_obj, w_obj, Py_EQ);
+        } else {
+            /* Fall back to generic richcompare */
+            result = PyObject_RichCompare(v_obj, w_obj, Py_EQ);
+        }
+        if (result == NULL) {
+            return NULL; /* There seems to be an error */
+        }
+        if (result == Py_False) {
+            // This entry is not identical, Shortcut for Py_EQ
+            if (op == Py_EQ) {
+                return result;
+            }
+            Py_DECREF(result);
+            break;
+        }
+        if (result != Py_True) {
+            /* We don't know *what* richcompare is returning, but it
+             * isn't something we recognize
+             */
+            PyErr_BadInternalCall();
+            Py_DECREF(result);
+            return NULL;
+        }
+        Py_DECREF(result);
+    }
+    if (i >= min_len) {
+        /* We walked off one of the lists, but everything compared equal so
+         * far. Just compare the size.
+         */
+        int cmp;
+        PyObject *res;
+        switch (op) {
+        case Py_LT: cmp = vlen <  wlen; break;
+        case Py_LE: cmp = vlen <= wlen; break;
+        case Py_EQ: cmp = vlen == wlen; break;
+        case Py_NE: cmp = vlen != wlen; break;
+        case Py_GT: cmp = vlen >  wlen; break;
+        case Py_GE: cmp = vlen >= wlen; break;
+        default: return NULL; /* cannot happen */
+        }
+        if (cmp)
+            res = Py_True;
+        else
+            res = Py_False;
+        Py_INCREF(res);
+        return res;
+    }
+    /* The last item differs, shortcut the Py_NE case */
+    if (op == Py_NE) {
+        Py_INCREF(Py_True);
+        return Py_True;
+    }
+    /* It is some other comparison, go ahead and do the real check. */
+    if (PyString_CheckExact(v_obj) && PyString_CheckExact(w_obj))
+    {
+        return string_richcompare(v_obj, w_obj, op);
+    } else if (StaticTuple_CheckExact(v_obj) &&
+               StaticTuple_CheckExact(w_obj))
+    {
+        /* Both are StaticTuple types, so recurse */
+        return StaticTuple_richcompare(v_obj, w_obj, op);
+    } else {
+        return PyObject_RichCompare(v_obj, w_obj, op);
+    }
+}
+
+
+static Py_ssize_t
+StaticTuple_length(StaticTuple *self)
+{
+    return self->size;
+}
+
+
+static PyObject *
+StaticTuple__is_interned(StaticTuple *self)
+{
+    if (_StaticTuple_is_interned(self)) {
+        Py_INCREF(Py_True);
+        return Py_True;
+    }
+    Py_INCREF(Py_False);
+    return Py_False;
+}
+
+static char StaticTuple__is_interned_doc[] = "_is_interned() => True/False\n"
+    "Check to see if this tuple has been interned.\n";
+
+
+static PyObject *
+StaticTuple_reduce(StaticTuple *self)
+{
+    PyObject *result = NULL, *as_tuple = NULL;
+
+    result = PyTuple_New(2);
+    if (!result) {
+        return NULL;
+    }
+    as_tuple = StaticTuple_as_tuple(self);
+    if (as_tuple == NULL) {
+        Py_DECREF(result);
+        return NULL;
+    }
+    Py_INCREF(&StaticTuple_Type);
+    PyTuple_SET_ITEM(result, 0, (PyObject *)&StaticTuple_Type);
+    PyTuple_SET_ITEM(result, 1, as_tuple);
+    return result;
+}
+
+static char StaticTuple_reduce_doc[] = "__reduce__() => tuple\n";
+
+
+static PyObject *
+StaticTuple_add(PyObject *v, PyObject *w)
+{
+    Py_ssize_t i, len_v, len_w;
+    PyObject *item;
+    StaticTuple *result;
+     /* StaticTuples and plain tuples may be added (concatenated) to
+      * StaticTuples.
+      */
+    if (StaticTuple_CheckExact(v)) {
+        len_v = ((StaticTuple*)v)->size;
+    } else if (PyTuple_Check(v)) {
+        len_v = PyTuple_GET_SIZE(v);
+    } else {
+        Py_INCREF(Py_NotImplemented);
+        return Py_NotImplemented;
+    }
+    if (StaticTuple_CheckExact(w)) {
+        len_w = ((StaticTuple*)w)->size;
+    } else if (PyTuple_Check(w)) {
+        len_w = PyTuple_GET_SIZE(w);
+    } else {
+        Py_INCREF(Py_NotImplemented);
+        return Py_NotImplemented;
+    }
+    result = StaticTuple_New(len_v + len_w);
+    if (result == NULL)
+        return NULL;
+    for (i = 0; i < len_v; ++i) {
+        // This returns a new reference, which we then 'steal' with 
+        // StaticTuple_SET_ITEM
+        item = PySequence_GetItem(v, i);
+        if (item == NULL) {
+            Py_DECREF(result);
+            return NULL;
+        }
+        StaticTuple_SET_ITEM(result, i, item);
+    }
+    for (i = 0; i < len_w; ++i) {
+        item = PySequence_GetItem(w, i);
+        if (item == NULL) {
+            Py_DECREF(result);
+            return NULL;
+        }
+        StaticTuple_SET_ITEM(result, i+len_v, item);
+    }
+    if (!StaticTuple_check_items(result)) {
+        Py_DECREF(result);
+        return NULL;
+    }
+    return (PyObject *)result;
+}
+
+static PyObject *
+StaticTuple_item(StaticTuple *self, Py_ssize_t offset)
+{
+    PyObject *obj;
+    /* We cast to (int) to avoid worrying about whether Py_ssize_t is a
+     * long long, etc. offsets should never be >2**31 anyway.
+     */
+    if (offset < 0) {
+        PyErr_Format(PyExc_IndexError, "StaticTuple_item does not support"
+            " negative indices: %d\n", (int)offset);
+    } else if (offset >= self->size) {
+        PyErr_Format(PyExc_IndexError, "StaticTuple index out of range"
+            " %d >= %d", (int)offset, (int)self->size);
+        return NULL;
+    }
+    obj = (PyObject *)self->items[offset];
+    Py_INCREF(obj);
+    return obj;
+}
+
+static PyObject *
+StaticTuple_slice(StaticTuple *self, Py_ssize_t ilow, Py_ssize_t ihigh)
+{
+    PyObject *as_tuple, *result;
+
+    as_tuple = StaticTuple_as_tuple(self);
+    if (as_tuple == NULL) {
+        return NULL;
+    }
+    result = PyTuple_Type.tp_as_sequence->sq_slice(as_tuple, ilow, ihigh);
+    Py_DECREF(as_tuple);
+    return result;
+}
+
+static int
+StaticTuple_traverse(StaticTuple *self, visitproc visit, void *arg)
+{
+    Py_ssize_t i;
+    for (i = self->size; --i >= 0;) {
+        Py_VISIT(self->items[i]);
+    }
+    return 0;
+}
+
+static char StaticTuple_doc[] =
+    "C implementation of a StaticTuple structure."
+    "\n This is used as StaticTuple(item1, item2, item3)"
+    "\n This is similar to tuple, less flexible in what it"
+    "\n supports, but also lighter memory consumption."
+    "\n Note that the constructor mimics the () form of tuples"
+    "\n Rather than the 'tuple()' constructor."
+    "\n  eg. StaticTuple(a, b) == (a, b) == tuple((a, b))";
+
+static PyMethodDef StaticTuple_methods[] = {
+    {"as_tuple", (PyCFunction)StaticTuple_as_tuple, METH_NOARGS, StaticTuple_as_tuple_doc},
+    {"intern", (PyCFunction)StaticTuple_Intern, METH_NOARGS, StaticTuple_Intern_doc},
+    {"_is_interned", (PyCFunction)StaticTuple__is_interned, METH_NOARGS,
+     StaticTuple__is_interned_doc},
+    {"from_sequence", (PyCFunction)StaticTuple_from_sequence,
+     METH_STATIC | METH_VARARGS,
+     "Create a StaticTuple from a given sequence. This functions"
+     " the same as the tuple() constructor."},
+    {"__reduce__", (PyCFunction)StaticTuple_reduce, METH_NOARGS, StaticTuple_reduce_doc},
+    {NULL, NULL} /* sentinel */
+};
+
+
+static PyNumberMethods StaticTuple_as_number = {
+    (binaryfunc) StaticTuple_add,   /* nb_add */
+    0,                              /* nb_subtract */
+    0,                              /* nb_multiply */
+    0,                              /* nb_divide */
+    0,                              /* nb_remainder */
+    0,                              /* nb_divmod */
+    0,                              /* nb_power */
+    0,                              /* nb_negative */
+    0,                              /* nb_positive */
+    0,                              /* nb_absolute */
+    0,                              /* nb_nonzero */
+    0,                              /* nb_invert */
+    0,                              /* nb_lshift */
+    0,                              /* nb_rshift */
+    0,                              /* nb_and */
+    0,                              /* nb_xor */
+    0,                              /* nb_or */
+    0,                              /* nb_coerce */
+};
+    
+
+static PySequenceMethods StaticTuple_as_sequence = {
+    (lenfunc)StaticTuple_length,            /* sq_length */
+    0,                              /* sq_concat */
+    0,                              /* sq_repeat */
+    (ssizeargfunc)StaticTuple_item,         /* sq_item */
+    (ssizessizeargfunc)StaticTuple_slice,   /* sq_slice */
+    0,                              /* sq_ass_item */
+    0,                              /* sq_ass_slice */
+    0,                              /* sq_contains */
+};
+
+/* TODO: Implement StaticTuple_as_mapping.
+ *       The only thing we really want to support from there is mp_subscript,
+ *       so that we could support extended slicing (foo[::2]). Not worth it
+ *       yet, though.
+ */
+
+
+PyTypeObject StaticTuple_Type = {
+    PyObject_HEAD_INIT(NULL)
+    0,                                           /* ob_size */
+    "bzrlib._static_tuple_c.StaticTuple",        /* tp_name */
+    sizeof(StaticTuple),                         /* tp_basicsize */
+    sizeof(PyObject *),                          /* tp_itemsize */
+    (destructor)StaticTuple_dealloc,             /* tp_dealloc */
+    0,                                           /* tp_print */
+    0,                                           /* tp_getattr */
+    0,                                           /* tp_setattr */
+    0,                                           /* tp_compare */
+    (reprfunc)StaticTuple_repr,                  /* tp_repr */
+    &StaticTuple_as_number,                      /* tp_as_number */
+    &StaticTuple_as_sequence,                    /* tp_as_sequence */
+    0,                                           /* tp_as_mapping */
+    (hashfunc)StaticTuple_hash,                  /* tp_hash */
+    0,                                           /* tp_call */
+    0,                                           /* tp_str */
+    0,                                           /* tp_getattro */
+    0,                                           /* tp_setattro */
+    0,                                           /* tp_as_buffer */
+    /* Py_TPFLAGS_CHECKTYPES tells the number operations that they shouldn't
+     * try to 'coerce' but instead stuff like 'add' will check it arguments.
+     */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_CHECKTYPES,  /* tp_flags*/
+    StaticTuple_doc,                             /* tp_doc */
+    /* gc.get_referents checks the IS_GC flag before it calls tp_traverse
+     * And we don't include this object in the garbage collector because we
+     * know it doesn't create cycles. However, 'meliae' will follow
+     * tp_traverse, even if the object isn't GC, and we want that.
+     */
+    (traverseproc)StaticTuple_traverse,          /* tp_traverse */
+    0,                                           /* tp_clear */
+    StaticTuple_richcompare,                     /* tp_richcompare */
+    0,                                           /* tp_weaklistoffset */
+    // without implementing tp_iter, Python will fall back to PySequence*
+    // which seems to work ok, we may need something faster/lighter in the
+    // future.
+    0,                                           /* tp_iter */
+    0,                                           /* tp_iternext */
+    StaticTuple_methods,                         /* tp_methods */
+    0,                                           /* tp_members */
+    0,                                           /* tp_getset */
+    0,                                           /* tp_base */
+    0,                                           /* tp_dict */
+    0,                                           /* tp_descr_get */
+    0,                                           /* tp_descr_set */
+    0,                                           /* tp_dictoffset */
+    0,                                           /* tp_init */
+    0,                                           /* tp_alloc */
+    StaticTuple_new_constructor,                 /* tp_new */
+};
+
+
+static PyMethodDef static_tuple_c_methods[] = {
+    {NULL, NULL}
+};
+
+
+static void
+setup_interned_tuples(PyObject *m)
+{
+    _interned_tuples = (PyObject *)SimpleSet_New();
+    if (_interned_tuples != NULL) {
+        Py_INCREF(_interned_tuples);
+        PyModule_AddObject(m, "_interned_tuples", _interned_tuples);
+    }
+}
+
+
+static void
+setup_empty_tuple(PyObject *m)
+{
+    StaticTuple *stuple;
+    if (_interned_tuples == NULL) {
+        fprintf(stderr, "You need to call setup_interned_tuples() before"
+                " setup_empty_tuple, because we intern it.\n");
+    }
+    // We need to create the empty tuple
+    stuple = (StaticTuple *)StaticTuple_New(0);
+    _empty_tuple = StaticTuple_Intern(stuple);
+    assert(_empty_tuple == stuple);
+    // At this point, refcnt is 2: 1 from New(), and 1 from the return from
+    // intern(). We will keep 1 for the _empty_tuple global, and use the other
+    // for the module reference.
+    PyModule_AddObject(m, "_empty_tuple", (PyObject *)_empty_tuple);
+}
+
+static int
+_StaticTuple_CheckExact(PyObject *obj)
+{
+    return StaticTuple_CheckExact(obj);
+}
+
+static void
+setup_c_api(PyObject *m)
+{
+    _export_function(m, "StaticTuple_New", StaticTuple_New,
+        "StaticTuple *(Py_ssize_t)");
+    _export_function(m, "StaticTuple_Intern", StaticTuple_Intern,
+        "StaticTuple *(StaticTuple *)");
+    _export_function(m, "StaticTuple_FromSequence", StaticTuple_FromSequence,
+        "StaticTuple *(PyObject *)");
+    _export_function(m, "_StaticTuple_CheckExact", _StaticTuple_CheckExact,
+        "int(PyObject *)");
+}
+
+
+static int
+_workaround_pyrex_096(void)
+{
+    /* Work around an incompatibility in how pyrex 0.9.6 exports a module,
+     * versus how pyrex 0.9.8 and cython 0.11 export it.
+     * Namely 0.9.6 exports import__simple_set_pyx and tries to
+     * "import _simple_set_pyx" but it is available only as
+     * "import bzrlib._simple_set_pyx"
+     * It is a shame to hack up sys.modules, but that is what we've got to do.
+     */
+    PyObject *sys_module = NULL, *modules = NULL, *set_module = NULL;
+    int retval = -1;
+
+    /* Clear out the current ImportError exception, and try again. */
+    PyErr_Clear();
+    /* Note that this only seems to work if somewhere else imports
+     * bzrlib._simple_set_pyx before importing bzrlib._static_tuple_c
+     */
+    set_module = PyImport_ImportModule("bzrlib._simple_set_pyx");
+    if (set_module == NULL) {
+        goto end;
+    }
+    /* Add the _simple_set_pyx into sys.modules at the appropriate location. */
+    sys_module = PyImport_ImportModule("sys");
+    if (sys_module == NULL) {
+        goto end;
+    }
+    modules = PyObject_GetAttrString(sys_module, "modules");
+    if (modules == NULL || !PyDict_Check(modules)) {
+        goto end;
+    }
+    PyDict_SetItemString(modules, "_simple_set_pyx", set_module);
+    /* Now that we have hacked it in, try the import again. */
+    retval = import_bzrlib___simple_set_pyx();
+end:
+    Py_XDECREF(set_module);
+    Py_XDECREF(sys_module);
+    Py_XDECREF(modules);
+    return retval;
+}
+
+
+PyMODINIT_FUNC
+init_static_tuple_c(void)
+{
+    PyObject* m;
+
+    StaticTuple_Type.tp_getattro = PyObject_GenericGetAttr;
+    if (PyType_Ready(&StaticTuple_Type) < 0)
+        return;
+
+    m = Py_InitModule3("_static_tuple_c", static_tuple_c_methods,
+                       "C implementation of a StaticTuple structure");
+    if (m == NULL)
+      return;
+
+    Py_INCREF(&StaticTuple_Type);
+    PyModule_AddObject(m, "StaticTuple", (PyObject *)&StaticTuple_Type);
+    if (import_bzrlib___simple_set_pyx() == -1
+        && _workaround_pyrex_096() == -1)
+    {
+        return;
+    }
+    setup_interned_tuples(m);
+    setup_empty_tuple(m);
+    setup_c_api(m);
+}
+
+// vim: tabstop=4 sw=4 expandtab

=== added file 'bzrlib/_static_tuple_c.h'
--- bzrlib/_static_tuple_c.h	1970-01-01 00:00:00 +0000
+++ bzrlib/_static_tuple_c.h	2009-10-13 18:00:16 +0000
@@ -0,0 +1,116 @@
+/* Copyright (C) 2009 Canonical Ltd
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+#ifndef _STATIC_TUPLE_H_
+#define _STATIC_TUPLE_H_
+#include <Python.h>
+#include <string.h>
+
+#define STATIC_TUPLE_HAS_HASH 0
+/* Caching the hash adds memory, but allows us to save a little time during
+ * lookups. TIMEIT hash(key) shows it as
+ *  0.108usec w/ hash
+ *  0.160usec w/o hash
+ * Note that the entries themselves are strings, which already cache their
+ * hashes. So while there is a 1.5:1 difference in the time for hash(), it is
+ * already a function which is quite fast. Probably the only reason we might
+ * want to do so, is if we customized SimpleSet to the point that the item
+ * pointers were exactly certain types, and then accessed table[i]->hash
+ * directly. So far StaticTuple_hash() is fast enough to not warrant the memory
+ * difference.
+ */
+
+/* This defines a single variable-width key.
+ * It is basically the same as a tuple, but
+ * 1) Lighter weight in memory
+ * 2) Only supports strings or other static types (that don't reference other
+ *    objects.)
+ */
+
+#define STATIC_TUPLE_INTERNED_FLAG 0x01
+typedef struct {
+    PyObject_HEAD
+    // We could go with unsigned short here, and support 64k width tuples
+    // without any memory impact, might be worthwhile
+    unsigned char size;
+    unsigned char flags;
+    unsigned char _unused0;
+    unsigned char _unused1;
+    // Note that on 64-bit, we actually have 4-more unused bytes
+    // because items will always be aligned to a 64-bit boundary
+#if STATIC_TUPLE_HAS_HASH
+    long hash;
+#endif
+    PyObject *items[0];
+} StaticTuple;
+extern PyTypeObject StaticTuple_Type;
+
+typedef struct {
+    PyObject_VAR_HEAD
+    PyObject *table[0];
+} KeyIntern;
+
+#define StaticTuple_SET_ITEM(key, offset, val) \
+    ((((StaticTuple*)(key))->items[(offset)]) = ((PyObject *)(val)))
+#define StaticTuple_GET_ITEM(key, offset) (((StaticTuple*)key)->items[offset])
+
+
+#ifdef STATIC_TUPLE_MODULE
+/* Used when compiling _static_tuple_c.c */
+
+static StaticTuple * StaticTuple_New(Py_ssize_t);
+static StaticTuple * StaticTuple_Intern(StaticTuple *self);
+static StaticTuple * StaticTuple_FromSequence(PyObject *);
+#define StaticTuple_CheckExact(op) (Py_TYPE(op) == &StaticTuple_Type)
+
+#else
+/* Used as the foreign api */
+
+#include "_import_c_api.h"
+
+static StaticTuple *(*StaticTuple_New)(Py_ssize_t);
+static StaticTuple *(*StaticTuple_Intern)(StaticTuple *);
+static StaticTuple *(*StaticTuple_FromSequence)(PyObject *);
+static PyTypeObject *_p_StaticTuple_Type;
+
+#define StaticTuple_CheckExact(op) (Py_TYPE(op) == _p_StaticTuple_Type)
+static int (*_StaticTuple_CheckExact)(PyObject *);
+
+
+/* Return -1 and set exception on error, 0 on success */
+static int
+import_static_tuple_c(void)
+{
+    struct function_description functions[] = {
+        {"StaticTuple_New", (void **)&StaticTuple_New,
+            "StaticTuple *(Py_ssize_t)"},
+        {"StaticTuple_Intern", (void **)&StaticTuple_Intern,
+            "StaticTuple *(StaticTuple *)"},
+        {"StaticTuple_FromSequence", (void **)&StaticTuple_FromSequence,
+            "StaticTuple *(PyObject *)"},
+        {"_StaticTuple_CheckExact", (void **)&_StaticTuple_CheckExact,
+            "int(PyObject *)"},
+        {NULL}};
+    struct type_description types[] = {
+        {"StaticTuple", &_p_StaticTuple_Type},
+        {NULL}};
+    return _import_extension_module("bzrlib._static_tuple_c",
+        functions, types);
+}
+
+#endif // !STATIC_TUPLE_MODULE
+#endif // !_STATIC_TUPLE_H_

=== added file 'bzrlib/_static_tuple_c.pxd'
--- bzrlib/_static_tuple_c.pxd	1970-01-01 00:00:00 +0000
+++ bzrlib/_static_tuple_c.pxd	2009-10-21 21:27:19 +0000
@@ -0,0 +1,44 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""The interface definition file for the StaticTuple class."""
+
+
+cdef extern from "Python.h":
+    ctypedef int Py_ssize_t # Required for older pyrex versions
+    ctypedef struct PyObject:
+        pass
+
+cdef extern from "_static_tuple_c.h":
+    ctypedef class bzrlib._static_tuple_c.StaticTuple [object StaticTuple]:
+        cdef unsigned char size
+        cdef unsigned char flags
+        cdef PyObject *items[0]
+
+    # Must be called before using any of the C api, as it sets the function
+    # pointers in memory.
+    int import_static_tuple_c() except -1
+    StaticTuple StaticTuple_New(Py_ssize_t)
+    StaticTuple StaticTuple_Intern(StaticTuple)
+
+    # Steals a reference and val must be a valid type, no checking is done
+    void StaticTuple_SET_ITEM(StaticTuple key, Py_ssize_t offset, object val)
+    # We would normally use PyObject * here. However it seems that cython/pyrex
+    # treat the PyObject defined in this header as something different than one
+    # defined in a .pyx file. And since we don't INCREF, we need a raw pointer,
+    # not an 'object' return value.
+    void *StaticTuple_GET_ITEM(StaticTuple key, Py_ssize_t offset)
+    int StaticTuple_CheckExact(object)

=== added file 'bzrlib/_static_tuple_py.py'
--- bzrlib/_static_tuple_py.py	1970-01-01 00:00:00 +0000
+++ bzrlib/_static_tuple_py.py	2009-11-28 21:54:08 +0000
@@ -0,0 +1,80 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""The pure-python implementation of the StaticTuple type.
+
+Note that it is generally just implemented as using tuples of tuples of
+strings.
+"""
+
+
+class StaticTuple(tuple):
+    """A static type, similar to a tuple of strings."""
+
+    __slots__ = ()
+
+    def __new__(cls, *args):
+        # Make the empty StaticTuple a singleton
+        if not args and _empty_tuple is not None:
+            return _empty_tuple
+        return tuple.__new__(cls, args)
+
+    def __init__(self, *args):
+        """Create a new 'StaticTuple'"""
+        for bit in args:
+            if type(bit) not in (str, StaticTuple, unicode, int, long, float,
+                                 None.__class__, bool):
+                raise TypeError('StaticTuple can only point to'
+                    ' StaticTuple, str, unicode, int, long, float, bool, or'
+                    ' None not %s' % (type(bit),))
+        num_keys = len(args)
+        if num_keys < 0 or num_keys > 255:
+            raise ValueError('must have 1 => 256 key bits')
+        # We don't need to pass args to tuple.__init__, because that was
+        # already handled in __new__.
+        tuple.__init__(self)
+
+    def __repr__(self):
+        return '%s%s' % (self.__class__.__name__, tuple.__repr__(self))
+
+    def __reduce__(self):
+        return (StaticTuple, tuple(self))
+
+    def __add__(self, other):
+        """Concatenate self with other"""
+        return StaticTuple.from_sequence(tuple.__add__(self,other))
+
+    def as_tuple(self):
+        return tuple(self)
+
+    def intern(self):
+        return _interned_tuples.setdefault(self, self)
+
+    @staticmethod
+    def from_sequence(seq):
+        """Convert a sequence object into a StaticTuple instance."""
+        if isinstance(seq, StaticTuple):
+            # it already is
+            return seq
+        return StaticTuple(*seq)
+
+
+
+# Have to set it to None first, so that __new__ can determine whether
+# the _empty_tuple singleton has been created yet or not.
+_empty_tuple = None
+_empty_tuple = StaticTuple()
+_interned_tuples = {}

=== modified file 'bzrlib/annotate.py'
--- bzrlib/annotate.py	2009-08-17 18:52:01 +0000
+++ bzrlib/annotate.py	2009-09-14 01:48:28 +0000
@@ -458,5 +458,6 @@
 
 try:
     from bzrlib._annotator_pyx import Annotator
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib._annotator_py import Annotator

=== modified file 'bzrlib/bencode.py'
--- bzrlib/bencode.py	2009-06-03 14:14:31 +0000
+++ bzrlib/bencode.py	2009-09-11 06:36:50 +0000
@@ -16,7 +16,10 @@
 
 """Wrapper around the bencode pyrex and python implementation"""
 
+from bzrlib import osutils
+
 try:
     from bzrlib._bencode_pyx import bdecode, bdecode_as_tuple, bencode, Bencached
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib.util._bencode_py import bdecode, bdecode_as_tuple, bencode, Bencached

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2009-08-19 18:04:49 +0000
+++ bzrlib/branch.py	2009-12-03 02:24:54 +0000
@@ -46,9 +46,10 @@
     )
 """)
 
-from bzrlib.decorators import needs_read_lock, needs_write_lock
+from bzrlib.decorators import needs_read_lock, needs_write_lock, only_raises
 from bzrlib.hooks import HookPoint, Hooks
 from bzrlib.inter import InterObject
+from bzrlib.lock import _RelockDebugMixin
 from bzrlib import registry
 from bzrlib.symbol_versioning import (
     deprecated_in,
@@ -1284,16 +1285,9 @@
         # clone call. Or something. 20090224 RBC/spiv.
         if revision_id is None:
             revision_id = self.last_revision()
-        try:
-            dir_to = self.bzrdir.clone_on_transport(to_transport,
-                revision_id=revision_id, stacked_on=stacked_on,
-                create_prefix=create_prefix, use_existing_dir=use_existing_dir)
-        except errors.FileExists:
-            if not use_existing_dir:
-                raise
-        except errors.NoSuchFile:
-            if not create_prefix:
-                raise
+        dir_to = self.bzrdir.clone_on_transport(to_transport,
+            revision_id=revision_id, stacked_on=stacked_on,
+            create_prefix=create_prefix, use_existing_dir=use_existing_dir)
         return dir_to.open_branch()
 
     def create_checkout(self, to_location, revision_id=None,
@@ -1439,7 +1433,7 @@
         """Return the format for the branch object in a_bzrdir."""
         try:
             transport = a_bzrdir.get_branch_transport(None)
-            format_string = transport.get("format").read()
+            format_string = transport.get_bytes("format")
             return klass._formats[format_string]
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
@@ -1978,7 +1972,7 @@
     def get_reference(self, a_bzrdir):
         """See BranchFormat.get_reference()."""
         transport = a_bzrdir.get_branch_transport(None)
-        return transport.get('location').read()
+        return transport.get_bytes('location')
 
     def set_reference(self, a_bzrdir, to_branch):
         """See BranchFormat.set_reference()."""
@@ -2079,7 +2073,7 @@
     _legacy_formats[0].network_name(), _legacy_formats[0].__class__)
 
 
-class BzrBranch(Branch):
+class BzrBranch(Branch, _RelockDebugMixin):
     """A branch stored in the actual filesystem.
 
     Note that it's "local" in the context of the filesystem; it doesn't
@@ -2131,6 +2125,8 @@
         return self.control_files.is_locked()
 
     def lock_write(self, token=None):
+        if not self.is_locked():
+            self._note_lock('w')
         # All-in-one needs to always unlock/lock.
         repo_control = getattr(self.repository, 'control_files', None)
         if self.control_files == repo_control or not self.is_locked():
@@ -2146,6 +2142,8 @@
             raise
 
     def lock_read(self):
+        if not self.is_locked():
+            self._note_lock('r')
         # All-in-one needs to always unlock/lock.
         repo_control = getattr(self.repository, 'control_files', None)
         if self.control_files == repo_control or not self.is_locked():
@@ -2160,6 +2158,7 @@
                 self.repository.unlock()
             raise
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         try:
             self.control_files.unlock()

=== modified file 'bzrlib/btree_index.py'
--- bzrlib/btree_index.py	2009-08-17 22:11:06 +0000
+++ bzrlib/btree_index.py	2009-11-07 01:58:11 +0000
@@ -17,6 +17,7 @@
 
 """B+Tree indices"""
 
+import cStringIO
 from bisect import bisect_right
 import math
 import tempfile
@@ -30,6 +31,7 @@
     index,
     lru_cache,
     osutils,
+    static_tuple,
     trace,
     )
 from bzrlib.index import _OPTION_NODE_REFS, _OPTION_KEY_ELEMENTS, _OPTION_LEN
@@ -60,14 +62,20 @@
     def __init__(self):
         """Create a _BuilderRow."""
         self.nodes = 0
-        self.spool = tempfile.TemporaryFile()
+        self.spool = None# tempfile.TemporaryFile(prefix='bzr-index-row-')
         self.writer = None
 
     def finish_node(self, pad=True):
         byte_lines, _, padding = self.writer.finish()
         if self.nodes == 0:
+            self.spool = cStringIO.StringIO()
             # padded note:
             self.spool.write("\x00" * _RESERVED_HEADER_BYTES)
+        elif self.nodes == 1:
+            # We got bigger than 1 node, switch to a temp file
+            spool = tempfile.TemporaryFile(prefix='bzr-index-row-')
+            spool.write(self.spool.getvalue())
+            self.spool = spool
         skipped_bytes = 0
         if not pad and padding:
             del byte_lines[-1]
@@ -152,15 +160,16 @@
         :param value: The value to associate with the key. It may be any
             bytes as long as it does not contain \0 or \n.
         """
+        # Ensure that 'key' is a StaticTuple
+        key = static_tuple.StaticTuple.from_sequence(key).intern()
         # we don't care about absent_references
         node_refs, _ = self._check_key_ref_value(key, references, value)
         if key in self._nodes:
             raise errors.BadIndexDuplicateKey(key, self)
-        self._nodes[key] = (node_refs, value)
-        self._keys.add(key)
+        self._nodes[key] = static_tuple.StaticTuple(node_refs, value)
         if self._nodes_by_key is not None and self._key_length > 1:
             self._update_nodes_by_key(key, value, node_refs)
-        if len(self._keys) < self._spill_at:
+        if len(self._nodes) < self._spill_at:
             return
         self._spill_mem_keys_to_disk()
 
@@ -182,11 +191,9 @@
              backing_pos) = self._spill_mem_keys_and_combine()
         else:
             new_backing_file, size = self._spill_mem_keys_without_combining()
-        dir_path, base_name = osutils.split(new_backing_file.name)
         # Note: The transport here isn't strictly needed, because we will use
         #       direct access to the new_backing._file object
-        new_backing = BTreeGraphIndex(get_transport(dir_path),
-                                      base_name, size)
+        new_backing = BTreeGraphIndex(get_transport('.'), '<temp>', size)
         # GC will clean up the file
         new_backing._file = new_backing_file
         if self._combine_backing_indices:
@@ -197,7 +204,6 @@
                 self._backing_indices[backing_pos] = None
         else:
             self._backing_indices.append(new_backing)
-        self._keys = set()
         self._nodes = {}
         self._nodes_by_key = None
 
@@ -379,13 +385,16 @@
         for row in reversed(rows):
             pad = (type(row) != _LeafBuilderRow)
             row.finish_node(pad=pad)
-        result = tempfile.NamedTemporaryFile(prefix='bzr-index-')
         lines = [_BTSIGNATURE]
         lines.append(_OPTION_NODE_REFS + str(self.reference_lists) + '\n')
         lines.append(_OPTION_KEY_ELEMENTS + str(self._key_length) + '\n')
         lines.append(_OPTION_LEN + str(key_count) + '\n')
         row_lengths = [row.nodes for row in rows]
         lines.append(_OPTION_ROW_LENGTHS + ','.join(map(str, row_lengths)) + '\n')
+        if row_lengths and row_lengths[-1] > 1:
+            result = tempfile.NamedTemporaryFile(prefix='bzr-index-')
+        else:
+            result = cStringIO.StringIO()
         result.writelines(lines)
         position = sum(map(len, lines))
         root_row = True
@@ -402,7 +411,8 @@
             # Special case the first node as it may be prefixed
             node = row.spool.read(_PAGE_SIZE)
             result.write(node[reserved:])
-            result.write("\x00" * (reserved - position))
+            if len(node) == _PAGE_SIZE:
+                result.write("\x00" * (reserved - position))
             position = 0 # Only the root row actually has an offset
             copied_len = osutils.pumpfile(row.spool, result)
             if copied_len != (row.nodes - 1) * _PAGE_SIZE:
@@ -453,14 +463,22 @@
             efficient order for the index (keys iteration order in this case).
         """
         keys = set(keys)
-        local_keys = keys.intersection(self._keys)
+        # Note: We don't use keys.intersection() here. If you read the C api,
+        #       set.intersection(other) special cases when other is a set and
+        #       will iterate the smaller of the two and lookup in the other.
+        #       It does *not* do this for any other type (even dict, unlike
+        #       some other set functions.) Since we expect keys is generally <<
+        #       self._nodes, it is faster to iterate over it in a list
+        #       comprehension
+        nodes = self._nodes
+        local_keys = [key for key in keys if key in nodes]
         if self.reference_lists:
             for key in local_keys:
-                node = self._nodes[key]
+                node = nodes[key]
                 yield self, key, node[1], node[0]
         else:
             for key in local_keys:
-                node = self._nodes[key]
+                node = nodes[key]
                 yield self, key, node[1]
         # Find things that are in backing indices that have not been handled
         # yet.
@@ -576,7 +594,7 @@
 
         For InMemoryGraphIndex the estimate is exact.
         """
-        return len(self._keys) + sum(backing.key_count() for backing in
+        return len(self._nodes) + sum(backing.key_count() for backing in
             self._backing_indices if backing is not None)
 
     def validate(self):
@@ -614,10 +632,11 @@
     def _parse_lines(self, lines):
         nodes = []
         self.offset = int(lines[1][7:])
+        as_st = static_tuple.StaticTuple.from_sequence
         for line in lines[2:]:
             if line == '':
                 break
-            nodes.append(tuple(map(intern, line.split('\0'))))
+            nodes.append(as_st(map(intern, line.split('\0'))).intern())
         return nodes
 
 
@@ -628,7 +647,7 @@
     memory except when very large walks are done.
     """
 
-    def __init__(self, transport, name, size):
+    def __init__(self, transport, name, size, unlimited_cache=False):
         """Create a B+Tree index object on the index name.
 
         :param transport: The transport to read data for the index from.
@@ -638,6 +657,9 @@
             the initial read (to read the root node header) can be done
             without over-reading even on empty indices, and on small indices
             allows single-IO to read the entire index.
+        :param unlimited_cache: If set to True, then instead of using an
+            LRUCache with size _NODE_CACHE_SIZE, we will use a dict and always
+            cache all leaf nodes.
         """
         self._transport = transport
         self._name = name
@@ -647,12 +669,15 @@
         self._root_node = None
         # Default max size is 100,000 leave values
         self._leaf_value_cache = None # lru_cache.LRUCache(100*1000)
-        self._leaf_node_cache = lru_cache.LRUCache(_NODE_CACHE_SIZE)
-        # We could limit this, but even a 300k record btree has only 3k leaf
-        # nodes, and only 20 internal nodes. So the default of 100 nodes in an
-        # LRU would mean we always cache everything anyway, no need to pay the
-        # overhead of LRU
-        self._internal_node_cache = fifo_cache.FIFOCache(100)
+        if unlimited_cache:
+            self._leaf_node_cache = {}
+            self._internal_node_cache = {}
+        else:
+            self._leaf_node_cache = lru_cache.LRUCache(_NODE_CACHE_SIZE)
+            # We use a FIFO here just to prevent possible blowout. However, a
+            # 300k record btree has only 3k leaf nodes, and only 20 internal
+            # nodes. A value of 100 scales to ~100*100*100 = 1M records.
+            self._internal_node_cache = fifo_cache.FIFOCache(100)
         self._key_count = None
         self._row_lengths = None
         self._row_offsets = None # Start of each row, [-1] is the end
@@ -690,9 +715,9 @@
                 if start_of_leaves is None:
                     start_of_leaves = self._row_offsets[-2]
                 if node_pos < start_of_leaves:
-                    self._internal_node_cache.add(node_pos, node)
+                    self._internal_node_cache[node_pos] = node
                 else:
-                    self._leaf_node_cache.add(node_pos, node)
+                    self._leaf_node_cache[node_pos] = node
             found[node_pos] = node
         return found
 
@@ -837,6 +862,19 @@
             new_tips = next_tips
         return final_offsets
 
+    def clear_cache(self):
+        """Clear out any cached/memoized values.
+
+        This can be called at any time, but generally it is used when we have
+        extracted some information, but don't expect to be requesting any more
+        from this index.
+        """
+        # Note that we don't touch self._root_node or self._internal_node_cache
+        # We don't expect either of those to be big, and it can save
+        # round-trips in the future. We may re-evaluate this if InternalNode
+        # memory starts to be an issue.
+        self._leaf_node_cache.clear()
+
     def external_references(self, ref_list_num):
         if self._root_node is None:
             self._get_root_node()
@@ -1526,5 +1564,6 @@
 
 try:
     from bzrlib import _btree_serializer_pyx as _btree_serializer
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib import _btree_serializer_py as _btree_serializer

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2009-08-26 03:20:32 +0000
+++ bzrlib/builtins.py	2009-12-02 23:14:10 +0000
@@ -43,7 +43,9 @@
     reconfigure,
     rename_map,
     revision as _mod_revision,
+    static_tuple,
     symbol_versioning,
+    timestamp,
     transport,
     ui,
     urlutils,
@@ -257,6 +259,10 @@
     unknown
         Not versioned and not matching an ignore pattern.
 
+    Additionally for directories, symlinks and files with an executable
+    bit, Bazaar indicates their type using a trailing character: '/', '@'
+    or '*' respectively.
+
     To see ignored files use 'bzr ignored'.  For details on the
     changes to file texts, use 'bzr diff'.
 
@@ -431,7 +437,9 @@
         for node in bt.iter_all_entries():
             # Node is made up of:
             # (index, key, value, [references])
-            self.outf.write('%s\n' % (node[1:],))
+            refs_as_tuples = static_tuple.as_tuples(node[3])
+            as_tuple = (tuple(node[1]), node[2], refs_as_tuples)
+            self.outf.write('%s\n' % (as_tuple,))
 
 
 class cmd_remove_tree(Command):
@@ -461,8 +469,7 @@
             raise errors.BzrCommandError("You cannot remove the working tree"
                                          " of a remote path")
         if not force:
-            # XXX: What about pending merges ? -- vila 20090629
-            if working.has_changes(working.basis_tree()):
+            if (working.has_changes()):
                 raise errors.UncommittedChanges(working)
 
         working_path = working.bzrdir.root_transport.base
@@ -653,7 +660,6 @@
         if base_tree:
             base_tree.lock_read()
         try:
-            file_list = self._maybe_expand_globs(file_list)
             tree, file_list = tree_files_for_add(file_list)
             added, ignored = tree.smart_add(file_list, not
                 no_recurse, action=action, save=not dry_run)
@@ -848,8 +854,9 @@
             # All entries reference existing inventory items, so fix them up
             # for cicp file-systems.
             rel_names = tree.get_canonical_inventory_paths(rel_names)
-            for pair in tree.move(rel_names[:-1], rel_names[-1], after=after):
-                self.outf.write("%s => %s\n" % pair)
+            for src, dest in tree.move(rel_names[:-1], rel_names[-1], after=after):
+                if not is_quiet():
+                    self.outf.write("%s => %s\n" % (src, dest))
         else:
             if len(names_list) != 2:
                 raise errors.BzrCommandError('to mv multiple files the'
@@ -899,7 +906,8 @@
             dest = osutils.pathjoin(dest_parent, dest_tail)
             mutter("attempting to move %s => %s", src, dest)
             tree.rename_one(src, dest, after=after)
-            self.outf.write("%s => %s\n" % (src, dest))
+            if not is_quiet():
+                self.outf.write("%s => %s\n" % (src, dest))
 
 
 class cmd_pull(Command):
@@ -1109,8 +1117,7 @@
         else:
             revision_id = None
         if strict and tree is not None and revision_id is None:
-            if (tree.has_changes(tree.basis_tree())
-                or len(tree.get_parent_ids()) > 1):
+            if (tree.has_changes()):
                 raise errors.UncommittedChanges(
                     tree, more='Use --no-strict to force the push.')
             if tree.last_revision() != tree.branch.last_revision():
@@ -1673,7 +1680,7 @@
                 lazy_registry=('bzrlib.bzrdir', 'format_registry'),
                 converter=lambda name: bzrdir.format_registry.make_bzrdir(name),
                 value_switches=True,
-                title="Branch Format",
+                title="Branch format",
                 ),
          Option('append-revisions-only',
                 help='Never change revnos or the existing log.'
@@ -1748,16 +1755,22 @@
 
 
 class cmd_init_repository(Command):
-    """Create a shared repository to hold branches.
+    """Create a shared repository for branches to share storage space.
 
     New branches created under the repository directory will store their
-    revisions in the repository, not in the branch directory.
+    revisions in the repository, not in the branch directory.  For branches
+    with shared history, this reduces the amount of storage needed and 
+    speeds up the creation of new branches.
 
-    If the --no-trees option is used then the branches in the repository
-    will not have working trees by default.
+    If the --no-trees option is given then the branches in the repository
+    will not have working trees by default.  They will still exist as 
+    directories on disk, but they will not have separate copies of the 
+    files at a certain revision.  This can be useful for repositories that
+    store branches which are interacted with through checkouts or remote
+    branches, such as on a server.
 
     :Examples:
-        Create a shared repositories holding just branches::
+        Create a shared repository holding just branches::
 
             bzr init-repo --no-trees repo
             bzr init repo/trunk
@@ -1829,13 +1842,27 @@
 
             bzr diff -r1
 
-        Difference between revision 2 and revision 1::
-
-            bzr diff -r1..2
-
-        Difference between revision 2 and revision 1 for branch xxx::
-
-            bzr diff -r1..2 xxx
+        Difference between revision 3 and revision 1::
+
+            bzr diff -r1..3
+
+        Difference between revision 3 and revision 1 for branch xxx::
+
+            bzr diff -r1..3 xxx
+
+        To see the changes introduced in revision X::
+        
+            bzr diff -cX
+
+        Note that in the case of a merge, the -c option shows the changes
+        compared to the left hand parent. To see the changes against
+        another parent, use::
+
+            bzr diff -r<chosen_parent>..X
+
+        The changes introduced by revision 2 (equivalent to -r1..2)::
+
+            bzr diff -c2
 
         Show just the differences for file NEWS::
 
@@ -1887,7 +1914,7 @@
     @display_command
     def run(self, revision=None, file_list=None, diff_options=None,
             prefix=None, old=None, new=None, using=None):
-        from bzrlib.diff import _get_trees_to_diff, show_diff_trees
+        from bzrlib.diff import get_trees_and_branches_to_diff, show_diff_trees
 
         if (prefix is None) or (prefix == '0'):
             # diff -p0 format
@@ -1907,9 +1934,10 @@
             raise errors.BzrCommandError('bzr diff --revision takes exactly'
                                          ' one or two revision specifiers')
 
-        old_tree, new_tree, specific_files, extra_trees = \
-                _get_trees_to_diff(file_list, revision, old, new,
-                apply_view=True)
+        (old_tree, new_tree,
+         old_branch, new_branch,
+         specific_files, extra_trees) = get_trees_and_branches_to_diff(
+            file_list, revision, old, new, apply_view=True)
         return show_diff_trees(old_tree, new_tree, sys.stdout,
                                specific_files=specific_files,
                                external_diff_options=diff_options,
@@ -2274,50 +2302,51 @@
 
         file_ids = []
         filter_by_dir = False
-        if file_list:
-            # find the file ids to log and check for directory filtering
-            b, file_info_list, rev1, rev2 = _get_info_for_log_files(revision,
-                file_list)
-            for relpath, file_id, kind in file_info_list:
-                if file_id is None:
-                    raise errors.BzrCommandError(
-                        "Path unknown at end or start of revision range: %s" %
-                        relpath)
-                # If the relpath is the top of the tree, we log everything
-                if relpath == '':
-                    file_ids = []
-                    break
+        b = None
+        try:
+            if file_list:
+                # find the file ids to log and check for directory filtering
+                b, file_info_list, rev1, rev2 = _get_info_for_log_files(
+                    revision, file_list)
+                for relpath, file_id, kind in file_info_list:
+                    if file_id is None:
+                        raise errors.BzrCommandError(
+                            "Path unknown at end or start of revision range: %s" %
+                            relpath)
+                    # If the relpath is the top of the tree, we log everything
+                    if relpath == '':
+                        file_ids = []
+                        break
+                    else:
+                        file_ids.append(file_id)
+                    filter_by_dir = filter_by_dir or (
+                        kind in ['directory', 'tree-reference'])
+            else:
+                # log everything
+                # FIXME ? log the current subdir only RBC 20060203
+                if revision is not None \
+                        and len(revision) > 0 and revision[0].get_branch():
+                    location = revision[0].get_branch()
                 else:
-                    file_ids.append(file_id)
-                filter_by_dir = filter_by_dir or (
-                    kind in ['directory', 'tree-reference'])
-        else:
-            # log everything
-            # FIXME ? log the current subdir only RBC 20060203
-            if revision is not None \
-                    and len(revision) > 0 and revision[0].get_branch():
-                location = revision[0].get_branch()
-            else:
-                location = '.'
-            dir, relpath = bzrdir.BzrDir.open_containing(location)
-            b = dir.open_branch()
-            rev1, rev2 = _get_revision_range(revision, b, self.name())
-
-        # Decide on the type of delta & diff filtering to use
-        # TODO: add an --all-files option to make this configurable & consistent
-        if not verbose:
-            delta_type = None
-        else:
-            delta_type = 'full'
-        if not show_diff:
-            diff_type = None
-        elif file_ids:
-            diff_type = 'partial'
-        else:
-            diff_type = 'full'
-
-        b.lock_read()
-        try:
+                    location = '.'
+                dir, relpath = bzrdir.BzrDir.open_containing(location)
+                b = dir.open_branch()
+                b.lock_read()
+                rev1, rev2 = _get_revision_range(revision, b, self.name())
+
+            # Decide on the type of delta & diff filtering to use
+            # TODO: add an --all-files option to make this configurable & consistent
+            if not verbose:
+                delta_type = None
+            else:
+                delta_type = 'full'
+            if not show_diff:
+                diff_type = None
+            elif file_ids:
+                diff_type = 'partial'
+            else:
+                diff_type = 'full'
+
             # Build the log formatter
             if log_format is None:
                 log_format = log.log_formatter_registry.get_default(b)
@@ -2353,7 +2382,8 @@
                 diff_type=diff_type, _match_using_deltas=match_using_deltas)
             Logger(b, rqst).show(lf)
         finally:
-            b.unlock()
+            if b is not None:
+                b.unlock()
 
 
 def _get_revision_range(revisionspec_list, branch, command_name):
@@ -2423,10 +2453,15 @@
     @display_command
     def run(self, filename):
         tree, relpath = WorkingTree.open_containing(filename)
+        file_id = tree.path2id(relpath)
         b = tree.branch
-        file_id = tree.path2id(relpath)
-        for revno, revision_id, what in log.find_touching_revisions(b, file_id):
-            self.outf.write("%6d %s\n" % (revno, what))
+        b.lock_read()
+        try:
+            touching_revs = log.find_touching_revisions(b, file_id)
+            for revno, revision_id, what in touching_revs:
+                self.outf.write("%6d %s\n" % (revno, what))
+        finally:
+            b.unlock()
 
 
 class cmd_ls(Command):
@@ -2484,7 +2519,7 @@
         if from_root:
             if relpath:
                 prefix = relpath + '/'
-        elif fs_path != '.':
+        elif fs_path != '.' and not fs_path.endswith('/'):
             prefix = fs_path + '/'
 
         if revision is not None or tree is None:
@@ -2566,6 +2601,12 @@
 
     See ``bzr help patterns`` for details on the syntax of patterns.
 
+    If a .bzrignore file does not exist, the ignore command
+    will create one and add the specified files or patterns to the newly
+    created file. The ignore command will also automatically add the 
+    .bzrignore file to be versioned. Creating a .bzrignore file without
+    the use of the ignore command will require an explicit add command.
+
     To remove patterns from the ignore list, edit the .bzrignore file.
     After adding, editing or deleting that file either indirectly by
     using this command or directly by using an editor, be sure to commit
@@ -2939,6 +2980,9 @@
              Option('strict',
                     help="Refuse to commit if there are unknown "
                     "files in the working tree."),
+             Option('commit-time', type=str,
+                    help="Manually set a commit time using commit date "
+                    "format, e.g. '2009-10-10 08:00:00 +0100'."),
              ListOption('fixes', type=str,
                     help="Mark a bug as being fixed by this revision "
                          "(see \"bzr help bugs\")."),
@@ -2951,9 +2995,9 @@
                          "the master branch until a normal commit "
                          "is performed."
                     ),
-              Option('show-diff',
-                     help='When no message is supplied, show the diff along'
-                     ' with the status summary in the message editor.'),
+             Option('show-diff',
+                    help='When no message is supplied, show the diff along'
+                    ' with the status summary in the message editor.'),
              ]
     aliases = ['ci', 'checkin']
 
@@ -2978,7 +3022,7 @@
 
     def run(self, message=None, file=None, verbose=False, selected_list=None,
             unchanged=False, strict=False, local=False, fixes=None,
-            author=None, show_diff=False, exclude=None):
+            author=None, show_diff=False, exclude=None, commit_time=None):
         from bzrlib.errors import (
             PointlessCommit,
             ConflictsInTree,
@@ -2990,6 +3034,14 @@
             make_commit_message_template_encoded
         )
 
+        commit_stamp = offset = None
+        if commit_time is not None:
+            try:
+                commit_stamp, offset = timestamp.parse_patch_date(commit_time)
+            except ValueError, e:
+                raise errors.BzrCommandError(
+                    "Could not parse --commit-time: " + str(e))
+
         # TODO: Need a blackbox test for invoking the external editor; may be
         # slightly problematic to run this cross-platform.
 
@@ -3018,6 +3070,9 @@
         def get_message(commit_obj):
             """Callback to get commit message"""
             my_message = message
+            if my_message is not None and '\r' in my_message:
+                my_message = my_message.replace('\r\n', '\n')
+                my_message = my_message.replace('\r', '\n')
             if my_message is None and not file:
                 t = make_commit_message_template_encoded(tree,
                         selected_list, diff=show_diff,
@@ -3047,7 +3102,8 @@
                         specific_files=selected_list,
                         allow_pointless=unchanged, strict=strict, local=local,
                         reporter=None, verbose=verbose, revprops=properties,
-                        authors=author,
+                        authors=author, timestamp=commit_stamp,
+                        timezone=offset,
                         exclude=safe_relpath_files(tree, exclude))
         except PointlessCommit:
             # FIXME: This should really happen before the file is read in;
@@ -3340,6 +3396,9 @@
     Tests that need working space on disk use a common temporary directory,
     typically inside $TMPDIR or /tmp.
 
+    If you set BZR_TEST_PDB=1 when running selftest, failing tests will drop
+    into a pdb postmortem session.
+
     :Examples:
         Run only tests relating to 'ignore'::
 
@@ -3382,6 +3441,8 @@
                      Option('lsprof-timed',
                             help='Generate lsprof output for benchmarked'
                                  ' sections of code.'),
+                     Option('lsprof-tests',
+                            help='Generate lsprof output for each test.'),
                      Option('cache-dir', type=str,
                             help='Cache intermediate benchmark output in this '
                                  'directory.'),
@@ -3428,7 +3489,7 @@
             first=False, list_only=False,
             randomize=None, exclude=None, strict=False,
             load_list=None, debugflag=None, starting_with=None, subunit=False,
-            parallel=None):
+            parallel=None, lsprof_tests=False):
         from bzrlib.tests import selftest
         import bzrlib.benchmarks as benchmarks
         from bzrlib.benchmarks import tree_creator
@@ -3468,6 +3529,7 @@
                               "transport": transport,
                               "test_suite_factory": test_suite_factory,
                               "lsprof_timed": lsprof_timed,
+                              "lsprof_tests": lsprof_tests,
                               "bench_history": benchfile,
                               "matching_tests_first": first,
                               "list_only": list_only,
@@ -3597,7 +3659,7 @@
 
             bzr merge -r 81..82 ../bzr.dev
 
-        To apply a merge directive contained in /tmp/merge:
+        To apply a merge directive contained in /tmp/merge::
 
             bzr merge /tmp/merge
     """
@@ -3650,13 +3712,14 @@
         verified = 'inapplicable'
         tree = WorkingTree.open_containing(directory)[0]
 
-        # die as quickly as possible if there are uncommitted changes
         try:
             basis_tree = tree.revision_tree(tree.last_revision())
         except errors.NoSuchRevision:
             basis_tree = tree.basis_tree()
+
+        # die as quickly as possible if there are uncommitted changes
         if not force:
-            if tree.has_changes(basis_tree):
+            if tree.has_changes():
                 raise errors.UncommittedChanges(tree)
 
         view_info = _get_view_info_for_change_reporter(tree)
@@ -3713,7 +3776,10 @@
                                        merger.other_rev_id)
                     result.report(self.outf)
                     return 0
-            merger.check_basis(False)
+            if merger.this_basis is None:
+                raise errors.BzrCommandError(
+                    "This branch has no commits."
+                    " (perhaps you would prefer 'bzr pull')")
             if preview:
                 return self._do_preview(merger, cleanups)
             elif interactive:
@@ -4013,9 +4079,10 @@
     name.  If you name a directory, all the contents of that directory will be
     reverted.
 
-    Any files that have been newly added since that revision will be deleted,
-    with a backup kept if appropriate.  Directories containing unknown files
-    will not be deleted.
+    If you have newly added files since the target revision, they will be
+    removed.  If the files to be removed have been changed, backups will be
+    created as above.  Directories containing unknown files will not be
+    deleted.
 
     The working tree contains a list of pending merged revisions, which will
     be included as parents in the next commit.  Normally, revert clears that
@@ -4024,6 +4091,16 @@
     revert ." in the tree root to revert all files but keep the merge record,
     and "bzr revert --forget-merges" to clear the pending merge list without
     reverting any files.
+
+    Using "bzr revert --forget-merges", it is possible to apply the changes
+    from an arbitrary merge as a single revision.  To do this, perform the
+    merge as desired.  Then doing revert with the "--forget-merges" option will
+    keep the content of the tree as it was, but it will clear the list of
+    pending merges.  The next commit will then contain all of the changes that
+    would have been in the merge, but without any mention of the other parent
+    revisions.  Because this technique forgets where these changes originated,
+    it may cause additional conflicts on later merges involving the source and
+    target branches.
     """
 
     _see_also = ['cat', 'export']
@@ -4110,6 +4187,10 @@
     To filter on a range of revisions, you can use the command -r begin..end
     -r revision requests a specific revision, -r ..end or -r begin.. are
     also valid.
+            
+    :Exit values:
+        1 - some missing revisions
+        0 - no missing revisions
 
     :Examples:
 
@@ -4499,7 +4580,7 @@
     before they will be applied to the local branch.
 
     Bound branches use the nickname of its master branch unless it is set
-    locally, in which case binding will update the the local nickname to be
+    locally, in which case binding will update the local nickname to be
     that of the master.
     """
 
@@ -4705,8 +4786,8 @@
     takes_options = [
         Option('inet',
                help='Serve on stdin/out for use from inetd or sshd.'),
-        RegistryOption('protocol', 
-               help="Protocol to serve.", 
+        RegistryOption('protocol',
+               help="Protocol to serve.",
                lazy_registry=('bzrlib.transport', 'transport_server_registry'),
                value_switches=True),
         Option('port',
@@ -4721,7 +4802,11 @@
         Option('allow-writes',
                help='By default the server is a readonly server.  Supplying '
                     '--allow-writes enables write access to the contents of '
-                    'the served directory and below.'
+                    'the served directory and below.  Note that ``bzr serve`` '
+                    'does not perform authentication, so unless some form of '
+                    'external authentication is arranged supplying this '
+                    'option leads to global uncontrolled write access to your '
+                    'file system.'
                 ),
         ]
 
@@ -4962,9 +5047,10 @@
 
     To use a specific mail program, set the mail_client configuration option.
     (For Thunderbird 1.5, this works around some bugs.)  Supported values for
-    specific clients are "claws", "evolution", "kmail", "mutt", and
-    "thunderbird"; generic options are "default", "editor", "emacsclient",
-    "mapi", and "xdg-email".  Plugins may also add supported clients.
+    specific clients are "claws", "evolution", "kmail", "mail.app" (MacOS X's
+    Mail.app), "mutt", and "thunderbird"; generic options are "default",
+    "editor", "emacsclient", "mapi", and "xdg-email".  Plugins may also add
+    supported clients.
 
     If mail is being sent, a to address is required.  This can be supplied
     either on the commandline, by setting the submit_to configuration
@@ -5349,7 +5435,7 @@
     /path/to/newbranch.
 
     Bound branches use the nickname of its master branch unless it is set
-    locally, in which case switching will update the the local nickname to be
+    locally, in which case switching will update the local nickname to be
     that of the master.
     """
 
@@ -5649,7 +5735,7 @@
             try:
                 shelver.run()
             finally:
-                shelver.work_tree.unlock()
+                shelver.finalize()
         except errors.UserAbort:
             return 0
 

=== modified file 'bzrlib/bundle/__init__.py'
--- bzrlib/bundle/__init__.py	2009-07-20 02:04:21 +0000
+++ bzrlib/bundle/__init__.py	2009-11-28 00:48:03 +0000
@@ -14,6 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+from cStringIO import StringIO
+
 from bzrlib.symbol_versioning import deprecated_function, deprecated_in
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
@@ -22,6 +24,7 @@
     urlutils,
     )
 from bzrlib.bundle import serializer as _serializer
+from bzrlib.merge_directive import MergeDirective
 from bzrlib.transport import (
     do_catching_redirections,
     get_transport,
@@ -51,33 +54,22 @@
 
 
 def read_mergeable_from_transport(transport, filename, _do_directive=True):
-    # All of this must be in the try/except
-    # Some transports cannot detect that we are trying to read a
-    # directory until we actually issue read() on the handle.
+    def get_bundle(transport):
+        return StringIO(transport.get_bytes(filename)), transport
+
+    def redirected_transport(transport, exception, redirection_notice):
+        note(redirection_notice)
+        url, filename = urlutils.split(exception.target,
+                                       exclude_trailing_slash=False)
+        if not filename:
+            raise errors.NotABundle('A directory cannot be a bundle')
+        return get_transport(url)
+
     try:
-        def get_bundle(transport):
-            return transport.get(filename), transport
-
-        def redirected_transport(transport, exception, redirection_notice):
-            note(redirection_notice)
-            url, filename = urlutils.split(exception.target,
-                                           exclude_trailing_slash=False)
-            if not filename:
-                raise errors.NotABundle('A directory cannot be a bundle')
-            return get_transport(url)
-
-        try:
-            f, transport = do_catching_redirections(get_bundle, transport,
+        bytef, transport = do_catching_redirections(get_bundle, transport,
                                                     redirected_transport)
-        except errors.TooManyRedirections:
-            raise errors.NotABundle(transport.clone(filename).base)
-
-        if _do_directive:
-            from bzrlib.merge_directive import MergeDirective
-            directive = MergeDirective.from_lines(f.readlines())
-            return directive, transport
-        else:
-            return _serializer.read_bundle(f), transport
+    except errors.TooManyRedirections:
+        raise errors.NotABundle(transport.clone(filename).base)
     except (errors.ConnectionReset, errors.ConnectionError), e:
         raise
     except (errors.TransportError, errors.PathError), e:
@@ -91,6 +83,11 @@
         # StubSFTPServer does fail during get() (because of prefetch)
         # so it has an opportunity to translate the error.
         raise errors.NotABundle(str(e))
-    except errors.NotAMergeDirective:
-        f.seek(0)
-        return _serializer.read_bundle(f), transport
+
+    if _do_directive:
+        try:
+            return MergeDirective.from_lines(bytef), transport
+        except errors.NotAMergeDirective:
+            bytef.seek(0)
+
+    return _serializer.read_bundle(bytef), transport

=== modified file 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/bundle/apply_bundle.py	2009-03-23 14:59:43 +0000
+++ bzrlib/bundle/apply_bundle.py	2009-10-06 14:40:37 +0000
@@ -56,7 +56,8 @@
                         change_reporter=change_reporter)
         merger.pp = pp
         merger.pp.next_phase()
-        merger.check_basis(check_clean, require_commits=False)
+        if check_clean and tree.has_changes():
+            raise errors.UncommittedChanges(self)
         merger.other_rev_id = reader.target
         merger.other_tree = merger.revision_tree(reader.target)
         merger.other_basis = reader.target

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2009-08-21 02:10:06 +0000
+++ bzrlib/bzrdir.py	2009-12-02 17:56:06 +0000
@@ -584,8 +584,7 @@
             # permissions as the .bzr directory (probably a bug in copy_tree)
             old_path = self.root_transport.abspath('.bzr')
             new_path = self.root_transport.abspath('backup.bzr')
-            pb.note('making backup of %s' % (old_path,))
-            pb.note('  to %s' % (new_path,))
+            ui.ui_factory.note('making backup of %s\n  to %s' % (old_path, new_path,))
             self.root_transport.copy_tree('.bzr', 'backup.bzr')
             return (old_path, new_path)
         finally:
@@ -1537,6 +1536,10 @@
     This is a deprecated format and may be removed after sept 2006.
     """
 
+    def has_workingtree(self):
+        """See BzrDir.has_workingtree."""
+        return True
+    
     def open_repository(self):
         """See BzrDir.open_repository."""
         from bzrlib.repofmt.weaverepo import RepositoryFormat5
@@ -1558,6 +1561,10 @@
     This is a deprecated format and may be removed after sept 2006.
     """
 
+    def has_workingtree(self):
+        """See BzrDir.has_workingtree."""
+        return True
+    
     def open_repository(self):
         """See BzrDir.open_repository."""
         from bzrlib.repofmt.weaverepo import RepositoryFormat6
@@ -1683,6 +1690,22 @@
             pass
         return self.transport.clone('checkout')
 
+    def has_workingtree(self):
+        """Tell if this bzrdir contains a working tree.
+
+        This will still raise an exception if the bzrdir has a workingtree that
+        is remote & inaccessible.
+
+        Note: if you're going to open the working tree, you should just go
+        ahead and try, and not ask permission first.
+        """
+        from bzrlib.workingtree import WorkingTreeFormat
+        try:
+            WorkingTreeFormat.find_format(self)
+        except errors.NoWorkingTree:
+            return False
+        return True
+
     def needs_format_conversion(self, format=None):
         """See BzrDir.needs_format_conversion()."""
         if format is None:
@@ -1804,7 +1827,7 @@
     def probe_transport(klass, transport):
         """Return the .bzrdir style format present in a directory."""
         try:
-            format_string = transport.get(".bzr/branch-format").read()
+            format_string = transport.get_bytes(".bzr/branch-format")
         except errors.NoSuchFile:
             raise errors.NotBranchError(path=transport.base)
 
@@ -2587,14 +2610,14 @@
         """See Converter.convert()."""
         self.bzrdir = to_convert
         self.pb = pb
-        self.pb.note('starting upgrade from format 4 to 5')
+        ui.ui_factory.note('starting upgrade from format 4 to 5')
         if isinstance(self.bzrdir.transport, local.LocalTransport):
             self.bzrdir.get_workingtree_transport(None).delete('stat-cache')
         self._convert_to_weaves()
         return BzrDir.open(self.bzrdir.root_transport.base)
 
     def _convert_to_weaves(self):
-        self.pb.note('note: upgrade may be faster if all store files are ungzipped first')
+        ui.ui_factory.note('note: upgrade may be faster if all store files are ungzipped first')
         try:
             # TODO permissions
             stat = self.bzrdir.transport.stat('weaves')
@@ -2628,10 +2651,10 @@
         self.pb.clear()
         self._write_all_weaves()
         self._write_all_revs()
-        self.pb.note('upgraded to weaves:')
-        self.pb.note('  %6d revisions and inventories', len(self.revisions))
-        self.pb.note('  %6d revisions not present', len(self.absent_revisions))
-        self.pb.note('  %6d texts', self.text_count)
+        ui.ui_factory.note('upgraded to weaves:')
+        ui.ui_factory.note('  %6d revisions and inventories' % len(self.revisions))
+        ui.ui_factory.note('  %6d revisions not present' % len(self.absent_revisions))
+        ui.ui_factory.note('  %6d texts' % self.text_count)
         self._cleanup_spare_files_after_format4()
         self.branch._transport.put_bytes(
             'branch-format',
@@ -2705,8 +2728,8 @@
                        len(self.known_revisions))
         if not self.branch.repository.has_revision(rev_id):
             self.pb.clear()
-            self.pb.note('revision {%s} not present in branch; '
-                         'will be converted as a ghost',
+            ui.ui_factory.note('revision {%s} not present in branch; '
+                         'will be converted as a ghost' %
                          rev_id)
             self.absent_revisions.add(rev_id)
         else:
@@ -2839,7 +2862,7 @@
         """See Converter.convert()."""
         self.bzrdir = to_convert
         self.pb = pb
-        self.pb.note('starting upgrade from format 5 to 6')
+        ui.ui_factory.note('starting upgrade from format 5 to 6')
         self._convert_to_prefixed()
         return BzrDir.open(self.bzrdir.root_transport.base)
 
@@ -2847,7 +2870,7 @@
         from bzrlib.store import TransportStore
         self.bzrdir.transport.delete('branch-format')
         for store_name in ["weaves", "revision-store"]:
-            self.pb.note("adding prefixes to %s" % store_name)
+            ui.ui_factory.note("adding prefixes to %s" % store_name)
             store_transport = self.bzrdir.transport.clone(store_name)
             store = TransportStore(store_transport, prefixed=True)
             for urlfilename in store_transport.list_dir('.'):
@@ -2887,7 +2910,7 @@
         self.dir_mode = self.bzrdir._get_dir_mode()
         self.file_mode = self.bzrdir._get_file_mode()
 
-        self.pb.note('starting upgrade from format 6 to metadir')
+        ui.ui_factory.note('starting upgrade from format 6 to metadir')
         self.bzrdir.transport.put_bytes(
                 'branch-format',
                 "Converting to format 6",
@@ -2943,7 +2966,7 @@
         else:
             has_checkout = True
         if not has_checkout:
-            self.pb.note('No working tree.')
+            ui.ui_factory.note('No working tree.')
             # If some checkout files are there, we may as well get rid of them.
             for name, mandatory in checkout_files:
                 if name in bzrcontents:
@@ -3018,7 +3041,7 @@
         else:
             if not isinstance(repo._format, self.target_format.repository_format.__class__):
                 from bzrlib.repository import CopyConverter
-                self.pb.note('starting repository conversion')
+                ui.ui_factory.note('starting repository conversion')
                 converter = CopyConverter(self.target_format.repository_format)
                 converter.convert(repo, pb)
         try:
@@ -3088,6 +3111,9 @@
         self._network_name = None
 
     def get_format_description(self):
+        if self._network_name:
+            real_format = network_format_registry.get(self._network_name)
+            return 'Remote: ' + real_format.get_format_description()
         return 'bzr remote bzrdir'
 
     def get_format_string(self):

=== modified file 'bzrlib/check.py'
--- bzrlib/check.py	2009-08-05 02:30:59 +0000
+++ bzrlib/check.py	2009-09-18 01:06:10 +0000
@@ -55,7 +55,7 @@
 from bzrlib.repository import Repository
 from bzrlib.revision import NULL_REVISION
 from bzrlib.symbol_versioning import deprecated_function, deprecated_in
-from bzrlib.trace import log_error, note
+from bzrlib.trace import note
 import bzrlib.ui
 from bzrlib.workingtree import WorkingTree
 
@@ -201,7 +201,7 @@
                 len(self.unreferenced_versions))
         if verbose and len(self.unreferenced_versions):
                 for file_id, revision_id in self.unreferenced_versions:
-                    log_error('unreferenced version: {%s} in %s', revision_id,
+                    note('unreferenced version: {%s} in %s', revision_id,
                         file_id)
         if self.missing_inventory_sha_cnt:
             note('%6d revisions are missing inventory_sha1',
@@ -445,9 +445,9 @@
                     if do_branch:
                         scan_branch(branch, needed_refs, to_unlock)
             if do_branch and not branches:
-                log_error("No branch found at specified location.")
+                note("No branch found at specified location.")
             if do_tree and base_tree is None and not saw_tree:
-                log_error("No working tree found at specified location.")
+                note("No working tree found at specified location.")
             if do_repo or do_branch or do_tree:
                 if do_repo:
                     note("Checking repository at '%s'."
@@ -457,11 +457,11 @@
                 result.report_results(verbose)
         else:
             if do_tree:
-                log_error("No working tree found at specified location.")
+                note("No working tree found at specified location.")
             if do_branch:
-                log_error("No branch found at specified location.")
+                note("No branch found at specified location.")
             if do_repo:
-                log_error("No repository found at specified location.")
+                note("No repository found at specified location.")
     finally:
         for thing in to_unlock:
             thing.unlock()

=== modified file 'bzrlib/chk_map.py'
--- bzrlib/chk_map.py	2009-08-04 14:10:09 +0000
+++ bzrlib/chk_map.py	2009-11-02 17:27:52 +0000
@@ -50,8 +50,10 @@
     lru_cache,
     osutils,
     registry,
+    static_tuple,
     trace,
     )
+from bzrlib.static_tuple import StaticTuple
 
 # approx 4MB
 # If each line is 50 bytes, and you have 255 internal pages, with 255-way fan
@@ -83,6 +85,8 @@
 class CHKMap(object):
     """A persistent map from string to string backed by a CHK store."""
 
+    __slots__ = ('_store', '_root_node', '_search_key_func')
+
     def __init__(self, store, root_key, search_key_func=None):
         """Create a CHKMap object.
 
@@ -112,8 +116,9 @@
         """
         delete_count = 0
         # Check preconditions first.
-        new_items = set([key for (old, key, value) in delta if key is not None
-            and old is None])
+        as_st = StaticTuple.from_sequence
+        new_items = set([as_st(key) for (old, key, value) in delta
+                         if key is not None and old is None])
         existing_new = list(self.iteritems(key_filter=new_items))
         if existing_new:
             raise errors.InconsistentDeltaDelta(delta,
@@ -133,7 +138,7 @@
 
     def _ensure_root(self):
         """Ensure that the root node is an object not a key."""
-        if type(self._root_node) is tuple:
+        if type(self._root_node) is StaticTuple:
             # Demand-load the root
             self._root_node = self._get_node(self._root_node)
 
@@ -147,7 +152,7 @@
         :param node: A tuple key or node object.
         :return: A node object.
         """
-        if type(node) is tuple:
+        if type(node) is StaticTuple:
             bytes = self._read_bytes(node)
             return _deserialise(bytes, node,
                 search_key_func=self._search_key_func)
@@ -194,7 +199,7 @@
             for key, value in sorted(node._items.iteritems()):
                 # Don't use prefix nor indent here to line up when used in
                 # tests in conjunction with assertEqualDiff
-                result.append('      %r %r' % (key, value))
+                result.append('      %r %r' % (tuple(key), value))
         return result
 
     @classmethod
@@ -218,6 +223,9 @@
         root_key = klass._create_directly(store, initial_value,
             maximum_size=maximum_size, key_width=key_width,
             search_key_func=search_key_func)
+        if type(root_key) is not StaticTuple:
+            raise AssertionError('we got a %s instead of a StaticTuple'
+                                 % (type(root_key),))
         return root_key
 
     @classmethod
@@ -238,9 +246,11 @@
         node = LeafNode(search_key_func=search_key_func)
         node.set_maximum_size(maximum_size)
         node._key_width = key_width
-        node._items = dict(initial_value)
+        as_st = StaticTuple.from_sequence
+        node._items = dict([(as_st(key), val) for key, val
+                                               in initial_value.iteritems()])
         node._raw_size = sum([node._key_value_len(key, value)
-                              for key,value in initial_value.iteritems()])
+                              for key,value in node._items.iteritems()])
         node._len = len(node._items)
         node._compute_search_prefix()
         node._compute_serialised_prefix()
@@ -482,11 +492,14 @@
     def iteritems(self, key_filter=None):
         """Iterate over the entire CHKMap's contents."""
         self._ensure_root()
+        if key_filter is not None:
+            as_st = StaticTuple.from_sequence
+            key_filter = [as_st(key) for key in key_filter]
         return self._root_node.iteritems(self._store, key_filter=key_filter)
 
     def key(self):
         """Return the key for this map."""
-        if type(self._root_node) is tuple:
+        if type(self._root_node) is StaticTuple:
             return self._root_node
         else:
             return self._root_node._key
@@ -501,6 +514,7 @@
         :param key: A key to map.
         :param value: The value to assign to key.
         """
+        key = StaticTuple.from_sequence(key)
         # Need a root object.
         self._ensure_root()
         prefix, node_details = self._root_node.map(self._store, key, value)
@@ -517,12 +531,15 @@
     def _node_key(self, node):
         """Get the key for a node whether it's a tuple or node."""
         if type(node) is tuple:
+            node = StaticTuple.from_sequence(node)
+        if type(node) is StaticTuple:
             return node
         else:
             return node._key
 
     def unmap(self, key, check_remap=True):
         """remove key from the map."""
+        key = StaticTuple.from_sequence(key)
         self._ensure_root()
         if type(self._root_node) is InternalNode:
             unmapped = self._root_node.unmap(self._store, key,
@@ -542,7 +559,7 @@
 
         :return: The key of the root node.
         """
-        if type(self._root_node) is tuple:
+        if type(self._root_node) is StaticTuple:
             # Already saved.
             return self._root_node
         keys = list(self._root_node.serialise(self._store))
@@ -556,6 +573,10 @@
         adding the header bytes, and without prefix compression.
     """
 
+    __slots__ = ('_key', '_len', '_maximum_size', '_key_width',
+                 '_raw_size', '_items', '_search_prefix', '_search_key_func'
+                )
+
     def __init__(self, key_width=1):
         """Create a node.
 
@@ -650,6 +671,8 @@
         the key/value pairs.
     """
 
+    __slots__ = ('_common_serialised_prefix', '_serialise_key')
+
     def __init__(self, search_key_func=None):
         Node.__init__(self)
         # All of the keys in this leaf node share this common prefix
@@ -698,6 +721,7 @@
         :param bytes: The bytes of the node.
         :param key: The key that the serialised node has.
         """
+        key = static_tuple.expect_static_tuple(key)
         return _deserialise_leaf_node(bytes, key,
                                       search_key_func=search_key_func)
 
@@ -873,7 +897,7 @@
             lines.append(serialized[prefix_len:])
             lines.extend(value_lines)
         sha1, _, _ = store.add_lines((None,), (), lines)
-        self._key = ("sha1:" + sha1,)
+        self._key = StaticTuple("sha1:" + sha1,).intern()
         bytes = ''.join(lines)
         if len(bytes) != self._current_size():
             raise AssertionError('Invalid _current_size')
@@ -947,6 +971,8 @@
         LeafNode or InternalNode.
     """
 
+    __slots__ = ('_node_width',)
+
     def __init__(self, prefix='', search_key_func=None):
         Node.__init__(self)
         # The size of an internalnode with default values and no children.
@@ -994,6 +1020,7 @@
         :param key: The key that the serialised node has.
         :return: An InternalNode instance.
         """
+        key = static_tuple.expect_static_tuple(key)
         return _deserialise_internal_node(bytes, key,
                                           search_key_func=search_key_func)
 
@@ -1024,7 +1051,7 @@
             # for whatever we are missing
             shortcut = True
             for prefix, node in self._items.iteritems():
-                if node.__class__ is tuple:
+                if node.__class__ is StaticTuple:
                     keys[node] = (prefix, None)
                 else:
                     yield node, None
@@ -1059,7 +1086,7 @@
                     # A given key can only match 1 child node, if it isn't
                     # there, then we can just return nothing
                     return
-                if node.__class__ is tuple:
+                if node.__class__ is StaticTuple:
                     keys[node] = (search_prefix, [key])
                 else:
                     # This is loaded, and the only thing that can match,
@@ -1092,7 +1119,7 @@
                         # We can ignore this one
                         continue
                     node_key_filter = prefix_to_keys[search_prefix]
-                    if node.__class__ is tuple:
+                    if node.__class__ is StaticTuple:
                         keys[node] = (search_prefix, node_key_filter)
                     else:
                         yield node, node_key_filter
@@ -1107,7 +1134,7 @@
                         if sub_prefix in length_filter:
                             node_key_filter.extend(prefix_to_keys[sub_prefix])
                     if node_key_filter: # this key matched something, yield it
-                        if node.__class__ is tuple:
+                        if node.__class__ is StaticTuple:
                             keys[node] = (prefix, node_key_filter)
                         else:
                             yield node, node_key_filter
@@ -1245,7 +1272,7 @@
         :return: An iterable of the keys inserted by this operation.
         """
         for node in self._items.itervalues():
-            if type(node) is tuple:
+            if type(node) is StaticTuple:
                 # Never deserialised.
                 continue
             if node._key is not None:
@@ -1262,7 +1289,7 @@
         lines.append('%s\n' % (self._search_prefix,))
         prefix_len = len(self._search_prefix)
         for prefix, node in sorted(self._items.items()):
-            if type(node) is tuple:
+            if type(node) is StaticTuple:
                 key = node[0]
             else:
                 key = node._key[0]
@@ -1272,7 +1299,7 @@
                     % (serialised, self._search_prefix))
             lines.append(serialised[prefix_len:])
         sha1, _, _ = store.add_lines((None,), (), lines)
-        self._key = ("sha1:" + sha1,)
+        self._key = StaticTuple("sha1:" + sha1,).intern()
         _page_cache.add(self._key, ''.join(lines))
         yield self._key
 
@@ -1307,7 +1334,7 @@
             raise AssertionError("unserialised nodes have no refs.")
         refs = []
         for value in self._items.itervalues():
-            if type(value) is tuple:
+            if type(value) is StaticTuple:
                 refs.append(value)
             else:
                 refs.append(value.key())
@@ -1427,6 +1454,12 @@
 
     def __init__(self, store, new_root_keys, old_root_keys,
                  search_key_func, pb=None):
+        # TODO: Should we add a StaticTuple barrier here? It would be nice to
+        #       force callers to use StaticTuple, because there will often be
+        #       lots of keys passed in here. And even if we cast it locally,
+        #       that just meanst that we will have *both* a StaticTuple and a
+        #       tuple() in memory, referring to the same object. (so a net
+        #       increase in memory, not a decrease.)
         self._store = store
         self._new_root_keys = new_root_keys
         self._old_root_keys = old_root_keys
@@ -1434,11 +1467,16 @@
         # All uninteresting chks that we have seen. By the time they are added
         # here, they should be either fully ignored, or queued up for
         # processing
+        # TODO: This might grow to a large size if there are lots of merge
+        #       parents, etc. However, it probably doesn't scale to O(history)
+        #       like _processed_new_refs does.
         self._all_old_chks = set(self._old_root_keys)
         # All items that we have seen from the old_root_keys
         self._all_old_items = set()
         # These are interesting items which were either read, or already in the
         # interesting queue (so we don't need to walk them again)
+        # TODO: processed_new_refs becomes O(all_chks), consider switching to
+        #       SimpleSet here.
         self._processed_new_refs = set()
         self._search_key_func = search_key_func
 
@@ -1456,6 +1494,7 @@
         # this code. (We may want to evaluate saving the raw bytes into the
         # page cache, which would allow a working tree update after the fetch
         # to not have to read the bytes again.)
+        as_st = StaticTuple.from_sequence
         stream = self._store.get_record_stream(keys, 'unordered', True)
         for record in stream:
             if self._pb is not None:
@@ -1468,10 +1507,18 @@
             if type(node) is InternalNode:
                 # Note we don't have to do node.refs() because we know that
                 # there are no children that have been pushed into this node
+                # Note: Using as_st() here seemed to save 1.2MB, which would
+                #       indicate that we keep 100k prefix_refs around while
+                #       processing. They *should* be shorter lived than that...
+                #       It does cost us ~10s of processing time
+                #prefix_refs = [as_st(item) for item in node._items.iteritems()]
                 prefix_refs = node._items.items()
                 items = []
             else:
                 prefix_refs = []
+                # Note: We don't use a StaticTuple here. Profiling showed a
+                #       minor memory improvement (0.8MB out of 335MB peak 0.2%)
+                #       But a significant slowdown (15s / 145s, or 10%)
                 items = node._items.items()
             yield record, node, prefix_refs, items
 
@@ -1485,6 +1532,10 @@
                                 if p_r[1] not in all_old_chks]
             new_refs = [p_r[1] for p_r in prefix_refs]
             all_old_chks.update(new_refs)
+            # TODO: This might be a good time to turn items into StaticTuple
+            #       instances and possibly intern them. However, this does not
+            #       impact 'initial branch' performance, so I'm not worrying
+            #       about this yet
             self._all_old_items.update(items)
             # Queue up the uninteresting references
             # Don't actually put them in the 'to-read' queue until we have
@@ -1543,6 +1594,9 @@
             #       current design allows for this, as callers will do the work
             #       to make the results unique. We might profile whether we
             #       gain anything by ensuring unique return values for items
+            # TODO: This might be a good time to cast to StaticTuple, as
+            #       self._new_item_queue will hold the contents of multiple
+            #       records for an extended lifetime
             new_items = [item for item in items
                                if item not in self._all_old_items]
             self._new_item_queue.extend(new_items)
@@ -1573,16 +1627,31 @@
         if new_items:
             yield None, new_items
         refs = refs.difference(all_old_chks)
+        processed_new_refs.update(refs)
         while refs:
+            # TODO: Using a SimpleSet for self._processed_new_refs and
+            #       saved as much as 10MB of peak memory. However, it requires
+            #       implementing a non-pyrex version.
             next_refs = set()
             next_refs_update = next_refs.update
             # Inlining _read_nodes_from_store improves 'bzr branch bzr.dev'
             # from 1m54s to 1m51s. Consider it.
             for record, _, p_refs, items in self._read_nodes_from_store(refs):
-                items = [item for item in items
-                         if item not in all_old_items]
+                if all_old_items:
+                    # using the 'if' check saves about 145s => 141s, when
+                    # streaming initial branch of Launchpad data.
+                    items = [item for item in items
+                             if item not in all_old_items]
                 yield record, items
                 next_refs_update([p_r[1] for p_r in p_refs])
+                del p_refs
+            # set1.difference(set/dict) walks all of set1, and checks if it
+            # exists in 'other'.
+            # set1.difference(iterable) walks all of iterable, and does a
+            # 'difference_update' on a clone of set1. Pick wisely based on the
+            # expected sizes of objects.
+            # in our case it is expected that 'new_refs' will always be quite
+            # small.
             next_refs = next_refs.difference(all_old_chks)
             next_refs = next_refs.difference(processed_new_refs)
             processed_new_refs.update(next_refs)
@@ -1595,6 +1664,7 @@
         self._old_queue = []
         all_old_chks = self._all_old_chks
         for record, _, prefix_refs, items in self._read_nodes_from_store(refs):
+            # TODO: Use StaticTuple here?
             self._all_old_items.update(items)
             refs = [r for _,r in prefix_refs if r not in all_old_chks]
             self._old_queue.extend(refs)
@@ -1640,7 +1710,8 @@
         _deserialise_leaf_node,
         _deserialise_internal_node,
         )
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib._chk_map_py import (
         _search_key_16,
         _search_key_255,
@@ -1649,3 +1720,22 @@
         )
 search_key_registry.register('hash-16-way', _search_key_16)
 search_key_registry.register('hash-255-way', _search_key_255)
+
+
+def _check_key(key):
+    """Helper function to assert that a key is properly formatted.
+
+    This generally shouldn't be used in production code, but it can be helpful
+    to debug problems.
+    """
+    if type(key) is not StaticTuple:
+        raise TypeError('key %r is not StaticTuple but %s' % (key, type(key)))
+    if len(key) != 1:
+        raise ValueError('key %r should have length 1, not %d' % (key, len(key),))
+    if type(key[0]) is not str:
+        raise TypeError('key %r should hold a str, not %r'
+                        % (key, type(key[0])))
+    if not key[0].startswith('sha1:'):
+        raise ValueError('key %r should point to a sha1:' % (key,))
+
+

=== added file 'bzrlib/cleanup.py'
--- bzrlib/cleanup.py	1970-01-01 00:00:00 +0000
+++ bzrlib/cleanup.py	2009-10-26 06:23:14 +0000
@@ -0,0 +1,177 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Helpers for managing cleanup functions and the errors they might raise.
+
+The usual way to run cleanup code in Python is::
+
+    try:
+        do_something()
+    finally:
+        cleanup_something()
+
+However if both `do_something` and `cleanup_something` raise an exception
+Python will forget the original exception and propagate the one from
+cleanup_something.  Unfortunately, this is almost always much less useful than
+the original exception.
+
+If you want to be certain that the first, and only the first, error is raised,
+then use::
+
+    operation = OperationWithCleanups(lambda operation: do_something())
+    operation.add_cleanup(cleanup_something)
+    operation.run()
+
+This is more inconvenient (because you need to make every try block a
+function), but will ensure that the first error encountered is the one raised,
+while also ensuring all cleanups are run.  See OperationWithCleanups for more
+details.
+"""
+
+
+from collections import deque
+import sys
+from bzrlib import (
+    debug,
+    trace,
+    )
+
+def _log_cleanup_error(exc):
+    trace.mutter('Cleanup failed:')
+    trace.log_exception_quietly()
+    if 'cleanup' in debug.debug_flags:
+        trace.warning('bzr: warning: Cleanup failed: %s', exc)
+
+
+def _run_cleanup(func, *args, **kwargs):
+    """Run func(*args, **kwargs), logging but not propagating any error it
+    raises.
+
+    :returns: True if func raised no errors, else False.
+    """
+    try:
+        func(*args, **kwargs)
+    except KeyboardInterrupt:
+        raise
+    except Exception, exc:
+        _log_cleanup_error(exc)
+        return False
+    return True
+
+
+def _run_cleanups(funcs):
+    """Run a series of cleanup functions."""
+    for func, args, kwargs in funcs:
+        _run_cleanup(func, *args, **kwargs)
+
+
+class OperationWithCleanups(object):
+    """A way to run some code with a dynamic cleanup list.
+
+    This provides a way to add cleanups while the function-with-cleanups is
+    running.
+
+    Typical use::
+
+        operation = OperationWithCleanups(some_func)
+        operation.run(args...)
+
+    where `some_func` is::
+
+        def some_func(operation, args, ...)
+            do_something()
+            operation.add_cleanup(something)
+            # etc
+
+    Note that the first argument passed to `some_func` will be the
+    OperationWithCleanups object.
+    """
+
+    def __init__(self, func):
+        self.func = func
+        self.cleanups = deque()
+
+    def add_cleanup(self, cleanup_func, *args, **kwargs):
+        """Add a cleanup to run.
+
+        Cleanups may be added at any time before or during the execution of
+        self.func.  Cleanups will be executed in LIFO order.
+        """
+        self.cleanups.appendleft((cleanup_func, args, kwargs))
+
+    def run(self, *args, **kwargs):
+        return _do_with_cleanups(
+            self.cleanups, self.func, self, *args, **kwargs)
+
+
+def _do_with_cleanups(cleanup_funcs, func, *args, **kwargs):
+    """Run `func`, then call all the cleanup_funcs.
+
+    All the cleanup_funcs are guaranteed to be run.  The first exception raised
+    by func or any of the cleanup_funcs is the one that will be propagted by
+    this function (subsequent errors are caught and logged).
+
+    Conceptually similar to::
+
+        try:
+            return func(*args, **kwargs)
+        finally:
+            for cleanup, cargs, ckwargs in cleanup_funcs:
+                cleanup(*cargs, **ckwargs)
+
+    It avoids several problems with using try/finally directly:
+     * an exception from func will not be obscured by a subsequent exception
+       from a cleanup.
+     * an exception from a cleanup will not prevent other cleanups from
+       running (but the first exception encountered is still the one
+       propagated).
+
+    Unike `_run_cleanup`, `_do_with_cleanups` can propagate an exception from a
+    cleanup, but only if there is no exception from func.
+    """
+    # As correct as Python 2.4 allows.
+    try:
+        result = func(*args, **kwargs)
+    except:
+        # We have an exception from func already, so suppress cleanup errors.
+        _run_cleanups(cleanup_funcs)
+        raise
+    else:
+        # No exception from func, so allow the first exception from
+        # cleanup_funcs to propagate if one occurs (but only after running all
+        # of them).
+        exc_info = None
+        for cleanup, c_args, c_kwargs in cleanup_funcs:
+            # XXX: Hmm, if KeyboardInterrupt arrives at exactly this line, we
+            # won't run all cleanups... perhaps we should temporarily install a
+            # SIGINT handler?
+            if exc_info is None:
+                try:
+                    cleanup(*c_args, **c_kwargs)
+                except:
+                    # This is the first cleanup to fail, so remember its
+                    # details.
+                    exc_info = sys.exc_info()
+            else:
+                # We already have an exception to propagate, so log any errors
+                # but don't propagate them.
+                _run_cleanup(cleanup, *c_args, **kwargs)
+        if exc_info is not None:
+            raise exc_info[0], exc_info[1], exc_info[2]
+        # No error, so we can return the result
+        return result
+
+

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2009-06-19 09:06:56 +0000
+++ bzrlib/commands.py	2009-12-02 07:56:16 +0000
@@ -56,6 +56,7 @@
 from bzrlib.symbol_versioning import (
     deprecated_function,
     deprecated_in,
+    deprecated_method,
     suppress_deprecation_warnings,
     )
 
@@ -101,11 +102,11 @@
             registry.Registry.register(self, k_unsquished, cmd,
                                        override_existing=decorate, info=info)
         except KeyError:
-            trace.log_error('Two plugins defined the same command: %r' % k)
-            trace.log_error('Not loading the one in %r' %
-                            sys.modules[cmd.__module__])
-            trace.log_error('Previously this command was registered from %r' %
-                            sys.modules[previous.__module__])
+            trace.warning('Two plugins defined the same command: %r' % k)
+            trace.warning('Not loading the one in %r' %
+                sys.modules[cmd.__module__])
+            trace.warning('Previously this command was registered from %r' %
+                sys.modules[previous.__module__])
         return previous
 
     def register_lazy(self, command_name, aliases, module_name):
@@ -383,18 +384,18 @@
         # List of standard options directly supported
         self.supported_std_options = []
 
+    @deprecated_method(deprecated_in((2, 1, 0)))
     def _maybe_expand_globs(self, file_list):
         """Glob expand file_list if the platform does not do that itself.
 
+        Not used anymore, now that the bzr command-line parser globs on
+        Windows.
+
         :return: A possibly empty list of unicode paths.
 
         Introduced in bzrlib 0.18.
         """
-        if not file_list:
-            file_list = []
-        if sys.platform == 'win32':
-            file_list = win32utils.glob_expand(file_list)
-        return list(file_list)
+        return file_list
 
     def _usage(self):
         """Return single-line grammar for this command.
@@ -457,6 +458,13 @@
         # so we get <https://bugs.launchpad.net/bzr/+bug/249908>.  -- mbp
         # 20090319
         options = option.get_optparser(self.options()).format_option_help()
+        # XXX: According to the spec, ReST option lists actually don't support 
+        # options like --1.9 so that causes syntax errors (in Sphinx at least).
+        # As that pattern always appears in the commands that break, we trap
+        # on that and then format that block of 'format' options as a literal
+        # block.
+        if not plain and options.find('  --1.9  ') != -1:
+            options = options.replace(' format:\n', ' format::\n\n', 1)
         if options.startswith('Options:'):
             result += ':' + options
         elif options.startswith('options:'):
@@ -932,6 +940,9 @@
 
     --coverage
         Generate line coverage report in the specified directory.
+
+    --concurrency
+        Specify the number of processes that can be run concurrently (selftest).
     """
     argv = list(argv)
     trace.mutter("bzr arguments: %r", argv)
@@ -962,6 +973,9 @@
             opt_no_aliases = True
         elif a == '--builtin':
             opt_builtin = True
+        elif a == '--concurrency':
+            os.environ['BZR_CONCURRENCY'] = argv[i + 1]
+            i += 1
         elif a == '--coverage':
             opt_coverage_dir = argv[i + 1]
             i += 1
@@ -1028,13 +1042,13 @@
             ret = apply_coveraged(opt_coverage_dir, run, *run_argv)
         else:
             ret = run(*run_argv)
-        if 'memory' in debug.debug_flags:
-            trace.debug_memory('Process status after command:', short=False)
         return ret or 0
     finally:
         # reset, in case we may do other commands later within the same
         # process. Commands that want to execute sub-commands must propagate
         # --verbose in their own way.
+        if 'memory' in debug.debug_flags:
+            trace.debug_memory('Process status after command:', short=False)
         option._verbosity_level = saved_verbosity_level
 
 
@@ -1090,7 +1104,7 @@
 
     # Is this a final release version? If so, we should suppress warnings
     if bzrlib.version_info[3] == 'final':
-        suppress_deprecation_warnings(override=False)
+        suppress_deprecation_warnings(override=True)
     if argv is None:
         argv = osutils.get_unicode_argv()
     else:
@@ -1107,6 +1121,7 @@
         argv = new_argv
     ret = run_bzr_catch_errors(argv)
     trace.mutter("return code %d", ret)
+    osutils.report_extension_load_failures()
     return ret
 
 

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2009-08-26 05:38:16 +0000
+++ bzrlib/commit.py	2009-10-15 02:53:30 +0000
@@ -65,6 +65,7 @@
     xml_serializer,
     )
 from bzrlib.branch import Branch
+from bzrlib.cleanup import OperationWithCleanups
 import bzrlib.config
 from bzrlib.errors import (BzrError, PointlessCommit,
                            ConflictsInTree,
@@ -234,6 +235,31 @@
             commit. Pending changes to excluded files will be ignored by the
             commit.
         """
+        operation = OperationWithCleanups(self._commit)
+        return operation.run(
+               message=message,
+               timestamp=timestamp,
+               timezone=timezone,
+               committer=committer,
+               specific_files=specific_files,
+               rev_id=rev_id,
+               allow_pointless=allow_pointless,
+               strict=strict,
+               verbose=verbose,
+               revprops=revprops,
+               working_tree=working_tree,
+               local=local,
+               reporter=reporter,
+               config=config,
+               message_callback=message_callback,
+               recursive=recursive,
+               exclude=exclude,
+               possible_master_transports=possible_master_transports)
+
+    def _commit(self, operation, message, timestamp, timezone, committer,
+            specific_files, rev_id, allow_pointless, strict, verbose, revprops,
+            working_tree, local, reporter, config, message_callback, recursive,
+            exclude, possible_master_transports):
         mutter('preparing to commit')
 
         if working_tree is None:
@@ -262,7 +288,6 @@
             self.exclude = []
         self.local = local
         self.master_branch = None
-        self.master_locked = False
         self.recursive = recursive
         self.rev_id = None
         # self.specific_files is None to indicate no filter, or any iterable to
@@ -283,6 +308,7 @@
         self.verbose = verbose
 
         self.work_tree.lock_write()
+        operation.add_cleanup(self.work_tree.unlock)
         self.parents = self.work_tree.get_parent_ids()
         # We can use record_iter_changes IFF iter_changes is compatible with
         # the command line parameters, and the repository has fast delta
@@ -293,119 +319,118 @@
             (self.branch.repository._format.fast_deltas or
              len(self.parents) < 2))
         self.pb = bzrlib.ui.ui_factory.nested_progress_bar()
+        operation.add_cleanup(self.pb.finished)
         self.basis_revid = self.work_tree.last_revision()
         self.basis_tree = self.work_tree.basis_tree()
         self.basis_tree.lock_read()
+        operation.add_cleanup(self.basis_tree.unlock)
+        # Cannot commit with conflicts present.
+        if len(self.work_tree.conflicts()) > 0:
+            raise ConflictsInTree
+
+        # Setup the bound branch variables as needed.
+        self._check_bound_branch(operation, possible_master_transports)
+
+        # Check that the working tree is up to date
+        old_revno, new_revno = self._check_out_of_date_tree()
+
+        # Complete configuration setup
+        if reporter is not None:
+            self.reporter = reporter
+        elif self.reporter is None:
+            self.reporter = self._select_reporter()
+        if self.config is None:
+            self.config = self.branch.get_config()
+
+        self._set_specific_file_ids()
+
+        # Setup the progress bar. As the number of files that need to be
+        # committed in unknown, progress is reported as stages.
+        # We keep track of entries separately though and include that
+        # information in the progress bar during the relevant stages.
+        self.pb_stage_name = ""
+        self.pb_stage_count = 0
+        self.pb_stage_total = 5
+        if self.bound_branch:
+            self.pb_stage_total += 1
+        self.pb.show_pct = False
+        self.pb.show_spinner = False
+        self.pb.show_eta = False
+        self.pb.show_count = True
+        self.pb.show_bar = True
+
+        self._gather_parents()
+        # After a merge, a selected file commit is not supported.
+        # See 'bzr help merge' for an explanation as to why.
+        if len(self.parents) > 1 and self.specific_files is not None:
+            raise errors.CannotCommitSelectedFileMerge(self.specific_files)
+        # Excludes are a form of selected file commit.
+        if len(self.parents) > 1 and self.exclude:
+            raise errors.CannotCommitSelectedFileMerge(self.exclude)
+
+        # Collect the changes
+        self._set_progress_stage("Collecting changes", counter=True)
+        self.builder = self.branch.get_commit_builder(self.parents,
+            self.config, timestamp, timezone, committer, revprops, rev_id)
+
         try:
-            # Cannot commit with conflicts present.
-            if len(self.work_tree.conflicts()) > 0:
-                raise ConflictsInTree
-
-            # Setup the bound branch variables as needed.
-            self._check_bound_branch(possible_master_transports)
-
-            # Check that the working tree is up to date
-            old_revno, new_revno = self._check_out_of_date_tree()
-
-            # Complete configuration setup
-            if reporter is not None:
-                self.reporter = reporter
-            elif self.reporter is None:
-                self.reporter = self._select_reporter()
-            if self.config is None:
-                self.config = self.branch.get_config()
-
-            self._set_specific_file_ids()
-
-            # Setup the progress bar. As the number of files that need to be
-            # committed in unknown, progress is reported as stages.
-            # We keep track of entries separately though and include that
-            # information in the progress bar during the relevant stages.
-            self.pb_stage_name = ""
-            self.pb_stage_count = 0
-            self.pb_stage_total = 5
-            if self.bound_branch:
-                self.pb_stage_total += 1
-            self.pb.show_pct = False
-            self.pb.show_spinner = False
-            self.pb.show_eta = False
-            self.pb.show_count = True
-            self.pb.show_bar = True
-
-            self._gather_parents()
-            # After a merge, a selected file commit is not supported.
-            # See 'bzr help merge' for an explanation as to why.
-            if len(self.parents) > 1 and self.specific_files is not None:
-                raise errors.CannotCommitSelectedFileMerge(self.specific_files)
-            # Excludes are a form of selected file commit.
-            if len(self.parents) > 1 and self.exclude:
-                raise errors.CannotCommitSelectedFileMerge(self.exclude)
-
-            # Collect the changes
-            self._set_progress_stage("Collecting changes", counter=True)
-            self.builder = self.branch.get_commit_builder(self.parents,
-                self.config, timestamp, timezone, committer, revprops, rev_id)
-
-            try:
-                self.builder.will_record_deletes()
-                # find the location being committed to
-                if self.bound_branch:
-                    master_location = self.master_branch.base
-                else:
-                    master_location = self.branch.base
-
-                # report the start of the commit
-                self.reporter.started(new_revno, self.rev_id, master_location)
-
-                self._update_builder_with_changes()
-                self._check_pointless()
-
-                # TODO: Now the new inventory is known, check for conflicts.
-                # ADHB 2006-08-08: If this is done, populate_new_inv should not add
-                # weave lines, because nothing should be recorded until it is known
-                # that commit will succeed.
-                self._set_progress_stage("Saving data locally")
-                self.builder.finish_inventory()
-
-                # Prompt the user for a commit message if none provided
-                message = message_callback(self)
-                self.message = message
-
-                # Add revision data to the local branch
-                self.rev_id = self.builder.commit(self.message)
-
-            except Exception, e:
-                mutter("aborting commit write group because of exception:")
-                trace.log_exception_quietly()
-                note("aborting commit write group: %r" % (e,))
-                self.builder.abort()
-                raise
-
-            self._process_pre_hooks(old_revno, new_revno)
-
-            # Upload revision data to the master.
-            # this will propagate merged revisions too if needed.
-            if self.bound_branch:
-                self._set_progress_stage("Uploading data to master branch")
-                # 'commit' to the master first so a timeout here causes the
-                # local branch to be out of date
-                self.master_branch.import_last_revision_info(
-                    self.branch.repository, new_revno, self.rev_id)
-
-            # and now do the commit locally.
-            self.branch.set_last_revision_info(new_revno, self.rev_id)
-
-            # Make the working tree be up to date with the branch. This
-            # includes automatic changes scheduled to be made to the tree, such
-            # as updating its basis and unversioning paths that were missing.
-            self.work_tree.unversion(self.deleted_ids)
-            self._set_progress_stage("Updating the working tree")
-            self.work_tree.update_basis_by_delta(self.rev_id,
-                 self.builder.get_basis_delta())
-            self.reporter.completed(new_revno, self.rev_id)
-            self._process_post_hooks(old_revno, new_revno)
-        finally:
-            self._cleanup()
+            self.builder.will_record_deletes()
+            # find the location being committed to
+            if self.bound_branch:
+                master_location = self.master_branch.base
+            else:
+                master_location = self.branch.base
+
+            # report the start of the commit
+            self.reporter.started(new_revno, self.rev_id, master_location)
+
+            self._update_builder_with_changes()
+            self._check_pointless()
+
+            # TODO: Now the new inventory is known, check for conflicts.
+            # ADHB 2006-08-08: If this is done, populate_new_inv should not add
+            # weave lines, because nothing should be recorded until it is known
+            # that commit will succeed.
+            self._set_progress_stage("Saving data locally")
+            self.builder.finish_inventory()
+
+            # Prompt the user for a commit message if none provided
+            message = message_callback(self)
+            self.message = message
+
+            # Add revision data to the local branch
+            self.rev_id = self.builder.commit(self.message)
+
+        except Exception, e:
+            mutter("aborting commit write group because of exception:")
+            trace.log_exception_quietly()
+            note("aborting commit write group: %r" % (e,))
+            self.builder.abort()
+            raise
+
+        self._process_pre_hooks(old_revno, new_revno)
+
+        # Upload revision data to the master.
+        # this will propagate merged revisions too if needed.
+        if self.bound_branch:
+            self._set_progress_stage("Uploading data to master branch")
+            # 'commit' to the master first so a timeout here causes the
+            # local branch to be out of date
+            self.master_branch.import_last_revision_info(
+                self.branch.repository, new_revno, self.rev_id)
+
+        # and now do the commit locally.
+        self.branch.set_last_revision_info(new_revno, self.rev_id)
+
+        # Make the working tree be up to date with the branch. This
+        # includes automatic changes scheduled to be made to the tree, such
+        # as updating its basis and unversioning paths that were missing.
+        self.work_tree.unversion(self.deleted_ids)
+        self._set_progress_stage("Updating the working tree")
+        self.work_tree.update_basis_by_delta(self.rev_id,
+             self.builder.get_basis_delta())
+        self.reporter.completed(new_revno, self.rev_id)
+        self._process_post_hooks(old_revno, new_revno)
         return self.rev_id
 
     def _select_reporter(self):
@@ -433,7 +458,7 @@
             return
         raise PointlessCommit()
 
-    def _check_bound_branch(self, possible_master_transports=None):
+    def _check_bound_branch(self, operation, possible_master_transports=None):
         """Check to see if the local branch is bound.
 
         If it is bound, then most of the commit will actually be
@@ -474,7 +499,7 @@
         # so grab the lock
         self.bound_branch = self.branch
         self.master_branch.lock_write()
-        self.master_locked = True
+        operation.add_cleanup(self.master_branch.unlock)
 
     def _check_out_of_date_tree(self):
         """Check that the working tree is up to date.
@@ -565,42 +590,6 @@
                      old_revno, old_revid, new_revno, self.rev_id,
                      tree_delta, future_tree)
 
-    def _cleanup(self):
-        """Cleanup any open locks, progress bars etc."""
-        cleanups = [self._cleanup_bound_branch,
-                    self.basis_tree.unlock,
-                    self.work_tree.unlock,
-                    self.pb.finished]
-        found_exception = None
-        for cleanup in cleanups:
-            try:
-                cleanup()
-            # we want every cleanup to run no matter what.
-            # so we have a catchall here, but we will raise the
-            # last encountered exception up the stack: and
-            # typically this will be useful enough.
-            except Exception, e:
-                found_exception = e
-        if found_exception is not None:
-            # don't do a plan raise, because the last exception may have been
-            # trashed, e is our sure-to-work exception even though it loses the
-            # full traceback. XXX: RBC 20060421 perhaps we could check the
-            # exc_info and if its the same one do a plain raise otherwise
-            # 'raise e' as we do now.
-            raise e
-
-    def _cleanup_bound_branch(self):
-        """Executed at the end of a try/finally to cleanup a bound branch.
-
-        If the branch wasn't bound, this is a no-op.
-        If it was, it resents self.branch to the local branch, instead
-        of being the master.
-        """
-        if not self.bound_branch:
-            return
-        if self.master_locked:
-            self.master_branch.unlock()
-
     def _gather_parents(self):
         """Record the parents of a merge for merge detection."""
         # TODO: Make sure that this list doesn't contain duplicate

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2009-08-20 04:53:23 +0000
+++ bzrlib/config.py	2009-12-02 22:04:04 +0000
@@ -153,6 +153,15 @@
         """Get the users pop up editor."""
         raise NotImplementedError
 
+    def get_change_editor(self, old_tree, new_tree):
+        from bzrlib import diff
+        cmd = self._get_change_editor()
+        if cmd is None:
+            return None
+        return diff.DiffFromTool.from_string(cmd, old_tree, new_tree,
+                                             sys.stdout)
+
+
     def get_mail_client(self):
         """Get a mail client to use"""
         selected_client = self.get_user_option('mail_client')
@@ -346,6 +355,9 @@
         """Return the policy for the given (section, option_name) pair."""
         return POLICY_NONE
 
+    def _get_change_editor(self):
+        return self.get_user_option('change_editor')
+
     def _get_signature_checking(self):
         """See Config._get_signature_checking."""
         policy = self._get_user_option('check_signatures')
@@ -679,6 +691,9 @@
 
         return self._get_best_value('_get_user_id')
 
+    def _get_change_editor(self):
+        return self._get_best_value('_get_change_editor')
+
     def _get_signature_checking(self):
         """See Config._get_signature_checking."""
         return self._get_best_value('_get_signature_checking')
@@ -1457,7 +1472,7 @@
 
     def _get_config_file(self):
         try:
-            return self._transport.get(self._filename)
+            return StringIO(self._transport.get_bytes(self._filename))
         except errors.NoSuchFile:
             return StringIO()
 

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2009-03-23 14:59:43 +0000
+++ bzrlib/conflicts.py	2009-11-23 03:15:33 +0000
@@ -53,13 +53,12 @@
     instead.  (This is useful for editing all files with text conflicts.)
 
     Use bzr resolve when you have fixed a problem.
-
-    See also bzr resolve.
     """
     takes_options = [
             Option('text',
                    help='List paths of files with text conflicts.'),
         ]
+    _see_also = ['resolve']
 
     def run(self, text=False):
         from bzrlib.workingtree import WorkingTree
@@ -82,16 +81,15 @@
     before you should commit.
 
     Once you have fixed a problem, use "bzr resolve" to automatically mark
-    text conflicts as fixed, resolve FILE to mark a specific conflict as
+    text conflicts as fixed, "bzr resolve FILE" to mark a specific conflict as
     resolved, or "bzr resolve --all" to mark all conflicts as resolved.
-
-    See also bzr conflicts.
     """
     aliases = ['resolved']
     takes_args = ['file*']
     takes_options = [
             Option('all', help='Resolve all conflicts in this tree.'),
             ]
+    _see_also = ['conflicts']
     def run(self, file_list=None, all=False):
         from bzrlib.workingtree import WorkingTree
         if all:

=== modified file 'bzrlib/decorators.py'
--- bzrlib/decorators.py	2009-03-23 14:59:43 +0000
+++ bzrlib/decorators.py	2009-10-15 02:19:43 +0000
@@ -24,6 +24,8 @@
 
 import sys
 
+from bzrlib import trace
+
 
 def _get_parameters(func):
     """Recreate the parameters for a function using introspection.
@@ -204,6 +206,31 @@
     return write_locked
 
 
+def only_raises(*errors):
+    """Make a decorator that will only allow the given error classes to be
+    raised.  All other errors will be logged and then discarded.
+
+    Typical use is something like::
+
+        @only_raises(LockNotHeld, LockBroken)
+        def unlock(self):
+            # etc
+    """
+    def decorator(unbound):
+        def wrapped(*args, **kwargs):
+            try:
+                return unbound(*args, **kwargs)
+            except errors:
+                raise
+            except:
+                trace.mutter('Error suppressed by only_raises:')
+                trace.log_exception_quietly()
+        wrapped.__doc__ = unbound.__doc__
+        wrapped.__name__ = unbound.__name__
+        return wrapped
+    return decorator
+
+
 # Default is more functionality, 'bzr' the commandline will request fast
 # versions.
 needs_read_lock = _pretty_needs_read_lock

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2009-03-23 14:59:43 +0000
+++ bzrlib/delta.py	2009-10-29 05:54:49 +0000
@@ -47,7 +47,7 @@
 
     Files that are both modified and renamed are listed only in
     renamed, with the text_modified flag true. The text_modified
-    applies either to the the content of the file or the target of the
+    applies either to the content of the file or the target of the
     symbolic link, depending of the kind of file.
 
     Files are only considered renamed if their name has changed or

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2009-07-29 21:35:05 +0000
+++ bzrlib/diff.py	2009-11-03 01:15:09 +0000
@@ -18,6 +18,7 @@
 import os
 import re
 import shutil
+import string
 import sys
 
 from bzrlib.lazy_import import lazy_import
@@ -46,6 +47,12 @@
 from bzrlib.trace import mutter, note, warning
 
 
+class AtTemplate(string.Template):
+    """Templating class that uses @ instead of $."""
+
+    delimiter = '@'
+
+
 # TODO: Rather than building a changeset object, we should probably
 # invoke callbacks on an object.  That object can either accumulate a
 # list, write them out directly, etc etc.
@@ -277,8 +284,8 @@
                         new_abspath, e)
 
 
-def _get_trees_to_diff(path_list, revision_specs, old_url, new_url,
-    apply_view=True):
+def get_trees_and_branches_to_diff(path_list, revision_specs, old_url, new_url,
+                                   apply_view=True):
     """Get the trees and specific files to diff given a list of paths.
 
     This method works out the trees to be diff'ed and the files of
@@ -299,9 +306,9 @@
         if True and a view is set, apply the view or check that the paths
         are within it
     :returns:
-        a tuple of (old_tree, new_tree, specific_files, extra_trees) where
-        extra_trees is a sequence of additional trees to search in for
-        file-ids.
+        a tuple of (old_tree, new_tree, old_branch, new_branch,
+        specific_files, extra_trees) where extra_trees is a sequence of
+        additional trees to search in for file-ids.
     """
     # Get the old and new revision specs
     old_revision_spec = None
@@ -341,6 +348,7 @@
             views.check_path_in_view(working_tree, relpath)
         specific_files.append(relpath)
     old_tree = _get_tree_to_diff(old_revision_spec, working_tree, branch)
+    old_branch = branch
 
     # Get the new location
     if new_url is None:
@@ -354,6 +362,7 @@
             specific_files.append(relpath)
     new_tree = _get_tree_to_diff(new_revision_spec, working_tree, branch,
         basis_is_default=working_tree is None)
+    new_branch = branch
 
     # Get the specific files (all files is None, no files is [])
     if make_paths_wt_relative and working_tree is not None:
@@ -378,7 +387,8 @@
     extra_trees = None
     if working_tree is not None and working_tree not in (old_tree, new_tree):
         extra_trees = (working_tree,)
-    return old_tree, new_tree, specific_files, extra_trees
+    return old_tree, new_tree, old_branch, new_branch, specific_files, extra_trees
+
 
 def _get_tree_to_diff(spec, tree=None, branch=None, basis_is_default=True):
     if branch is None and tree is not None:
@@ -669,7 +679,8 @@
     def from_string(klass, command_string, old_tree, new_tree, to_file,
                     path_encoding='utf-8'):
         command_template = commands.shlex_split_unicode(command_string)
-        command_template.extend(['%(old_path)s', '%(new_path)s'])
+        if '@' not in command_string:
+            command_template.extend(['@old_path', '@new_path'])
         return klass(command_template, old_tree, new_tree, to_file,
                      path_encoding)
 
@@ -682,7 +693,8 @@
 
     def _get_command(self, old_path, new_path):
         my_map = {'old_path': old_path, 'new_path': new_path}
-        return [t % my_map for t in self.command_template]
+        return [AtTemplate(t).substitute(my_map) for t in
+                self.command_template]
 
     def _execute(self, old_path, new_path):
         command = self._get_command(old_path, new_path)
@@ -708,9 +720,10 @@
                 raise
         return True
 
-    def _write_file(self, file_id, tree, prefix, relpath):
+    def _write_file(self, file_id, tree, prefix, relpath, force_temp=False,
+                    allow_write=False):
         full_path = osutils.pathjoin(self._root, prefix, relpath)
-        if self._try_symlink_root(tree, prefix):
+        if not force_temp and self._try_symlink_root(tree, prefix):
             return full_path
         parent_dir = osutils.dirname(full_path)
         try:
@@ -727,16 +740,19 @@
                 target.close()
         finally:
             source.close()
-        osutils.make_readonly(full_path)
+        if not allow_write:
+            osutils.make_readonly(full_path)
         mtime = tree.get_file_mtime(file_id)
         os.utime(full_path, (mtime, mtime))
         return full_path
 
-    def _prepare_files(self, file_id, old_path, new_path):
+    def _prepare_files(self, file_id, old_path, new_path, force_temp=False,
+                       allow_write_new=False):
         old_disk_path = self._write_file(file_id, self.old_tree, 'old',
-                                         old_path)
+                                         old_path, force_temp)
         new_disk_path = self._write_file(file_id, self.new_tree, 'new',
-                                         new_path)
+                                         new_path, force_temp,
+                                         allow_write=allow_write_new)
         return old_disk_path, new_disk_path
 
     def finish(self):
@@ -754,6 +770,29 @@
         self._execute(osutils.pathjoin('old', old_path),
                       osutils.pathjoin('new', new_path))
 
+    def edit_file(self, file_id):
+        """Use this tool to edit a file.
+
+        A temporary copy will be edited, and the new contents will be
+        returned.
+
+        :param file_id: The id of the file to edit.
+        :return: The new contents of the file.
+        """
+        old_path = self.old_tree.id2path(file_id)
+        new_path = self.new_tree.id2path(file_id)
+        new_abs_path = self._prepare_files(file_id, old_path, new_path,
+                                           allow_write_new=True,
+                                           force_temp=True)[1]
+        command = self._get_command(osutils.pathjoin('old', old_path),
+                                    osutils.pathjoin('new', new_path))
+        subprocess.call(command, cwd=self._root)
+        new_file = open(new_abs_path, 'r')
+        try:
+            return new_file.read()
+        finally:
+            new_file.close()
+
 
 class DiffTree(object):
     """Provides textual representations of the difference between two trees.

=== modified file 'bzrlib/dirstate.py'
--- bzrlib/dirstate.py	2009-08-26 03:20:32 +0000
+++ bzrlib/dirstate.py	2009-11-08 19:29:02 +0000
@@ -1324,7 +1324,7 @@
                 key = (dirname_utf8, basename, file_id)
                 minikind = DirState._kind_to_minikind[inv_entry.kind]
                 if minikind == 't':
-                    fingerprint = inv_entry.reference_revision
+                    fingerprint = inv_entry.reference_revision or ''
                 else:
                     fingerprint = ''
                 insertions[file_id] = (key, minikind, inv_entry.executable,
@@ -1339,14 +1339,14 @@
                     minikind = child[1][0][0]
                     fingerprint = child[1][0][4]
                     executable = child[1][0][3]
-                    old_child_path = osutils.pathjoin(child[0][0],
-                                                      child[0][1])
+                    old_child_path = osutils.pathjoin(child_dirname,
+                                                      child_basename)
                     removals[child[0][2]] = old_child_path
                     child_suffix = child_dirname[len(old_path):]
                     new_child_dirname = (new_path + child_suffix)
                     key = (new_child_dirname, child_basename, child[0][2])
-                    new_child_path = os.path.join(new_child_dirname,
-                                                  child_basename)
+                    new_child_path = osutils.pathjoin(new_child_dirname,
+                                                      child_basename)
                     insertions[child[0][2]] = (key, minikind, executable,
                                                fingerprint, new_child_path)
         self._check_delta_ids_absent(new_ids, delta, 0)
@@ -3328,7 +3328,9 @@
                         content_change = False
                     target_exec = False
                 else:
-                    raise Exception, "unknown kind %s" % path_info[2]
+                    if path is None:
+                        path = pathjoin(old_dirname, old_basename)
+                    raise errors.BadFileKindError(path, path_info[2])
             if source_minikind == 'd':
                 if path is None:
                     old_path = path = pathjoin(old_dirname, old_basename)
@@ -3969,7 +3971,8 @@
         ProcessEntryC as _process_entry,
         update_entry as update_entry,
         )
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib._dirstate_helpers_py import (
         _read_dirblocks,
         bisect_dirblock,

=== modified file 'bzrlib/doc_generate/autodoc_man.py'
--- bzrlib/doc_generate/autodoc_man.py	2009-06-19 10:00:56 +0000
+++ bzrlib/doc_generate/autodoc_man.py	2009-11-04 12:25:49 +0000
@@ -171,7 +171,7 @@
 man_head = """\
 .TH bzr 1 "%(datestamp)s" "%(version)s" "Bazaar"
 .SH "NAME"
-Bazaar (%(bzrcmd)s) - next-generation distributed version control
+%(bzrcmd)s - Bazaar next-generation distributed version control
 .SH "SYNOPSIS"
 .B "%(bzrcmd)s"
 .I "command"

=== modified file 'bzrlib/doc_generate/autodoc_rstx.py'
--- bzrlib/doc_generate/autodoc_rstx.py	2009-07-22 14:36:38 +0000
+++ bzrlib/doc_generate/autodoc_rstx.py	2009-09-09 14:35:26 +0000
@@ -31,6 +31,14 @@
 import bzrlib.osutils
 
 
+# Set this to True to generate a file per topic.
+# This probably ought to be an option. The files probably
+# ought to be prefixed with their section name as well so
+# there's zero risk of clashing with a standard sphinx
+# topic (like search.html).
+FILE_PER_TOPIC = False
+
+
 def get_filename(options):
     """Provides name of manual"""
     return "%s_man.txt" % (options.bzr_name)
@@ -119,6 +127,8 @@
 
 def _dump_text(filename, text):
     """Dump text to filename."""
+    if not FILE_PER_TOPIC:
+        return
     f =  open(filename, "w")
     f.writelines(text)
     f.close()
@@ -160,13 +170,6 @@
 Bazaar User Reference
 #####################
 
-:Version:   %(version)s
-:Generated: %(datestamp)s
-
-.. contents:: :depth: 3
-
------
-
 About This Manual
 #################
 

=== added file 'bzrlib/doc_generate/sphinx_conf.py'
--- bzrlib/doc_generate/sphinx_conf.py	1970-01-01 00:00:00 +0000
+++ bzrlib/doc_generate/sphinx_conf.py	2009-09-08 16:37:05 +0000
@@ -0,0 +1,214 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# All configuration values have a default; values that are commented out
+# serve to show the default.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+#sys.path.append(os.path.abspath('.'))
+
+
+# -- General configuration -----------------------------------------------------
+
+# Add any Sphinx extension module names here, as strings. They can be extensions
+# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+extensions = ['sphinx.ext.ifconfig']
+
+# Add any paths that contain templates here, relative to this directory.
+templates_path = ['_templates']
+
+# The suffix of source filenames.
+source_suffix = '.txt'
+
+# The encoding of source files.
+#source_encoding = 'utf-8'
+
+# The master toctree document.
+master_doc = 'index'
+
+# General information about the project.
+project = u'Bazaar'
+copyright = u'2009, Canonical Ltd'
+
+# The version info for the project you're documenting, acts as replacement for
+# |version| and |release|, also used in various other places throughout the
+# built documents.
+#
+# The short X.Y version.
+import bzrlib
+version = '.'.join(str(p) for p in bzrlib.version_info[:2])
+# The full version, including alpha/beta/rc tags.
+release = bzrlib.version_string
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+#language = None
+
+# There are two options for replacing |today|: either, you set today to some
+# non-false value, then it is used:
+#today = ''
+# Else, today_fmt is used as the format for a strftime call.
+#today_fmt = '%B %d, %Y'
+
+# List of documents that shouldn't be included in the build.
+#unused_docs = []
+
+# List of directories, relative to source directory, that shouldn't be searched
+# for source files.
+exclude_trees = ['_build']
+
+# The reST default role (used for this markup: `text`) to use for all documents.
+#default_role = None
+
+# If true, '()' will be appended to :func: etc. cross-reference text.
+#add_function_parentheses = True
+
+# If true, the current module name will be prepended to all description
+# unit titles (such as .. function::).
+#add_module_names = True
+
+# If true, sectionauthor and moduleauthor directives will be shown in the
+# output. They are ignored by default.
+#show_authors = False
+
+# The name of the Pygments (syntax highlighting) style to use.
+pygments_style = 'sphinx'
+
+# A list of ignored prefixes for module index sorting.
+#modindex_common_prefix = []
+
+
+# -- Options for HTML output ---------------------------------------------------
+
+# The theme to use for HTML and HTML Help pages.  Major themes that come with
+# Sphinx are currently 'default' and 'sphinxdoc'.
+html_theme = 'default'
+
+# Theme options are theme-specific and customize the look and feel of a theme
+# further.  For a list of options available for each theme, see the
+# documentation.
+html_theme_options = {
+    # Unfortunately, the right sidebar breaks under IE6 and maybe IE7.
+    # So we stick with the default left placement to cater for users stuck
+    # on those browsers.
+    #'rightsidebar': True,
+
+    # Non-document areas: header (relbar), footer, sidebar, etc.
+    # Some useful colours here:
+    # * blue: darkblue, mediumblue, darkslateblue, cornflowerblue, royalblue,
+    #   midnightblue
+    # * gray: dimgray, slategray, lightslategray
+    'sidebarbgcolor':   "cornflowerblue",
+    'sidebarlinkcolor': "midnightblue",
+    'relbarbgcolor':    "darkblue",
+    'footerbgcolor':    "lightslategray",
+
+    # Text, heading and code colouring
+    'codebgcolor':      "lightyellow",
+    'codetextcolor':    "firebrick",
+    'linkcolor':        "mediumblue",
+    }
+
+# Add any paths that contain custom themes here, relative to this directory.
+#html_theme_path = []
+
+# The name for this set of Sphinx documents.  If None, it defaults to
+# "<project> v<release> documentation".
+#html_title = None
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+#html_short_title = None
+
+# The name of an image file (relative to this directory) to place at the top
+# of the sidebar.
+#html_logo = None
+
+# The name of an image file (within the static path) to use as favicon of the
+# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
+# pixels large.
+html_favicon = "bzr.ico"
+
+# Add any paths that contain custom static files (such as style sheets) here,
+# relative to this directory. They are copied after the builtin static files,
+# so a file named "default.css" will overwrite the builtin "default.css".
+html_static_path = ['_static']
+
+# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
+# using the given strftime format.
+#html_last_updated_fmt = '%b %d, %Y'
+
+# If true, SmartyPants will be used to convert quotes and dashes to
+# typographically correct entities.
+#html_use_smartypants = True
+
+# Custom sidebar templates, maps document names to template names.
+#html_sidebars = {}
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {}
+
+# If false, no module index is generated.
+html_use_modindex = False
+
+# If false, no index is generated.
+html_use_index = False
+
+# If true, the index is split into individual pages for each letter.
+#html_split_index = False
+
+# If true, links to the reST sources are added to the pages.
+html_show_sourcelink = True
+
+# If true, an OpenSearch description file will be output, and all pages will
+# contain a <link> tag referring to it.  The value of this option must be the
+# base URL from which the finished HTML is served.
+#html_use_opensearch = ''
+
+# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
+#html_file_suffix = ''
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-docs'
+
+
+# -- Options for LaTeX output --------------------------------------------------
+
+# The paper size ('letter' or 'a4').
+#latex_paper_size = 'letter'
+
+# The font size ('10pt', '11pt' or '12pt').
+#latex_font_size = '10pt'
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = []
+
+# The name of an image file (relative to this directory) to place at the top of
+# the title page.
+latex_logo = '../Bazaar-Logo-For-Manuals.png'
+
+# For "manual" documents, if this is true, then toplevel headings are parts,
+# not chapters.
+#latex_use_parts = False
+
+# Additional stuff for the LaTeX preamble.
+#latex_preamble = ''
+
+# Documents to append as an appendix to all manuals.
+#latex_appendices = []
+
+# If false, no module index is generated.
+#latex_use_modindex = True
+
+
+# -- Bazaar-specific configuration ---------------------------------------------
+
+# Authors of the documents
+bzr_team = u'Bazaar Developers'

=== modified file 'bzrlib/export/zip_exporter.py'
--- bzrlib/export/zip_exporter.py	2009-03-23 14:59:43 +0000
+++ bzrlib/export/zip_exporter.py	2009-11-25 00:14:05 +0000
@@ -36,8 +36,9 @@
 # Windows expects this bit to be set in the 'external_attr' section
 # Or it won't consider the entry a directory
 ZIP_DIRECTORY_BIT = (1 << 4)
+FILE_PERMISSIONS = (0644 << 16)
 
-_FILE_ATTR = stat.S_IFREG
+_FILE_ATTR = stat.S_IFREG | FILE_PERMISSIONS
 _DIR_ATTR = stat.S_IFDIR | ZIP_DIRECTORY_BIT
 
 

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2009-08-07 04:29:36 +0000
+++ bzrlib/fetch.py	2009-12-01 22:34:04 +0000
@@ -28,6 +28,8 @@
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 from bzrlib import (
+    graph as _mod_graph,
+    static_tuple,
     tsort,
     versionedfile,
     )
@@ -36,10 +38,10 @@
 from bzrlib import (
     errors,
     symbol_versioning,
+    ui,
     )
 from bzrlib.revision import NULL_REVISION
 from bzrlib.trace import mutter
-import bzrlib.ui
 
 
 class RepoFetcher(object):
@@ -96,7 +98,7 @@
         # assert not missing
         self.count_total = 0
         self.file_ids_names = {}
-        pb = bzrlib.ui.ui_factory.nested_progress_bar()
+        pb = ui.ui_factory.nested_progress_bar()
         pb.show_pct = pb.show_count = False
         try:
             pb.update("Finding revisions", 0, 2)
@@ -123,7 +125,7 @@
             raise errors.IncompatibleRepositories(
                 self.from_repository, self.to_repository,
                 "different rich-root support")
-        pb = bzrlib.ui.ui_factory.nested_progress_bar()
+        pb = ui.ui_factory.nested_progress_bar()
         try:
             pb.update("Get stream source")
             source = self.from_repository._get_source(
@@ -251,13 +253,22 @@
         # yet, and are unlikely to in non-rich-root environments anyway.
         root_id_order.sort(key=operator.itemgetter(0))
         # Create a record stream containing the roots to create.
-        from bzrlib.graph import FrozenHeadsCache
-        graph = FrozenHeadsCache(graph)
+        if len(revs) > 100:
+            graph = _get_rich_root_heads_graph(self.source_repo, revs)
         new_roots_stream = _new_root_data_stream(
             root_id_order, rev_id_to_root_id, parent_map, self.source, graph)
         return [('texts', new_roots_stream)]
 
 
+def _get_rich_root_heads_graph(source_repo, revision_ids):
+    """Get a Graph object suitable for asking heads() for new rich roots."""
+    st = static_tuple.StaticTuple
+    revision_keys = [st(r_id).intern() for r_id in revision_ids]
+    known_graph = source_repo.revisions.get_known_graph_ancestry(
+                    revision_keys)
+    return _mod_graph.GraphThunkIdsToKeys(known_graph)
+
+
 def _new_root_data_stream(
     root_keys_to_create, rev_id_to_root_id_map, parent_map, repo, graph=None):
     """Generate a texts substream of synthesised root entries.

=== modified file 'bzrlib/foreign.py'
--- bzrlib/foreign.py	2009-07-14 02:15:03 +0000
+++ bzrlib/foreign.py	2009-10-27 21:54:26 +0000
@@ -36,7 +36,7 @@
 """)
 
 class VcsMapping(object):
-    """Describes the mapping between the semantics of Bazaar and a foreign vcs.
+    """Describes the mapping between the semantics of Bazaar and a foreign VCS.
 
     """
     # Whether this is an experimental mapping that is still open to changes.
@@ -122,7 +122,17 @@
 class ForeignVcs(object):
     """A foreign version control system."""
 
-    def __init__(self, mapping_registry):
+    branch_format = None
+
+    repository_format = None
+
+    def __init__(self, mapping_registry, abbreviation=None):
+        """Create a new foreign vcs instance.
+
+        :param mapping_registry: Registry with mappings for this VCS.
+        :param abbreviation: Optional abbreviation ('bzr', 'svn', 'git', etc)
+        """
+        self.abbreviation = abbreviation
         self.mapping_registry = mapping_registry
 
     def show_foreign_revid(self, foreign_revid):
@@ -133,6 +143,15 @@
         """
         return { }
 
+    def serialize_foreign_revid(self, foreign_revid):
+        """Serialize a foreign revision id for this VCS.
+
+        :param foreign_revid: Foreign revision id
+        :return: Bytestring with serialized revid, will not contain any 
+            newlines.
+        """
+        raise NotImplementedError(self.serialize_foreign_revid)
+
 
 class ForeignVcsRegistry(registry.Registry):
     """Registry for Foreign VCSes.
@@ -271,20 +290,25 @@
     """
     hidden = True
     takes_args = ['location?']
-    takes_options = ['remember', Option('directory',
-            help='Branch to push from, '
-                 'rather than the one containing the working directory.',
-            short_name='d',
-            type=unicode,
-            ),
-            Option('no-rebase', help="Do not rebase after push.")]
+    takes_options = [
+        'remember',
+        Option('directory',
+               help='Branch to push from, '
+               'rather than the one containing the working directory.',
+               short_name='d',
+               type=unicode,
+               ),
+        Option('no-rebase', help="Do not rebase after push."),
+        Option('strict',
+               help='Refuse to push if there are uncommitted changes in'
+               ' the working tree, --no-strict disables the check.'),
+        ]
 
-    def run(self, location=None, remember=False, directory=None, 
-            no_rebase=False):
+    def run(self, location=None, remember=False, directory=None,
+            no_rebase=False, strict=None):
         from bzrlib import urlutils
         from bzrlib.bzrdir import BzrDir
         from bzrlib.errors import BzrCommandError, NoWorkingTree
-        from bzrlib.trace import info
         from bzrlib.workingtree import WorkingTree
 
         if directory is None:
@@ -295,6 +319,20 @@
         except NoWorkingTree:
             source_branch = Branch.open(directory)
             source_wt = None
+        if strict is None:
+            strict = source_branch.get_config(
+                ).get_user_option_as_bool('dpush_strict')
+        if strict is None: strict = True # default value
+        if strict and source_wt is not None:
+            if (source_wt.has_changes()):
+                raise errors.UncommittedChanges(
+                    source_wt, more='Use --no-strict to force the push.')
+            if source_wt.last_revision() != source_wt.branch.last_revision():
+                # The tree has lost sync with its branch, there is little
+                # chance that the user is aware of it but he can still force
+                # the push with --no-strict
+                raise errors.OutOfDateTree(
+                    source_wt, more='Use --no-strict to force the push.')
         stored_loc = source_branch.get_push_location()
         if location is None:
             if stored_loc is None:

=== modified file 'bzrlib/globbing.py'
--- bzrlib/globbing.py	2009-03-23 14:59:43 +0000
+++ bzrlib/globbing.py	2009-11-11 21:38:02 +0000
@@ -238,11 +238,15 @@
                     prefix=r'(?:.*/)?(?!.*/)')
 
 
+_slashes = re.compile(r'[\\/]+')
 def normalize_pattern(pattern):
     """Converts backslashes in path patterns to forward slashes.
 
     Doesn't normalize regular expressions - they may contain escapes.
     """
+
     if not pattern.startswith('RE:'):
-        pattern = pattern.replace('\\','/')
-    return pattern.rstrip('/')
+        pattern = _slashes.sub('/', pattern)
+    if len(pattern) > 1:
+        pattern = pattern.rstrip('/')
+    return pattern

=== modified file 'bzrlib/graph.py'
--- bzrlib/graph.py	2009-08-17 18:36:14 +0000
+++ bzrlib/graph.py	2009-11-30 03:16:22 +0000
@@ -19,6 +19,7 @@
 from bzrlib import (
     debug,
     errors,
+    osutils,
     revision,
     trace,
     )
@@ -1678,8 +1679,22 @@
     return result
 
 
+class GraphThunkIdsToKeys(object):
+    """Forwards calls about 'ids' to be about keys internally."""
+
+    def __init__(self, graph):
+        self._graph = graph
+
+    def heads(self, ids):
+        """See Graph.heads()"""
+        as_keys = [(i,) for i in ids]
+        head_keys = self._graph.heads(as_keys)
+        return set([h[0] for h in head_keys])
+
+
 _counters = [0,0,0,0,0,0,0]
 try:
     from bzrlib._known_graph_pyx import KnownGraph
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib._known_graph_py import KnownGraph

=== modified file 'bzrlib/groupcompress.py'
--- bzrlib/groupcompress.py	2009-08-26 16:47:51 +0000
+++ bzrlib/groupcompress.py	2009-12-01 03:35:25 +0000
@@ -31,6 +31,7 @@
     knit,
     osutils,
     pack,
+    static_tuple,
     trace,
     )
 from bzrlib.btree_index import BTreeBuilder
@@ -119,13 +120,8 @@
         :param num_bytes: Ensure that we have extracted at least num_bytes of
             content. If None, consume everything
         """
-        # TODO: If we re-use the same content block at different times during
-        #       get_record_stream(), it is possible that the first pass will
-        #       get inserted, triggering an extract/_ensure_content() which
-        #       will get rid of _z_content. And then the next use of the block
-        #       will try to access _z_content (to send it over the wire), and
-        #       fail because it is already extracted. Consider never releasing
-        #       _z_content because of this.
+        if self._content_length is None:
+            raise AssertionError('self._content_length should never be None')
         if num_bytes is None:
             num_bytes = self._content_length
         elif (self._content_length is not None
@@ -148,7 +144,10 @@
                 self._content = pylzma.decompress(self._z_content)
             elif self._compressor_name == 'zlib':
                 # Start a zlib decompressor
-                if num_bytes is None:
+                if num_bytes * 4 > self._content_length * 3:
+                    # If we are requesting more that 3/4ths of the content,
+                    # just extract the whole thing in a single pass
+                    num_bytes = self._content_length
                     self._content = zlib.decompress(self._z_content)
                 else:
                     self._z_content_decompressor = zlib.decompressobj()
@@ -156,6 +155,8 @@
                     # that the rest of the code is simplified
                     self._content = self._z_content_decompressor.decompress(
                         self._z_content, num_bytes + _ZLIB_DECOMP_WINDOW)
+                    if not self._z_content_decompressor.unconsumed_tail:
+                        self._z_content_decompressor = None
             else:
                 raise AssertionError('Unknown compressor: %r'
                                      % self._compressor_name)
@@ -163,45 +164,28 @@
         # 'unconsumed_tail'
 
         # Do we have enough bytes already?
-        if num_bytes is not None and len(self._content) >= num_bytes:
-            return
-        if num_bytes is None and self._z_content_decompressor is None:
-            # We must have already decompressed everything
+        if len(self._content) >= num_bytes:
             return
         # If we got this far, and don't have a decompressor, something is wrong
         if self._z_content_decompressor is None:
             raise AssertionError(
                 'No decompressor to decompress %d bytes' % num_bytes)
         remaining_decomp = self._z_content_decompressor.unconsumed_tail
-        if num_bytes is None:
-            if remaining_decomp:
-                # We don't know how much is left, but we'll decompress it all
-                self._content += self._z_content_decompressor.decompress(
-                    remaining_decomp)
-                # Note: There's what I consider a bug in zlib.decompressobj
-                #       If you pass back in the entire unconsumed_tail, only
-                #       this time you don't pass a max-size, it doesn't
-                #       change the unconsumed_tail back to None/''.
-                #       However, we know we are done with the whole stream
-                self._z_content_decompressor = None
-            # XXX: Why is this the only place in this routine we set this?
-            self._content_length = len(self._content)
-        else:
-            if not remaining_decomp:
-                raise AssertionError('Nothing left to decompress')
-            needed_bytes = num_bytes - len(self._content)
-            # We always set max_size to 32kB over the minimum needed, so that
-            # zlib will give us as much as we really want.
-            # TODO: If this isn't good enough, we could make a loop here,
-            #       that keeps expanding the request until we get enough
-            self._content += self._z_content_decompressor.decompress(
-                remaining_decomp, needed_bytes + _ZLIB_DECOMP_WINDOW)
-            if len(self._content) < num_bytes:
-                raise AssertionError('%d bytes wanted, only %d available'
-                                     % (num_bytes, len(self._content)))
-            if not self._z_content_decompressor.unconsumed_tail:
-                # The stream is finished
-                self._z_content_decompressor = None
+        if not remaining_decomp:
+            raise AssertionError('Nothing left to decompress')
+        needed_bytes = num_bytes - len(self._content)
+        # We always set max_size to 32kB over the minimum needed, so that
+        # zlib will give us as much as we really want.
+        # TODO: If this isn't good enough, we could make a loop here,
+        #       that keeps expanding the request until we get enough
+        self._content += self._z_content_decompressor.decompress(
+            remaining_decomp, needed_bytes + _ZLIB_DECOMP_WINDOW)
+        if len(self._content) < num_bytes:
+            raise AssertionError('%d bytes wanted, only %d available'
+                                 % (num_bytes, len(self._content)))
+        if not self._z_content_decompressor.unconsumed_tail:
+            # The stream is finished
+            self._z_content_decompressor = None
 
     def _parse_bytes(self, bytes, pos):
         """Read the various lengths from the header.
@@ -457,7 +441,6 @@
                 # There are code paths that first extract as fulltext, and then
                 # extract as storage_kind (smart fetch). So we don't break the
                 # refcycle here, but instead in manager.get_record_stream()
-                # self._manager = None
             if storage_kind == 'fulltext':
                 return self._bytes
             else:
@@ -469,6 +452,14 @@
 class _LazyGroupContentManager(object):
     """This manages a group of _LazyGroupCompressFactory objects."""
 
+    _max_cut_fraction = 0.75 # We allow a block to be trimmed to 75% of
+                             # current size, and still be considered
+                             # resuable
+    _full_block_size = 4*1024*1024
+    _full_mixed_block_size = 2*1024*1024
+    _full_enough_block_size = 3*1024*1024 # size at which we won't repack
+    _full_enough_mixed_block_size = 2*768*1024 # 1.5MB
+
     def __init__(self, block):
         self._block = block
         # We need to preserve the ordering
@@ -546,22 +537,23 @@
         # time (self._block._content) is a little expensive.
         self._block._ensure_content(self._last_byte)
 
-    def _check_rebuild_block(self):
+    def _check_rebuild_action(self):
         """Check to see if our block should be repacked."""
         total_bytes_used = 0
         last_byte_used = 0
         for factory in self._factories:
             total_bytes_used += factory._end - factory._start
-            last_byte_used = max(last_byte_used, factory._end)
-        # If we are using most of the bytes from the block, we have nothing
-        # else to check (currently more that 1/2)
+            if last_byte_used < factory._end:
+                last_byte_used = factory._end
+        # If we are using more than half of the bytes from the block, we have
+        # nothing else to check
         if total_bytes_used * 2 >= self._block._content_length:
-            return
-        # Can we just strip off the trailing bytes? If we are going to be
-        # transmitting more than 50% of the front of the content, go ahead
+            return None, last_byte_used, total_bytes_used
+        # We are using less than 50% of the content. Is the content we are
+        # using at the beginning of the block? If so, we can just trim the
+        # tail, rather than rebuilding from scratch.
         if total_bytes_used * 2 > last_byte_used:
-            self._trim_block(last_byte_used)
-            return
+            return 'trim', last_byte_used, total_bytes_used
 
         # We are using a small amount of the data, and it isn't just packed
         # nicely at the front, so rebuild the content.
@@ -574,7 +566,80 @@
         #       expanding many deltas into fulltexts, as well.
         #       If we build a cheap enough 'strip', then we could try a strip,
         #       if that expands the content, we then rebuild.
-        self._rebuild_block()
+        return 'rebuild', last_byte_used, total_bytes_used
+
+    def check_is_well_utilized(self):
+        """Is the current block considered 'well utilized'?
+
+        This heuristic asks if the current block considers itself to be a fully
+        developed group, rather than just a loose collection of data.
+        """
+        if len(self._factories) == 1:
+            # A block of length 1 could be improved by combining with other
+            # groups - don't look deeper. Even larger than max size groups
+            # could compress well with adjacent versions of the same thing.
+            return False
+        action, last_byte_used, total_bytes_used = self._check_rebuild_action()
+        block_size = self._block._content_length
+        if total_bytes_used < block_size * self._max_cut_fraction:
+            # This block wants to trim itself small enough that we want to
+            # consider it under-utilized.
+            return False
+        # TODO: This code is meant to be the twin of _insert_record_stream's
+        #       'start_new_block' logic. It would probably be better to factor
+        #       out that logic into a shared location, so that it stays
+        #       together better
+        # We currently assume a block is properly utilized whenever it is >75%
+        # of the size of a 'full' block. In normal operation, a block is
+        # considered full when it hits 4MB of same-file content. So any block
+        # >3MB is 'full enough'.
+        # The only time this isn't true is when a given block has large-object
+        # content. (a single file >4MB, etc.)
+        # Under these circumstances, we allow a block to grow to
+        # 2 x largest_content.  Which means that if a given block had a large
+        # object, it may actually be under-utilized. However, given that this
+        # is 'pack-on-the-fly' it is probably reasonable to not repack large
+        # content blobs on-the-fly. Note that because we return False for all
+        # 1-item blobs, we will repack them; we may wish to reevaluate our
+        # treatment of large object blobs in the future.
+        if block_size >= self._full_enough_block_size:
+            return True
+        # If a block is <3MB, it still may be considered 'full' if it contains
+        # mixed content. The current rule is 2MB of mixed content is considered
+        # full. So check to see if this block contains mixed content, and
+        # set the threshold appropriately.
+        common_prefix = None
+        for factory in self._factories:
+            prefix = factory.key[:-1]
+            if common_prefix is None:
+                common_prefix = prefix
+            elif prefix != common_prefix:
+                # Mixed content, check the size appropriately
+                if block_size >= self._full_enough_mixed_block_size:
+                    return True
+                break
+        # The content failed both the mixed check and the single-content check
+        # so obviously it is not fully utilized
+        # TODO: there is one other constraint that isn't being checked
+        #       namely, that the entries in the block are in the appropriate
+        #       order. For example, you could insert the entries in exactly
+        #       reverse groupcompress order, and we would think that is ok.
+        #       (all the right objects are in one group, and it is fully
+        #       utilized, etc.) For now, we assume that case is rare,
+        #       especially since we should always fetch in 'groupcompress'
+        #       order.
+        return False
+
+    def _check_rebuild_block(self):
+        action, last_byte_used, total_bytes_used = self._check_rebuild_action()
+        if action is None:
+            return
+        if action == 'trim':
+            self._trim_block(last_byte_used)
+        elif action == 'rebuild':
+            self._rebuild_block()
+        else:
+            raise ValueError('unknown rebuild action: %r' % (action,))
 
     def _wire_bytes(self):
         """Return a byte stream suitable for transmitting over the wire."""
@@ -1087,20 +1152,28 @@
 class GroupCompressVersionedFiles(VersionedFiles):
     """A group-compress based VersionedFiles implementation."""
 
-    def __init__(self, index, access, delta=True):
+    def __init__(self, index, access, delta=True, _unadded_refs=None):
         """Create a GroupCompressVersionedFiles object.
 
         :param index: The index object storing access and graph data.
         :param access: The access object storing raw data.
         :param delta: Whether to delta compress or just entropy compress.
+        :param _unadded_refs: private parameter, don't use.
         """
         self._index = index
         self._access = access
         self._delta = delta
-        self._unadded_refs = {}
+        if _unadded_refs is None:
+            _unadded_refs = {}
+        self._unadded_refs = _unadded_refs
         self._group_cache = LRUSizeCache(max_size=50*1024*1024)
         self._fallback_vfs = []
 
+    def without_fallbacks(self):
+        """Return a clone of this object without any fallbacks configured."""
+        return GroupCompressVersionedFiles(self._index, self._access,
+            self._delta, _unadded_refs=dict(self._unadded_refs))
+
     def add_lines(self, key, parents, lines, parent_texts=None,
         left_matching_blocks=None, nostore_sha=None, random_id=False,
         check_content=True):
@@ -1193,6 +1266,12 @@
         else:
             return self.get_record_stream(keys, 'unordered', True)
 
+    def clear_cache(self):
+        """See VersionedFiles.clear_cache()"""
+        self._group_cache.clear()
+        self._index._graph_index.clear_cache()
+        self._index._int_cache.clear()
+
     def _check_add(self, key, lines, random_id, check_content):
         """check that version_id and lines are safe to add."""
         version_id = key[-1]
@@ -1570,6 +1649,7 @@
         block_length = None
         # XXX: TODO: remove this, it is just for safety checking for now
         inserted_keys = set()
+        reuse_this_block = reuse_blocks
         for record in stream:
             # Raise an error when a record is missing.
             if record.storage_kind == 'absent':
@@ -1583,10 +1663,20 @@
             if reuse_blocks:
                 # If the reuse_blocks flag is set, check to see if we can just
                 # copy a groupcompress block as-is.
+                # We only check on the first record (groupcompress-block) not
+                # on all of the (groupcompress-block-ref) entries.
+                # The reuse_this_block flag is then kept for as long as
+                if record.storage_kind == 'groupcompress-block':
+                    # Check to see if we really want to re-use this block
+                    insert_manager = record._manager
+                    reuse_this_block = insert_manager.check_is_well_utilized()
+            else:
+                reuse_this_block = False
+            if reuse_this_block:
+                # We still want to reuse this block
                 if record.storage_kind == 'groupcompress-block':
                     # Insert the raw block into the target repo
                     insert_manager = record._manager
-                    insert_manager._check_rebuild_block()
                     bytes = record._manager._block.to_bytes()
                     _, start, length = self._access.add_raw_records(
                         [(None, len(bytes))], bytes)[0]
@@ -1597,6 +1687,11 @@
                                            'groupcompress-block-ref'):
                     if insert_manager is None:
                         raise AssertionError('No insert_manager set')
+                    if insert_manager is not record._manager:
+                        raise AssertionError('insert_manager does not match'
+                            ' the current record, we cannot be positive'
+                            ' that the appropriate content was inserted.'
+                            )
                     value = "%d %d %d %d" % (block_start, block_length,
                                              record._start, record._end)
                     nodes = [(record.key, value, (record.parents,))]
@@ -1652,8 +1747,13 @@
                 key = record.key
             self._unadded_refs[key] = record.parents
             yield found_sha1
-            keys_to_add.append((key, '%d %d' % (start_point, end_point),
-                (record.parents,)))
+            as_st = static_tuple.StaticTuple.from_sequence
+            if record.parents is not None:
+                parents = as_st([as_st(p) for p in record.parents])
+            else:
+                parents = None
+            refs = static_tuple.StaticTuple(parents)
+            keys_to_add.append((key, '%d %d' % (start_point, end_point), refs))
         if len(keys_to_add):
             flush()
         self._compressor = None
@@ -1714,7 +1814,7 @@
 
     def __init__(self, graph_index, is_locked, parents=True,
         add_callback=None, track_external_parent_refs=False,
-        inconsistency_fatal=True):
+        inconsistency_fatal=True, track_new_keys=False):
         """Construct a _GCGraphIndex on a graph_index.
 
         :param graph_index: An implementation of bzrlib.index.GraphIndex.
@@ -1739,8 +1839,12 @@
         self.has_graph = parents
         self._is_locked = is_locked
         self._inconsistency_fatal = inconsistency_fatal
+        # GroupCompress records tend to have the same 'group' start + offset
+        # repeated over and over, this creates a surplus of ints
+        self._int_cache = {}
         if track_external_parent_refs:
-            self._key_dependencies = knit._KeyRefs()
+            self._key_dependencies = knit._KeyRefs(
+                track_new_keys=track_new_keys)
         else:
             self._key_dependencies = None
 
@@ -1779,8 +1883,11 @@
         if not random_id:
             present_nodes = self._get_entries(keys)
             for (index, key, value, node_refs) in present_nodes:
-                if node_refs != keys[key][1]:
-                    details = '%s %s %s' % (key, (value, node_refs), keys[key])
+                # Sometimes these are passed as a list rather than a tuple
+                node_refs = static_tuple.as_tuples(node_refs)
+                passed = static_tuple.as_tuples(keys[key])
+                if node_refs != passed[1]:
+                    details = '%s %s %s' % (key, (value, node_refs), passed)
                     if self._inconsistency_fatal:
                         raise errors.KnitCorrupt(self, "inconsistent details"
                                                  " in add_records: %s" %
@@ -1800,10 +1907,14 @@
                     result.append((key, value))
             records = result
         key_dependencies = self._key_dependencies
-        if key_dependencies is not None and self._parents:
-            for key, value, refs in records:
-                parents = refs[0]
-                key_dependencies.add_references(key, parents)
+        if key_dependencies is not None:
+            if self._parents:
+                for key, value, refs in records:
+                    parents = refs[0]
+                    key_dependencies.add_references(key, parents)
+            else:
+                for key, value, refs in records:
+                    new_keys.add_key(key)
         self._add_callback(records)
 
     def _check_read(self):
@@ -1866,7 +1977,7 @@
         """Return the keys of missing parents."""
         # Copied from _KnitGraphIndex.get_missing_parents
         # We may have false positives, so filter those out.
-        self._key_dependencies.add_keys(
+        self._key_dependencies.satisfy_refs_for_keys(
             self.get_parent_map(self._key_dependencies.get_unsatisfied_refs()))
         return frozenset(self._key_dependencies.get_unsatisfied_refs())
 
@@ -1915,28 +2026,41 @@
         """Convert an index value to position details."""
         bits = node[2].split(' ')
         # It would be nice not to read the entire gzip.
+        # start and stop are put into _int_cache because they are very common.
+        # They define the 'group' that an entry is in, and many groups can have
+        # thousands of objects.
+        # Branching Launchpad, for example, saves ~600k integers, at 12 bytes
+        # each, or about 7MB. Note that it might be even more when you consider
+        # how PyInt is allocated in separate slabs. And you can't return a slab
+        # to the OS if even 1 int on it is in use. Note though that Python uses
+        # a LIFO when re-using PyInt slots, which probably causes more
+        # fragmentation.
         start = int(bits[0])
+        start = self._int_cache.setdefault(start, start)
         stop = int(bits[1])
+        stop = self._int_cache.setdefault(stop, stop)
         basis_end = int(bits[2])
         delta_end = int(bits[3])
-        return node[0], start, stop, basis_end, delta_end
+        # We can't use StaticTuple here, because node[0] is a BTreeGraphIndex
+        # instance...
+        return (node[0], start, stop, basis_end, delta_end)
 
     def scan_unvalidated_index(self, graph_index):
         """Inform this _GCGraphIndex that there is an unvalidated index.
 
         This allows this _GCGraphIndex to keep track of any missing
         compression parents we may want to have filled in to make those
-        indices valid.
+        indices valid.  It also allows _GCGraphIndex to track any new keys.
 
         :param graph_index: A GraphIndex
         """
-        if self._key_dependencies is not None:
-            # Add parent refs from graph_index (and discard parent refs that
-            # the graph_index has).
-            add_refs = self._key_dependencies.add_references
-            for node in graph_index.iter_all_entries():
-                add_refs(node[1], node[3][0])
-
+        key_dependencies = self._key_dependencies
+        if key_dependencies is None:
+            return
+        for node in graph_index.iter_all_entries():
+            # Add parent refs from graph_index (and discard parent refs
+            # that the graph_index has).
+            key_dependencies.add_references(node[1], node[3][0])
 
 
 from bzrlib._groupcompress_py import (
@@ -1956,6 +2080,7 @@
         decode_base128_int,
         )
     GroupCompressor = PyrexGroupCompressor
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     GroupCompressor = PythonGroupCompressor
 

=== modified file 'bzrlib/help_topics/__init__.py'
--- bzrlib/help_topics/__init__.py	2009-06-19 09:06:56 +0000
+++ bzrlib/help_topics/__init__.py	2009-12-02 23:11:43 +0000
@@ -152,10 +152,16 @@
     out.append(
 """Revision Identifiers
 
-A revision identifier refers to a specific state of a branch's history. It can
-be a revision number, or a keyword followed by ':' and often other
-parameters. Some examples of identifiers are '3', 'last:1', 'before:yesterday'
-and 'submit:'.
+A revision identifier refers to a specific state of a branch's history.  It
+can be expressed in several ways.  It can begin with a keyword to
+unambiguously specify a given lookup type; some examples are 'last:1',
+'before:yesterday' and 'submit:'.
+
+Alternately, it can be given without a keyword, in which case it will be
+checked as a revision number, a tag, a revision id, a date specification, or a
+branch specification, in that order.  For example, 'date:today' could be
+written as simply 'today', though if you have a tag called 'today' that will
+be found first.
 
 If 'REV1' and 'REV2' are revision identifiers, then 'REV1..REV2' denotes a
 revision range. Examples: '3647..3649', 'date:yesterday..-1' and
@@ -245,6 +251,26 @@
         out += "\nSupported modifiers::\n\n  " + \
             '  '.join(decl)
 
+    out += """\
+\nBazaar supports all of the standard parts within the URL::
+
+  <protocol>://[user[:password]@]host[:port]/[path]
+
+allowing URLs such as::
+
+  http://bzruser:BadPass@bzr.example.com:8080/bzr/trunk
+
+For bzr+ssh:// and sftp:// URLs, Bazaar also supports paths that begin
+with '~' as meaning that the rest of the path should be interpreted
+relative to the remote user's home directory.  For example if the user
+``remote`` has a  home directory of ``/home/remote`` on the server
+shell.example.com, then::
+
+  bzr+ssh://remote@shell.example.com/~/myproject/trunk
+
+would refer to ``/home/remote/myproject/trunk``.
+"""
+
     return out
 
 
@@ -287,6 +313,7 @@
 --builtin      Use the built-in version of a command, not the plugin version.
                This does not suppress other plugin effects.
 --no-plugins   Do not process any plugins.
+--concurrency  Number of processes that can be run concurrently (selftest).
 
 --profile      Profile execution using the hotshot profiler.
 --lsprof       Profile execution using the lsprof profiler.
@@ -555,9 +582,10 @@
 BZR_HOME         Directory holding .bazaar config dir. Overrides HOME.
 BZR_HOME (Win32) Directory holding bazaar config dir. Overrides APPDATA and HOME.
 BZR_REMOTE_PATH  Full name of remote 'bzr' command (for bzr+ssh:// URLs).
-BZR_SSH          SSH client: paramiko (default), openssh, ssh, plink.
+BZR_SSH          Path to SSH client, or one of paramiko, openssh, sshcorp, plink.
 BZR_LOG          Location of .bzr.log (use '/dev/null' to suppress log).
 BZR_LOG (Win32)  Location of .bzr.log (use 'NUL' to suppress log).
+BZR_CONCURRENCY  Number of processes that can be run concurrently (selftest).
 ================ =================================================================
 """
 
@@ -644,38 +672,20 @@
 formats may also be introduced to improve performance and
 scalability.
 
-Use the following guidelines to select a format (stopping
-as soon as a condition is true):
-
-* If you are working on an existing project, use whatever
-  format that project is using. (Bazaar will do this for you
-  by default).
-
-* If you are using bzr-svn to interoperate with a Subversion
-  repository, use 1.14-rich-root.
-
-* If you are working on a project with big trees (5000+ paths)
-  or deep history (5000+ revisions), use 1.14.
-
-* Otherwise, use the default format - it is good enough for
-  most projects.
-
-If some of your developers are unable to use the most recent
-version of Bazaar (due to distro package availability say), be
-sure to adjust the guidelines above accordingly. For example,
-you may need to select 1.9 instead of 1.14 if your project has
-standardized on Bazaar 1.13.1 say.
-
-Note: Many of the currently supported formats have two variants:
+The newest format, 2a, is highly recommended. If your
+project is not using 2a, then you should suggest to the
+project owner to upgrade.
+
+
+Note: Some of the older formats have two variants:
 a plain one and a rich-root one. The latter include an additional
 field about the root of the tree. There is no performance cost
 for using a rich-root format but you cannot easily merge changes
 from a rich-root format into a plain format. As a consequence,
 moving a project to a rich-root format takes some co-ordination
 in that all contributors need to upgrade their repositories
-around the same time. (It is for this reason that we have delayed
-making a rich-root format the default so far, though we will do
-so at some appropriate time in the future.)
+around the same time. 2a and all future formats will be
+implicitly rich-root.
 
 See ``bzr help current-formats`` for the complete list of
 currently supported formats. See ``bzr help other-formats`` for

=== modified file 'bzrlib/help_topics/en/configuration.txt'
--- bzrlib/help_topics/en/configuration.txt	2009-06-26 18:13:41 +0000
+++ bzrlib/help_topics/en/configuration.txt	2009-10-02 09:11:43 +0000
@@ -63,6 +63,60 @@
 ~~~~~~~~~~~~~~~
 
 The path to the plugins directory that Bazaar should use.
+If not set, Bazaar will search for plugins in:
+
+* the user specific plugin directory (containing the ``user`` plugins),
+
+* the bzrlib directory (containing the ``core`` plugins),
+
+* the site specific plugin directory if applicable (containing
+  the ``site`` plugins).
+
+If ``BZR_PLUGIN_PATH`` is set in any fashion, it will change the
+the way the plugin are searched. 
+
+As for the ``PATH`` variables, if multiple directories are
+specified in ``BZR_PLUGIN_PATH`` they should be separated by the
+platform specific appropriate character (':' on Unix/Linux/etc,
+';' on windows)
+
+By default if ``BZR_PLUGIN_PATH`` is set, it replaces searching
+in ``user``.  However it will continue to search in ``core`` and
+``site`` unless they are explicitly removed.
+
+If you need to change the order or remove one of these
+directories, you should use special values:
+
+* ``-user``, ``-core``, ``-site`` will remove the corresponding
+  path from the default values,
+
+* ``+user``, ``+core``, ``+site`` will add the corresponding path
+  before the remaining default values (and also remove it from
+  the default values).
+
+Note that the special values 'user', 'core' and 'site' should be
+used literally, they will be substituted by the corresponding,
+platform specific, values.
+
+Examples:
+^^^^^^^^^
+
+The examples below uses ':' as the separator, windows users
+should use ';'.
+
+Overriding the default user plugin directory:
+``BZR_PLUGIN_PATH='/path/to/my/other/plugins'``
+
+Disabling the site directory while retaining the user directory:
+``BZR_PLUGIN_PATH='-site:+user'``
+
+Disabling all plugins (better achieved with --no-plugins):
+``BZR_PLUGIN_PATH='-user:-core:-site'``
+
+Overriding the default site plugin directory:
+``BZR_PLUGIN_PATH='/path/to/my/site/plugins:-site':+user``
+
+
 
 BZRPATH
 ~~~~~~~
@@ -410,6 +464,13 @@
 If present, defines the ``--strict`` option default value for checking
 uncommitted changes before pushing.
 
+dpush_strict
+~~~~~~~~~~~~
+
+If present, defines the ``--strict`` option default value for checking
+uncommitted changes before pushing into a different VCS without any
+custom bzr metadata.
+
 bound_location
 ~~~~~~~~~~~~~~
 

=== modified file 'bzrlib/help_topics/en/conflicts.txt'
--- bzrlib/help_topics/en/conflicts.txt	2007-12-25 04:17:50 +0000
+++ bzrlib/help_topics/en/conflicts.txt	2009-11-25 16:42:55 +0000
@@ -79,6 +79,29 @@
 FILE".  Bazaar cannot auto-detect when conflicts of this kind have been
 resolved.
 
+Tag conflicts
+-------------
+
+Typical message::
+
+  Conflicting tags:
+      version-0.1
+
+When pulling from or pushing to another branch, Bazaar informs you about tags
+that conflict between the two branches; that is the same tag points to two
+different revisions.  You need not resolve these conflicts, but subsequent
+uses of pull or push will result in the same message.
+
+To resolve the conflict, you must apply the correct tags to either the target
+branch or the source branch as appropriate.  Use "bzr tags --show-ids -d
+SOURCE_URL" to see the tags in the source branch.  If you want to make the
+target branch's tags match the source branch, then in the target branch do 
+``bzr tag --force -r revid:REVISION_ID CONFLICTING_TAG`` for each of the
+CONFLICTING_TAGs, where REVISION_ID comes from the list of tags in the source
+branch.  You need not call "bzr resolve" after doing this.  To resolve in favor of the target branch, you need to similarly use ``tag --force`` in the source
+branch.  (Note that pulling or pushing using --overwrite will overwrite all
+tags as well.)
+
 Duplicate paths
 ---------------
 

=== modified file 'bzrlib/help_topics/en/debug-flags.txt'
--- bzrlib/help_topics/en/debug-flags.txt	2009-08-20 05:02:45 +0000
+++ bzrlib/help_topics/en/debug-flags.txt	2009-11-02 17:15:20 +0000
@@ -22,16 +22,19 @@
 -Dhttp            Trace http connections, requests and responses.
 -Dindex           Trace major index operations.
 -Dknit            Trace knit operations.
--Dstrict_locks    Trace when OS locks are potentially used in a non-portable
-                  manner.
 -Dlock            Trace when lockdir locks are taken or released.
 -Dprogress        Trace progress bar operations.
 -Dmerge           Emit information for debugging merges.
 -Dno_apport       Don't use apport to report crashes.
--Dunlock          Some errors during unlock are treated as warnings.
 -Dpack            Emit information about pack operations.
+-Drelock          Emit a message every time a branch or repository object is
+                  unlocked then relocked the same way.
 -Dsftp            Trace SFTP internals.
+-Dstatic_tuple    Error when a tuple is used where a StaticTuple is expected
 -Dstream          Trace fetch streams.
+-Dstrict_locks    Trace when OS locks are potentially used in a non-portable
+                  manner.
+-Dunlock          Some errors during unlock are treated as warnings.
 -DIDS_never       Never use InterDifferingSerializer when fetching.
 -DIDS_always      Always use InterDifferingSerializer to fetch if appropriate
                   for the format, even for non-local fetches.

=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2009-06-10 03:31:01 +0000
+++ bzrlib/hooks.py	2009-09-01 12:29:54 +0000
@@ -219,9 +219,7 @@
         strings.append('Introduced in: %s' % introduced_string)
         if self.deprecated:
             deprecated_string = _format_version_tuple(self.deprecated)
-        else:
-            deprecated_string = 'Not deprecated'
-        strings.append('Deprecated in: %s' % deprecated_string)
+            strings.append('Deprecated in: %s' % deprecated_string)
         strings.append('')
         strings.extend(textwrap.wrap(self.__doc__,
             break_long_words=False))

=== modified file 'bzrlib/index.py'
--- bzrlib/index.py	2009-08-17 22:11:06 +0000
+++ bzrlib/index.py	2009-12-02 17:59:15 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007, 2008 Canonical Ltd
+# Copyright (C) 2007, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
     debug,
     errors,
     )
+from bzrlib.static_tuple import StaticTuple
 
 _HEADER_READV = (0, 200)
 _OPTION_KEY_ELEMENTS = "key_elements="
@@ -92,9 +93,10 @@
         :param key_elements: The number of bytestrings in each key.
         """
         self.reference_lists = reference_lists
-        self._keys = set()
         # A dict of {key: (absent, ref_lists, value)}
         self._nodes = {}
+        # Keys that are referenced but not actually present in this index
+        self._absent_keys = set()
         self._nodes_by_key = None
         self._key_length = key_elements
         self._optimize_for_size = False
@@ -102,7 +104,7 @@
 
     def _check_key(self, key):
         """Raise BadIndexKey if key is not a valid key for this index."""
-        if type(key) != tuple:
+        if type(key) not in (tuple, StaticTuple):
             raise errors.BadIndexKey(key)
         if self._key_length != len(key):
             raise errors.BadIndexKey(key)
@@ -164,9 +166,9 @@
             return
         key_dict = self._nodes_by_key
         if self.reference_lists:
-            key_value = key, value, node_refs
+            key_value = StaticTuple(key, value, node_refs)
         else:
-            key_value = key, value
+            key_value = StaticTuple(key, value)
         for subkey in key[:-1]:
             key_dict = key_dict.setdefault(subkey, {})
         key_dict[key[-1]] = key_value
@@ -188,6 +190,7 @@
                                 This may contain duplicates if the same key is
                                 referenced in multiple lists.
         """
+        as_st = StaticTuple.from_sequence
         self._check_key(key)
         if _newline_null_re.search(value) is not None:
             raise errors.BadIndexValue(value)
@@ -202,8 +205,10 @@
                 if reference not in self._nodes:
                     self._check_key(reference)
                     absent_references.append(reference)
-            node_refs.append(tuple(reference_list))
-        return tuple(node_refs), absent_references
+            reference_list = as_st([as_st(ref).intern()
+                                    for ref in reference_list])
+            node_refs.append(reference_list)
+        return as_st(node_refs), absent_references
 
     def add_node(self, key, value, references=()):
         """Add a node to the index.
@@ -224,16 +229,25 @@
             # There may be duplicates, but I don't think it is worth worrying
             # about
             self._nodes[reference] = ('a', (), '')
+        self._absent_keys.update(absent_references)
+        self._absent_keys.discard(key)
         self._nodes[key] = ('', node_refs, value)
-        self._keys.add(key)
         if self._nodes_by_key is not None and self._key_length > 1:
             self._update_nodes_by_key(key, value, node_refs)
 
+    def clear_cache(self):
+        """See GraphIndex.clear_cache()
+
+        This is a no-op, but we need the api to conform to a generic 'Index'
+        abstraction.
+        """
+        
     def finish(self):
         lines = [_SIGNATURE]
         lines.append(_OPTION_NODE_REFS + str(self.reference_lists) + '\n')
         lines.append(_OPTION_KEY_ELEMENTS + str(self._key_length) + '\n')
-        lines.append(_OPTION_LEN + str(len(self._keys)) + '\n')
+        key_count = len(self._nodes) - len(self._absent_keys)
+        lines.append(_OPTION_LEN + str(key_count) + '\n')
         prefix_length = sum(len(x) for x in lines)
         # references are byte offsets. To avoid having to do nasty
         # polynomial work to resolve offsets (references to later in the
@@ -368,7 +382,7 @@
     suitable for production use. :XXX
     """
 
-    def __init__(self, transport, name, size):
+    def __init__(self, transport, name, size, unlimited_cache=False):
         """Open an index called name on transport.
 
         :param transport: A bzrlib.transport.Transport.
@@ -441,6 +455,7 @@
         trailers = 0
         pos = stream.tell()
         lines = stream.read().split('\n')
+        stream.close()
         del lines[-1]
         _, _, _, trailers = self._parse_lines(lines, pos)
         for key, absent, references, value in self._keys_by_offset.itervalues():
@@ -453,11 +468,18 @@
                 node_value = value
             self._nodes[key] = node_value
         # cache the keys for quick set intersections
-        self._keys = set(self._nodes)
         if trailers != 1:
             # there must be one line - the empty trailer line.
             raise errors.BadIndexData(self)
 
+    def clear_cache(self):
+        """Clear out any cached/memoized values.
+
+        This can be called at any time, but generally it is used when we have
+        extracted some information, but don't expect to be requesting any more
+        from this index.
+        """
+
     def external_references(self, ref_list_num):
         """Return references that are not present in this index.
         """
@@ -466,10 +488,11 @@
             raise ValueError('No ref list %d, index has %d ref lists'
                 % (ref_list_num, self.node_ref_lists))
         refs = set()
-        for key, (value, ref_lists) in self._nodes.iteritems():
+        nodes = self._nodes
+        for key, (value, ref_lists) in nodes.iteritems():
             ref_list = ref_lists[ref_list_num]
-            refs.update(ref_list)
-        return refs - self._keys
+            refs.update([ref for ref in ref_list if ref not in nodes])
+        return refs
 
     def _get_nodes_by_key(self):
         if self._nodes_by_key is None:
@@ -602,14 +625,17 @@
 
     def _iter_entries_from_total_buffer(self, keys):
         """Iterate over keys when the entire index is parsed."""
-        keys = keys.intersection(self._keys)
+        # Note: See the note in BTreeBuilder.iter_entries for why we don't use
+        #       .intersection() here
+        nodes = self._nodes
+        keys = [key for key in keys if key in nodes]
         if self.node_ref_lists:
             for key in keys:
-                value, node_refs = self._nodes[key]
+                value, node_refs = nodes[key]
                 yield self, key, value, node_refs
         else:
             for key in keys:
-                yield self, key, self._nodes[key]
+                yield self, key, nodes[key]
 
     def iter_entries(self, keys):
         """Iterate over keys within the index.
@@ -1152,7 +1178,7 @@
             self._parsed_key_map.insert(index + 1, new_key)
 
     def _read_and_parse(self, readv_ranges):
-        """Read the the ranges and parse the resulting data.
+        """Read the ranges and parse the resulting data.
 
         :param readv_ranges: A prepared readv range list.
         """
@@ -1223,6 +1249,11 @@
                 self.__class__.__name__,
                 ', '.join(map(repr, self._indices)))
 
+    def clear_cache(self):
+        """See GraphIndex.clear_cache()"""
+        for index in self._indices:
+            index.clear_cache()
+
     def get_parent_map(self, keys):
         """See graph.StackedParentsProvider.get_parent_map"""
         search_keys = set(keys)
@@ -1484,15 +1515,18 @@
             defined order for the result iteration - it will be in the most
             efficient order for the index (keys iteration order in this case).
         """
-        keys = set(keys)
+        # Note: See BTreeBuilder.iter_entries for an explanation of why we
+        #       aren't using set().intersection() here
+        nodes = self._nodes
+        keys = [key for key in keys if key in nodes]
         if self.reference_lists:
-            for key in keys.intersection(self._keys):
-                node = self._nodes[key]
+            for key in keys:
+                node = nodes[key]
                 if not node[0]:
                     yield self, key, node[2], node[1]
         else:
-            for key in keys.intersection(self._keys):
-                node = self._nodes[key]
+            for key in keys:
+                node = nodes[key]
                 if not node[0]:
                     yield self, key, node[2]
 
@@ -1572,7 +1606,7 @@
 
         For InMemoryGraphIndex the estimate is exact.
         """
-        return len(self._keys)
+        return len(self._nodes) - len(self._absent_keys)
 
     def validate(self):
         """In memory index's have no known corruption at the moment."""

=== modified file 'bzrlib/info.py'
--- bzrlib/info.py	2009-05-01 14:29:06 +0000
+++ bzrlib/info.py	2009-11-03 09:32:17 +0000
@@ -484,6 +484,7 @@
     """Hooks for the info command."""
 
     def __init__(self):
+        super(InfoHooks, self).__init__()
         self.create_hook(_mod_hooks.HookPoint('repository',
             "Invoked when displaying the statistics for a repository. "
             "repository is called with a statistics dictionary as returned "

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2009-08-30 22:02:45 +0000
+++ bzrlib/inventory.py	2009-11-13 19:19:11 +0000
@@ -51,6 +51,7 @@
     )
 from bzrlib.symbol_versioning import deprecated_in, deprecated_method
 from bzrlib.trace import mutter
+from bzrlib.static_tuple import StaticTuple
 
 
 class InventoryEntry(object):
@@ -958,21 +959,21 @@
         descend(self.root, u'')
         return accum
 
-    def path2id(self, name):
+    def path2id(self, relpath):
         """Walk down through directories to return entry of last component.
 
-        names may be either a list of path components, or a single
-        string, in which case it is automatically split.
+        :param relpath: may be either a list of path components, or a single
+            string, in which case it is automatically split.
 
         This returns the entry of the last component in the path,
         which may be either a file or a directory.
 
         Returns None IFF the path is not found.
         """
-        if isinstance(name, basestring):
-            name = osutils.splitpath(name)
-
-        # mutter("lookup path %r" % name)
+        if isinstance(relpath, basestring):
+            names = osutils.splitpath(relpath)
+        else:
+            names = relpath
 
         try:
             parent = self.root
@@ -981,7 +982,7 @@
             return None
         if parent is None:
             return None
-        for f in name:
+        for f in names:
             try:
                 children = getattr(parent, 'children', None)
                 if children is None:
@@ -1197,6 +1198,14 @@
             raise errors.InconsistentDelta("<deleted>", parent_id,
                 "The file id was deleted but its children were not deleted.")
 
+    def create_by_apply_delta(self, inventory_delta, new_revision_id,
+                              propagate_caches=False):
+        """See CHKInventory.create_by_apply_delta()"""
+        new_inv = self.copy()
+        new_inv.apply_delta(inventory_delta)
+        new_inv.revision_id = new_revision_id
+        return new_inv
+
     def _set_root(self, ie):
         self.root = ie
         self._byid = {self.root.file_id: self.root}
@@ -1546,6 +1555,121 @@
         else:
             raise ValueError("unknown kind %r" % entry.kind)
 
+    def _expand_fileids_to_parents_and_children(self, file_ids):
+        """Give a more wholistic view starting with the given file_ids.
+
+        For any file_id which maps to a directory, we will include all children
+        of that directory. We will also include all directories which are
+        parents of the given file_ids, but we will not include their children.
+
+        eg:
+          /     # TREE_ROOT
+          foo/  # foo-id
+            baz # baz-id
+            frob/ # frob-id
+              fringle # fringle-id
+          bar/  # bar-id
+            bing # bing-id
+
+        if given [foo-id] we will include
+            TREE_ROOT as interesting parents
+        and 
+            foo-id, baz-id, frob-id, fringle-id
+        As interesting ids.
+        """
+        interesting = set()
+        # TODO: Pre-pass over the list of fileids to see if anything is already
+        #       deserialized in self._fileid_to_entry_cache
+
+        directories_to_expand = set()
+        children_of_parent_id = {}
+        # It is okay if some of the fileids are missing
+        for entry in self._getitems(file_ids):
+            if entry.kind == 'directory':
+                directories_to_expand.add(entry.file_id)
+            interesting.add(entry.parent_id)
+            children_of_parent_id.setdefault(entry.parent_id, []
+                                             ).append(entry.file_id)
+
+        # Now, interesting has all of the direct parents, but not the
+        # parents of those parents. It also may have some duplicates with
+        # specific_fileids
+        remaining_parents = interesting.difference(file_ids)
+        # When we hit the TREE_ROOT, we'll get an interesting parent of None,
+        # but we don't actually want to recurse into that
+        interesting.add(None) # this will auto-filter it in the loop
+        remaining_parents.discard(None) 
+        while remaining_parents:
+            next_parents = set()
+            for entry in self._getitems(remaining_parents):
+                next_parents.add(entry.parent_id)
+                children_of_parent_id.setdefault(entry.parent_id, []
+                                                 ).append(entry.file_id)
+            # Remove any search tips we've already processed
+            remaining_parents = next_parents.difference(interesting)
+            interesting.update(remaining_parents)
+            # We should probably also .difference(directories_to_expand)
+        interesting.update(file_ids)
+        interesting.discard(None)
+        while directories_to_expand:
+            # Expand directories by looking in the
+            # parent_id_basename_to_file_id map
+            keys = [StaticTuple(f,).intern() for f in directories_to_expand]
+            directories_to_expand = set()
+            items = self.parent_id_basename_to_file_id.iteritems(keys)
+            next_file_ids = set([item[1] for item in items])
+            next_file_ids = next_file_ids.difference(interesting)
+            interesting.update(next_file_ids)
+            for entry in self._getitems(next_file_ids):
+                if entry.kind == 'directory':
+                    directories_to_expand.add(entry.file_id)
+                children_of_parent_id.setdefault(entry.parent_id, []
+                                                 ).append(entry.file_id)
+        return interesting, children_of_parent_id
+
+    def filter(self, specific_fileids):
+        """Get an inventory view filtered against a set of file-ids.
+
+        Children of directories and parents are included.
+
+        The result may or may not reference the underlying inventory
+        so it should be treated as immutable.
+        """
+        (interesting,
+         parent_to_children) = self._expand_fileids_to_parents_and_children(
+                                specific_fileids)
+        # There is some overlap here, but we assume that all interesting items
+        # are in the _fileid_to_entry_cache because we had to read them to
+        # determine if they were a dir we wanted to recurse, or just a file
+        # This should give us all the entries we'll want to add, so start
+        # adding
+        other = Inventory(self.root_id)
+        other.root.revision = self.root.revision
+        other.revision_id = self.revision_id
+        if not interesting or not parent_to_children:
+            # empty filter, or filtering entrys that don't exist
+            # (if even 1 existed, then we would have populated
+            # parent_to_children with at least the tree root.)
+            return other
+        cache = self._fileid_to_entry_cache
+        try:
+            remaining_children = collections.deque(parent_to_children[self.root_id])
+        except:
+            import pdb; pdb.set_trace()
+            raise
+        while remaining_children:
+            file_id = remaining_children.popleft()
+            ie = cache[file_id]
+            if ie.kind == 'directory':
+                ie = ie.copy() # We create a copy to depopulate the .children attribute
+            # TODO: depending on the uses of 'other' we should probably alwyas
+            #       '.copy()' to prevent someone from mutating other and
+            #       invaliding our internal cache
+            other.add(ie)
+            if file_id in parent_to_children:
+                remaining_children.extend(parent_to_children[file_id])
+        return other
+
     @staticmethod
     def _bytes_to_utf8name_key(bytes):
         """Get the file_id, revision_id key out of bytes."""
@@ -1553,7 +1677,7 @@
         # to filter out empty names because of non rich-root...
         sections = bytes.split('\n')
         kind, file_id = sections[0].split(': ')
-        return (sections[2], file_id, sections[3])
+        return (sections[2], intern(file_id), intern(sections[3]))
 
     def _bytes_to_entry(self, bytes):
         """Deserialise a serialised entry."""
@@ -1581,7 +1705,8 @@
             result.reference_revision = sections[4]
         else:
             raise ValueError("Not a serialised entry %r" % bytes)
-        result.revision = sections[3]
+        result.file_id = intern(result.file_id)
+        result.revision = intern(sections[3])
         if result.parent_id == '':
             result.parent_id = None
         self._fileid_to_entry_cache[result.file_id] = result
@@ -1685,7 +1810,7 @@
                         pass
                 deletes.add(file_id)
             else:
-                new_key = (file_id,)
+                new_key = StaticTuple(file_id,)
                 new_value = result._entry_to_bytes(entry)
                 # Update caches. It's worth doing this whether
                 # we're propagating the old caches or not.
@@ -1694,13 +1819,13 @@
             if old_path is None:
                 old_key = None
             else:
-                old_key = (file_id,)
+                old_key = StaticTuple(file_id,)
                 if self.id2path(file_id) != old_path:
                     raise errors.InconsistentDelta(old_path, file_id,
                         "Entry was at wrong other path %r." %
                         self.id2path(file_id))
                 altered.add(file_id)
-            id_to_entry_delta.append((old_key, new_key, new_value))
+            id_to_entry_delta.append(StaticTuple(old_key, new_key, new_value))
             if result.parent_id_basename_to_file_id is not None:
                 # parent_id, basename changes
                 if old_path is None:
@@ -1793,12 +1918,18 @@
                 raise errors.BzrError('Duplicate key in inventory: %r\n%r'
                                       % (key, bytes))
             info[key] = value
-        revision_id = info['revision_id']
-        root_id = info['root_id']
-        search_key_name = info.get('search_key_name', 'plain')
-        parent_id_basename_to_file_id = info.get(
-            'parent_id_basename_to_file_id', None)
+        revision_id = intern(info['revision_id'])
+        root_id = intern(info['root_id'])
+        search_key_name = intern(info.get('search_key_name', 'plain'))
+        parent_id_basename_to_file_id = intern(info.get(
+            'parent_id_basename_to_file_id', None))
+        if not parent_id_basename_to_file_id.startswith('sha1:'):
+            raise ValueError('parent_id_basename_to_file_id should be a sha1'
+                             ' key not %r' % (parent_id_basename_to_file_id,))
         id_to_entry = info['id_to_entry']
+        if not id_to_entry.startswith('sha1:'):
+            raise ValueError('id_to_entry should be a sha1'
+                             ' key not %r' % (id_to_entry,))
 
         result = CHKInventory(search_key_name)
         result.revision_id = revision_id
@@ -1807,12 +1938,13 @@
                             result._search_key_name)
         if parent_id_basename_to_file_id is not None:
             result.parent_id_basename_to_file_id = chk_map.CHKMap(
-                chk_store, (parent_id_basename_to_file_id,),
+                chk_store, StaticTuple(parent_id_basename_to_file_id,),
                 search_key_func=search_key_func)
         else:
             result.parent_id_basename_to_file_id = None
 
-        result.id_to_entry = chk_map.CHKMap(chk_store, (id_to_entry,),
+        result.id_to_entry = chk_map.CHKMap(chk_store,
+                                            StaticTuple(id_to_entry,),
                                             search_key_func=search_key_func)
         if (result.revision_id,) != expected_revision_id:
             raise ValueError("Mismatched revision id and expected: %r, %r" %
@@ -1840,7 +1972,8 @@
         id_to_entry_dict = {}
         parent_id_basename_dict = {}
         for path, entry in inventory.iter_entries():
-            id_to_entry_dict[(entry.file_id,)] = entry_to_bytes(entry)
+            key = StaticTuple(entry.file_id,).intern()
+            id_to_entry_dict[key] = entry_to_bytes(entry)
             p_id_key = parent_id_basename_key(entry)
             parent_id_basename_dict[p_id_key] = entry.file_id
 
@@ -1869,7 +2002,7 @@
             parent_id = entry.parent_id
         else:
             parent_id = ''
-        return parent_id, entry.name.encode('utf8')
+        return StaticTuple(parent_id, entry.name.encode('utf8')).intern()
 
     def __getitem__(self, file_id):
         """map a single file_id -> InventoryEntry."""
@@ -1880,16 +2013,38 @@
             return result
         try:
             return self._bytes_to_entry(
-                self.id_to_entry.iteritems([(file_id,)]).next()[1])
+                self.id_to_entry.iteritems([StaticTuple(file_id,)]).next()[1])
         except StopIteration:
             # really we're passing an inventory, not a tree...
             raise errors.NoSuchId(self, file_id)
 
+    def _getitems(self, file_ids):
+        """Similar to __getitem__, but lets you query for multiple.
+        
+        The returned order is undefined. And currently if an item doesn't
+        exist, it isn't included in the output.
+        """
+        result = []
+        remaining = []
+        for file_id in file_ids:
+            entry = self._fileid_to_entry_cache.get(file_id, None)
+            if entry is None:
+                remaining.append(file_id)
+            else:
+                result.append(entry)
+        file_keys = [StaticTuple(f,).intern() for f in remaining]
+        for file_key, value in self.id_to_entry.iteritems(file_keys):
+            entry = self._bytes_to_entry(value)
+            result.append(entry)
+            self._fileid_to_entry_cache[entry.file_id] = entry
+        return result
+
     def has_id(self, file_id):
         # Perhaps have an explicit 'contains' method on CHKMap ?
         if self._fileid_to_entry_cache.get(file_id, None) is not None:
             return True
-        return len(list(self.id_to_entry.iteritems([(file_id,)]))) == 1
+        return len(list(
+            self.id_to_entry.iteritems([StaticTuple(file_id,)]))) == 1
 
     def is_root(self, file_id):
         return file_id == self.root_id
@@ -2024,35 +2179,41 @@
             delta.append((old_path, new_path, file_id, entry))
         return delta
 
-    def path2id(self, name):
+    def path2id(self, relpath):
         """See CommonInventory.path2id()."""
         # TODO: perhaps support negative hits?
-        result = self._path_to_fileid_cache.get(name, None)
+        result = self._path_to_fileid_cache.get(relpath, None)
         if result is not None:
             return result
-        if isinstance(name, basestring):
-            names = osutils.splitpath(name)
+        if isinstance(relpath, basestring):
+            names = osutils.splitpath(relpath)
         else:
-            names = name
+            names = relpath
         current_id = self.root_id
         if current_id is None:
             return None
         parent_id_index = self.parent_id_basename_to_file_id
+        cur_path = None
         for basename in names:
-            # TODO: Cache each path we figure out in this function.
+            if cur_path is None:
+                cur_path = basename
+            else:
+                cur_path = cur_path + '/' + basename
             basename_utf8 = basename.encode('utf8')
-            key_filter = [(current_id, basename_utf8)]
-            file_id = None
-            for (parent_id, name_utf8), file_id in parent_id_index.iteritems(
-                key_filter=key_filter):
-                if parent_id != current_id or name_utf8 != basename_utf8:
-                    raise errors.BzrError("corrupt inventory lookup! "
-                        "%r %r %r %r" % (parent_id, current_id, name_utf8,
-                        basename_utf8))
+            file_id = self._path_to_fileid_cache.get(cur_path, None)
             if file_id is None:
-                return None
+                key_filter = [StaticTuple(current_id, basename_utf8)]
+                items = parent_id_index.iteritems(key_filter)
+                for (parent_id, name_utf8), file_id in items:
+                    if parent_id != current_id or name_utf8 != basename_utf8:
+                        raise errors.BzrError("corrupt inventory lookup! "
+                            "%r %r %r %r" % (parent_id, current_id, name_utf8,
+                            basename_utf8))
+                if file_id is None:
+                    return None
+                else:
+                    self._path_to_fileid_cache[cur_path] = file_id
             current_id = file_id
-        self._path_to_fileid_cache[name] = current_id
         return current_id
 
     def to_lines(self):
@@ -2063,16 +2224,16 @@
             lines.append('search_key_name: %s\n' % (self._search_key_name,))
             lines.append("root_id: %s\n" % self.root_id)
             lines.append('parent_id_basename_to_file_id: %s\n' %
-                self.parent_id_basename_to_file_id.key())
+                (self.parent_id_basename_to_file_id.key()[0],))
             lines.append("revision_id: %s\n" % self.revision_id)
-            lines.append("id_to_entry: %s\n" % self.id_to_entry.key())
+            lines.append("id_to_entry: %s\n" % (self.id_to_entry.key()[0],))
         else:
             lines.append("revision_id: %s\n" % self.revision_id)
             lines.append("root_id: %s\n" % self.root_id)
             if self.parent_id_basename_to_file_id is not None:
                 lines.append('parent_id_basename_to_file_id: %s\n' %
-                    self.parent_id_basename_to_file_id.key())
-            lines.append("id_to_entry: %s\n" % self.id_to_entry.key())
+                    (self.parent_id_basename_to_file_id.key()[0],))
+            lines.append("id_to_entry: %s\n" % (self.id_to_entry.key()[0],))
         return lines
 
     @property
@@ -2119,8 +2280,8 @@
         parent_id_index = self._chk_inventory.parent_id_basename_to_file_id
         child_keys = set()
         for (parent_id, name_utf8), file_id in parent_id_index.iteritems(
-            key_filter=[(self.file_id,)]):
-            child_keys.add((file_id,))
+            key_filter=[StaticTuple(self.file_id,)]):
+            child_keys.add(StaticTuple(file_id,))
         cached = set()
         for file_id_key in child_keys:
             entry = self._chk_inventory._fileid_to_entry_cache.get(
@@ -2159,7 +2320,7 @@
     try:
         factory = entry_factory[kind]
     except KeyError:
-        raise BzrError("unknown kind %r" % kind)
+        raise errors.BadFileKindError(name, kind)
     return factory(file_id, name, parent_id)
 
 

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2009-08-26 16:44:27 +0000
+++ bzrlib/knit.py	2009-11-30 21:21:07 +0000
@@ -69,6 +69,7 @@
     lru_cache,
     pack,
     progress,
+    static_tuple,
     trace,
     tsort,
     tuned_gzip,
@@ -1518,10 +1519,10 @@
                 if source is parent_maps[0]:
                     # this KnitVersionedFiles
                     records = [(key, positions[key][1]) for key in keys]
-                    for key, raw_data, sha1 in self._read_records_iter_raw(records):
+                    for key, raw_data in self._read_records_iter_unchecked(records):
                         (record_details, index_memo, _) = positions[key]
                         yield KnitContentFactory(key, global_map[key],
-                            record_details, sha1, raw_data, self._factory.annotated, None)
+                            record_details, None, raw_data, self._factory.annotated, None)
                 else:
                     vf = self._fallback_vfs[parent_maps.index(source) - 1]
                     for record in vf.get_record_stream(keys, ordering,
@@ -1596,6 +1597,13 @@
         # key = basis_parent, value = index entry to add
         buffered_index_entries = {}
         for record in stream:
+            kind = record.storage_kind
+            if kind.startswith('knit-') and kind.endswith('-gz'):
+                # Check that the ID in the header of the raw knit bytes matches
+                # the record metadata.
+                raw_data = record._raw_record
+                df, rec = self._parse_record_header(record.key, raw_data)
+                df.close()
             buffered = False
             parents = record.parents
             if record.storage_kind in delta_types:
@@ -1703,10 +1711,12 @@
             # There were index entries buffered at the end of the stream,
             # So these need to be added (if the index supports holding such
             # entries for later insertion)
+            all_entries = []
             for key in buffered_index_entries:
                 index_entries = buffered_index_entries[key]
-                self._index.add_records(index_entries,
-                    missing_compression_parents=True)
+                all_entries.extend(index_entries)
+            self._index.add_records(
+                all_entries, missing_compression_parents=True)
 
     def get_missing_compression_parent_keys(self):
         """Return an iterable of keys of missing compression parents.
@@ -2358,7 +2368,7 @@
     FLAGS is a comma separated list of flags about the record. Values include
         no-eol, line-delta, fulltext.
     BYTE_OFFSET is the ascii representation of the byte offset in the data file
-        that the the compressed data starts at.
+        that the compressed data starts at.
     LENGTH is the ascii representation of the length of the data file.
     PARENT_ID a utf-8 revision id prefixed by a '.' that is a parent of
         REVISION_ID.
@@ -2777,9 +2787,20 @@
 
 class _KeyRefs(object):
 
-    def __init__(self):
+    def __init__(self, track_new_keys=False):
         # dict mapping 'key' to 'set of keys referring to that key'
         self.refs = {}
+        if track_new_keys:
+            # set remembering all new keys
+            self.new_keys = set()
+        else:
+            self.new_keys = None
+
+    def clear(self):
+        if self.refs:
+            self.refs.clear()
+        if self.new_keys:
+            self.new_keys.clear()
 
     def add_references(self, key, refs):
         # Record the new references
@@ -2792,19 +2813,28 @@
         # Discard references satisfied by the new key
         self.add_key(key)
 
+    def get_new_keys(self):
+        return self.new_keys
+    
     def get_unsatisfied_refs(self):
         return self.refs.iterkeys()
 
-    def add_key(self, key):
+    def _satisfy_refs_for_key(self, key):
         try:
             del self.refs[key]
         except KeyError:
             # No keys depended on this key.  That's ok.
             pass
 
-    def add_keys(self, keys):
+    def add_key(self, key):
+        # satisfy refs for key, and remember that we've seen this key.
+        self._satisfy_refs_for_key(key)
+        if self.new_keys is not None:
+            self.new_keys.add(key)
+
+    def satisfy_refs_for_keys(self, keys):
         for key in keys:
-            self.add_key(key)
+            self._satisfy_refs_for_key(key)
 
     def get_referrers(self):
         result = set()
@@ -2915,10 +2945,15 @@
         if not random_id:
             present_nodes = self._get_entries(keys)
             for (index, key, value, node_refs) in present_nodes:
+                parents = node_refs[:1]
+                # Sometimes these are passed as a list rather than a tuple
+                passed = static_tuple.as_tuples(keys[key])
+                passed_parents = passed[1][:1]
                 if (value[0] != keys[key][0][0] or
-                    node_refs[:1] != keys[key][1][:1]):
+                    parents != passed_parents):
+                    node_refs = static_tuple.as_tuples(node_refs)
                     raise KnitCorrupt(self, "inconsistent details in add_records"
-                        ": %s %s" % ((value, node_refs), keys[key]))
+                        ": %s %s" % ((value, node_refs), passed))
                 del keys[key]
         result = []
         if self._parents:
@@ -2972,7 +3007,7 @@
         # If updating this, you should also update
         # groupcompress._GCGraphIndex.get_missing_parents
         # We may have false positives, so filter those out.
-        self._key_dependencies.add_keys(
+        self._key_dependencies.satisfy_refs_for_keys(
             self.get_parent_map(self._key_dependencies.get_unsatisfied_refs()))
         return frozenset(self._key_dependencies.get_unsatisfied_refs())
 
@@ -3673,5 +3708,6 @@
 
 try:
     from bzrlib._knit_load_data_pyx import _load_data_c as _load_data
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib._knit_load_data_py import _load_data_py as _load_data

=== modified file 'bzrlib/lock.py'
--- bzrlib/lock.py	2009-07-31 16:51:48 +0000
+++ bzrlib/lock.py	2009-10-07 08:17:25 +0000
@@ -518,3 +518,24 @@
 # We default to using the first available lock class.
 _lock_type, WriteLock, ReadLock = _lock_classes[0]
 
+
+class _RelockDebugMixin(object):
+    """Mixin support for -Drelock flag.
+
+    Add this as a base class then call self._note_lock with 'r' or 'w' when
+    acquiring a read- or write-lock.  If this object was previously locked (and
+    locked the same way), and -Drelock is set, then this will trace.note a
+    message about it.
+    """
+    
+    _prev_lock = None
+
+    def _note_lock(self, lock_type):
+        if 'relock' in debug.debug_flags and self._prev_lock == lock_type:
+            if lock_type == 'r':
+                type_name = 'read'
+            else:
+                type_name = 'write'
+            trace.note('%r was %s locked again', self, type_name)
+        self._prev_lock = lock_type
+

=== modified file 'bzrlib/lockable_files.py'
--- bzrlib/lockable_files.py	2009-07-27 05:39:01 +0000
+++ bzrlib/lockable_files.py	2009-10-15 02:11:18 +0000
@@ -32,8 +32,7 @@
 """)
 
 from bzrlib.decorators import (
-    needs_read_lock,
-    needs_write_lock,
+    only_raises,
     )
 from bzrlib.symbol_versioning import (
     deprecated_in,
@@ -221,6 +220,7 @@
         """Setup a write transaction."""
         self._set_transaction(transactions.WriteTransaction())
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         if not self._lock_mode:
             return lock.cant_unlock_not_held(self)

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2009-07-27 05:24:02 +0000
+++ bzrlib/lockdir.py	2009-12-02 17:49:45 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007, 2008 Canonical Ltd
+# Copyright (C) 2006, 2007, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -110,8 +110,10 @@
     debug,
     errors,
     lock,
+    osutils,
     )
 import bzrlib.config
+from bzrlib.decorators import only_raises
 from bzrlib.errors import (
         DirectoryNotEmpty,
         FileExists,
@@ -286,6 +288,7 @@
                                             info_bytes)
         return tmpname
 
+    @only_raises(LockNotHeld, LockBroken)
     def unlock(self):
         """Release a held lock
         """
@@ -414,7 +417,7 @@
 
         peek() reads the info file of the lock holder, if any.
         """
-        return self._parse_info(self.transport.get(path))
+        return self._parse_info(self.transport.get_bytes(path))
 
     def peek(self):
         """Check if the lock is held by anyone.
@@ -447,8 +450,9 @@
                    )
         return s.to_string()
 
-    def _parse_info(self, info_file):
-        return rio.read_stanza(info_file.readlines()).as_dict()
+    def _parse_info(self, info_bytes):
+        # TODO: Handle if info_bytes is empty
+        return rio.read_stanza(osutils.split_lines(info_bytes)).as_dict()
 
     def attempt_lock(self):
         """Take the lock; fail if it's already held.

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2009-06-10 03:56:49 +0000
+++ bzrlib/log.py	2009-11-30 12:24:55 +0000
@@ -83,6 +83,7 @@
     )
 from bzrlib.osutils import (
     format_date,
+    format_date_with_offset_in_original_timezone,
     get_terminal_encoding,
     re_compile_checked,
     terminal_width,
@@ -384,27 +385,28 @@
         :return: An iterator yielding LogRevision objects.
         """
         rqst = self.rqst
+        levels = rqst.get('levels')
+        limit = rqst.get('limit')
+        diff_type = rqst.get('diff_type')
         log_count = 0
         revision_iterator = self._create_log_revision_iterator()
         for revs in revision_iterator:
             for (rev_id, revno, merge_depth), rev, delta in revs:
                 # 0 levels means show everything; merge_depth counts from 0
-                levels = rqst.get('levels')
                 if levels != 0 and merge_depth >= levels:
                     continue
-                diff = self._format_diff(rev, rev_id)
+                if diff_type is None:
+                    diff = None
+                else:
+                    diff = self._format_diff(rev, rev_id, diff_type)
                 yield LogRevision(rev, revno, merge_depth, delta,
                     self.rev_tag_dict.get(rev_id), diff)
-                limit = rqst.get('limit')
                 if limit:
                     log_count += 1
                     if log_count >= limit:
                         return
 
-    def _format_diff(self, rev, rev_id):
-        diff_type = self.rqst.get('diff_type')
-        if diff_type is None:
-            return None
+    def _format_diff(self, rev, rev_id, diff_type):
         repo = self.branch.repository
         if len(rev.parent_ids) == 0:
             ancestor_id = _mod_revision.NULL_REVISION
@@ -1291,7 +1293,7 @@
     preferred_levels = 0
 
     def __init__(self, to_file, show_ids=False, show_timezone='original',
-                 delta_format=None, levels=None, show_advice=False):
+            delta_format=None, levels=None, show_advice=False):
         """Create a LogFormatter.
 
         :param to_file: the file to output to
@@ -1367,48 +1369,64 @@
         else:
             return ''
 
-    def show_foreign_info(self, rev, indent):
+    def show_properties(self, revision, indent):
+        """Displays the custom properties returned by each registered handler.
+
+        If a registered handler raises an error it is propagated.
+        """
+        for line in self.custom_properties(revision):
+            self.to_file.write("%s%s\n" % (indent, line))
+
+    def custom_properties(self, revision):
+        """Format the custom properties returned by each registered handler.
+
+        If a registered handler raises an error it is propagated.
+
+        :return: a list of formatted lines (excluding trailing newlines)
+        """
+        lines = self._foreign_info_properties(revision)
+        for key, handler in properties_handler_registry.iteritems():
+            lines.extend(self._format_properties(handler(revision)))
+        return lines
+
+    def _foreign_info_properties(self, rev):
         """Custom log displayer for foreign revision identifiers.
 
         :param rev: Revision object.
         """
         # Revision comes directly from a foreign repository
         if isinstance(rev, foreign.ForeignRevision):
-            self._write_properties(indent, rev.mapping.vcs.show_foreign_revid(
-                rev.foreign_revid))
-            return
+            return rev.mapping.vcs.show_foreign_revid(rev.foreign_revid)
 
         # Imported foreign revision revision ids always contain :
         if not ":" in rev.revision_id:
-            return
+            return []
 
         # Revision was once imported from a foreign repository
         try:
             foreign_revid, mapping = \
                 foreign.foreign_vcs_registry.parse_revision_id(rev.revision_id)
         except errors.InvalidRevisionId:
-            return
+            return []
 
-        self._write_properties(indent, 
+        return self._format_properties(
             mapping.vcs.show_foreign_revid(foreign_revid))
 
-    def show_properties(self, revision, indent):
-        """Displays the custom properties returned by each registered handler.
-
-        If a registered handler raises an error it is propagated.
-        """
-        for key, handler in properties_handler_registry.iteritems():
-            self._write_properties(indent, handler(revision))
-
-    def _write_properties(self, indent, properties):
+    def _format_properties(self, properties):
+        lines = []
         for key, value in properties.items():
-            self.to_file.write(indent + key + ': ' + value + '\n')
+            lines.append(key + ': ' + value)
+        return lines
 
     def show_diff(self, to_file, diff, indent):
         for l in diff.rstrip().split('\n'):
             to_file.write(indent + '%s\n' % (l,))
 
 
+# Separator between revisions in long format
+_LONG_SEP = '-' * 60
+
+
 class LongLogFormatter(LogFormatter):
 
     supports_merge_revisions = True
@@ -1417,46 +1435,59 @@
     supports_tags = True
     supports_diff = True
 
+    def __init__(self, *args, **kwargs):
+        super(LongLogFormatter, self).__init__(*args, **kwargs)
+        if self.show_timezone == 'original':
+            self.date_string = self._date_string_original_timezone
+        else:
+            self.date_string = self._date_string_with_timezone
+
+    def _date_string_with_timezone(self, rev):
+        return format_date(rev.timestamp, rev.timezone or 0,
+                           self.show_timezone)
+
+    def _date_string_original_timezone(self, rev):
+        return format_date_with_offset_in_original_timezone(rev.timestamp,
+            rev.timezone or 0)
+
     def log_revision(self, revision):
         """Log a revision, either merged or not."""
         indent = '    ' * revision.merge_depth
-        to_file = self.to_file
-        to_file.write(indent + '-' * 60 + '\n')
+        lines = [_LONG_SEP]
         if revision.revno is not None:
-            to_file.write(indent + 'revno: %s%s\n' % (revision.revno,
+            lines.append('revno: %s%s' % (revision.revno,
                 self.merge_marker(revision)))
         if revision.tags:
-            to_file.write(indent + 'tags: %s\n' % (', '.join(revision.tags)))
+            lines.append('tags: %s' % (', '.join(revision.tags)))
         if self.show_ids:
-            to_file.write(indent + 'revision-id: ' + revision.rev.revision_id)
-            to_file.write('\n')
+            lines.append('revision-id: %s' % (revision.rev.revision_id,))
             for parent_id in revision.rev.parent_ids:
-                to_file.write(indent + 'parent: %s\n' % (parent_id,))
-        self.show_foreign_info(revision.rev, indent)
-        self.show_properties(revision.rev, indent)
+                lines.append('parent: %s' % (parent_id,))
+        lines.extend(self.custom_properties(revision.rev))
 
         committer = revision.rev.committer
         authors = revision.rev.get_apparent_authors()
         if authors != [committer]:
-            to_file.write(indent + 'author: %s\n' % (", ".join(authors),))
-        to_file.write(indent + 'committer: %s\n' % (committer,))
+            lines.append('author: %s' % (", ".join(authors),))
+        lines.append('committer: %s' % (committer,))
 
         branch_nick = revision.rev.properties.get('branch-nick', None)
         if branch_nick is not None:
-            to_file.write(indent + 'branch nick: %s\n' % (branch_nick,))
-
-        date_str = format_date(revision.rev.timestamp,
-                               revision.rev.timezone or 0,
-                               self.show_timezone)
-        to_file.write(indent + 'timestamp: %s\n' % (date_str,))
-
-        to_file.write(indent + 'message:\n')
+            lines.append('branch nick: %s' % (branch_nick,))
+
+        lines.append('timestamp: %s' % (self.date_string(revision.rev),))
+
+        lines.append('message:')
         if not revision.rev.message:
-            to_file.write(indent + '  (no message)\n')
+            lines.append('  (no message)')
         else:
             message = revision.rev.message.rstrip('\r\n')
             for l in message.split('\n'):
-                to_file.write(indent + '  %s\n' % (l,))
+                lines.append('  %s' % (l,))
+
+        # Dump the output, appending the delta and diff if requested
+        to_file = self.to_file
+        to_file.write("%s%s\n" % (indent, ('\n' + indent).join(lines)))
         if revision.delta is not None:
             # We don't respect delta_format for compatibility
             revision.delta.show(to_file, self.show_ids, indent=indent,
@@ -1515,7 +1546,6 @@
                             self.show_timezone, date_fmt="%Y-%m-%d",
                             show_offset=False),
                 tags, self.merge_marker(revision)))
-        self.show_foreign_info(revision.rev, indent+offset)
         self.show_properties(revision.rev, indent+offset)
         if self.show_ids:
             to_file.write(indent + offset + 'revision-id:%s\n'
@@ -1846,9 +1876,11 @@
     :return: (branch, info_list, start_rev_info, end_rev_info) where
       info_list is a list of (relative_path, file_id, kind) tuples where
       kind is one of values 'directory', 'file', 'symlink', 'tree-reference'.
+      branch will be read-locked.
     """
     from builtins import _get_revision_range, safe_relpath_files
     tree, b, path = bzrdir.BzrDir.open_containing_tree_or_branch(file_list[0])
+    b.lock_read()
     # XXX: It's damn messy converting a list of paths to relative paths when
     # those paths might be deleted ones, they might be on a case-insensitive
     # filesystem and/or they might be in silly locations (like another branch).

=== modified file 'bzrlib/lsprof.py'
--- bzrlib/lsprof.py	2009-03-08 06:18:06 +0000
+++ bzrlib/lsprof.py	2009-08-24 21:05:09 +0000
@@ -13,45 +13,74 @@
 
 __all__ = ['profile', 'Stats']
 
-_g_threadmap = {}
-
-
-def _thread_profile(f, *args, **kwds):
-    # we lose the first profile point for a new thread in order to trampoline
-    # a new Profile object into place
-    global _g_threadmap
-    thr = thread.get_ident()
-    _g_threadmap[thr] = p = Profiler()
-    # this overrides our sys.setprofile hook:
-    p.enable(subcalls=True, builtins=True)
-
-
 def profile(f, *args, **kwds):
     """Run a function profile.
 
     Exceptions are not caught: If you need stats even when exceptions are to be
-    raised, passing in a closure that will catch the exceptions and transform
-    them appropriately for your driver function.
+    raised, pass in a closure that will catch the exceptions and transform them
+    appropriately for your driver function.
 
     :return: The functions return value and a stats object.
     """
-    global _g_threadmap
-    p = Profiler()
-    p.enable(subcalls=True)
-    threading.setprofile(_thread_profile)
+    profiler = BzrProfiler()
+    profiler.start()
     try:
         ret = f(*args, **kwds)
     finally:
-        p.disable()
-        for pp in _g_threadmap.values():
+        stats = profiler.stop()
+    return ret, stats
+
+
+class BzrProfiler(object):
+    """Bzr utility wrapper around Profiler.
+    
+    For most uses the module level 'profile()' function will be suitable.
+    However profiling when a simple wrapped function isn't available may
+    be easier to accomplish using this class.
+
+    To use it, create a BzrProfiler and call start() on it. Some arbitrary
+    time later call stop() to stop profiling and retrieve the statistics
+    from the code executed in the interim.
+    """
+
+    def start(self):
+        """Start profiling.
+        
+        This hooks into threading and will record all calls made until
+        stop() is called.
+        """
+        self._g_threadmap = {}
+        self.p = Profiler()
+        self.p.enable(subcalls=True)
+        threading.setprofile(self._thread_profile)
+
+    def stop(self):
+        """Stop profiling.
+
+        This unhooks from threading and cleans up the profiler, returning
+        the gathered Stats object.
+
+        :return: A bzrlib.lsprof.Stats object.
+        """
+        self.p.disable()
+        for pp in self._g_threadmap.values():
             pp.disable()
         threading.setprofile(None)
+        p = self.p
+        self.p = None
+        threads = {}
+        for tid, pp in self._g_threadmap.items():
+            threads[tid] = Stats(pp.getstats(), {})
+        self._g_threadmap = None
+        return Stats(p.getstats(), threads)
 
-    threads = {}
-    for tid, pp in _g_threadmap.items():
-        threads[tid] = Stats(pp.getstats(), {})
-    _g_threadmap = {}
-    return ret, Stats(p.getstats(), threads)
+    def _thread_profile(self, f, *args, **kwds):
+        # we lose the first profile point for a new thread in order to
+        # trampoline a new Profile object into place
+        thr = thread.get_ident()
+        self._g_threadmap[thr] = p = Profiler()
+        # this overrides our sys.setprofile hook:
+        p.enable(subcalls=True, builtins=True)
 
 
 class Stats(object):

=== modified file 'bzrlib/mail_client.py'
--- bzrlib/mail_client.py	2009-06-10 03:56:49 +0000
+++ bzrlib/mail_client.py	2009-09-24 19:51:37 +0000
@@ -424,6 +424,10 @@
 
     _client_commands = ['emacsclient']
 
+    def __init__(self, config):
+        super(EmacsMail, self).__init__(config)
+        self.elisp_tmp_file = None
+
     def _prepare_send_function(self):
         """Write our wrapper function into a temporary file.
 
@@ -500,6 +504,7 @@
         if attach_path is not None:
             # Do not create a file if there is no attachment
             elisp = self._prepare_send_function()
+            self.elisp_tmp_file = elisp
             lmmform = '(load "%s")' % elisp
             mmform  = '(bzr-add-mime-att "%s")' % \
                 self._encode_path(attach_path, 'attachment')
@@ -534,6 +539,65 @@
                               help=MAPIClient.__doc__)
 
 
+class MailApp(BodyExternalMailClient):
+    """Use MacOS X's Mail.app for sending email messages.
+
+    Although it would be nice to use appscript, it's not installed
+    with the shipped Python installations.  We instead build an
+    AppleScript and invoke the script using osascript(1).  We don't
+    use the _encode_safe() routines as it's not clear what encoding
+    osascript expects the script to be in.
+    """
+
+    _client_commands = ['osascript']
+
+    def _get_compose_commandline(self, to, subject, attach_path, body=None,
+                                from_=None):
+       """See ExternalMailClient._get_compose_commandline"""
+
+       fd, self.temp_file = tempfile.mkstemp(prefix="bzr-send-",
+                                         suffix=".scpt")
+       try:
+           os.write(fd, 'tell application "Mail"\n')
+           os.write(fd, 'set newMessage to make new outgoing message\n')
+           os.write(fd, 'tell newMessage\n')
+           if to is not None:
+               os.write(fd, 'make new to recipient with properties'
+                   ' {address:"%s"}\n' % to)
+           if from_ is not None:
+               # though from_ doesn't actually seem to be used
+               os.write(fd, 'set sender to "%s"\n'
+                   % sender.replace('"', '\\"'))
+           if subject is not None:
+               os.write(fd, 'set subject to "%s"\n'
+                   % subject.replace('"', '\\"'))
+           if body is not None:
+               # FIXME: would be nice to prepend the body to the
+               # existing content (e.g., preserve signature), but
+               # can't seem to figure out the right applescript
+               # incantation.
+               os.write(fd, 'set content to "%s\\n\n"\n' %
+                   body.replace('"', '\\"').replace('\n', '\\n'))
+
+           if attach_path is not None:
+               # FIXME: would be nice to first append a newline to
+               # ensure the attachment is on a new paragraph, but
+               # can't seem to figure out the right applescript
+               # incantation.
+               os.write(fd, 'tell content to make new attachment'
+                   ' with properties {file name:"%s"}'
+                   ' at after the last paragraph\n'
+                   % self._encode_path(attach_path, 'attachment'))
+           os.write(fd, 'set visible to true\n')
+           os.write(fd, 'end tell\n')
+           os.write(fd, 'end tell\n')
+       finally:
+           os.close(fd) # Just close the handle but do not remove the file.
+       return [self.temp_file]
+mail_client_registry.register('mail.app', MailApp,
+                              help=MailApp.__doc__)
+
+
 class DefaultMail(MailClient):
     """Default mail handling.  Tries XDGEmail (or MAPIClient on Windows),
     falls back to Editor"""
@@ -570,3 +634,5 @@
 mail_client_registry.register('default', DefaultMail,
                               help=DefaultMail.__doc__)
 mail_client_registry.default_key = 'default'
+
+

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2009-09-01 01:25:37 +0000
+++ bzrlib/merge.py	2009-12-03 02:24:54 +0000
@@ -15,51 +15,30 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-import errno
-from itertools import chain
-import os
-import warnings
-
 from bzrlib import (
+    branch as _mod_branch,
+    conflicts as _mod_conflicts,
     debug,
     errors,
     graph as _mod_graph,
+    merge3,
     osutils,
     patiencediff,
+    progress,
     registry,
     revision as _mod_revision,
+    textfile,
+    trace,
+    transform,
     tree as _mod_tree,
     tsort,
-    )
-from bzrlib.branch import Branch
-from bzrlib.conflicts import ConflictList, Conflict
-from bzrlib.errors import (BzrCommandError,
-                           BzrError,
-                           NoCommonAncestor,
-                           NoCommits,
-                           NoSuchRevision,
-                           NoSuchFile,
-                           NotBranchError,
-                           NotVersionedError,
-                           UnrelatedBranches,
-                           UnsupportedOperation,
-                           WorkingTreeNotRevision,
-                           BinaryFile,
-                           )
-from bzrlib.graph import Graph
-from bzrlib.merge3 import Merge3
-from bzrlib.osutils import rename, pathjoin
-from progress import DummyProgress, ProgressPhase
-from bzrlib.revision import (NULL_REVISION, ensure_null)
-from bzrlib.textfile import check_text_lines
-from bzrlib.trace import mutter, warning, note, is_quiet
-from bzrlib.transform import (TransformPreview, TreeTransform,
-                              resolve_conflicts, cook_conflicts,
-                              conflict_pass, FinalPaths, create_from_tree,
-                              unique_add, ROOT_PARENT)
-from bzrlib.versionedfile import PlanWeaveMerge
-from bzrlib import ui
-
+    ui,
+    versionedfile
+    )
+from bzrlib.symbol_versioning import (
+    deprecated_in,
+    deprecated_method,
+    )
 # TODO: Report back as changes are merged in
 
 
@@ -94,7 +73,7 @@
         self.show_base = False
         self.reprocess = False
         if pb is None:
-            pb = DummyProgress()
+            pb = progress.DummyProgress()
         self._pb = pb
         self.pp = None
         self.recurse = recurse
@@ -184,7 +163,7 @@
                 base_revision_id, tree.branch.last_revision())):
                 base_revision_id = None
             else:
-                warning('Performing cherrypick')
+                trace.warning('Performing cherrypick')
         merger = klass.from_revision_ids(pb, tree, other_revision_id,
                                          base_revision_id, revision_graph=
                                          revision_graph)
@@ -242,14 +221,16 @@
         if revno is None:
             tree = workingtree.WorkingTree.open_containing(location)[0]
             return tree.branch, tree
-        branch = Branch.open_containing(location, possible_transports)[0]
+        branch = _mod_branch.Branch.open_containing(
+            location, possible_transports)[0]
         if revno == -1:
             revision_id = branch.last_revision()
         else:
             revision_id = branch.get_rev_id(revno)
-        revision_id = ensure_null(revision_id)
+        revision_id = _mod_revision.ensure_null(revision_id)
         return branch, self.revision_tree(revision_id, branch)
 
+    @deprecated_method(deprecated_in((2, 1, 0)))
     def ensure_revision_trees(self):
         if self.this_revision_tree is None:
             self.this_basis_tree = self.revision_tree(self.this_basis)
@@ -263,6 +244,7 @@
             other_rev_id = self.other_basis
             self.other_tree = other_basis_tree
 
+    @deprecated_method(deprecated_in((2, 1, 0)))
     def file_revisions(self, file_id):
         self.ensure_revision_trees()
         def get_id(tree, file_id):
@@ -271,20 +253,23 @@
         if self.this_rev_id is None:
             if self.this_basis_tree.get_file_sha1(file_id) != \
                 self.this_tree.get_file_sha1(file_id):
-                raise WorkingTreeNotRevision(self.this_tree)
+                raise errors.WorkingTreeNotRevision(self.this_tree)
 
         trees = (self.this_basis_tree, self.other_tree)
         return [get_id(tree, file_id) for tree in trees]
 
+    @deprecated_method(deprecated_in((2, 1, 0)))
     def check_basis(self, check_clean, require_commits=True):
         if self.this_basis is None and require_commits is True:
-            raise BzrCommandError("This branch has no commits."
-                                  " (perhaps you would prefer 'bzr pull')")
+            raise errors.BzrCommandError(
+                "This branch has no commits."
+                " (perhaps you would prefer 'bzr pull')")
         if check_clean:
             self.compare_basis()
             if self.this_basis != self.this_rev_id:
                 raise errors.UncommittedChanges(self.this_tree)
 
+    @deprecated_method(deprecated_in((2, 1, 0)))
     def compare_basis(self):
         try:
             basis_tree = self.revision_tree(self.this_tree.last_revision())
@@ -297,7 +282,8 @@
         self.interesting_files = file_list
 
     def set_pending(self):
-        if not self.base_is_ancestor or not self.base_is_other_ancestor or self.other_rev_id is None:
+        if (not self.base_is_ancestor or not self.base_is_other_ancestor
+            or self.other_rev_id is None):
             return
         self._add_parent()
 
@@ -333,7 +319,7 @@
             self.other_rev_id = _mod_revision.ensure_null(
                 self.other_branch.last_revision())
             if _mod_revision.is_null(self.other_rev_id):
-                raise NoCommits(self.other_branch)
+                raise errors.NoCommits(self.other_branch)
             self.other_basis = self.other_rev_id
         elif other_revision[1] is not None:
             self.other_rev_id = self.other_branch.get_rev_id(other_revision[1])
@@ -342,7 +328,7 @@
             self.other_rev_id = None
             self.other_basis = self.other_branch.last_revision()
             if self.other_basis is None:
-                raise NoCommits(self.other_branch)
+                raise errors.NoCommits(self.other_branch)
         if self.other_rev_id is not None:
             self._cached_trees[self.other_rev_id] = self.other_tree
         self._maybe_fetch(self.other_branch,self.this_branch, self.other_basis)
@@ -375,17 +361,17 @@
             target.fetch(source, revision_id)
 
     def find_base(self):
-        revisions = [ensure_null(self.this_basis),
-                     ensure_null(self.other_basis)]
-        if NULL_REVISION in revisions:
-            self.base_rev_id = NULL_REVISION
+        revisions = [_mod_revision.ensure_null(self.this_basis),
+                     _mod_revision.ensure_null(self.other_basis)]
+        if _mod_revision.NULL_REVISION in revisions:
+            self.base_rev_id = _mod_revision.NULL_REVISION
             self.base_tree = self.revision_tree(self.base_rev_id)
             self._is_criss_cross = False
         else:
             lcas = self.revision_graph.find_lca(revisions[0], revisions[1])
             self._is_criss_cross = False
             if len(lcas) == 0:
-                self.base_rev_id = NULL_REVISION
+                self.base_rev_id = _mod_revision.NULL_REVISION
             elif len(lcas) == 1:
                 self.base_rev_id = list(lcas)[0]
             else: # len(lcas) > 1
@@ -400,12 +386,12 @@
                     self.base_rev_id = self.revision_graph.find_unique_lca(
                                             *lcas)
                 self._is_criss_cross = True
-            if self.base_rev_id == NULL_REVISION:
-                raise UnrelatedBranches()
+            if self.base_rev_id == _mod_revision.NULL_REVISION:
+                raise errors.UnrelatedBranches()
             if self._is_criss_cross:
-                warning('Warning: criss-cross merge encountered.  See bzr'
-                        ' help criss-cross.')
-                mutter('Criss-cross lcas: %r' % lcas)
+                trace.warning('Warning: criss-cross merge encountered.  See bzr'
+                              ' help criss-cross.')
+                trace.mutter('Criss-cross lcas: %r' % lcas)
                 interesting_revision_ids = [self.base_rev_id]
                 interesting_revision_ids.extend(lcas)
                 interesting_trees = dict((t.get_revision_id(), t)
@@ -421,14 +407,14 @@
                 self.base_tree = self.revision_tree(self.base_rev_id)
         self.base_is_ancestor = True
         self.base_is_other_ancestor = True
-        mutter('Base revid: %r' % self.base_rev_id)
+        trace.mutter('Base revid: %r' % self.base_rev_id)
 
     def set_base(self, base_revision):
         """Set the base revision to use for the merge.
 
         :param base_revision: A 2-list containing a path and revision number.
         """
-        mutter("doing merge() with no base_revision specified")
+        trace.mutter("doing merge() with no base_revision specified")
         if base_revision == [None, None]:
             self.find_base()
         else:
@@ -454,13 +440,14 @@
         if self.merge_type.supports_reprocess:
             kwargs['reprocess'] = self.reprocess
         elif self.reprocess:
-            raise BzrError("Conflict reduction is not supported for merge"
-                                  " type %s." % self.merge_type)
+            raise errors.BzrError(
+                "Conflict reduction is not supported for merge"
+                " type %s." % self.merge_type)
         if self.merge_type.supports_show_base:
             kwargs['show_base'] = self.show_base
         elif self.show_base:
-            raise BzrError("Showing base is not supported for this"
-                           " merge type. %s" % self.merge_type)
+            raise errors.BzrError("Showing base is not supported for this"
+                                  " merge type. %s" % self.merge_type)
         if (not getattr(self.merge_type, 'supports_reverse_cherrypick', True)
             and not self.base_is_other_ancestor):
             raise errors.CannotReverseCherrypick()
@@ -515,10 +502,11 @@
         finally:
             self.this_tree.unlock()
         if len(merge.cooked_conflicts) == 0:
-            if not self.ignore_zero and not is_quiet():
-                note("All changes applied successfully.")
+            if not self.ignore_zero and not trace.is_quiet():
+                trace.note("All changes applied successfully.")
         else:
-            note("%d conflicts encountered." % len(merge.cooked_conflicts))
+            trace.note("%d conflicts encountered."
+                       % len(merge.cooked_conflicts))
 
         return len(merge.cooked_conflicts)
 
@@ -553,7 +541,7 @@
 
     def __init__(self, working_tree, this_tree, base_tree, other_tree,
                  interesting_ids=None, reprocess=False, show_base=False,
-                 pb=DummyProgress(), pp=None, change_reporter=None,
+                 pb=progress.DummyProgress(), pp=None, change_reporter=None,
                  interesting_files=None, do_merge=True,
                  cherrypick=False, lca_trees=None):
         """Initialize the merger object and perform the merge.
@@ -605,7 +593,7 @@
         self.change_reporter = change_reporter
         self.cherrypick = cherrypick
         if self.pp is None:
-            self.pp = ProgressPhase("Merge phase", 3, self.pb)
+            self.pp = progress.ProgressPhase("Merge phase", 3, self.pb)
         if do_merge:
             self.do_merge()
 
@@ -613,19 +601,21 @@
         self.this_tree.lock_tree_write()
         self.base_tree.lock_read()
         self.other_tree.lock_read()
-        self.tt = TreeTransform(self.this_tree, self.pb)
         try:
-            self.pp.next_phase()
-            self._compute_transform()
-            self.pp.next_phase()
-            results = self.tt.apply(no_conflicts=True)
-            self.write_modified(results)
+            self.tt = transform.TreeTransform(self.this_tree, self.pb)
             try:
-                self.this_tree.add_conflicts(self.cooked_conflicts)
-            except UnsupportedOperation:
-                pass
+                self.pp.next_phase()
+                self._compute_transform()
+                self.pp.next_phase()
+                results = self.tt.apply(no_conflicts=True)
+                self.write_modified(results)
+                try:
+                    self.this_tree.add_conflicts(self.cooked_conflicts)
+                except errors.UnsupportedOperation:
+                    pass
+            finally:
+                self.tt.finalize()
         finally:
-            self.tt.finalize()
             self.other_tree.unlock()
             self.base_tree.unlock()
             self.this_tree.unlock()
@@ -634,7 +624,7 @@
     def make_preview_transform(self):
         self.base_tree.lock_read()
         self.other_tree.lock_read()
-        self.tt = TransformPreview(self.this_tree)
+        self.tt = transform.TransformPreview(self.this_tree)
         try:
             self.pp.next_phase()
             self._compute_transform()
@@ -670,8 +660,8 @@
         self.pp.next_phase()
         child_pb = ui.ui_factory.nested_progress_bar()
         try:
-            fs_conflicts = resolve_conflicts(self.tt, child_pb,
-                lambda t, c: conflict_pass(t, c, self.other_tree))
+            fs_conflicts = transform.resolve_conflicts(self.tt, child_pb,
+                lambda t, c: transform.conflict_pass(t, c, self.other_tree))
         finally:
             child_pb.finished()
         if self.change_reporter is not None:
@@ -680,7 +670,7 @@
                 self.tt.iter_changes(), self.change_reporter)
         self.cook_conflicts(fs_conflicts)
         for conflict in self.cooked_conflicts:
-            warning(conflict)
+            trace.warning(conflict)
 
     def _entries3(self):
         """Gather data about files modified between three trees.
@@ -888,7 +878,7 @@
     def fix_root(self):
         try:
             self.tt.final_kind(self.tt.root)
-        except NoSuchFile:
+        except errors.NoSuchFile:
             self.tt.cancel_deletion(self.tt.root)
         if self.tt.final_file_id(self.tt.root) is None:
             self.tt.version_file(self.tt.tree_file_id(self.tt.root),
@@ -901,7 +891,7 @@
             return
         try:
             self.tt.final_kind(other_root)
-        except NoSuchFile:
+        except errors.NoSuchFile:
             return
         if self.other_tree.inventory.root.file_id in self.this_tree.inventory:
             # the other tree's root is a non-root in the current tree
@@ -1162,11 +1152,18 @@
                 # OTHER changed the file
                 wt = self.this_tree
                 if wt.supports_content_filtering():
-                    filter_tree_path = self.other_tree.id2path(file_id)
+                    # We get the path from the working tree if it exists.
+                    # That fails though when OTHER is adding a file, so
+                    # we fall back to the other tree to find the path if
+                    # it doesn't exist locally.
+                    try:
+                        filter_tree_path = wt.id2path(file_id)
+                    except errors.NoSuchId:
+                        filter_tree_path = self.other_tree.id2path(file_id)
                 else:
                     # Skip the id2path lookup for older formats
                     filter_tree_path = None
-                create_from_tree(self.tt, trans_id,
+                transform.create_from_tree(self.tt, trans_id,
                                  self.other_tree, file_id,
                                  filter_tree_path=filter_tree_path)
                 if not file_in_this:
@@ -1185,14 +1182,14 @@
                 # have agreement that output should be a file.
                 try:
                     self.text_merge(file_id, trans_id)
-                except BinaryFile:
+                except errors.BinaryFile:
                     return contents_conflict()
                 if file_id not in self.this_tree:
                     self.tt.version_file(file_id, trans_id)
                 try:
                     self.tt.tree_kind(trans_id)
                     self.tt.delete_contents(trans_id)
-                except NoSuchFile:
+                except errors.NoSuchFile:
                     pass
                 return "modified"
             else:
@@ -1216,8 +1213,8 @@
             base_lines = []
         other_lines = self.get_lines(self.other_tree, file_id)
         this_lines = self.get_lines(self.this_tree, file_id)
-        m3 = Merge3(base_lines, this_lines, other_lines,
-                    is_cherrypick=self.cherrypick)
+        m3 = merge3.Merge3(base_lines, this_lines, other_lines,
+                           is_cherrypick=self.cherrypick)
         start_marker = "!START OF MERGE CONFLICT!" + "I HOPE THIS IS UNIQUE"
         if self.show_base is True:
             base_marker = '|' * 7
@@ -1292,7 +1289,7 @@
         """Emit a single conflict file."""
         name = name + '.' + suffix
         trans_id = self.tt.create_path(name, parent_id)
-        create_from_tree(self.tt, trans_id, tree, file_id, lines,
+        transform.create_from_tree(self.tt, trans_id, tree, file_id, lines,
             filter_tree_path)
         return trans_id
 
@@ -1323,7 +1320,7 @@
         try:
             if self.tt.final_kind(trans_id) != "file":
                 return
-        except NoSuchFile:
+        except errors.NoSuchFile:
             return
         if winner == "this":
             executability = this_executable
@@ -1340,10 +1337,10 @@
 
     def cook_conflicts(self, fs_conflicts):
         """Convert all conflicts into a form that doesn't depend on trans_id"""
-        from conflicts import Conflict
         name_conflicts = {}
-        self.cooked_conflicts.extend(cook_conflicts(fs_conflicts, self.tt))
-        fp = FinalPaths(self.tt)
+        self.cooked_conflicts.extend(transform.cook_conflicts(
+                fs_conflicts, self.tt))
+        fp = transform.FinalPaths(self.tt)
         for conflict in self._raw_conflicts:
             conflict_type = conflict[0]
             if conflict_type in ('name conflict', 'parent conflict'):
@@ -1351,8 +1348,8 @@
                 conflict_args = conflict[2:]
                 if trans_id not in name_conflicts:
                     name_conflicts[trans_id] = {}
-                unique_add(name_conflicts[trans_id], conflict_type,
-                           conflict_args)
+                transform.unique_add(name_conflicts[trans_id], conflict_type,
+                                     conflict_args)
             if conflict_type == 'contents conflict':
                 for trans_id in conflict[1]:
                     file_id = self.tt.final_file_id(trans_id)
@@ -1363,13 +1360,15 @@
                     if path.endswith(suffix):
                         path = path[:-len(suffix)]
                         break
-                c = Conflict.factory(conflict_type, path=path, file_id=file_id)
+                c = _mod_conflicts.Conflict.factory(conflict_type,
+                                                    path=path, file_id=file_id)
                 self.cooked_conflicts.append(c)
             if conflict_type == 'text conflict':
                 trans_id = conflict[1]
                 path = fp.get_path(trans_id)
                 file_id = self.tt.final_file_id(trans_id)
-                c = Conflict.factory(conflict_type, path=path, file_id=file_id)
+                c = _mod_conflicts.Conflict.factory(conflict_type,
+                                                    path=path, file_id=file_id)
                 self.cooked_conflicts.append(c)
 
         for trans_id, conflicts in name_conflicts.iteritems():
@@ -1390,14 +1389,15 @@
             if this_parent is not None and this_name is not None:
                 this_parent_path = \
                     fp.get_path(self.tt.trans_id_file_id(this_parent))
-                this_path = pathjoin(this_parent_path, this_name)
+                this_path = osutils.pathjoin(this_parent_path, this_name)
             else:
                 this_path = "<deleted>"
             file_id = self.tt.final_file_id(trans_id)
-            c = Conflict.factory('path conflict', path=this_path,
-                                 conflict_path=other_path, file_id=file_id)
+            c = _mod_conflicts.Conflict.factory('path conflict', path=this_path,
+                                                conflict_path=other_path,
+                                                file_id=file_id)
             self.cooked_conflicts.append(c)
-        self.cooked_conflicts.sort(key=Conflict.sort_key)
+        self.cooked_conflicts.sort(key=_mod_conflicts.Conflict.sort_key)
 
 
 class WeaveMerger(Merge3Merger):
@@ -1424,8 +1424,8 @@
             name = self.tt.final_name(trans_id) + '.plan'
             contents = ('%10s|%s' % l for l in plan)
             self.tt.new_file(name, self.tt.final_parent(trans_id), contents)
-        textmerge = PlanWeaveMerge(plan, '<<<<<<< TREE\n',
-            '>>>>>>> MERGE-SOURCE\n')
+        textmerge = versionedfile.PlanWeaveMerge(plan, '<<<<<<< TREE\n',
+                                                 '>>>>>>> MERGE-SOURCE\n')
         return textmerge.merge_lines(self.reprocess)
 
     def text_merge(self, file_id, trans_id):
@@ -1437,7 +1437,7 @@
         lines = list(lines)
         # Note we're checking whether the OUTPUT is binary in this case,
         # because we don't want to get into weave merge guts.
-        check_text_lines(lines)
+        textfile.check_text_lines(lines)
         self.tt.create_file(lines, trans_id)
         if conflicts:
             self._raw_conflicts.append(('text conflict', trans_id))
@@ -1467,8 +1467,8 @@
             name = self.tt.final_name(trans_id) + '.plan'
             contents = ('%10s|%s' % l for l in plan)
             self.tt.new_file(name, self.tt.final_parent(trans_id), contents)
-        textmerge = PlanWeaveMerge(plan, '<<<<<<< TREE\n',
-            '>>>>>>> MERGE-SOURCE\n')
+        textmerge = versionedfile.PlanWeaveMerge(plan, '<<<<<<< TREE\n',
+                                                 '>>>>>>> MERGE-SOURCE\n')
         return textmerge.merge_lines(self.reprocess)
 
 
@@ -1476,7 +1476,7 @@
     """Three-way merger using external diff3 for text merging"""
 
     def dump_file(self, temp_dir, name, tree, file_id):
-        out_path = pathjoin(temp_dir, name)
+        out_path = osutils.pathjoin(temp_dir, name)
         out_file = open(out_path, "wb")
         try:
             in_file = tree.get_file(file_id)
@@ -1494,13 +1494,13 @@
         import bzrlib.patch
         temp_dir = osutils.mkdtemp(prefix="bzr-")
         try:
-            new_file = pathjoin(temp_dir, "new")
+            new_file = osutils.pathjoin(temp_dir, "new")
             this = self.dump_file(temp_dir, "this", self.this_tree, file_id)
             base = self.dump_file(temp_dir, "base", self.base_tree, file_id)
             other = self.dump_file(temp_dir, "other", self.other_tree, file_id)
             status = bzrlib.patch.diff3(new_file, this, base, other)
             if status not in (0, 1):
-                raise BzrError("Unhandled diff3 exit code")
+                raise errors.BzrError("Unhandled diff3 exit code")
             f = open(new_file, 'rb')
             try:
                 self.tt.create_file(f, trans_id)
@@ -1524,7 +1524,7 @@
                 other_rev_id=None,
                 interesting_files=None,
                 this_tree=None,
-                pb=DummyProgress(),
+                pb=progress.DummyProgress(),
                 change_reporter=None):
     """Primary interface for merging.
 
@@ -1533,8 +1533,8 @@
                      branch.get_revision_tree(base_revision))'
         """
     if this_tree is None:
-        raise BzrError("bzrlib.merge.merge_inner requires a this_tree "
-            "parameter as of bzrlib version 0.8.")
+        raise errors.BzrError("bzrlib.merge.merge_inner requires a this_tree "
+                              "parameter as of bzrlib version 0.8.")
     merger = Merger(this_branch, other_tree, base_tree, this_tree=this_tree,
                     pb=pb, change_reporter=change_reporter)
     merger.backup_files = backup_files
@@ -1758,7 +1758,7 @@
         super(_PlanMerge, self).__init__(a_rev, b_rev, vf, key_prefix)
         self.a_key = self._key_prefix + (self.a_rev,)
         self.b_key = self._key_prefix + (self.b_rev,)
-        self.graph = Graph(self.vf)
+        self.graph = _mod_graph.Graph(self.vf)
         heads = self.graph.heads((self.a_key, self.b_key))
         if len(heads) == 1:
             # one side dominates, so we can just return its values, yay for
@@ -1769,8 +1769,8 @@
                 other = b_rev
             else:
                 other = a_rev
-            mutter('found dominating revision for %s\n%s > %s', self.vf,
-                   self._head_key[-1], other)
+            trace.mutter('found dominating revision for %s\n%s > %s', self.vf,
+                         self._head_key[-1], other)
             self._weave = None
         else:
             self._head_key = None
@@ -1790,7 +1790,7 @@
         while True:
             next_lcas = self.graph.find_lca(*cur_ancestors)
             # Map a plain NULL_REVISION to a simple no-ancestors
-            if next_lcas == set([NULL_REVISION]):
+            if next_lcas == set([_mod_revision.NULL_REVISION]):
                 next_lcas = ()
             # Order the lca's based on when they were merged into the tip
             # While the actual merge portion of weave merge uses a set() of
@@ -1808,8 +1808,9 @@
             elif len(next_lcas) > 2:
                 # More than 2 lca's, fall back to grabbing all nodes between
                 # this and the unique lca.
-                mutter('More than 2 LCAs, falling back to all nodes for:'
-                       ' %s, %s\n=> %s', self.a_key, self.b_key, cur_ancestors)
+                trace.mutter('More than 2 LCAs, falling back to all nodes for:'
+                             ' %s, %s\n=> %s',
+                             self.a_key, self.b_key, cur_ancestors)
                 cur_lcas = next_lcas
                 while len(cur_lcas) > 1:
                     cur_lcas = self.graph.find_lca(*cur_lcas)
@@ -1818,7 +1819,7 @@
                     unique_lca = None
                 else:
                     unique_lca = list(cur_lcas)[0]
-                    if unique_lca == NULL_REVISION:
+                    if unique_lca == _mod_revision.NULL_REVISION:
                         # find_lca will return a plain 'NULL_REVISION' rather
                         # than a key tuple when there is no common ancestor, we
                         # prefer to just use None, because it doesn't confuse
@@ -1847,8 +1848,8 @@
             # We remove NULL_REVISION because it isn't a proper tuple key, and
             # thus confuses things like _get_interesting_texts, and our logic
             # to add the texts into the memory weave.
-            if NULL_REVISION in parent_map:
-                parent_map.pop(NULL_REVISION)
+            if _mod_revision.NULL_REVISION in parent_map:
+                parent_map.pop(_mod_revision.NULL_REVISION)
         else:
             interesting = set()
             for tip in tip_keys:
@@ -2006,7 +2007,7 @@
         lcas = graph.find_lca(key_prefix + (a_rev,), key_prefix + (b_rev,))
         self.lcas = set()
         for lca in lcas:
-            if lca == NULL_REVISION:
+            if lca == _mod_revision.NULL_REVISION:
                 self.lcas.add(lca)
             else:
                 self.lcas.add(lca[-1])

=== modified file 'bzrlib/merge_directive.py'
--- bzrlib/merge_directive.py	2009-05-11 19:11:14 +0000
+++ bzrlib/merge_directive.py	2009-11-28 00:48:03 +0000
@@ -371,15 +371,13 @@
         :return: a MergeRequest
         """
         line_iter = iter(lines)
+        firstline = ""
         for line in line_iter:
             if line.startswith('# Bazaar merge directive format '):
-                break
-        else:
-            if len(lines) > 0:
-                raise errors.NotAMergeDirective(lines[0])
-            else:
-                raise errors.NotAMergeDirective('')
-        return _format_registry.get(line[2:].rstrip())._from_lines(line_iter)
+                return _format_registry.get(line[2:].rstrip())._from_lines(
+                    line_iter)
+            firstline = firstline or line.strip()
+        raise errors.NotAMergeDirective(firstline)
 
     @classmethod
     def _from_lines(klass, line_iter):
@@ -582,11 +580,13 @@
                     revision_id):
                     raise errors.PublicBranchOutOfDate(public_branch,
                                                        revision_id)
+            testament_sha1 = t.as_sha1()
         finally:
             for entry in reversed(locked):
                 entry.unlock()
-        return klass(revision_id, t.as_sha1(), time, timezone, target_branch,
-            patch, public_branch, message, bundle, base_revision_id)
+        return klass(revision_id, testament_sha1, time, timezone,
+            target_branch, patch, public_branch, message, bundle,
+            base_revision_id)
 
     def _verify_patch(self, repository):
         calculated_patch = self._generate_diff(repository, self.revision_id,

=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2009-03-23 14:59:43 +0000
+++ bzrlib/msgeditor.py	2009-11-17 23:05:04 +0000
@@ -64,7 +64,13 @@
             x = call(edargs + [filename])
         except OSError, e:
             # We're searching for an editor, so catch safe errors and continue
-            if e.errno in (errno.ENOENT, errno.EACCES):
+            # errno 193 is ERROR_BAD_EXE_FORMAT on Windows. Python2.4 uses the
+            # winerror for errno. Python2.5+ use errno ENOEXEC and set winerror
+            # to 193. However, catching 193 here should be fine. Other
+            # platforms aren't likely to have that high of an error. And even
+            # if they do, it is still reasonable to fall back to the next
+            # editor.
+            if e.errno in (errno.ENOENT, errno.EACCES, errno.ENOEXEC, 193):
                 if candidate_source is not None:
                     # We tried this editor because some user configuration (an
                     # environment variable or config file) said to try it.  Let

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2009-07-10 08:33:11 +0000
+++ bzrlib/mutabletree.py	2009-10-06 14:40:37 +0000
@@ -23,25 +23,22 @@
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 import os
+import re
 
 from bzrlib import (
     add,
     bzrdir,
+    errors,
     hooks,
+    osutils,
+    revisiontree,
     symbol_versioning,
+    trace,
+    tree,
     )
-from bzrlib.osutils import dirname
-from bzrlib.revisiontree import RevisionTree
-from bzrlib.trace import mutter, warning
 """)
 
-from bzrlib import (
-    errors,
-    osutils,
-    tree,
-    )
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-from bzrlib.osutils import splitpath
 
 
 def needs_tree_write_lock(unbound):
@@ -129,7 +126,7 @@
             # generic constraint checks:
             if self.is_control_filename(f):
                 raise errors.ForbiddenControlFileError(filename=f)
-            fp = splitpath(f)
+            fp = osutils.splitpath(f)
         # fill out file kinds for all files [not needed when we stop
         # caring about the instantaneous file kind within a uncommmitted tree
         #
@@ -226,6 +223,9 @@
             revprops=revprops,
             possible_master_transports=possible_master_transports,
             *args, **kwargs)
+        post_hook_params = PostCommitHookParams(self)
+        for hook in MutableTree.hooks['post_commit']:
+            hook(post_hook_params)
         return committed_id
 
     def _gather_kinds(self, files, kinds):
@@ -233,12 +233,20 @@
         raise NotImplementedError(self._gather_kinds)
 
     @needs_read_lock
-    def has_changes(self, from_tree):
-        """Quickly check that the tree contains at least one change.
+    def has_changes(self, _from_tree=None):
+        """Quickly check that the tree contains at least one commitable change.
+
+        :param _from_tree: tree to compare against to find changes (default to
+            the basis tree and is intended to be used by tests).
 
         :return: True if a change is found. False otherwise
         """
-        changes = self.iter_changes(from_tree)
+        # Check pending merges
+        if len(self.get_parent_ids()) > 1:
+            return True
+        if _from_tree is None:
+            _from_tree = self.basis_tree()
+        changes = self.iter_changes(_from_tree)
         try:
             change = changes.next()
             # Exclude root (talk about black magic... --vila 20090629)
@@ -386,8 +394,8 @@
         # perform the canonicalization in bulk.
         for filepath in osutils.canonical_relpaths(self.basedir, file_list):
             rf = _FastPath(filepath)
-            # validate user parameters. Our recursive code avoids adding new files
-            # that need such validation
+            # validate user parameters. Our recursive code avoids adding new
+            # files that need such validation
             if self.is_control_filename(rf.raw_path):
                 raise errors.ForbiddenControlFileError(filename=rf.raw_path)
 
@@ -399,10 +407,10 @@
             else:
                 if not InventoryEntry.versionable_kind(kind):
                     raise errors.BadFileKindError(filename=abspath, kind=kind)
-            # ensure the named path is added, so that ignore rules in the later directory
-            # walk dont skip it.
-            # we dont have a parent ie known yet.: use the relatively slower inventory
-            # probing method
+            # ensure the named path is added, so that ignore rules in the later
+            # directory walk dont skip it.
+            # we dont have a parent ie known yet.: use the relatively slower
+            # inventory probing method
             versioned = inv.has_filename(rf.raw_path)
             if versioned:
                 continue
@@ -424,6 +432,7 @@
                 dirs_to_add.append((path, None))
             prev_dir = path.raw_path
 
+        illegalpath_re = re.compile(r'[\r\n]')
         # dirs_to_add is initialised to a list of directories, but as we scan
         # directories we append files to it.
         # XXX: We should determine kind of files when we scan them rather than
@@ -438,7 +447,11 @@
             kind = osutils.file_kind(abspath)
 
             if not InventoryEntry.versionable_kind(kind):
-                warning("skipping %s (can't add file of kind '%s')", abspath, kind)
+                trace.warning("skipping %s (can't add file of kind '%s')",
+                              abspath, kind)
+                continue
+            if illegalpath_re.search(directory.raw_path):
+                trace.warning("skipping %r (contains \\n or \\r)" % abspath)
                 continue
 
             if parent_ie is not None:
@@ -467,14 +480,15 @@
                 pass
                 # mutter("%r is already versioned", abspath)
             elif sub_tree:
-                # XXX: This is wrong; people *might* reasonably be trying to add
-                # subtrees as subtrees.  This should probably only be done in formats
-                # which can represent subtrees, and even then perhaps only when
-                # the user asked to add subtrees.  At the moment you can add them
-                # specially through 'join --reference', which is perhaps
-                # reasonable: adding a new reference is a special operation and
-                # can have a special behaviour.  mbp 20070306
-                mutter("%r is a nested bzr tree", abspath)
+                # XXX: This is wrong; people *might* reasonably be trying to
+                # add subtrees as subtrees.  This should probably only be done
+                # in formats which can represent subtrees, and even then
+                # perhaps only when the user asked to add subtrees.  At the
+                # moment you can add them specially through 'join --reference',
+                # which is perhaps reasonable: adding a new reference is a
+                # special operation and can have a special behaviour.  mbp
+                # 20070306
+                trace.mutter("%r is a nested bzr tree", abspath)
             else:
                 _add_one(self, inv, parent_ie, directory, kind, action)
                 added.append(directory.raw_path)
@@ -487,7 +501,7 @@
                     # without the parent ie, use the relatively slower inventory
                     # probing method
                     this_id = inv.path2id(
-                            self._fix_case_of_inventory_path(directory.raw_path))
+                        self._fix_case_of_inventory_path(directory.raw_path))
                     if this_id is None:
                         this_ie = None
                     else:
@@ -502,7 +516,7 @@
                     # faster - its impossible for a non root dir to have a
                     # control file.
                     if self.is_control_filename(subp):
-                        mutter("skip control directory %r", subp)
+                        trace.mutter("skip control directory %r", subp)
                     elif subf in this_ie.children:
                         # recurse into this already versioned subdir.
                         dirs_to_add.append((_FastPath(subp, subf), this_ie))
@@ -564,7 +578,8 @@
         inventory = basis.inventory._get_mutable_inventory()
         basis.unlock()
         inventory.apply_delta(delta)
-        rev_tree = RevisionTree(self.branch.repository, inventory, new_revid)
+        rev_tree = revisiontree.RevisionTree(self.branch.repository,
+                                             inventory, new_revid)
         self.set_parent_trees([(new_revid, rev_tree)])
 
 
@@ -581,14 +596,32 @@
         self.create_hook(hooks.HookPoint('start_commit',
             "Called before a commit is performed on a tree. The start commit "
             "hook is able to change the tree before the commit takes place. "
-            "start_commit is called with the bzrlib.tree.MutableTree that the "
-            "commit is being performed on.", (1, 4), None))
+            "start_commit is called with the bzrlib.mutabletree.MutableTree "
+            "that the commit is being performed on.", (1, 4), None))
+        self.create_hook(hooks.HookPoint('post_commit',
+            "Called after a commit is performed on a tree. The hook is "
+            "called with a bzrlib.mutabletree.PostCommitHookParams object. "
+            "The mutable tree the commit was performed on is available via "
+            "the mutable_tree attribute of that object.", (2, 0), None))
 
 
 # install the default hooks into the MutableTree class.
 MutableTree.hooks = MutableTreeHooks()
 
 
+class PostCommitHookParams(object):
+    """Parameters for the post_commit hook.
+
+    To access the parameters, use the following attributes:
+
+    * mutable_tree - the MutableTree object
+    """
+
+    def __init__(self, mutable_tree):
+        """Create the parameters for the post_commit hook."""
+        self.mutable_tree = mutable_tree
+
+
 class _FastPath(object):
     """A path object with fast accessors for things like basename."""
 
@@ -635,8 +668,8 @@
         # there are a limited number of dirs we can be nested under, it should
         # generally find it very fast and not recurse after that.
         added = _add_one_and_parent(tree, inv, None,
-            _FastPath(dirname(path.raw_path)), 'directory', action)
-        parent_id = inv.path2id(dirname(path.raw_path))
+            _FastPath(osutils.dirname(path.raw_path)), 'directory', action)
+        parent_id = inv.path2id(osutils.dirname(path.raw_path))
         parent_ie = inv[parent_id]
     _add_one(tree, inv, parent_ie, path, kind, action)
     return added + [path.raw_path]

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2009-04-03 20:05:25 +0000
+++ bzrlib/option.py	2009-08-18 08:10:44 +0000
@@ -40,25 +40,25 @@
     each revision specifier supplied.
 
     >>> _parse_revision_str('234')
-    [<RevisionSpec_revno 234>]
+    [<RevisionSpec_dwim 234>]
     >>> _parse_revision_str('234..567')
-    [<RevisionSpec_revno 234>, <RevisionSpec_revno 567>]
+    [<RevisionSpec_dwim 234>, <RevisionSpec_dwim 567>]
     >>> _parse_revision_str('..')
     [<RevisionSpec None>, <RevisionSpec None>]
     >>> _parse_revision_str('..234')
-    [<RevisionSpec None>, <RevisionSpec_revno 234>]
+    [<RevisionSpec None>, <RevisionSpec_dwim 234>]
     >>> _parse_revision_str('234..')
-    [<RevisionSpec_revno 234>, <RevisionSpec None>]
+    [<RevisionSpec_dwim 234>, <RevisionSpec None>]
     >>> _parse_revision_str('234..456..789') # Maybe this should be an error
-    [<RevisionSpec_revno 234>, <RevisionSpec_revno 456>, <RevisionSpec_revno 789>]
+    [<RevisionSpec_dwim 234>, <RevisionSpec_dwim 456>, <RevisionSpec_dwim 789>]
     >>> _parse_revision_str('234....789') #Error ?
-    [<RevisionSpec_revno 234>, <RevisionSpec None>, <RevisionSpec_revno 789>]
+    [<RevisionSpec_dwim 234>, <RevisionSpec None>, <RevisionSpec_dwim 789>]
     >>> _parse_revision_str('revid:test@other.com-234234')
     [<RevisionSpec_revid revid:test@other.com-234234>]
     >>> _parse_revision_str('revid:test@other.com-234234..revid:test@other.com-234235')
     [<RevisionSpec_revid revid:test@other.com-234234>, <RevisionSpec_revid revid:test@other.com-234235>]
     >>> _parse_revision_str('revid:test@other.com-234234..23')
-    [<RevisionSpec_revid revid:test@other.com-234234>, <RevisionSpec_revno 23>]
+    [<RevisionSpec_revid revid:test@other.com-234234>, <RevisionSpec_dwim 23>]
     >>> _parse_revision_str('date:2005-04-12')
     [<RevisionSpec_date date:2005-04-12>]
     >>> _parse_revision_str('date:2005-04-12 12:24:33')
@@ -68,27 +68,23 @@
     >>> _parse_revision_str('date:2005-04-12,12:24:33')
     [<RevisionSpec_date date:2005-04-12,12:24:33>]
     >>> _parse_revision_str('-5..23')
-    [<RevisionSpec_revno -5>, <RevisionSpec_revno 23>]
+    [<RevisionSpec_dwim -5>, <RevisionSpec_dwim 23>]
     >>> _parse_revision_str('-5')
-    [<RevisionSpec_revno -5>]
+    [<RevisionSpec_dwim -5>]
     >>> _parse_revision_str('123a')
-    Traceback (most recent call last):
-      ...
-    NoSuchRevisionSpec: No namespace registered for string: '123a'
+    [<RevisionSpec_dwim 123a>]
     >>> _parse_revision_str('abc')
-    Traceback (most recent call last):
-      ...
-    NoSuchRevisionSpec: No namespace registered for string: 'abc'
+    [<RevisionSpec_dwim abc>]
     >>> _parse_revision_str('branch:../branch2')
     [<RevisionSpec_branch branch:../branch2>]
     >>> _parse_revision_str('branch:../../branch2')
     [<RevisionSpec_branch branch:../../branch2>]
     >>> _parse_revision_str('branch:../../branch2..23')
-    [<RevisionSpec_branch branch:../../branch2>, <RevisionSpec_revno 23>]
+    [<RevisionSpec_branch branch:../../branch2>, <RevisionSpec_dwim 23>]
     >>> _parse_revision_str('branch:..\\\\branch2')
     [<RevisionSpec_branch branch:..\\branch2>]
     >>> _parse_revision_str('branch:..\\\\..\\\\branch2..23')
-    [<RevisionSpec_branch branch:..\\..\\branch2>, <RevisionSpec_revno 23>]
+    [<RevisionSpec_branch branch:..\\..\\branch2>, <RevisionSpec_dwim 23>]
     """
     # TODO: Maybe move this into revisionspec.py
     revs = []
@@ -104,7 +100,7 @@
     parent of the revision.
 
     >>> _parse_change_str('123')
-    (<RevisionSpec_before before:123>, <RevisionSpec_revno 123>)
+    (<RevisionSpec_before before:123>, <RevisionSpec_dwim 123>)
     >>> _parse_change_str('123..124')
     Traceback (most recent call last):
       ...

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2009-07-23 16:01:17 +0000
+++ bzrlib/osutils.py	2009-12-02 07:56:16 +0000
@@ -21,6 +21,7 @@
                   S_ISCHR, S_ISBLK, S_ISFIFO, S_ISSOCK)
 import sys
 import time
+import warnings
 
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
@@ -223,6 +224,7 @@
     else:
         file_existed = True
 
+    failure_exc = None
     success = False
     try:
         try:
@@ -234,8 +236,12 @@
             # source and target may be aliases of each other (e.g. on a
             # case-insensitive filesystem), so we may have accidentally renamed
             # source by when we tried to rename target
-            if not (file_existed and e.errno in (None, errno.ENOENT)):
-                raise
+            failure_exc = sys.exc_info()
+            if (file_existed and e.errno in (None, errno.ENOENT)
+                and old.lower() == new.lower()):
+                # source and target are the same file on a case-insensitive
+                # filesystem, so we don't generate an exception
+                failure_exc = None
     finally:
         if file_existed:
             # If the file used to exist, rename it back into place
@@ -244,6 +250,8 @@
                 unlink_func(tmp_name)
             else:
                 rename_func(tmp_name, new)
+    if failure_exc is not None:
+        raise failure_exc[0], failure_exc[1], failure_exc[2]
 
 
 # In Python 2.4.2 and older, os.path.abspath and os.path.realpath
@@ -687,6 +695,8 @@
     return offset.days * 86400 + offset.seconds
 
 weekdays = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
+_default_format_by_weekday_num = [wd + " %Y-%m-%d %H:%M:%S" for wd in weekdays]
+
 
 def format_date(t, offset=0, timezone='original', date_fmt=None,
                 show_offset=True):
@@ -706,6 +716,32 @@
     date_str = time.strftime(date_fmt, tt)
     return date_str + offset_str
 
+
+# Cache of formatted offset strings
+_offset_cache = {}
+
+
+def format_date_with_offset_in_original_timezone(t, offset=0,
+    _cache=_offset_cache):
+    """Return a formatted date string in the original timezone.
+
+    This routine may be faster then format_date.
+
+    :param t: Seconds since the epoch.
+    :param offset: Timezone offset in seconds east of utc.
+    """
+    if offset is None:
+        offset = 0
+    tt = time.gmtime(t + offset)
+    date_fmt = _default_format_by_weekday_num[tt[6]]
+    date_str = time.strftime(date_fmt, tt)
+    offset_str = _cache.get(offset, None)
+    if offset_str is None:
+        offset_str = ' %+03d%02d' % (offset / 3600, (offset / 60) % 60)
+        _cache[offset] = offset_str
+    return date_str + offset_str
+
+
 def format_local_date(t, offset=0, timezone='original', date_fmt=None,
                       show_offset=True):
     """Return an unicode date string formatted according to the current locale.
@@ -725,6 +761,7 @@
         date_str = date_str.decode(get_user_encoding(), 'replace')
     return date_str + offset_str
 
+
 def _format_date(t, offset, timezone, date_fmt, show_offset):
     if timezone == 'utc':
         tt = time.gmtime(t)
@@ -881,9 +918,57 @@
     return parents
 
 
+_extension_load_failures = []
+
+
+def failed_to_load_extension(exception):
+    """Handle failing to load a binary extension.
+
+    This should be called from the ImportError block guarding the attempt to
+    import the native extension.  If this function returns, the pure-Python
+    implementation should be loaded instead::
+
+    >>> try:
+    >>>     import bzrlib._fictional_extension_pyx
+    >>> except ImportError, e:
+    >>>     bzrlib.osutils.failed_to_load_extension(e)
+    >>>     import bzrlib._fictional_extension_py
+    """
+    # NB: This docstring is just an example, not a doctest, because doctest
+    # currently can't cope with the use of lazy imports in this namespace --
+    # mbp 20090729
+    
+    # This currently doesn't report the failure at the time it occurs, because
+    # they tend to happen very early in startup when we can't check config
+    # files etc, and also we want to report all failures but not spam the user
+    # with 10 warnings.
+    from bzrlib import trace
+    exception_str = str(exception)
+    if exception_str not in _extension_load_failures:
+        trace.mutter("failed to load compiled extension: %s" % exception_str)
+        _extension_load_failures.append(exception_str)
+
+
+def report_extension_load_failures():
+    if not _extension_load_failures:
+        return
+    from bzrlib.config import GlobalConfig
+    if GlobalConfig().get_user_option_as_bool('ignore_missing_extensions'):
+        return
+    # the warnings framework should by default show this only once
+    from bzrlib.trace import warning
+    warning(
+        "bzr: warning: some compiled extensions could not be loaded; "
+        "see <https://answers.launchpad.net/bzr/+faq/703>")
+    # we no longer show the specific missing extensions here, because it makes
+    # the message too long and scary - see
+    # https://bugs.launchpad.net/bzr/+bug/430529
+
+
 try:
     from bzrlib._chunks_to_lines_pyx import chunks_to_lines
-except ImportError:
+except ImportError, e:
+    failed_to_load_extension(e)
     from bzrlib._chunks_to_lines_py import chunks_to_lines
 
 
@@ -1083,7 +1168,14 @@
     bit_iter = iter(rel.split('/'))
     for bit in bit_iter:
         lbit = bit.lower()
-        for look in _listdir(current):
+        try:
+            next_entries = _listdir(current)
+        except OSError: # enoent, eperm, etc
+            # We can't find this in the filesystem, so just append the
+            # remaining bits.
+            current = pathjoin(current, bit, *list(bit_iter))
+            break
+        for look in next_entries:
             if lbit == look.lower():
                 current = pathjoin(current, look)
                 break
@@ -1093,7 +1185,7 @@
             # the target of a move, for example).
             current = pathjoin(current, bit, *list(bit_iter))
             break
-    return current[len(abs_base)+1:]
+    return current[len(abs_base):].lstrip('/')
 
 # XXX - TODO - we need better detection/integration of case-insensitive
 # file-systems; Linux often sees FAT32 devices (or NFS-mounted OSX
@@ -1466,7 +1558,8 @@
             try:
                 from bzrlib._readdir_pyx import UTF8DirReader
                 _selected_dir_reader = UTF8DirReader()
-            except ImportError:
+            except ImportError, e:
+                failed_to_load_extension(e)
                 pass
 
     if _selected_dir_reader is None:
@@ -1778,7 +1871,9 @@
         try:
             from bzrlib._readdir_pyx import UTF8DirReader
             file_kind_from_stat_mode = UTF8DirReader().kind_from_mode
-        except ImportError:
+        except ImportError, e:
+            # This is one time where we won't warn that an extension failed to
+            # load. The extension is never available on Windows anyway.
             from bzrlib._readdir_py import (
                 _kind_from_mode as file_kind_from_stat_mode
                 )
@@ -1886,13 +1981,16 @@
     anything goes wrong.
     """
     global _cached_local_concurrency
+
     if _cached_local_concurrency is not None and use_cache:
         return _cached_local_concurrency
 
-    try:
-        concurrency = _local_concurrency()
-    except (OSError, IOError):
-        concurrency = None
+    concurrency = os.environ.get('BZR_CONCURRENCY', None)
+    if concurrency is None:
+        try:
+            concurrency = _local_concurrency()
+        except (OSError, IOError):
+            pass
     try:
         concurrency = int(concurrency)
     except (TypeError, ValueError):

=== modified file 'bzrlib/patches.py'
--- bzrlib/patches.py	2009-03-23 14:59:43 +0000
+++ bzrlib/patches.py	2009-11-03 15:45:56 +0000
@@ -14,6 +14,18 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+import re
+
+
+binary_files_re = 'Binary files (.*) and (.*) differ\n'
+
+
+class BinaryFiles(Exception):
+
+    def __init__(self, orig_name, mod_name):
+        self.orig_name = orig_name
+        self.mod_name = mod_name
+        Exception.__init__(self, 'Binary files section encountered.')
 
 
 class PatchSyntax(Exception):
@@ -57,6 +69,9 @@
 def get_patch_names(iter_lines):
     try:
         line = iter_lines.next()
+        match = re.match(binary_files_re, line)
+        if match is not None:
+            raise BinaryFiles(match.group(1), match.group(2))
         if not line.startswith("--- "):
             raise MalformedPatchHeader("No orig name", line)
         else:
@@ -259,10 +274,19 @@
         yield hunk
 
 
-class Patch:
+class BinaryPatch(object):
     def __init__(self, oldname, newname):
         self.oldname = oldname
         self.newname = newname
+
+    def __str__(self):
+        return 'Binary files %s and %s differ\n' % (self.oldname, self.newname)
+
+
+class Patch(BinaryPatch):
+
+    def __init__(self, oldname, newname):
+        BinaryPatch.__init__(self, oldname, newname)
         self.hunks = []
 
     def __str__(self):
@@ -317,14 +341,19 @@
 
 def parse_patch(iter_lines):
     iter_lines = iter_lines_handle_nl(iter_lines)
-    (orig_name, mod_name) = get_patch_names(iter_lines)
-    patch = Patch(orig_name, mod_name)
-    for hunk in iter_hunks(iter_lines):
-        patch.hunks.append(hunk)
-    return patch
+    try:
+        (orig_name, mod_name) = get_patch_names(iter_lines)
+    except BinaryFiles, e:
+        return BinaryPatch(e.orig_name, e.mod_name)
+    else:
+        patch = Patch(orig_name, mod_name)
+        for hunk in iter_hunks(iter_lines):
+            patch.hunks.append(hunk)
+        return patch
 
 
 def iter_file_patch(iter_lines):
+    regex = re.compile(binary_files_re)
     saved_lines = []
     orig_range = 0
     for line in iter_lines:
@@ -335,7 +364,7 @@
         elif orig_range > 0:
             if line.startswith('-') or line.startswith(' '):
                 orig_range -= 1
-        elif line.startswith('--- '):
+        elif line.startswith('--- ') or regex.match(line):
             if len(saved_lines) > 0:
                 yield saved_lines
             saved_lines = []

=== modified file 'bzrlib/plugin.py'
--- bzrlib/plugin.py	2009-03-24 01:53:42 +0000
+++ bzrlib/plugin.py	2009-09-04 15:36:48 +0000
@@ -52,12 +52,16 @@
 from bzrlib import plugins as _mod_plugins
 """)
 
-from bzrlib.symbol_versioning import deprecated_function
+from bzrlib.symbol_versioning import (
+    deprecated_function,
+    deprecated_in,
+    )
 
 
 DEFAULT_PLUGIN_PATH = None
 _loaded = False
 
+@deprecated_function(deprecated_in((2, 0, 0)))
 def get_default_plugin_path():
     """Get the DEFAULT_PLUGIN_PATH"""
     global DEFAULT_PLUGIN_PATH
@@ -91,13 +95,15 @@
     return path
 
 
-def get_standard_plugins_path():
-    """Determine a plugin path suitable for general use."""
-    path = os.environ.get('BZR_PLUGIN_PATH',
-                          get_default_plugin_path()).split(os.pathsep)
-    # Get rid of trailing slashes, since Python can't handle them when
-    # it tries to import modules.
-    path = map(_strip_trailing_sep, path)
+def _append_new_path(paths, new_path):
+    """Append a new path if it set and not already known."""
+    if new_path is not None and new_path not in paths:
+        paths.append(new_path)
+    return paths
+
+
+def get_core_plugin_path():
+    core_path = None
     bzr_exe = bool(getattr(sys, 'frozen', None))
     if bzr_exe:    # expand path for bzr.exe
         # We need to use relative path to system-wide plugin
@@ -110,25 +116,83 @@
         # then plugins directory is
         # C:\Program Files\Bazaar\plugins
         # so relative path is ../../../plugins
-        path.append(osutils.abspath(osutils.pathjoin(
-            osutils.dirname(__file__), '../../../plugins')))
-    if not bzr_exe:     # don't look inside library.zip
+        core_path = osutils.abspath(osutils.pathjoin(
+                osutils.dirname(__file__), '../../../plugins'))
+    else:     # don't look inside library.zip
         # search the plugin path before the bzrlib installed dir
-        path.append(os.path.dirname(_mod_plugins.__file__))
-    # search the arch independent path if we can determine that and
-    # the plugin is found nowhere else
-    if sys.platform != 'win32':
-        try:
-            from distutils.sysconfig import get_python_lib
-        except ImportError:
-            # If distutuils is not available, we just won't add that path
-            pass
-        else:
-            archless_path = osutils.pathjoin(get_python_lib(), 'bzrlib',
-                    'plugins')
-            if archless_path not in path:
-                path.append(archless_path)
-    return path
+        core_path = os.path.dirname(_mod_plugins.__file__)
+    return core_path
+
+
+def get_site_plugin_path():
+    """Returns the path for the site installed plugins."""
+    if sys.platform == 'win32':
+        # We don't have (yet) a good answer for windows since that is certainly
+        # related to the way we build the installers. -- vila20090821
+        return None
+    site_path = None
+    try:
+        from distutils.sysconfig import get_python_lib
+    except ImportError:
+        # If distutuils is not available, we just don't know where they are
+        pass
+    else:
+        site_path = osutils.pathjoin(get_python_lib(), 'bzrlib', 'plugins')
+    return site_path
+
+
+def get_user_plugin_path():
+    return osutils.pathjoin(config.config_dir(), 'plugins')
+
+
+def get_standard_plugins_path():
+    """Determine a plugin path suitable for general use."""
+    # Ad-Hoc default: core is not overriden by site but user can overrides both
+    # The rationale is that:
+    # - 'site' comes last, because these plugins should always be available and
+    #   are supposed to be in sync with the bzr installed on site.
+    # - 'core' comes before 'site' so that running bzr from sources or a user
+    #   installed version overrides the site version.
+    # - 'user' comes first, because... user is always right.
+    # - the above rules clearly defines which plugin version will be loaded if
+    #   several exist. Yet, it is sometimes desirable to disable some directory
+    #   so that a set of plugins is disabled as once. This can be done via
+    #   -site, -core, -user.
+
+    env_paths = os.environ.get('BZR_PLUGIN_PATH', '+user').split(os.pathsep)
+    defaults = ['+core', '+site']
+
+    # The predefined references
+    refs = dict(core=get_core_plugin_path(),
+                site=get_site_plugin_path(),
+                user=get_user_plugin_path())
+
+    # Unset paths that should be removed
+    for k,v in refs.iteritems():
+        removed = '-%s' % k
+        # defaults can never mention removing paths as that will make it
+        # impossible for the user to revoke these removals.
+        if removed in env_paths:
+            env_paths.remove(removed)
+            refs[k] = None
+
+    # Expand references
+    paths = []
+    for p in env_paths + defaults:
+        if p.startswith('+'):
+            # Resolve reference if they are known
+            try:
+                p = refs[p[1:]]
+            except KeyError:
+                # Leave them untouched otherwise, user may have paths starting
+                # with '+'...
+                pass
+        _append_new_path(paths, p)
+
+    # Get rid of trailing slashes, since Python can't handle them when
+    # it tries to import modules.
+    paths = map(_strip_trailing_sep, paths)
+    return paths
 
 
 def load_plugins(path=None):

=== modified file 'bzrlib/plugins/launchpad/__init__.py'
--- bzrlib/plugins/launchpad/__init__.py	2009-07-06 13:00:23 +0000
+++ bzrlib/plugins/launchpad/__init__.py	2009-10-30 14:44:52 +0000
@@ -262,30 +262,19 @@
 _register_directory()
 
 
-def test_suite():
-    """Called by bzrlib to fetch tests for this plugin"""
-    from unittest import TestSuite, TestLoader
-    from bzrlib.plugins.launchpad import (
-        test_account,
-        test_lp_directory,
-        test_lp_login,
-        test_lp_open,
-        test_lp_service,
-        test_register,
-        )
+def load_tests(basic_tests, module, loader):
+    testmod_names = [
+        'test_account',
+        'test_register',
+        'test_lp_directory',
+        'test_lp_login',
+        'test_lp_open',
+        'test_lp_service',
+        ]
+    basic_tests.addTest(loader.loadTestsFromModuleNames(
+            ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
+    return basic_tests
 
-    loader = TestLoader()
-    suite = TestSuite()
-    for module in [
-        test_account,
-        test_register,
-        test_lp_directory,
-        test_lp_login,
-        test_lp_open,
-        test_lp_service,
-        ]:
-        suite.addTests(loader.loadTestsFromModule(module))
-    return suite
 
 _launchpad_help = """Integration with Launchpad.net
 

=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- bzrlib/plugins/launchpad/lp_registration.py	2009-07-04 16:22:16 +0000
+++ bzrlib/plugins/launchpad/lp_registration.py	2009-11-05 18:32:31 +0000
@@ -31,6 +31,7 @@
     errors,
     __version__ as _bzrlib_version,
     )
+from bzrlib.transport.http import _urllib2_wrappers
 
 # for testing, do
 '''
@@ -53,6 +54,33 @@
         errors.BzrError.__init__(self, url=url)
 
 
+class XMLRPCTransport(xmlrpclib.Transport):
+
+    def __init__(self, scheme):
+        # In python2.4 xmlrpclib.Transport is a old-style class, and does not
+        # define __init__, so we check first
+        init = getattr(xmlrpclib.Transport, '__init__', None)
+        if init is not None:
+            init(self)
+        self._scheme = scheme
+        self._opener = _urllib2_wrappers.Opener()
+        self.verbose = 0
+
+    def request(self, host, handler, request_body, verbose=0):
+        self.verbose = verbose
+        url = self._scheme + "://" + host + handler
+        request = _urllib2_wrappers.Request("POST", url, request_body)
+        # FIXME: _urllib2_wrappers will override user-agent with its own
+        # request.add_header("User-Agent", self.user_agent)
+        request.add_header("Content-Type", "text/xml")
+
+        response = self._opener.open(request)
+        if response.code != 200:
+            raise xmlrpclib.ProtocolError(host + handler, response.code,
+                                          response.msg, response.info())
+        return self.parse_response(response)
+
+
 class LaunchpadService(object):
     """A service to talk to Launchpad via XMLRPC.
 
@@ -90,10 +118,7 @@
         self._lp_instance = lp_instance
         if transport is None:
             uri_type = urllib.splittype(self.service_url)[0]
-            if uri_type == 'https':
-                transport = xmlrpclib.SafeTransport()
-            else:
-                transport = xmlrpclib.Transport()
+            transport = XMLRPCTransport(uri_type)
             transport.user_agent = 'bzr/%s (xmlrpclib/%s)' \
                     % (_bzrlib_version, xmlrpclib.__version__)
         self.transport = transport

=== modified file 'bzrlib/plugins/launchpad/test_lp_directory.py'
--- bzrlib/plugins/launchpad/test_lp_directory.py	2009-03-23 14:59:43 +0000
+++ bzrlib/plugins/launchpad/test_lp_directory.py	2009-10-30 21:02:37 +0000
@@ -16,10 +16,12 @@
 
 """Tests for directory lookup through Launchpad.net"""
 
+import os
 import xmlrpclib
 
 from bzrlib import (
     errors,
+    tests,
     )
 from bzrlib.branch import Branch
 from bzrlib.directory_service import directories
@@ -28,10 +30,38 @@
     TestCaseWithMemoryTransport
 )
 from bzrlib.transport import get_transport
-from bzrlib.plugins.launchpad import _register_directory
+from bzrlib.plugins.launchpad import (
+    _register_directory,
+    lp_registration,
+    )
 from bzrlib.plugins.launchpad.lp_directory import (
     LaunchpadDirectory)
 from bzrlib.plugins.launchpad.account import get_lp_login
+from bzrlib.tests import (
+    http_server,
+    http_utils,
+    )
+
+
+def load_tests(standard_tests, module, loader):
+    result = loader.suiteClass()
+    t_tests, remaining_tests = tests.split_suite_by_condition(
+        standard_tests, tests.condition_isinstance((
+                TestXMLRPCTransport,
+                )))
+    transport_scenarios = [
+        ('http', dict(server_class=PreCannedHTTPServer,)),
+        ]
+    if tests.HTTPSServerFeature.available():
+        transport_scenarios.append(
+            ('https', dict(server_class=PreCannedHTTPSServer,)),
+            )
+    tests.multiply_tests(t_tests, transport_scenarios, result)
+
+    # No parametrization for the remaining tests
+    result.addTests(remaining_tests)
+
+    return result
 
 
 class FakeResolveFactory(object):
@@ -190,3 +220,116 @@
         transport = get_transport('lp:///apt')
         branch = Branch.open_from_transport(transport)
         self.assertEqual(target_branch.base, branch.base)
+
+
+class PredefinedRequestHandler(http_server.TestingHTTPRequestHandler):
+    """Request handler for a unique and pre-defined request.
+
+    The only thing we care about here is that we receive a connection. But
+    since we want to dialog with a real http client, we have to send it correct
+    responses.
+
+    We expect to receive a *single* request nothing more (and we won't even
+    check what request it is), the tests will recognize us from our response.
+    """
+
+    def handle_one_request(self):
+        tcs = self.server.test_case_server
+        requestline = self.rfile.readline()
+        headers = self.MessageClass(self.rfile, 0)
+        if requestline.startswith('POST'):
+            # The body should be a single line (or we don't know where it ends
+            # and we don't want to issue a blocking read)
+            body = self.rfile.readline()
+
+        self.wfile.write(tcs.canned_response)
+
+
+class PreCannedServerMixin(object):
+
+    def __init__(self):
+        super(PreCannedServerMixin, self).__init__(
+            request_handler=PredefinedRequestHandler)
+        # Bytes read and written by the server
+        self.bytes_read = 0
+        self.bytes_written = 0
+        self.canned_response = None
+
+
+class PreCannedHTTPServer(PreCannedServerMixin, http_server.HttpServer):
+    pass
+
+
+if tests.HTTPSServerFeature.available():
+    from bzrlib.tests import https_server
+    class PreCannedHTTPSServer(PreCannedServerMixin, https_server.HTTPSServer):
+        pass
+
+
+class TestXMLRPCTransport(tests.TestCase):
+
+    # set by load_tests
+    server_class = None
+
+    def setUp(self):
+        tests.TestCase.setUp(self)
+        self.server = self.server_class()
+        self.server.setUp()
+        # Ensure we don't clobber env
+        self._captureVar('BZR_LP_XMLRPC_URL', None)
+
+    def tearDown(self):
+        self.server.tearDown()
+        tests.TestCase.tearDown(self)
+
+    def set_canned_response(self, server, path):
+        response_format = '''HTTP/1.1 200 OK\r
+Date: Tue, 11 Jul 2006 04:32:56 GMT\r
+Server: Apache/2.0.54 (Fedora)\r
+Last-Modified: Sun, 23 Apr 2006 19:35:20 GMT\r
+ETag: "56691-23-38e9ae00"\r
+Accept-Ranges: bytes\r
+Content-Length: %(length)d\r
+Connection: close\r
+Content-Type: text/plain; charset=UTF-8\r
+\r
+<?xml version='1.0'?>
+<methodResponse>
+<params>
+<param>
+<value><struct>
+<member>
+<name>urls</name>
+<value><array><data>
+<value><string>bzr+ssh://bazaar.launchpad.net/%(path)s</string></value>
+<value><string>http://bazaar.launchpad.net/%(path)s</string></value>
+</data></array></value>
+</member>
+</struct></value>
+</param>
+</params>
+</methodResponse>
+'''
+        length = 334 + 2 * len(path)
+        server.canned_response = response_format % dict(length=length,
+                                                        path=path)
+
+    def do_request(self, server_url):
+        os.environ['BZR_LP_XMLRPC_URL'] = self.server.get_url()
+        service = lp_registration.LaunchpadService()
+        resolve = lp_registration.ResolveLaunchpadPathRequest('bzr')
+        result = resolve.submit(service)
+        return result
+
+    def test_direct_request(self):
+        self.set_canned_response(self.server, '~bzr-pqm/bzr/bzr.dev')
+        result = self.do_request(self.server.get_url())
+        urls = result.get('urls', None)
+        self.assertIsNot(None, urls)
+        self.assertEquals(
+            ['bzr+ssh://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev',
+             'http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev'],
+            urls)
+    # FIXME: we need to test with a real proxy, I can't find a way so simulate
+    # CONNECT without leaving one server hanging the test :-/ Since that maybe
+    # related to the leaking tests problems, I'll punt for now -- vila 20091030

=== modified file 'bzrlib/progress.py'
--- bzrlib/progress.py	2009-08-04 11:40:59 +0000
+++ bzrlib/progress.py	2009-10-15 02:19:43 +0000
@@ -34,6 +34,7 @@
 from bzrlib.symbol_versioning import (
     deprecated_function,
     deprecated_in,
+    deprecated_method,
     )
 
 
@@ -156,16 +157,27 @@
                 own_fraction = 0.0
             return self._parent_task._overall_completion_fraction(own_fraction)
 
+    @deprecated_method(deprecated_in((2, 1, 0)))
     def note(self, fmt_string, *args):
-        """Record a note without disrupting the progress bar."""
-        # XXX: shouldn't be here; put it in mutter or the ui instead
+        """Record a note without disrupting the progress bar.
+        
+        Deprecated: use ui_factory.note() instead or bzrlib.trace.  Note that
+        ui_factory.note takes just one string as the argument, not a format
+        string and arguments.
+        """
         if args:
             self.ui_factory.note(fmt_string % args)
         else:
             self.ui_factory.note(fmt_string)
 
     def clear(self):
-        # XXX: shouldn't be here; put it in mutter or the ui instead
+        # TODO: deprecate this method; the model object shouldn't be concerned
+        # with whether it's shown or not.  Most callers use this because they
+        # want to write some different non-progress output to the screen, but
+        # they should probably instead use a stream that's synchronized with
+        # the progress output.  It may be there is a model-level use for
+        # saying "this task's not active at the moment" but I don't see it. --
+        # mbp 20090623
         if self.progress_view:
             self.progress_view.clear()
         else:

=== modified file 'bzrlib/push.py'
--- bzrlib/push.py	2009-07-18 21:09:00 +0000
+++ bzrlib/push.py	2009-11-25 06:10:00 +0000
@@ -90,12 +90,19 @@
             br_to = br_from.create_clone_on_transport(to_transport,
                 revision_id=revision_id, stacked_on=stacked_on,
                 create_prefix=create_prefix, use_existing_dir=use_existing_dir)
-        except errors.FileExists:
+        except errors.FileExists, err:
+            if err.path.endswith('/.bzr'):
+                raise errors.BzrCommandError(
+                    "Target directory %s already contains a .bzr directory, "
+                    "but it is not valid." % (location,))
             if not use_existing_dir:
                 raise errors.BzrCommandError("Target directory %s"
-                     " already exists, but does not have a valid .bzr"
+                     " already exists, but does not have a .bzr"
                      " directory. Supply --use-existing-dir to push"
                      " there anyway." % location)
+            # This shouldn't occur, but if it does the FileExists error will be
+            # more informative than an UnboundLocalError for br_to.
+            raise
         except errors.NoSuchFile:
             if not create_prefix:
                 raise errors.BzrCommandError("Parent directory of %s"

=== modified file 'bzrlib/python-compat.h'
--- bzrlib/python-compat.h	2009-06-10 03:56:49 +0000
+++ bzrlib/python-compat.h	2009-10-21 20:53:21 +0000
@@ -28,6 +28,9 @@
 /* http://www.python.org/dev/peps/pep-0353/ */
 #if PY_VERSION_HEX < 0x02050000 && !defined(PY_SSIZE_T_MIN)
     typedef int Py_ssize_t;
+    typedef Py_ssize_t (*lenfunc)(PyObject *);
+    typedef PyObject * (*ssizeargfunc)(PyObject *, Py_ssize_t);
+    typedef PyObject * (*ssizessizeargfunc)(PyObject *, Py_ssize_t, Py_ssize_t);
     #define PY_SSIZE_T_MAX INT_MAX
     #define PY_SSIZE_T_MIN INT_MIN
     #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
@@ -73,4 +76,12 @@
 #define  snprintf  _snprintf
 #endif
 
+/* Introduced in Python 2.6 */
+#ifndef Py_TYPE
+#  define Py_TYPE(o) ((o)->ob_type)
+#endif
+#ifndef Py_REFCNT
+#  define Py_REFCNT(o) ((o)->ob_refcnt)
+#endif
+
 #endif /* _BZR_PYTHON_COMPAT_H */

=== modified file 'bzrlib/reconcile.py'
--- bzrlib/reconcile.py	2009-07-31 22:48:55 +0000
+++ bzrlib/reconcile.py	2009-09-24 04:54:19 +0000
@@ -90,26 +90,25 @@
             # Nothing to check here
             self.fixed_branch_history = None
             return
-        self.pb.note('Reconciling branch %s',
-                     self.branch.base)
+        ui.ui_factory.note('Reconciling branch %s' % self.branch.base)
         branch_reconciler = self.branch.reconcile(thorough=True)
         self.fixed_branch_history = branch_reconciler.fixed_history
 
     def _reconcile_repository(self):
         self.repo = self.bzrdir.find_repository()
-        self.pb.note('Reconciling repository %s',
-                     self.repo.bzrdir.root_transport.base)
+        ui.ui_factory.note('Reconciling repository %s' %
+            self.repo.bzrdir.root_transport.base)
         self.pb.update("Reconciling repository", 0, 1)
         repo_reconciler = self.repo.reconcile(thorough=True)
         self.inconsistent_parents = repo_reconciler.inconsistent_parents
         self.garbage_inventories = repo_reconciler.garbage_inventories
         if repo_reconciler.aborted:
-            self.pb.note(
+            ui.ui_factory.note(
                 'Reconcile aborted: revision index has inconsistent parents.')
-            self.pb.note(
+            ui.ui_factory.note(
                 'Run "bzr check" for more details.')
         else:
-            self.pb.note('Reconciliation complete.')
+            ui.ui_factory.note('Reconciliation complete.')
 
 
 class BranchReconciler(object):
@@ -151,13 +150,13 @@
             # set_revision_history, as this will regenerate it again.
             # Not really worth a whole BranchReconciler class just for this,
             # though.
-            self.pb.note('Fixing last revision info %s => %s',
-                         last_revno, len(real_history))
+            ui.ui_factory.note('Fixing last revision info %s => %s' % (
+                 last_revno, len(real_history)))
             self.branch.set_last_revision_info(len(real_history),
                                                last_revision_id)
         else:
             self.fixed_history = False
-            self.pb.note('revision_history ok.')
+            ui.ui_factory.note('revision_history ok.')
 
 
 class RepoReconciler(object):
@@ -238,11 +237,11 @@
         # (no garbage inventories or we are not doing a thorough check)
         if (not self.inconsistent_parents and
             (not self.garbage_inventories or not self.thorough)):
-            self.pb.note('Inventory ok.')
+            ui.ui_factory.note('Inventory ok.')
             return
         self.pb.update('Backing up inventory', 0, 0)
         self.repo._backup_inventory()
-        self.pb.note('Backup inventory created.')
+        ui.ui_factory.note('Backup inventory created.')
         new_inventories = self.repo._temp_inventories()
 
         # we have topological order of revisions and non ghost parents ready.
@@ -261,7 +260,7 @@
         self.pb.update('Writing weave')
         self.repo._activate_new_inventory()
         self.inventory = None
-        self.pb.note('Inventory regenerated.')
+        ui.ui_factory.note('Inventory regenerated.')
 
     def _new_inv_parents(self, revision_key):
         """Lookup ghost-filtered parents for revision_key."""
@@ -368,11 +367,11 @@
         self._check_garbage_inventories()
         self.pb.update('Checking unused inventories', 1, 3)
         if not self.garbage_inventories:
-            self.pb.note('Inventory ok.')
+            ui.ui_factory.note('Inventory ok.')
             return
         self.pb.update('Backing up inventory', 0, 0)
         self.repo._backup_inventory()
-        self.pb.note('Backup Inventory created')
+        ui.ui_factory.note('Backup Inventory created')
         # asking for '' should never return a non-empty weave
         new_inventories = self.repo._temp_inventories()
         # we have topological order of revisions and non ghost parents ready.
@@ -392,7 +391,7 @@
         self.pb.update('Writing weave')
         self.repo._activate_new_inventory()
         self.inventory = None
-        self.pb.note('Inventory regenerated.')
+        ui.ui_factory.note('Inventory regenerated.')
 
     def _fix_text_parents(self):
         """Fix bad versionedfile parent entries.

=== modified file 'bzrlib/reconfigure.py'
--- bzrlib/reconfigure.py	2009-07-24 03:15:56 +0000
+++ bzrlib/reconfigure.py	2009-10-06 14:40:37 +0000
@@ -265,9 +265,7 @@
 
     def _check(self):
         """Raise if reconfiguration would destroy local changes"""
-        if self._destroy_tree:
-            # XXX: What about pending merges ? -- vila 20090629
-            if self.tree.has_changes(self.tree.basis_tree()):
+        if self._destroy_tree and self.tree.has_changes():
                 raise errors.UncommittedChanges(self.tree)
         if self._create_reference and self.local_branch is not None:
             reference_branch = branch.Branch.open(self._select_bind_location())

=== modified file 'bzrlib/registry.py'
--- bzrlib/registry.py	2009-03-23 14:59:43 +0000
+++ bzrlib/registry.py	2009-09-16 10:37:29 +0000
@@ -222,7 +222,10 @@
             yield key, getter.get_obj()
 
     def items(self):
-        return sorted(self.iteritems())
+        # We should not use the iteritems() implementation below (see bug
+        # #430510)
+        return sorted([(key, getter.get_obj())
+                       for key, getter in self._dict.items()])
 
     def _set_default_key(self, key):
         if not self._dict.has_key(key):

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2009-08-27 05:22:14 +0000
+++ bzrlib/remote.py	2009-11-11 06:50:40 +0000
@@ -33,7 +33,7 @@
 )
 from bzrlib.branch import BranchReferenceFormat
 from bzrlib.bzrdir import BzrDir, RemoteBzrDirFormat
-from bzrlib.decorators import needs_read_lock, needs_write_lock
+from bzrlib.decorators import needs_read_lock, needs_write_lock, only_raises
 from bzrlib.errors import (
     NoSuchRevision,
     SmartProtocolError,
@@ -89,7 +89,7 @@
 class RemoteBzrDir(BzrDir, _RpcHelper):
     """Control directory on a remote server, accessed via bzr:// or similar."""
 
-    def __init__(self, transport, format, _client=None):
+    def __init__(self, transport, format, _client=None, _force_probe=False):
         """Construct a RemoteBzrDir.
 
         :param _client: Private parameter for testing. Disables probing and the
@@ -99,6 +99,7 @@
         # this object holds a delegated bzrdir that uses file-level operations
         # to talk to the other side
         self._real_bzrdir = None
+        self._has_working_tree = None
         # 1-shot cache for the call pattern 'create_branch; open_branch' - see
         # create_branch for details.
         self._next_open_branch_result = None
@@ -108,14 +109,44 @@
             self._client = client._SmartClient(medium)
         else:
             self._client = _client
-            return
-
+            if not _force_probe:
+                return
+
+        self._probe_bzrdir()
+
+    def _probe_bzrdir(self):
+        medium = self._client._medium
         path = self._path_for_remote_call(self._client)
+        if medium._is_remote_before((2, 1)):
+            self._rpc_open(path)
+            return
+        try:
+            self._rpc_open_2_1(path)
+            return
+        except errors.UnknownSmartMethod:
+            medium._remember_remote_is_before((2, 1))
+            self._rpc_open(path)
+
+    def _rpc_open_2_1(self, path):
+        response = self._call('BzrDir.open_2.1', path)
+        if response == ('no',):
+            raise errors.NotBranchError(path=self.root_transport.base)
+        elif response[0] == 'yes':
+            if response[1] == 'yes':
+                self._has_working_tree = True
+            elif response[1] == 'no':
+                self._has_working_tree = False
+            else:
+                raise errors.UnexpectedSmartServerResponse(response)
+        else:
+            raise errors.UnexpectedSmartServerResponse(response)
+
+    def _rpc_open(self, path):
         response = self._call('BzrDir.open', path)
         if response not in [('yes',), ('no',)]:
             raise errors.UnexpectedSmartServerResponse(response)
         if response == ('no',):
-            raise errors.NotBranchError(path=transport.base)
+            raise errors.NotBranchError(path=self.root_transport.base)
 
     def _ensure_real(self):
         """Ensure that there is a _real_bzrdir set.
@@ -123,6 +154,10 @@
         Used before calls to self._real_bzrdir.
         """
         if not self._real_bzrdir:
+            if 'hpssvfs' in debug.debug_flags:
+                import traceback
+                warning('VFS BzrDir access triggered\n%s',
+                    ''.join(traceback.format_stack()))
             self._real_bzrdir = BzrDir.open_from_transport(
                 self.root_transport, _server_formats=False)
             self._format._network_name = \
@@ -355,9 +390,14 @@
         else:
             raise errors.NoRepositoryPresent(self)
 
+    def has_workingtree(self):
+        if self._has_working_tree is None:
+            self._ensure_real()
+            self._has_working_tree = self._real_bzrdir.has_workingtree()
+        return self._has_working_tree
+
     def open_workingtree(self, recommend_upgrade=True):
-        self._ensure_real()
-        if self._real_bzrdir.has_workingtree():
+        if self.has_workingtree():
             raise errors.NotLocalUrl(self.root_transport)
         else:
             raise errors.NoWorkingTree(self.root_transport.base)
@@ -561,7 +601,8 @@
         return self._custom_format._fetch_reconcile
 
     def get_format_description(self):
-        return 'bzr remote repository'
+        self._ensure_real()
+        return 'Remote: ' + self._custom_format.get_format_description()
 
     def __eq__(self, other):
         return self.__class__ is other.__class__
@@ -583,7 +624,7 @@
         return self._custom_format._serializer
 
 
-class RemoteRepository(_RpcHelper):
+class RemoteRepository(_RpcHelper, lock._RelockDebugMixin):
     """Repository accessed over rpc.
 
     For the moment most operations are performed using local transport-backed
@@ -913,6 +954,7 @@
     def lock_read(self):
         # wrong eventually - want a local lock cache context
         if not self._lock_mode:
+            self._note_lock('r')
             self._lock_mode = 'r'
             self._lock_count = 1
             self._unstacked_provider.enable_cache(cache_misses=True)
@@ -938,6 +980,7 @@
 
     def lock_write(self, token=None, _skip_rpc=False):
         if not self._lock_mode:
+            self._note_lock('w')
             if _skip_rpc:
                 if self._lock_token is not None:
                     if token != self._lock_token:
@@ -1046,6 +1089,7 @@
         else:
             raise errors.UnexpectedSmartServerResponse(response)
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         if not self._lock_count:
             return lock.cant_unlock_not_held(self)
@@ -1739,6 +1783,7 @@
             # The stream included an inventory-delta record, but the remote
             # side isn't new enough to support them.  So we need to send the
             # rest of the stream via VFS.
+            self.target_repo.refresh_data()
             return self._resume_stream_with_vfs(response, src_format)
         if response[0][0] == 'missing-basis':
             tokens, missing_keys = bencode.bdecode_as_tuple(response[0][1])
@@ -1886,7 +1931,7 @@
         :param search: The overall search to satisfy with streams.
         :param sources: A list of Repository objects to query.
         """
-        self.serialiser = self.to_format._serializer
+        self.from_serialiser = self.from_repository._format._serializer
         self.seen_revs = set()
         self.referenced_revs = set()
         # If there are heads in the search, or the key count is > 0, we are not
@@ -1909,7 +1954,8 @@
     def missing_parents_rev_handler(self, substream):
         for content in substream:
             revision_bytes = content.get_bytes_as('fulltext')
-            revision = self.serialiser.read_revision_from_string(revision_bytes)
+            revision = self.from_serialiser.read_revision_from_string(
+                revision_bytes)
             self.seen_revs.add(content.key[-1])
             self.referenced_revs.update(revision.parent_ids)
             yield content
@@ -1954,7 +2000,8 @@
                 self._network_name)
 
     def get_format_description(self):
-        return 'Remote BZR Branch'
+        self._ensure_real()
+        return 'Remote: ' + self._custom_format.get_format_description()
 
     def network_name(self):
         return self._network_name
@@ -2043,7 +2090,7 @@
         return self._custom_format.supports_set_append_revisions_only()
 
 
-class RemoteBranch(branch.Branch, _RpcHelper):
+class RemoteBranch(branch.Branch, _RpcHelper, lock._RelockDebugMixin):
     """Branch stored on a server accessed by HPSS RPC.
 
     At the moment most operations are mapped down to simple file operations.
@@ -2267,6 +2314,7 @@
         medium = self._client._medium
         if medium._is_remote_before((1, 18)):
             self._vfs_set_tags_bytes(bytes)
+            return
         try:
             args = (
                 self._remote_path(), self._lock_token, self._repo_lock_token)
@@ -2279,6 +2327,7 @@
     def lock_read(self):
         self.repository.lock_read()
         if not self._lock_mode:
+            self._note_lock('r')
             self._lock_mode = 'r'
             self._lock_count = 1
             if self._real_branch is not None:
@@ -2304,6 +2353,7 @@
 
     def lock_write(self, token=None):
         if not self._lock_mode:
+            self._note_lock('w')
             # Lock the branch and repo in one remote call.
             remote_tokens = self._remote_lock_write(token)
             self._lock_token, self._repo_lock_token = remote_tokens
@@ -2344,6 +2394,7 @@
             return
         raise errors.UnexpectedSmartServerResponse(response)
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         try:
             self._lock_count -= 1
@@ -2389,6 +2440,7 @@
             raise NotImplementedError(self.dont_leave_lock_in_place)
         self._leave_lock = False
 
+    @needs_read_lock
     def get_rev_id(self, revno, history=None):
         if revno == 0:
             return _mod_revision.NULL_REVISION

=== modified file 'bzrlib/repofmt/groupcompress_repo.py'
--- bzrlib/repofmt/groupcompress_repo.py	2009-08-24 19:34:13 +0000
+++ bzrlib/repofmt/groupcompress_repo.py	2009-10-23 17:27:45 +0000
@@ -53,6 +53,7 @@
     ResumedPack,
     Packer,
     )
+from bzrlib.static_tuple import StaticTuple
 
 
 class GCPack(NewPack):
@@ -584,6 +585,92 @@
     pack_factory = GCPack
     resumed_pack_factory = ResumedGCPack
 
+    def _check_new_inventories(self):
+        """Detect missing inventories or chk root entries for the new revisions
+        in this write group.
+
+        :returns: list of strs, summarising any problems found.  If the list is
+            empty no problems were found.
+        """
+        # Ensure that all revisions added in this write group have:
+        #   - corresponding inventories,
+        #   - chk root entries for those inventories,
+        #   - and any present parent inventories have their chk root
+        #     entries too.
+        # And all this should be independent of any fallback repository.
+        problems = []
+        key_deps = self.repo.revisions._index._key_dependencies
+        new_revisions_keys = key_deps.get_new_keys()
+        no_fallback_inv_index = self.repo.inventories._index
+        no_fallback_chk_bytes_index = self.repo.chk_bytes._index
+        no_fallback_texts_index = self.repo.texts._index
+        inv_parent_map = no_fallback_inv_index.get_parent_map(
+            new_revisions_keys)
+        # Are any inventories for corresponding to the new revisions missing?
+        corresponding_invs = set(inv_parent_map)
+        missing_corresponding = set(new_revisions_keys)
+        missing_corresponding.difference_update(corresponding_invs)
+        if missing_corresponding:
+            problems.append("inventories missing for revisions %s" %
+                (sorted(missing_corresponding),))
+            return problems
+        # Are any chk root entries missing for any inventories?  This includes
+        # any present parent inventories, which may be used when calculating
+        # deltas for streaming.
+        all_inv_keys = set(corresponding_invs)
+        for parent_inv_keys in inv_parent_map.itervalues():
+            all_inv_keys.update(parent_inv_keys)
+        # Filter out ghost parents.
+        all_inv_keys.intersection_update(
+            no_fallback_inv_index.get_parent_map(all_inv_keys))
+        parent_invs_only_keys = all_inv_keys.symmetric_difference(
+            corresponding_invs)
+        all_missing = set()
+        inv_ids = [key[-1] for key in all_inv_keys]
+        parent_invs_only_ids = [key[-1] for key in parent_invs_only_keys]
+        root_key_info = _build_interesting_key_sets(
+            self.repo, inv_ids, parent_invs_only_ids)
+        expected_chk_roots = root_key_info.all_keys()
+        present_chk_roots = no_fallback_chk_bytes_index.get_parent_map(
+            expected_chk_roots)
+        missing_chk_roots = expected_chk_roots.difference(present_chk_roots)
+        if missing_chk_roots:
+            problems.append("missing referenced chk root keys: %s"
+                % (sorted(missing_chk_roots),))
+            # Don't bother checking any further.
+            return problems
+        # Find all interesting chk_bytes records, and make sure they are
+        # present, as well as the text keys they reference.
+        chk_bytes_no_fallbacks = self.repo.chk_bytes.without_fallbacks()
+        chk_bytes_no_fallbacks._search_key_func = \
+            self.repo.chk_bytes._search_key_func
+        chk_diff = chk_map.iter_interesting_nodes(
+            chk_bytes_no_fallbacks, root_key_info.interesting_root_keys,
+            root_key_info.uninteresting_root_keys)
+        bytes_to_info = inventory.CHKInventory._bytes_to_utf8name_key
+        text_keys = set()
+        try:
+            for record in _filter_text_keys(chk_diff, text_keys, bytes_to_info):
+                pass
+        except errors.NoSuchRevision, e:
+            # XXX: It would be nice if we could give a more precise error here.
+            problems.append("missing chk node(s) for id_to_entry maps")
+        chk_diff = chk_map.iter_interesting_nodes(
+            chk_bytes_no_fallbacks, root_key_info.interesting_pid_root_keys,
+            root_key_info.uninteresting_pid_root_keys)
+        try:
+            for interesting_rec, interesting_map in chk_diff:
+                pass
+        except errors.NoSuchRevision, e:
+            problems.append(
+                "missing chk node(s) for parent_id_basename_to_file_id maps")
+        present_text_keys = no_fallback_texts_index.get_parent_map(text_keys)
+        missing_text_keys = text_keys.difference(present_text_keys)
+        if missing_text_keys:
+            problems.append("missing text keys: %r"
+                % (sorted(missing_text_keys),))
+        return problems
+
     def _execute_pack_operations(self, pack_operations,
                                  _packer_class=GCCHKPacker,
                                  reload_func=None):
@@ -617,10 +704,11 @@
                 self._remove_pack_from_memory(pack)
         # record the newly available packs and stop advertising the old
         # packs
-        self._save_pack_names(clear_obsolete_packs=True)
+        result = self._save_pack_names(clear_obsolete_packs=True)
         # Move the old packs out of the way now they are no longer referenced.
         for revision_count, packs in pack_operations:
             self._obsolete_packs(packs)
+        return result
 
 
 class CHKInventoryRepository(KnitPackRepository):
@@ -651,7 +739,7 @@
             _GCGraphIndex(self._pack_collection.revision_index.combined_index,
                 add_callback=self._pack_collection.revision_index.add_callback,
                 parents=True, is_locked=self.is_locked,
-                track_external_parent_refs=True),
+                track_external_parent_refs=True, track_new_keys=True),
             access=self._pack_collection.revision_index.data_access,
             delta=False)
         self.signatures = GroupCompressVersionedFiles(
@@ -727,14 +815,16 @@
                                  ' no new_path %r' % (file_id,))
             if new_path == '':
                 new_inv.root_id = file_id
-                parent_id_basename_key = ('', '')
+                parent_id_basename_key = StaticTuple('', '').intern()
             else:
                 utf8_entry_name = entry.name.encode('utf-8')
-                parent_id_basename_key = (entry.parent_id, utf8_entry_name)
+                parent_id_basename_key = StaticTuple(entry.parent_id,
+                                                     utf8_entry_name).intern()
             new_value = entry_to_bytes(entry)
             # Populate Caches?
             # new_inv._path_to_fileid_cache[new_path] = file_id
-            id_to_entry_dict[(file_id,)] = new_value
+            key = StaticTuple(file_id).intern()
+            id_to_entry_dict[key] = new_value
             parent_id_basename_dict[parent_id_basename_key] = file_id
 
         new_inv._populate_from_dicts(self.chk_bytes, id_to_entry_dict,
@@ -850,23 +940,22 @@
                                         parent_keys)
             present_parent_inv_ids = set(
                 [k[-1] for k in present_parent_inv_keys])
-            uninteresting_root_keys = set()
-            interesting_root_keys = set()
             inventories_to_read = set(revision_ids)
             inventories_to_read.update(present_parent_inv_ids)
-            for inv in self.iter_inventories(inventories_to_read):
-                entry_chk_root_key = inv.id_to_entry.key()
-                if inv.revision_id in present_parent_inv_ids:
-                    uninteresting_root_keys.add(entry_chk_root_key)
-                else:
-                    interesting_root_keys.add(entry_chk_root_key)
-
+            root_key_info = _build_interesting_key_sets(
+                self, inventories_to_read, present_parent_inv_ids)
+            interesting_root_keys = root_key_info.interesting_root_keys
+            uninteresting_root_keys = root_key_info.uninteresting_root_keys
             chk_bytes = self.chk_bytes
             for record, items in chk_map.iter_interesting_nodes(chk_bytes,
                         interesting_root_keys, uninteresting_root_keys,
                         pb=pb):
                 for name, bytes in items:
                     (name_utf8, file_id, revision_id) = bytes_to_info(bytes)
+                    # TODO: consider interning file_id, revision_id here, or
+                    #       pushing that intern() into bytes_to_info()
+                    # TODO: rich_root should always be True here, for all
+                    #       repositories that support chk_bytes
                     if not rich_root and name_utf8 == '':
                         continue
                     try:
@@ -932,7 +1021,7 @@
         super(GroupCHKStreamSource, self).__init__(from_repository, to_format)
         self._revision_keys = None
         self._text_keys = None
-        # self._text_fetch_order = 'unordered'
+        self._text_fetch_order = 'groupcompress'
         self._chk_id_roots = None
         self._chk_p_id_roots = None
 
@@ -949,7 +1038,7 @@
             p_id_roots_set = set()
             source_vf = self.from_repository.inventories
             stream = source_vf.get_record_stream(inventory_keys,
-                                                 'unordered', True)
+                                                 'groupcompress', True)
             for record in stream:
                 if record.storage_kind == 'absent':
                     if allow_absent:
@@ -1000,13 +1089,10 @@
         bytes_to_info = inventory.CHKInventory._bytes_to_utf8name_key
         chk_bytes = self.from_repository.chk_bytes
         def _filter_id_to_entry():
-            for record, items in chk_map.iter_interesting_nodes(chk_bytes,
-                        self._chk_id_roots, uninteresting_root_keys):
-                for name, bytes in items:
-                    # Note: we don't care about name_utf8, because we are always
-                    # rich-root = True
-                    _, file_id, revision_id = bytes_to_info(bytes)
-                    self._text_keys.add((file_id, revision_id))
+            interesting_nodes = chk_map.iter_interesting_nodes(chk_bytes,
+                        self._chk_id_roots, uninteresting_root_keys)
+            for record in _filter_text_keys(interesting_nodes, self._text_keys,
+                    bytes_to_info):
                 if record is not None:
                     yield record
             # Consumed
@@ -1026,7 +1112,10 @@
         for stream_info in self._fetch_revision_texts(revision_ids):
             yield stream_info
         self._revision_keys = [(rev_id,) for rev_id in revision_ids]
+        self.from_repository.revisions.clear_cache()
+        self.from_repository.signatures.clear_cache()
         yield self._get_inventory_stream(self._revision_keys)
+        self.from_repository.inventories.clear_cache()
         # TODO: The keys to exclude might be part of the search recipe
         # For now, exclude all parents that are at the edge of ancestry, for
         # which we have inventories
@@ -1035,7 +1124,9 @@
                         self._revision_keys)
         for stream_info in self._get_filtered_chk_streams(parent_keys):
             yield stream_info
+        self.from_repository.chk_bytes.clear_cache()
         yield self._get_text_stream()
+        self.from_repository.texts.clear_cache()
 
     def get_stream_for_missing_keys(self, missing_keys):
         # missing keys can only occur when we are byte copying and not
@@ -1050,7 +1141,7 @@
             missing_inventory_keys.add(key[1:])
         if self._chk_id_roots or self._chk_p_id_roots:
             raise AssertionError('Cannot call get_stream_for_missing_keys'
-                ' untill all of get_stream() has been consumed.')
+                ' until all of get_stream() has been consumed.')
         # Yield the inventory stream, so we can find the chk stream
         # Some of the missing_keys will be missing because they are ghosts.
         # As such, we can ignore them. The Sink is required to verify there are
@@ -1063,6 +1154,56 @@
             yield stream_info
 
 
+class _InterestingKeyInfo(object):
+    def __init__(self):
+        self.interesting_root_keys = set()
+        self.interesting_pid_root_keys = set()
+        self.uninteresting_root_keys = set()
+        self.uninteresting_pid_root_keys = set()
+
+    def all_interesting(self):
+        return self.interesting_root_keys.union(self.interesting_pid_root_keys)
+
+    def all_uninteresting(self):
+        return self.uninteresting_root_keys.union(
+            self.uninteresting_pid_root_keys)
+
+    def all_keys(self):
+        return self.all_interesting().union(self.all_uninteresting())
+
+
+def _build_interesting_key_sets(repo, inventory_ids, parent_only_inv_ids):
+    result = _InterestingKeyInfo()
+    for inv in repo.iter_inventories(inventory_ids, 'unordered'):
+        root_key = inv.id_to_entry.key()
+        pid_root_key = inv.parent_id_basename_to_file_id.key()
+        if inv.revision_id in parent_only_inv_ids:
+            result.uninteresting_root_keys.add(root_key)
+            result.uninteresting_pid_root_keys.add(pid_root_key)
+        else:
+            result.interesting_root_keys.add(root_key)
+            result.interesting_pid_root_keys.add(pid_root_key)
+    return result
+
+
+def _filter_text_keys(interesting_nodes_iterable, text_keys, bytes_to_info):
+    """Iterate the result of iter_interesting_nodes, yielding the records
+    and adding to text_keys.
+    """
+    for record, items in interesting_nodes_iterable:
+        for name, bytes in items:
+            # Note: we don't care about name_utf8, because groupcompress repos
+            # are always rich-root, so there are no synthesised root records to
+            # ignore.
+            _, file_id, revision_id = bytes_to_info(bytes)
+            file_id = intern(file_id)
+            revision_id = intern(revision_id)
+            text_keys.add(StaticTuple(file_id, revision_id).intern())
+        yield record
+
+
+
+
 class RepositoryFormatCHK1(RepositoryFormatPack):
     """A hashed CHK+group compress pack repository."""
 
@@ -1145,3 +1286,8 @@
 
     def get_format_string(self):
         return ('Bazaar repository format 2a (needs bzr 1.16 or later)\n')
+
+    def get_format_description(self):
+        """See RepositoryFormat.get_format_description()."""
+        return ("Repository format 2a - rich roots, group compression"
+            " and chk inventories")

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2009-08-14 11:11:29 +0000
+++ bzrlib/repofmt/pack_repo.py	2009-10-29 05:54:49 +0000
@@ -54,7 +54,7 @@
     revision as _mod_revision,
     )
 
-from bzrlib.decorators import needs_write_lock
+from bzrlib.decorators import needs_write_lock, only_raises
 from bzrlib.btree_index import (
     BTreeGraphIndex,
     BTreeBuilder,
@@ -73,6 +73,7 @@
     )
 from bzrlib.trace import (
     mutter,
+    note,
     warning,
     )
 
@@ -224,10 +225,14 @@
         return self.index_name('text', name)
 
     def _replace_index_with_readonly(self, index_type):
+        unlimited_cache = False
+        if index_type == 'chk':
+            unlimited_cache = True
         setattr(self, index_type + '_index',
             self.index_class(self.index_transport,
                 self.index_name(index_type, self.name),
-                self.index_sizes[self.index_offset(index_type)]))
+                self.index_sizes[self.index_offset(index_type)],
+                unlimited_cache=unlimited_cache))
 
 
 class ExistingPack(Pack):
@@ -1112,7 +1117,7 @@
             iterator is a tuple with:
             index, readv_vector, node_vector. readv_vector is a list ready to
             hand to the transport readv method, and node_vector is a list of
-            (key, eol_flag, references) for the the node retrieved by the
+            (key, eol_flag, references) for the node retrieved by the
             matching readv_vector.
         """
         # group by pack so we do one readv per pack
@@ -1674,7 +1679,7 @@
             txt_index = self._make_index(name, '.tix')
             sig_index = self._make_index(name, '.six')
             if self.chk_index is not None:
-                chk_index = self._make_index(name, '.cix')
+                chk_index = self._make_index(name, '.cix', unlimited_cache=True)
             else:
                 chk_index = None
             result = ExistingPack(self._pack_transport, name, rev_index,
@@ -1699,7 +1704,8 @@
             txt_index = self._make_index(name, '.tix', resume=True)
             sig_index = self._make_index(name, '.six', resume=True)
             if self.chk_index is not None:
-                chk_index = self._make_index(name, '.cix', resume=True)
+                chk_index = self._make_index(name, '.cix', resume=True,
+                                             unlimited_cache=True)
             else:
                 chk_index = None
             result = self.resumed_pack_factory(name, rev_index, inv_index,
@@ -1735,7 +1741,7 @@
         return self._index_class(self.transport, 'pack-names', None
                 ).iter_all_entries()
 
-    def _make_index(self, name, suffix, resume=False):
+    def _make_index(self, name, suffix, resume=False, unlimited_cache=False):
         size_offset = self._suffix_offsets[suffix]
         index_name = name + suffix
         if resume:
@@ -1744,7 +1750,8 @@
         else:
             transport = self._index_transport
             index_size = self._names[name][size_offset]
-        return self._index_class(transport, index_name, index_size)
+        return self._index_class(transport, index_name, index_size,
+                                 unlimited_cache=unlimited_cache)
 
     def _max_pack_count(self, total_revisions):
         """Return the maximum number of packs to use for total revisions.
@@ -2063,6 +2070,16 @@
             self._remove_pack_indices(resumed_pack)
         del self._resumed_packs[:]
 
+    def _check_new_inventories(self):
+        """Detect missing inventories in this write group.
+
+        :returns: list of strs, summarising any problems found.  If the list is
+            empty no problems were found.
+        """
+        # The base implementation does no checks.  GCRepositoryPackCollection
+        # overrides this.
+        return []
+        
     def _commit_write_group(self):
         all_missing = set()
         for prefix, versioned_file in (
@@ -2077,14 +2094,19 @@
             raise errors.BzrCheckError(
                 "Repository %s has missing compression parent(s) %r "
                  % (self.repo, sorted(all_missing)))
+        problems = self._check_new_inventories()
+        if problems:
+            problems_summary = '\n'.join(problems)
+            raise errors.BzrCheckError(
+                "Cannot add revision(s) to repository: " + problems_summary)
         self._remove_pack_indices(self._new_pack)
-        should_autopack = False
+        any_new_content = False
         if self._new_pack.data_inserted():
             # get all the data to disk and read to use
             self._new_pack.finish()
             self.allocate(self._new_pack)
             self._new_pack = None
-            should_autopack = True
+            any_new_content = True
         else:
             self._new_pack.abort()
             self._new_pack = None
@@ -2095,13 +2117,15 @@
             self._remove_pack_from_memory(resumed_pack)
             resumed_pack.finish()
             self.allocate(resumed_pack)
-            should_autopack = True
+            any_new_content = True
         del self._resumed_packs[:]
-        if should_autopack:
-            if not self.autopack():
+        if any_new_content:
+            result = self.autopack()
+            if not result:
                 # when autopack takes no steps, the names list is still
                 # unsaved.
                 return self._save_pack_names()
+            return result
         return []
 
     def _suspend_write_group(self):
@@ -2222,7 +2246,7 @@
                     % (self._format, self.bzrdir.transport.base))
 
     def _abort_write_group(self):
-        self.revisions._index._key_dependencies.refs.clear()
+        self.revisions._index._key_dependencies.clear()
         self._pack_collection._abort_write_group()
 
     def _get_source(self, to_format):
@@ -2242,13 +2266,14 @@
         self._pack_collection._start_write_group()
 
     def _commit_write_group(self):
-        self.revisions._index._key_dependencies.refs.clear()
-        return self._pack_collection._commit_write_group()
+        hint = self._pack_collection._commit_write_group()
+        self.revisions._index._key_dependencies.clear()
+        return hint
 
     def suspend_write_group(self):
         # XXX check self._write_group is self.get_transaction()?
         tokens = self._pack_collection._suspend_write_group()
-        self.revisions._index._key_dependencies.refs.clear()
+        self.revisions._index._key_dependencies.clear()
         self._write_group = None
         return tokens
 
@@ -2282,6 +2307,9 @@
         if self._write_lock_count == 1:
             self._transaction = transactions.WriteTransaction()
         if not locked:
+            if 'relock' in debug.debug_flags and self._prev_lock == 'w':
+                note('%r was write locked again', self)
+            self._prev_lock = 'w'
             for repo in self._fallback_repositories:
                 # Writes don't affect fallback repos
                 repo.lock_read()
@@ -2294,6 +2322,9 @@
         else:
             self.control_files.lock_read()
         if not locked:
+            if 'relock' in debug.debug_flags and self._prev_lock == 'r':
+                note('%r was read locked again', self)
+            self._prev_lock = 'r'
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
@@ -2327,6 +2358,7 @@
         packer = ReconcilePacker(collection, packs, extension, revs)
         return packer.pack(pb)
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         if self._write_lock_count == 1 and self._write_group is not None:
             self.abort_write_group()

=== modified file 'bzrlib/repofmt/weaverepo.py'
--- bzrlib/repofmt/weaverepo.py	2009-08-18 14:49:52 +0000
+++ bzrlib/repofmt/weaverepo.py	2009-09-16 17:19:07 +0000
@@ -688,7 +688,7 @@
             path, ext = os.path.splitext(relpath)
             if ext == '.gz':
                 relpath = path
-            if '.sig' not in relpath:
+            if not relpath.endswith('.sig'):
                 relpaths.add(relpath)
         paths = list(relpaths)
         return set([self._mapper.unmap(path) for path in paths])

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2009-08-30 22:02:45 +0000
+++ bzrlib/repository.py	2009-12-02 18:05:08 +0000
@@ -26,6 +26,7 @@
     chk_map,
     debug,
     errors,
+    fetch as _mod_fetch,
     fifo_cache,
     generate_ids,
     gpg,
@@ -49,7 +50,7 @@
 from bzrlib.testament import Testament
 """)
 
-from bzrlib.decorators import needs_read_lock, needs_write_lock
+from bzrlib.decorators import needs_read_lock, needs_write_lock, only_raises
 from bzrlib.inter import InterObject
 from bzrlib.inventory import (
     Inventory,
@@ -57,6 +58,7 @@
     ROOT_ID,
     entry_factory,
     )
+from bzrlib.lock import _RelockDebugMixin
 from bzrlib import registry
 from bzrlib.trace import (
     log_exception_quietly, note, mutter, mutter_callsite, warning)
@@ -205,7 +207,10 @@
             # an inventory delta was accumulated without creating a new
             # inventory.
             basis_id = self.basis_delta_revision
-            self.inv_sha1 = self.repository.add_inventory_by_delta(
+            # We ignore the 'inventory' returned by add_inventory_by_delta
+            # because self.new_inventory is used to hint to the rest of the
+            # system what code path was taken
+            self.inv_sha1, _ = self.repository.add_inventory_by_delta(
                 basis_id, self._basis_delta, self._new_revision_id,
                 self.parents)
         else:
@@ -856,7 +861,7 @@
 # Repositories
 
 
-class Repository(object):
+class Repository(_RelockDebugMixin):
     """Repository holding history for one or more branches.
 
     The repository holds and retrieves historical information including
@@ -1381,6 +1386,7 @@
         locked = self.is_locked()
         result = self.control_files.lock_write(token=token)
         if not locked:
+            self._note_lock('w')
             for repo in self._fallback_repositories:
                 # Writes don't affect fallback repos
                 repo.lock_read()
@@ -1391,6 +1397,7 @@
         locked = self.is_locked()
         self.control_files.lock_read()
         if not locked:
+            self._note_lock('r')
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
@@ -1604,7 +1611,7 @@
         # but at the moment we're only checking for texts referenced by
         # inventories at the graph's edge.
         key_deps = self.revisions._index._key_dependencies
-        key_deps.add_keys(present_inventories)
+        key_deps.satisfy_refs_for_keys(present_inventories)
         referrers = frozenset(r[0] for r in key_deps.get_referrers())
         file_ids = self.fileids_altered_by_revision_ids(referrers)
         missing_texts = set()
@@ -1720,6 +1727,7 @@
         self.start_write_group()
         return result
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         if (self.control_files._lock_count == 1 and
             self.control_files._lock_mode == 'w'):
@@ -2329,7 +2337,7 @@
         num_file_ids = len(file_ids)
         for file_id, altered_versions in file_ids.iteritems():
             if pb is not None:
-                pb.update("fetch texts", count, num_file_ids)
+                pb.update("Fetch texts", count, num_file_ids)
             count += 1
             yield ("file", file_id, altered_versions)
 
@@ -2661,8 +2669,8 @@
         for ((revision_id,), parent_keys) in \
                 self.revisions.get_parent_map(query_keys).iteritems():
             if parent_keys:
-                result[revision_id] = tuple(parent_revid
-                    for (parent_revid,) in parent_keys)
+                result[revision_id] = tuple([parent_revid
+                    for (parent_revid,) in parent_keys])
             else:
                 result[revision_id] = (_mod_revision.NULL_REVISION,)
         return result
@@ -3086,7 +3094,7 @@
         """
         try:
             transport = a_bzrdir.get_repository_transport(None)
-            format_string = transport.get("format").read()
+            format_string = transport.get_bytes("format")
             return format_registry.get(format_string)
         except errors.NoSuchFile:
             raise errors.NoRepositoryPresent(a_bzrdir)
@@ -3405,8 +3413,7 @@
                    provided a default one will be created.
         :return: None.
         """
-        from bzrlib.fetch import RepoFetcher
-        f = RepoFetcher(to_repository=self.target,
+        f = _mod_fetch.RepoFetcher(to_repository=self.target,
                                from_repository=self.source,
                                last_revision=revision_id,
                                fetch_spec=fetch_spec,
@@ -3585,7 +3592,7 @@
                 self.target.texts.insert_record_stream(
                     self.source.texts.get_record_stream(
                         self.source.texts.keys(), 'topological', False))
-                pb.update('copying inventory', 0, 1)
+                pb.update('Copying inventory', 0, 1)
                 self.target.inventories.insert_record_stream(
                     self.source.inventories.get_record_stream(
                         self.source.inventories.keys(), 'topological', False))
@@ -3812,13 +3819,15 @@
                 basis_id, delta, current_revision_id, parents_parents)
             cache[current_revision_id] = parent_tree
 
-    def _fetch_batch(self, revision_ids, basis_id, cache):
+    def _fetch_batch(self, revision_ids, basis_id, cache, a_graph=None):
         """Fetch across a few revisions.
 
         :param revision_ids: The revisions to copy
         :param basis_id: The revision_id of a tree that must be in cache, used
             as a basis for delta when no other base is available
         :param cache: A cache of RevisionTrees that we can use.
+        :param a_graph: A Graph object to determine the heads() of the
+            rich-root data stream.
         :return: The revision_id of the last converted tree. The RevisionTree
             for it will be in cache
         """
@@ -3844,6 +3853,9 @@
                 possible_trees.append((basis_id, cache[basis_id]))
             basis_id, delta = self._get_delta_for_revision(tree, parent_ids,
                                                            possible_trees)
+            revision = self.source.get_revision(current_revision_id)
+            pending_deltas.append((basis_id, delta,
+                current_revision_id, revision.parent_ids))
             if self._converting_to_rich_root:
                 self._revision_id_to_root_id[current_revision_id] = \
                     tree.get_root_id()
@@ -3878,9 +3890,6 @@
                     if entry.revision == file_revision:
                         texts_possibly_new_in_tree.remove(file_key)
             text_keys.update(texts_possibly_new_in_tree)
-            revision = self.source.get_revision(current_revision_id)
-            pending_deltas.append((basis_id, delta,
-                current_revision_id, revision.parent_ids))
             pending_revisions.append(revision)
             cache[current_revision_id] = tree
             basis_id = current_revision_id
@@ -3888,10 +3897,9 @@
         from_texts = self.source.texts
         to_texts = self.target.texts
         if root_keys_to_create:
-            from bzrlib.fetch import _new_root_data_stream
-            root_stream = _new_root_data_stream(
+            root_stream = _mod_fetch._new_root_data_stream(
                 root_keys_to_create, self._revision_id_to_root_id, parent_map,
-                self.source)
+                self.source, graph=a_graph)
             to_texts.insert_record_stream(root_stream)
         to_texts.insert_record_stream(from_texts.get_record_stream(
             text_keys, self.target._format._fetch_order,
@@ -3954,13 +3962,20 @@
         cache[basis_id] = basis_tree
         del basis_tree # We don't want to hang on to it here
         hints = []
+        if self._converting_to_rich_root and len(revision_ids) > 100:
+            a_graph = _mod_fetch._get_rich_root_heads_graph(self.source,
+                                                            revision_ids)
+        else:
+            a_graph = None
+
         for offset in range(0, len(revision_ids), batch_size):
             self.target.start_write_group()
             try:
                 pb.update('Transferring revisions', offset,
                           len(revision_ids))
                 batch = revision_ids[offset:offset+batch_size]
-                basis_id = self._fetch_batch(batch, basis_id, cache)
+                basis_id = self._fetch_batch(batch, basis_id, cache,
+                                             a_graph=a_graph)
             except:
                 self.target.abort_write_group()
                 raise
@@ -4078,13 +4093,13 @@
                                                   self.source_repo.is_shared())
         converted.lock_write()
         try:
-            self.step('Copying content into repository.')
+            self.step('Copying content')
             self.source_repo.copy_content_into(converted)
         finally:
             converted.unlock()
-        self.step('Deleting old repository content.')
+        self.step('Deleting old repository content')
         self.repo_dir.transport.delete_tree('repository.backup')
-        self.pb.note('repository converted')
+        ui.ui_factory.note('repository converted')
 
     def step(self, message):
         """Update the pb by a step."""
@@ -4315,6 +4330,13 @@
                 ):
                 if versioned_file is None:
                     continue
+                # TODO: key is often going to be a StaticTuple object
+                #       I don't believe we can define a method by which
+                #       (prefix,) + StaticTuple will work, though we could
+                #       define a StaticTuple.sq_concat that would allow you to
+                #       pass in either a tuple or a StaticTuple as the second
+                #       object, so instead we could have:
+                #       StaticTuple(prefix) + key here...
                 missing_keys.update((prefix,) + key for key in
                     versioned_file.get_missing_compression_parent_keys())
         except NotImplementedError:
@@ -4432,8 +4454,7 @@
         fetching the inventory weave.
         """
         if self._rich_root_upgrade():
-            import bzrlib.fetch
-            return bzrlib.fetch.Inter1and2Helper(
+            return _mod_fetch.Inter1and2Helper(
                 self.from_repository).generate_root_texts(revs)
         else:
             return []

=== modified file 'bzrlib/revision.py'
--- bzrlib/revision.py	2009-06-30 16:16:55 +0000
+++ bzrlib/revision.py	2009-11-30 12:24:55 +0000
@@ -54,8 +54,11 @@
 
     def __init__(self, revision_id, properties=None, **args):
         self.revision_id = revision_id
-        self.properties = properties or {}
-        self._check_properties()
+        if properties is None:
+            self.properties = {}
+        else:
+            self.properties = properties
+            self._check_properties()
         self.committer = None
         self.parent_ids = []
         self.parent_sha1s = []
@@ -88,7 +91,7 @@
                 raise ValueError("invalid property name %r" % name)
             if not isinstance(value, basestring):
                 raise ValueError("invalid property value %r for %r" %
-                                 (name, value))
+                                 (value, name))
 
     def get_history(self, repository):
         """Return the canonical line-of-history for this revision.

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2009-07-25 08:26:42 +0000
+++ bzrlib/revisionspec.py	2009-10-27 14:04:29 +0000
@@ -113,8 +113,6 @@
         return RevisionInfo(branch, revno, revision_id)
 
 
-# classes in this list should have a "prefix" attribute, against which
-# string specs are matched
 _revno_regex = None
 
 
@@ -123,10 +121,10 @@
 
     help_txt = """A parsed revision specification.
 
-    A revision specification can be an integer, in which case it is
-    assumed to be a revno (though this will translate negative values
-    into positive ones); or it can be a string, in which case it is
-    parsed for something like 'date:' or 'revid:' etc.
+    A revision specification is a string, which may be unambiguous about
+    what it represents by giving a prefix like 'date:' or 'revid:' etc,
+    or it may have no prefix, in which case it's tried against several
+    specifier types in sequence to determine what the user meant.
 
     Revision specs are an UI element, and they have been moved out
     of the branch class to leave "back-end" classes unaware of such
@@ -139,6 +137,14 @@
 
     prefix = None
     wants_revision_history = True
+    dwim_catchable_exceptions = (errors.InvalidRevisionSpec,)
+    """Exceptions that RevisionSpec_dwim._match_on will catch.
+
+    If the revspec is part of ``dwim_revspecs``, it may be tried with an
+    invalid revspec and raises some exception. The exceptions mentioned here
+    will not be reported to the user but simply ignored without stopping the
+    dwim processing.
+    """
 
     @staticmethod
     def from_string(spec):
@@ -165,17 +171,9 @@
                     trace.mutter('Returning RevisionSpec %s for %s',
                                  spectype.__name__, spec)
                     return spectype(spec, _internal=True)
-            # RevisionSpec_revno is special cased, because it is the only
-            # one that directly handles plain integers
-            # TODO: This should not be special cased rather it should be
-            # a method invocation on spectype.canparse()
-            global _revno_regex
-            if _revno_regex is None:
-                _revno_regex = re.compile(r'^(?:(\d+(\.\d+)*)|-\d+)(:.*)?$')
-            if _revno_regex.match(spec) is not None:
-                return RevisionSpec_revno(spec, _internal=True)
-
-            raise errors.NoSuchRevisionSpec(spec)
+            # Otherwise treat it as a DWIM, build the RevisionSpec object and
+            # wait for _match_on to be called.
+            return RevisionSpec_dwim(spec, _internal=True)
 
     def __init__(self, spec, _internal=False):
         """Create a RevisionSpec referring to the Null revision.
@@ -290,16 +288,62 @@
 
 # private API
 
+class RevisionSpec_dwim(RevisionSpec):
+    """Provides a DWIMish revision specifier lookup.
+
+    Note that this does not go in the revspec_registry because by definition
+    there is no prefix to identify it.  It's solely called from
+    RevisionSpec.from_string() because the DWIMification happen when _match_on
+    is called so the string describing the revision is kept here until needed.
+    """
+
+    help_txt = None
+    # We don't need to build the revision history ourself, that's delegated to
+    # each revspec we try.
+    wants_revision_history = False
+
+    def _try_spectype(self, rstype, branch):
+        rs = rstype(self.spec, _internal=True)
+        # Hit in_history to find out if it exists, or we need to try the
+        # next type.
+        return rs.in_history(branch)
+
+    def _match_on(self, branch, revs):
+        """Run the lookup and see what we can get."""
+
+        # First, see if it's a revno
+        global _revno_regex
+        if _revno_regex is None:
+            _revno_regex = re.compile(r'^(?:(\d+(\.\d+)*)|-\d+)(:.*)?$')
+        if _revno_regex.match(self.spec) is not None:
+            try:
+                return self._try_spectype(RevisionSpec_revno, branch)
+            except RevisionSpec_revno.dwim_catchable_exceptions:
+                pass
+
+        # Next see what has been registered
+        for rs_class in dwim_revspecs:
+            try:
+                return self._try_spectype(rs_class, branch)
+            except rs_class.dwim_catchable_exceptions:
+                pass
+
+        # Well, I dunno what it is. Note that we don't try to keep track of the
+        # first of last exception raised during the DWIM tries as none seems
+        # really relevant.
+        raise errors.InvalidRevisionSpec(self.spec, branch)
+
+
 class RevisionSpec_revno(RevisionSpec):
     """Selects a revision using a number."""
 
     help_txt = """Selects a revision using a number.
 
     Use an integer to specify a revision in the history of the branch.
-    Optionally a branch can be specified. The 'revno:' prefix is optional.
-    A negative number will count from the end of the branch (-1 is the
-    last revision, -2 the previous one). If the negative number is larger
-    than the branch's history, the first revision is returned.
+    Optionally a branch can be specified.  A negative number will count
+    from the end of the branch (-1 is the last revision, -2 the previous
+    one). If the negative number is larger than the branch's history, the
+    first revision is returned.
     Examples::
 
       revno:1                   -> return the first revision of this branch
@@ -561,6 +605,7 @@
     """
 
     prefix = 'tag:'
+    dwim_catchable_exceptions = (errors.NoSuchTag, errors.TagsNotSupported)
 
     def _match_on(self, branch, revs):
         # Can raise tags not supported, NoSuchTag, etc
@@ -760,6 +805,7 @@
       branch:/path/to/branch
     """
     prefix = 'branch:'
+    dwim_catchable_exceptions = (errors.NotBranchError,)
 
     def _match_on(self, branch, revs):
         from bzrlib.branch import Branch
@@ -838,6 +884,17 @@
             self._get_submit_location(context_branch))
 
 
+# The order in which we want to DWIM a revision spec without any prefix.
+# revno is always tried first and isn't listed here, this is used by
+# RevisionSpec_dwim._match_on
+dwim_revspecs = [
+    RevisionSpec_tag, # Let's try for a tag
+    RevisionSpec_revid, # Maybe it's a revid?
+    RevisionSpec_date, # Perhaps a date?
+    RevisionSpec_branch, # OK, last try, maybe it's a branch
+    ]
+
+
 revspec_registry = registry.Registry()
 def _register_revspec(revspec):
     revspec_registry.register(revspec.prefix, revspec)
@@ -852,5 +909,7 @@
 _register_revspec(RevisionSpec_branch)
 _register_revspec(RevisionSpec_submit)
 
+# classes in this list should have a "prefix" attribute, against which
+# string specs are matched
 SPEC_TYPES = symbol_versioning.deprecated_list(
     symbol_versioning.deprecated_in((1, 12, 0)), "SPEC_TYPES", [])

=== modified file 'bzrlib/rio.py'
--- bzrlib/rio.py	2009-06-10 03:56:49 +0000
+++ bzrlib/rio.py	2009-09-11 06:36:50 +0000
@@ -32,6 +32,7 @@
 
 import re
 
+from bzrlib import osutils
 from bzrlib.iterablefile import IterableFile
 
 # XXX: some redundancy is allowing to write stanzas in isolation as well as
@@ -377,7 +378,8 @@
         _read_stanza_unicode,
         _valid_tag,
         )
-except ImportError:
+except ImportError, e:
+    osutils.failed_to_load_extension(e)
     from bzrlib._rio_py import (
        _read_stanza_utf8,
        _read_stanza_unicode,

=== modified file 'bzrlib/send.py'
--- bzrlib/send.py	2009-07-17 14:41:02 +0000
+++ bzrlib/send.py	2009-10-06 14:40:37 +0000
@@ -115,14 +115,13 @@
                     ).get_user_option_as_bool('send_strict')
             if strict is None: strict = True # default value
             if strict and tree is not None:
-                if (tree.has_changes(tree.basis_tree())
-                    or len(tree.get_parent_ids()) > 1):
+                if (tree.has_changes()):
                     raise errors.UncommittedChanges(
                         tree, more='Use --no-strict to force the send.')
                 if tree.last_revision() != tree.branch.last_revision():
                     # The tree has lost sync with its branch, there is little
                     # chance that the user is aware of it but he can still force
-                    # the push with --no-strict
+                    # the send with --no-strict
                     raise errors.OutOfDateTree(
                         tree, more='Use --no-strict to force the send.')
             revision_id = branch.last_revision()

=== modified file 'bzrlib/shelf_ui.py'
--- bzrlib/shelf_ui.py	2009-08-26 03:20:32 +0000
+++ bzrlib/shelf_ui.py	2009-11-26 17:06:32 +0000
@@ -22,11 +22,13 @@
 
 from bzrlib import (
     builtins,
+    commands,
     delta,
     diff,
     errors,
     osutils,
     patches,
+    patiencediff,
     shelf,
     textfile,
     trace,
@@ -35,6 +37,10 @@
 )
 
 
+class UseEditor(Exception):
+    """Use an editor instead of selecting hunks."""
+
+
 class ShelfReporter(object):
 
     vocab = {'add file': 'Shelve adding file "%(path)s"?',
@@ -143,6 +149,9 @@
         if reporter is None:
             reporter = ShelfReporter()
         self.reporter = reporter
+        config = self.work_tree.branch.get_config()
+        self.change_editor = config.get_change_editor(target_tree, work_tree)
+        self.work_tree.lock_tree_write()
 
     @classmethod
     def from_args(klass, diff_writer, revision=None, all=False, file_list=None,
@@ -168,11 +177,10 @@
             target_tree = builtins._get_one_revision_tree('shelf2', revision,
                 tree.branch, tree)
             files = builtins.safe_relpath_files(tree, file_list)
-        except:
+            return klass(tree, target_tree, diff_writer, all, all, files,
+                         message, destroy)
+        finally:
             tree.unlock()
-            raise
-        return klass(tree, target_tree, diff_writer, all, all, files, message,
-                     destroy)
 
     def run(self):
         """Interactively shelve the changes."""
@@ -211,6 +219,12 @@
             shutil.rmtree(self.tempdir)
             creator.finalize()
 
+    def finalize(self):
+        if self.change_editor is not None:
+            self.change_editor.finish()
+        self.work_tree.unlock()
+
+
     def get_parsed_patch(self, file_id, invert=False):
         """Return a parsed version of a file's patch.
 
@@ -239,13 +253,19 @@
         :param message: The message to prompt a user with.
         :return: A character.
         """
+        if not sys.stdin.isatty():
+            # Since there is no controlling terminal we will hang when trying
+            # to prompt the user, better abort now.  See
+            # https://code.launchpad.net/~bialix/bzr/shelve-no-tty/+merge/14905
+            # for more context.
+            raise errors.BzrError("You need a controlling terminal.")
         sys.stdout.write(message)
         char = osutils.getchar()
         sys.stdout.write("\r" + ' ' * len(message) + '\r')
         sys.stdout.flush()
         return char
 
-    def prompt_bool(self, question, long=False):
+    def prompt_bool(self, question, long=False, allow_editor=False):
         """Prompt the user with a yes/no question.
 
         This may be overridden by self.auto.  It may also *set* self.auto.  It
@@ -255,13 +275,20 @@
         """
         if self.auto:
             return True
+        editor_string = ''
         if long:
-            prompt = ' [(y)es, (N)o, (f)inish, or (q)uit]'
+            if allow_editor:
+                editor_string = '(E)dit manually, '
+            prompt = ' [(y)es, (N)o, %s(f)inish, or (q)uit]' % editor_string
         else:
-            prompt = ' [yNfq?]'
+            if allow_editor:
+                editor_string = 'e'
+            prompt = ' [yN%sfq?]' % editor_string
         char = self.prompt(question + prompt)
         if char == 'y':
             return True
+        elif char == 'e' and allow_editor:
+            raise UseEditor
         elif char == 'f':
             self.auto = True
             return True
@@ -273,6 +300,23 @@
             return False
 
     def handle_modify_text(self, creator, file_id):
+        """Handle modified text, by using hunk selection or file editing.
+
+        :param creator: A ShelfCreator.
+        :param file_id: The id of the file that was modified.
+        :return: The number of changes.
+        """
+        work_tree_lines = self.work_tree.get_file_lines(file_id)
+        try:
+            lines, change_count = self._select_hunks(creator, file_id,
+                                                     work_tree_lines)
+        except UseEditor:
+            lines, change_count = self._edit_file(file_id, work_tree_lines)
+        if change_count != 0:
+            creator.shelve_lines(file_id, lines)
+        return change_count
+
+    def _select_hunks(self, creator, file_id, work_tree_lines):
         """Provide diff hunk selection for modified text.
 
         If self.reporter.invert_diff is True, the diff is inverted so that
@@ -280,13 +324,14 @@
 
         :param creator: a ShelfCreator
         :param file_id: The id of the file to shelve.
+        :param work_tree_lines: Line contents of the file in the working tree.
         :return: number of shelved hunks.
         """
         if self.reporter.invert_diff:
-            target_lines = self.work_tree.get_file_lines(file_id)
+            target_lines = work_tree_lines
         else:
             target_lines = self.target_tree.get_file_lines(file_id)
-        textfile.check_text_lines(self.work_tree.get_file_lines(file_id))
+        textfile.check_text_lines(work_tree_lines)
         textfile.check_text_lines(target_lines)
         parsed = self.get_parsed_patch(file_id, self.reporter.invert_diff)
         final_hunks = []
@@ -295,7 +340,9 @@
             self.diff_writer.write(parsed.get_header())
             for hunk in parsed.hunks:
                 self.diff_writer.write(str(hunk))
-                selected = self.prompt_bool(self.reporter.vocab['hunk'])
+                selected = self.prompt_bool(self.reporter.vocab['hunk'],
+                                            allow_editor=(self.change_editor
+                                                          is not None))
                 if not self.reporter.invert_diff:
                     selected = (not selected)
                 if selected:
@@ -304,16 +351,32 @@
                 else:
                     offset -= (hunk.mod_range - hunk.orig_range)
         sys.stdout.flush()
-        if not self.reporter.invert_diff and (
-            len(parsed.hunks) == len(final_hunks)):
-            return 0
-        if self.reporter.invert_diff and len(final_hunks) == 0:
-            return 0
-        patched = patches.iter_patched_from_hunks(target_lines, final_hunks)
-        creator.shelve_lines(file_id, list(patched))
         if self.reporter.invert_diff:
-            return len(final_hunks)
-        return len(parsed.hunks) - len(final_hunks)
+            change_count = len(final_hunks)
+        else:
+            change_count = len(parsed.hunks) - len(final_hunks)
+        patched = patches.iter_patched_from_hunks(target_lines,
+                                                  final_hunks)
+        lines = list(patched)
+        return lines, change_count
+
+    def _edit_file(self, file_id, work_tree_lines):
+        """
+        :param file_id: id of the file to edit.
+        :param work_tree_lines: Line contents of the file in the working tree.
+        :return: (lines, change_region_count), where lines is the new line
+            content of the file, and change_region_count is the number of
+            changed regions.
+        """
+        lines = osutils.split_lines(self.change_editor.edit_file(file_id))
+        return lines, self._count_changed_regions(work_tree_lines, lines)
+
+    @staticmethod
+    def _count_changed_regions(old_lines, new_lines):
+        matcher = patiencediff.PatienceSequenceMatcher(None, old_lines,
+                                                       new_lines)
+        blocks = matcher.get_matching_blocks()
+        return len(blocks) - 2
 
 
 class Unshelver(object):

=== modified file 'bzrlib/shellcomplete.py'
--- bzrlib/shellcomplete.py	2009-06-15 11:05:33 +0000
+++ bzrlib/shellcomplete.py	2009-11-02 22:24:29 +0000
@@ -47,9 +47,10 @@
 
 def shellcomplete_on_options(options, outfile=None):
     for opt in options:
-        if opt.short_name:
+        short_name = opt.short_name()
+        if short_name:
             outfile.write('"(--%s -%s)"{--%s,-%s}\n'
-                    % (opt.name, opt.short_name(), opt.name, opt.short_name()))
+                    % (opt.name, short_name, opt.name, short_name))
         else:
             outfile.write('--%s\n' % opt.name)
 

=== modified file 'bzrlib/smart/branch.py'
--- bzrlib/smart/branch.py	2009-07-27 04:32:56 +0000
+++ bzrlib/smart/branch.py	2009-10-21 06:05:49 +0000
@@ -105,9 +105,9 @@
 
 class SmartServerBranchSetTagsBytes(SmartServerLockedBranchRequest):
 
-    def __init__(self, backing_transport, root_client_path='/'):
+    def __init__(self, backing_transport, root_client_path='/', jail_root=None):
         SmartServerLockedBranchRequest.__init__(
-            self, backing_transport, root_client_path)
+            self, backing_transport, root_client_path, jail_root)
         self.locked = False
         
     def do_with_locked_branch(self, branch):

=== modified file 'bzrlib/smart/bzrdir.py'
--- bzrlib/smart/bzrdir.py	2009-06-12 01:48:43 +0000
+++ bzrlib/smart/bzrdir.py	2009-09-22 00:34:10 +0000
@@ -34,7 +34,6 @@
 class SmartServerRequestOpenBzrDir(SmartServerRequest):
 
     def do(self, path):
-        from bzrlib.bzrdir import BzrDirFormat
         try:
             t = self.transport_from_client_path(path)
         except errors.PathNotChild:
@@ -56,6 +55,32 @@
         return SuccessfulSmartServerResponse((answer,))
 
 
+class SmartServerRequestOpenBzrDir_2_1(SmartServerRequest):
+
+    def do(self, path):
+        """Is there a BzrDir present, and if so does it have a working tree?
+
+        New in 2.1.
+        """
+        try:
+            t = self.transport_from_client_path(path)
+        except errors.PathNotChild:
+            # The client is trying to ask about a path that they have no access
+            # to.
+            return SuccessfulSmartServerResponse(('no',))
+        try:
+            bd = BzrDir.open_from_transport(t)
+        except errors.NotBranchError:
+            answer = ('no',)
+        else:
+            answer = ('yes',)
+            if bd.has_workingtree():
+                answer += ('yes',)
+            else:
+                answer += ('no',)
+        return SuccessfulSmartServerResponse(answer)
+
+
 class SmartServerRequestBzrDir(SmartServerRequest):
 
     def do(self, path, *args):

=== modified file 'bzrlib/smart/medium.py'
--- bzrlib/smart/medium.py	2009-08-07 05:56:29 +0000
+++ bzrlib/smart/medium.py	2009-09-01 07:47:36 +0000
@@ -291,7 +291,7 @@
     def terminate_due_to_error(self):
         # TODO: This should log to a server log file, but no such thing
         # exists yet.  Andrew Bennetts 2006-09-29.
-        self.socket.close()
+        osutils.until_no_eintr(self.socket.close)
         self.finished = True
 
     def _write_out(self, bytes):
@@ -326,27 +326,27 @@
             bytes_to_read = protocol.next_read_size()
             if bytes_to_read == 0:
                 # Finished serving this request.
-                self._out.flush()
+                osutils.until_no_eintr(self._out.flush)
                 return
             bytes = self.read_bytes(bytes_to_read)
             if bytes == '':
                 # Connection has been closed.
                 self.finished = True
-                self._out.flush()
+                osutils.until_no_eintr(self._out.flush)
                 return
             protocol.accept_bytes(bytes)
 
     def _read_bytes(self, desired_count):
-        return self._in.read(desired_count)
+        return osutils.until_no_eintr(self._in.read, desired_count)
 
     def terminate_due_to_error(self):
         # TODO: This should log to a server log file, but no such thing
         # exists yet.  Andrew Bennetts 2006-09-29.
-        self._out.close()
+        osutils.until_no_eintr(self._out.close)
         self.finished = True
 
     def _write_out(self, bytes):
-        self._out.write(bytes)
+        osutils.until_no_eintr(self._out.write, bytes)
 
 
 class SmartClientMediumRequest(object):
@@ -712,16 +712,16 @@
 
     def _accept_bytes(self, bytes):
         """See SmartClientStreamMedium.accept_bytes."""
-        self._writeable_pipe.write(bytes)
+        osutils.until_no_eintr(self._writeable_pipe.write, bytes)
         self._report_activity(len(bytes), 'write')
 
     def _flush(self):
         """See SmartClientStreamMedium._flush()."""
-        self._writeable_pipe.flush()
+        osutils.until_no_eintr(self._writeable_pipe.flush)
 
     def _read_bytes(self, count):
         """See SmartClientStreamMedium._read_bytes."""
-        bytes = self._readable_pipe.read(count)
+        bytes = osutils.until_no_eintr(self._readable_pipe.read, count)
         self._report_activity(len(bytes), 'read')
         return bytes
 
@@ -765,15 +765,15 @@
     def _accept_bytes(self, bytes):
         """See SmartClientStreamMedium.accept_bytes."""
         self._ensure_connection()
-        self._write_to.write(bytes)
+        osutils.until_no_eintr(self._write_to.write, bytes)
         self._report_activity(len(bytes), 'write')
 
     def disconnect(self):
         """See SmartClientMedium.disconnect()."""
         if not self._connected:
             return
-        self._read_from.close()
-        self._write_to.close()
+        osutils.until_no_eintr(self._read_from.close)
+        osutils.until_no_eintr(self._write_to.close)
         self._ssh_connection.close()
         self._connected = False
 
@@ -802,7 +802,7 @@
         if not self._connected:
             raise errors.MediumNotConnected(self)
         bytes_to_read = min(count, _MAX_READ_SIZE)
-        bytes = self._read_from.read(bytes_to_read)
+        bytes = osutils.until_no_eintr(self._read_from.read, bytes_to_read)
         self._report_activity(len(bytes), 'read')
         return bytes
 
@@ -832,7 +832,7 @@
         """See SmartClientMedium.disconnect()."""
         if not self._connected:
             return
-        self._socket.close()
+        osutils.until_no_eintr(self._socket.close)
         self._socket = None
         self._connected = False
 

=== modified file 'bzrlib/smart/message.py'
--- bzrlib/smart/message.py	2009-07-28 22:27:04 +0000
+++ bzrlib/smart/message.py	2009-09-11 06:07:05 +0000
@@ -134,7 +134,7 @@
 
     def _args_received(self, args):
         self.expecting = 'body'
-        self.request_handler.dispatch_command(args[0], args[1:])
+        self.request_handler.args_received(args)
         if self.request_handler.finished_reading:
             self._response_sent = True
             self.responder.send_response(self.request_handler.response)

=== modified file 'bzrlib/smart/protocol.py'
--- bzrlib/smart/protocol.py	2009-07-21 03:11:33 +0000
+++ bzrlib/smart/protocol.py	2009-10-21 06:05:49 +0000
@@ -114,9 +114,11 @@
 class SmartServerRequestProtocolOne(SmartProtocolBase):
     """Server-side encoding and decoding logic for smart version 1."""
 
-    def __init__(self, backing_transport, write_func, root_client_path='/'):
+    def __init__(self, backing_transport, write_func, root_client_path='/',
+            jail_root=None):
         self._backing_transport = backing_transport
         self._root_client_path = root_client_path
+        self._jail_root = jail_root
         self.unused_data = ''
         self._finished = False
         self.in_buffer = ''
@@ -144,8 +146,9 @@
                 req_args = _decode_tuple(first_line)
                 self.request = request.SmartServerRequestHandler(
                     self._backing_transport, commands=request.request_handlers,
-                    root_client_path=self._root_client_path)
-                self.request.dispatch_command(req_args[0], req_args[1:])
+                    root_client_path=self._root_client_path,
+                    jail_root=self._jail_root)
+                self.request.args_received(req_args)
                 if self.request.finished_reading:
                     # trivial request
                     self.unused_data = self.in_buffer
@@ -858,10 +861,10 @@
 
 
 def build_server_protocol_three(backing_transport, write_func,
-                                root_client_path):
+                                root_client_path, jail_root=None):
     request_handler = request.SmartServerRequestHandler(
         backing_transport, commands=request.request_handlers,
-        root_client_path=root_client_path)
+        root_client_path=root_client_path, jail_root=jail_root)
     responder = ProtocolThreeResponder(write_func)
     message_handler = message.ConventionalRequestHandler(request_handler, responder)
     return ProtocolThreeDecoder(message_handler)

=== modified file 'bzrlib/smart/repository.py'
--- bzrlib/smart/repository.py	2009-08-14 00:55:42 +0000
+++ bzrlib/smart/repository.py	2009-09-03 00:33:35 +0000
@@ -519,36 +519,97 @@
     yield pack_writer.end()
 
 
+class _ByteStreamDecoder(object):
+    """Helper for _byte_stream_to_stream.
+
+    The expected usage of this class is via the function _byte_stream_to_stream
+    which creates a _ByteStreamDecoder, pops off the stream format and then
+    yields the output of record_stream(), the main entry point to
+    _ByteStreamDecoder.
+
+    Broadly this class has to unwrap two layers of iterators:
+    (type, substream)
+    (substream details)
+
+    This is complicated by wishing to return type, iterator_for_type, but
+    getting the data for iterator_for_type when we find out type: we can't
+    simply pass a generator down to the NetworkRecordStream parser, instead
+    we have a little local state to seed each NetworkRecordStream instance,
+    and gather the type that we'll be yielding.
+
+    :ivar byte_stream: The byte stream being decoded.
+    :ivar stream_decoder: A pack parser used to decode the bytestream
+    :ivar current_type: The current type, used to join adjacent records of the
+        same type into a single stream.
+    :ivar first_bytes: The first bytes to give the next NetworkRecordStream.
+    """
+
+    def __init__(self, byte_stream):
+        """Create a _ByteStreamDecoder."""
+        self.stream_decoder = pack.ContainerPushParser()
+        self.current_type = None
+        self.first_bytes = None
+        self.byte_stream = byte_stream
+
+    def iter_stream_decoder(self):
+        """Iterate the contents of the pack from stream_decoder."""
+        # dequeue pending items
+        for record in self.stream_decoder.read_pending_records():
+            yield record
+        # Pull bytes of the wire, decode them to records, yield those records.
+        for bytes in self.byte_stream:
+            self.stream_decoder.accept_bytes(bytes)
+            for record in self.stream_decoder.read_pending_records():
+                yield record
+
+    def iter_substream_bytes(self):
+        if self.first_bytes is not None:
+            yield self.first_bytes
+            # If we run out of pack records, single the outer layer to stop.
+            self.first_bytes = None
+        for record in self.iter_pack_records:
+            record_names, record_bytes = record
+            record_name, = record_names
+            substream_type = record_name[0]
+            if substream_type != self.current_type:
+                # end of a substream, seed the next substream.
+                self.current_type = substream_type
+                self.first_bytes = record_bytes
+                return
+            yield record_bytes
+
+    def record_stream(self):
+        """Yield substream_type, substream from the byte stream."""
+        self.seed_state()
+        # Make and consume sub generators, one per substream type:
+        while self.first_bytes is not None:
+            substream = NetworkRecordStream(self.iter_substream_bytes())
+            # after substream is fully consumed, self.current_type is set to
+            # the next type, and self.first_bytes is set to the matching bytes.
+            yield self.current_type, substream.read()
+
+    def seed_state(self):
+        """Prepare the _ByteStreamDecoder to decode from the pack stream."""
+        # Set a single generator we can use to get data from the pack stream.
+        self.iter_pack_records = self.iter_stream_decoder()
+        # Seed the very first subiterator with content; after this each one
+        # seeds the next.
+        list(self.iter_substream_bytes())
+
+
 def _byte_stream_to_stream(byte_stream):
     """Convert a byte stream into a format and a stream.
 
     :param byte_stream: A bytes iterator, as output by _stream_to_byte_stream.
     :return: (RepositoryFormat, stream_generator)
     """
-    stream_decoder = pack.ContainerPushParser()
-    def record_stream():
-        """Closure to return the substreams."""
-        # May have fully parsed records already.
-        for record in stream_decoder.read_pending_records():
-            record_names, record_bytes = record
-            record_name, = record_names
-            substream_type = record_name[0]
-            substream = NetworkRecordStream([record_bytes])
-            yield substream_type, substream.read()
-        for bytes in byte_stream:
-            stream_decoder.accept_bytes(bytes)
-            for record in stream_decoder.read_pending_records():
-                record_names, record_bytes = record
-                record_name, = record_names
-                substream_type = record_name[0]
-                substream = NetworkRecordStream([record_bytes])
-                yield substream_type, substream.read()
+    decoder = _ByteStreamDecoder(byte_stream)
     for bytes in byte_stream:
-        stream_decoder.accept_bytes(bytes)
-        for record in stream_decoder.read_pending_records(max=1):
+        decoder.stream_decoder.accept_bytes(bytes)
+        for record in decoder.stream_decoder.read_pending_records(max=1):
             record_names, src_format_name = record
             src_format = network_format_registry.get(src_format_name)
-            return src_format, record_stream()
+            return src_format, decoder.record_stream()
 
 
 class SmartServerRepositoryUnlock(SmartServerRepositoryRequest):

=== modified file 'bzrlib/smart/request.py'
--- bzrlib/smart/request.py	2009-08-27 05:22:14 +0000
+++ bzrlib/smart/request.py	2009-10-29 00:25:26 +0000
@@ -86,7 +86,7 @@
     # XXX: rename this class to BaseSmartServerRequestHandler ?  A request
     # *handler* is a different concept to the request.
 
-    def __init__(self, backing_transport, root_client_path='/'):
+    def __init__(self, backing_transport, root_client_path='/', jail_root=None):
         """Constructor.
 
         :param backing_transport: the base transport to be used when performing
@@ -96,8 +96,13 @@
             from the client.  Clients will not be able to refer to paths above
             this root.  If root_client_path is None, then no translation will
             be performed on client paths.  Default is '/'.
+        :param jail_root: if specified, the root of the BzrDir.open jail to use
+            instead of backing_transport.
         """
         self._backing_transport = backing_transport
+        if jail_root is None:
+            jail_root = backing_transport
+        self._jail_root = jail_root
         if root_client_path is not None:
             if not root_client_path.startswith('/'):
                 root_client_path = '/' + root_client_path
@@ -155,7 +160,7 @@
         return self.do_body(body_bytes)
 
     def setup_jail(self):
-        jail_info.transports = [self._backing_transport]
+        jail_info.transports = [self._jail_root]
 
     def teardown_jail(self):
         jail_info.transports = None
@@ -183,7 +188,7 @@
             relpath = urlutils.joinpath('/', path)
             if not relpath.startswith('/'):
                 raise ValueError(relpath)
-            return '.' + relpath
+            return urlutils.escape('.' + relpath)
         else:
             raise errors.PathNotChild(client_path, self._root_client_path)
 
@@ -265,7 +270,8 @@
     # TODO: Better way of representing the body for commands that take it,
     # and allow it to be streamed into the server.
 
-    def __init__(self, backing_transport, commands, root_client_path):
+    def __init__(self, backing_transport, commands, root_client_path,
+        jail_root=None):
         """Constructor.
 
         :param backing_transport: a Transport to handle requests for.
@@ -275,6 +281,9 @@
         self._backing_transport = backing_transport
         self._root_client_path = root_client_path
         self._commands = commands
+        if jail_root is None:
+            jail_root = backing_transport
+        self._jail_root = jail_root
         self.response = None
         self.finished_reading = False
         self._command = None
@@ -292,15 +301,6 @@
         # cannot read after this.
         self.finished_reading = True
 
-    def dispatch_command(self, cmd, args):
-        """Deprecated compatibility method.""" # XXX XXX
-        try:
-            command = self._commands.get(cmd)
-        except LookupError:
-            raise errors.UnknownSmartMethod(cmd)
-        self._command = command(self._backing_transport, self._root_client_path)
-        self._run_handler_code(self._command.execute, args, {})
-
     def _run_handler_code(self, callable, args, kwargs):
         """Run some handler specific code 'callable'.
 
@@ -343,7 +343,8 @@
             command = self._commands.get(cmd)
         except LookupError:
             raise errors.UnknownSmartMethod(cmd)
-        self._command = command(self._backing_transport)
+        self._command = command(
+            self._backing_transport, self._root_client_path, self._jail_root)
         self._run_handler_code(self._command.execute, args, {})
 
     def end_received(self):
@@ -509,6 +510,8 @@
 request_handlers.register_lazy(
     'BzrDir.open', 'bzrlib.smart.bzrdir', 'SmartServerRequestOpenBzrDir')
 request_handlers.register_lazy(
+    'BzrDir.open_2.1', 'bzrlib.smart.bzrdir', 'SmartServerRequestOpenBzrDir_2_1')
+request_handlers.register_lazy(
     'BzrDir.open_branch', 'bzrlib.smart.bzrdir',
     'SmartServerRequestOpenBranch')
 request_handlers.register_lazy(

=== modified file 'bzrlib/smart/server.py'
--- bzrlib/smart/server.py	2009-07-20 11:27:05 +0000
+++ bzrlib/smart/server.py	2009-09-23 06:54:14 +0000
@@ -17,6 +17,7 @@
 """Server for smart-server protocol."""
 
 import errno
+import os.path
 import socket
 import sys
 import threading
@@ -30,6 +31,14 @@
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 from bzrlib.smart import medium
+from bzrlib.transport import (
+    chroot,
+    get_transport,
+    pathfilter,
+    )
+from bzrlib import (
+    urlutils,
+    )
 """)
 
 
@@ -134,8 +143,7 @@
                 # dont log when CTRL-C'd.
                 raise
             except Exception, e:
-                trace.error("Unhandled smart server error.")
-                trace.log_exception_quietly()
+                trace.report_exception(sys.exc_info(), sys.stderr)
                 raise
         finally:
             self._stopped.set()
@@ -313,34 +321,132 @@
         return transport.get_transport(url)
 
 
-def serve_bzr(transport, host=None, port=None, inet=False):
-    from bzrlib import lockdir, ui
-    from bzrlib.transport import get_transport
-    from bzrlib.transport.chroot import ChrootServer
-    chroot_server = ChrootServer(transport)
-    chroot_server.setUp()
-    transport = get_transport(chroot_server.get_url())
-    if inet:
-        smart_server = medium.SmartServerPipeStreamMedium(
-            sys.stdin, sys.stdout, transport)
+def _local_path_for_transport(transport):
+    """Return a local path for transport, if reasonably possible.
+    
+    This function works even if transport's url has a "readonly+" prefix,
+    unlike local_path_from_url.
+    
+    This essentially recovers the --directory argument the user passed to "bzr
+    serve" from the transport passed to serve_bzr.
+    """
+    try:
+        base_url = transport.external_url()
+    except (errors.InProcessTransport, NotImplementedError):
+        return None
     else:
-        if host is None:
-            host = medium.BZR_DEFAULT_INTERFACE
-        if port is None:
-            port = medium.BZR_DEFAULT_PORT
-        smart_server = SmartTCPServer(transport, host=host, port=port)
-        trace.note('listening on port: %s' % smart_server.port)
-    # For the duration of this server, no UI output is permitted. note
-    # that this may cause problems with blackbox tests. This should be
-    # changed with care though, as we dont want to use bandwidth sending
-    # progress over stderr to smart server clients!
-    old_factory = ui.ui_factory
-    old_lockdir_timeout = lockdir._DEFAULT_TIMEOUT_SECONDS
-    try:
+        # Strip readonly prefix
+        if base_url.startswith('readonly+'):
+            base_url = base_url[len('readonly+'):]
+        try:
+            return urlutils.local_path_from_url(base_url)
+        except errors.InvalidURL:
+            return None
+
+
+class BzrServerFactory(object):
+    """Helper class for serve_bzr."""
+
+    def __init__(self, userdir_expander=None, get_base_path=None):
+        self.cleanups = []
+        self.base_path = None
+        self.backing_transport = None
+        if userdir_expander is None:
+            userdir_expander = os.path.expanduser
+        self.userdir_expander = userdir_expander
+        if get_base_path is None:
+            get_base_path = _local_path_for_transport
+        self.get_base_path = get_base_path
+
+    def _expand_userdirs(self, path):
+        """Translate /~/ or /~user/ to e.g. /home/foo, using
+        self.userdir_expander (os.path.expanduser by default).
+
+        If the translated path would fall outside base_path, or the path does
+        not start with ~, then no translation is applied.
+
+        If the path is inside, it is adjusted to be relative to the base path.
+
+        e.g. if base_path is /home, and the expanded path is /home/joe, then
+        the translated path is joe.
+        """
+        result = path
+        if path.startswith('~'):
+            expanded = self.userdir_expander(path)
+            if not expanded.endswith('/'):
+                expanded += '/'
+            if expanded.startswith(self.base_path):
+                result = expanded[len(self.base_path):]
+        return result
+
+    def _make_expand_userdirs_filter(self, transport):
+        return pathfilter.PathFilteringServer(transport, self._expand_userdirs)
+
+    def _make_backing_transport(self, transport):
+        """Chroot transport, and decorate with userdir expander."""
+        self.base_path = self.get_base_path(transport)
+        chroot_server = chroot.ChrootServer(transport)
+        chroot_server.setUp()
+        self.cleanups.append(chroot_server.tearDown)
+        transport = get_transport(chroot_server.get_url())
+        if self.base_path is not None:
+            # Decorate the server's backing transport with a filter that can
+            # expand homedirs.
+            expand_userdirs = self._make_expand_userdirs_filter(transport)
+            expand_userdirs.setUp()
+            self.cleanups.append(expand_userdirs.tearDown)
+            transport = get_transport(expand_userdirs.get_url())
+        self.transport = transport
+
+    def _make_smart_server(self, host, port, inet):
+        if inet:
+            smart_server = medium.SmartServerPipeStreamMedium(
+                sys.stdin, sys.stdout, self.transport)
+        else:
+            if host is None:
+                host = medium.BZR_DEFAULT_INTERFACE
+            if port is None:
+                port = medium.BZR_DEFAULT_PORT
+            smart_server = SmartTCPServer(self.transport, host=host, port=port)
+            trace.note('listening on port: %s' % smart_server.port)
+        self.smart_server = smart_server
+
+    def _change_globals(self):
+        from bzrlib import lockdir, ui
+        # For the duration of this server, no UI output is permitted. note
+        # that this may cause problems with blackbox tests. This should be
+        # changed with care though, as we dont want to use bandwidth sending
+        # progress over stderr to smart server clients!
+        old_factory = ui.ui_factory
+        old_lockdir_timeout = lockdir._DEFAULT_TIMEOUT_SECONDS
+        def restore_default_ui_factory_and_lockdir_timeout():
+            ui.ui_factory = old_factory
+            lockdir._DEFAULT_TIMEOUT_SECONDS = old_lockdir_timeout
+        self.cleanups.append(restore_default_ui_factory_and_lockdir_timeout)
         ui.ui_factory = ui.SilentUIFactory()
         lockdir._DEFAULT_TIMEOUT_SECONDS = 0
-        smart_server.serve()
+
+    def set_up(self, transport, host, port, inet):
+        self._make_backing_transport(transport)
+        self._make_smart_server(host, port, inet)
+        self._change_globals()
+
+    def tear_down(self):
+        for cleanup in reversed(self.cleanups):
+            cleanup()
+
+
+def serve_bzr(transport, host=None, port=None, inet=False):
+    """This is the default implementation of 'bzr serve'.
+    
+    It creates a TCP or pipe smart server on 'transport, and runs it.  The
+    transport will be decorated with a chroot and pathfilter (using
+    os.path.expanduser).
+    """
+    bzr_server = BzrServerFactory()
+    try:
+        bzr_server.set_up(transport, host, port, inet)
+        bzr_server.smart_server.serve()
     finally:
-        ui.ui_factory = old_factory
-        lockdir._DEFAULT_TIMEOUT_SECONDS = old_lockdir_timeout
+        bzr_server.tear_down()
 

=== modified file 'bzrlib/smart/vfs.py'
--- bzrlib/smart/vfs.py	2009-03-23 14:59:43 +0000
+++ bzrlib/smart/vfs.py	2009-10-23 04:22:05 +0000
@@ -27,6 +27,7 @@
 import os
 
 from bzrlib import errors
+from bzrlib import urlutils
 from bzrlib.smart import request
 
 
@@ -59,6 +60,14 @@
         if not vfs_enabled():
             raise errors.DisabledMethod(self.__class__.__name__)
 
+    def translate_client_path(self, relpath):
+        # VFS requests are made with escaped paths so the escaping done in
+        # SmartServerRequest.translate_client_path leads to double escaping.
+        # Remove it here -- the fact that the result is still escaped means
+        # that the str() will not fail on valid input.
+        x = request.SmartServerRequest.translate_client_path(self, relpath)
+        return str(urlutils.unescape(x))
+
 
 class HasRequest(VfsRequest):
 

=== added file 'bzrlib/static_tuple.py'
--- bzrlib/static_tuple.py	1970-01-01 00:00:00 +0000
+++ bzrlib/static_tuple.py	2009-11-28 21:54:08 +0000
@@ -0,0 +1,56 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Interface thunk for a StaticTuple implementation."""
+
+from bzrlib import debug
+
+try:
+    from bzrlib._static_tuple_c import StaticTuple
+except ImportError, e:
+    from bzrlib import osutils
+    osutils.failed_to_load_extension(e)
+    from bzrlib._static_tuple_py import StaticTuple
+
+
+def expect_static_tuple(obj):
+    """Check if the passed object is a StaticTuple.
+
+    Cast it if necessary, but if the 'static_tuple' debug flag is set, raise an
+    error instead.
+
+    As apis are improved, we will probably eventually stop calling this as it
+    adds overhead we shouldn't need.
+    """
+    if 'static_tuple' not in debug.debug_flags:
+        return StaticTuple.from_sequence(obj)
+    if type(obj) is not StaticTuple:
+        raise TypeError('We expected a StaticTuple not a %s' % (type(obj),))
+    return obj
+
+
+def as_tuples(obj):
+    """Ensure that the object and any referenced objects are plain tuples.
+
+    :param obj: a list, tuple or StaticTuple
+    :return: a plain tuple instance, with all children also being tuples.
+    """
+    result = []
+    for item in obj:
+        if isinstance(item, (tuple, list, StaticTuple)):
+            item = as_tuples(item)
+        result.append(item)
+    return tuple(result)

=== modified file 'bzrlib/symbol_versioning.py'
--- bzrlib/symbol_versioning.py	2009-04-04 02:50:01 +0000
+++ bzrlib/symbol_versioning.py	2009-09-15 02:28:34 +0000
@@ -41,7 +41,7 @@
     """Generate a message that something was deprecated in a release.
 
     >>> deprecated_in((1, 4, 0))
-    '%s was deprecated in version 1.4.'
+    '%s was deprecated in version 1.4.0.'
     """
     return ("%%s was deprecated in version %s."
             % bzrlib._format_version_tuple(version_tuple))

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2009-08-24 20:30:18 +0000
+++ bzrlib/tests/__init__.py	2009-12-02 07:56:16 +0000
@@ -28,6 +28,7 @@
 
 import atexit
 import codecs
+from copy import copy
 from cStringIO import StringIO
 import difflib
 import doctest
@@ -52,6 +53,8 @@
 from bzrlib import (
     branchbuilder,
     bzrdir,
+    chk_map,
+    config,
     debug,
     errors,
     hooks,
@@ -89,7 +92,7 @@
     deprecated_passed,
     )
 import bzrlib.trace
-from bzrlib.transport import get_transport
+from bzrlib.transport import get_transport, pathfilter
 import bzrlib.transport
 from bzrlib.transport.local import LocalURLServer
 from bzrlib.transport.memory import MemoryServer
@@ -174,22 +177,56 @@
         self._overall_start_time = time.time()
         self._strict = strict
 
-    def done(self):
-        # nb: called stopTestRun in the version of this that Python merged
-        # upstream, according to lifeless 20090803
+    def stopTestRun(self):
+        run = self.testsRun
+        actionTaken = "Ran"
+        stopTime = time.time()
+        timeTaken = stopTime - self.startTime
+        self.printErrors()
+        self.stream.writeln(self.separator2)
+        self.stream.writeln("%s %d test%s in %.3fs" % (actionTaken,
+                            run, run != 1 and "s" or "", timeTaken))
+        self.stream.writeln()
+        if not self.wasSuccessful():
+            self.stream.write("FAILED (")
+            failed, errored = map(len, (self.failures, self.errors))
+            if failed:
+                self.stream.write("failures=%d" % failed)
+            if errored:
+                if failed: self.stream.write(", ")
+                self.stream.write("errors=%d" % errored)
+            if self.known_failure_count:
+                if failed or errored: self.stream.write(", ")
+                self.stream.write("known_failure_count=%d" %
+                    self.known_failure_count)
+            self.stream.writeln(")")
+        else:
+            if self.known_failure_count:
+                self.stream.writeln("OK (known_failures=%d)" %
+                    self.known_failure_count)
+            else:
+                self.stream.writeln("OK")
+        if self.skip_count > 0:
+            skipped = self.skip_count
+            self.stream.writeln('%d test%s skipped' %
+                                (skipped, skipped != 1 and "s" or ""))
+        if self.unsupported:
+            for feature, count in sorted(self.unsupported.items()):
+                self.stream.writeln("Missing feature '%s' skipped %d tests." %
+                    (feature, count))
         if self._strict:
             ok = self.wasStrictlySuccessful()
         else:
             ok = self.wasSuccessful()
-        if ok:
-            self.stream.write('tests passed\n')
-        else:
-            self.stream.write('tests failed\n')
         if TestCase._first_thread_leaker_id:
             self.stream.write(
                 '%s is leaking threads among %d leaking tests.\n' % (
                 TestCase._first_thread_leaker_id,
                 TestCase._leaking_threads_tests))
+            # We don't report the main thread as an active one.
+            self.stream.write(
+                '%d non-main threads were left active in the end.\n'
+                % (TestCase._active_threads - 1))
 
     def _extractBenchmarkTime(self, testCase):
         """Add a benchmark time for the current test case."""
@@ -261,18 +298,13 @@
         Called from the TestCase run() method when the test
         fails with an unexpected error.
         """
-        self._testConcluded(test)
-        if isinstance(err[1], TestNotApplicable):
-            return self._addNotApplicable(test, err)
-        elif isinstance(err[1], UnavailableFeature):
-            return self.addNotSupported(test, err[1].args[0])
-        else:
-            unittest.TestResult.addError(self, test, err)
-            self.error_count += 1
-            self.report_error(test, err)
-            if self.stop_early:
-                self.stop()
-            self._cleanupLogFile(test)
+        self._post_mortem()
+        unittest.TestResult.addError(self, test, err)
+        self.error_count += 1
+        self.report_error(test, err)
+        if self.stop_early:
+            self.stop()
+        self._cleanupLogFile(test)
 
     def addFailure(self, test, err):
         """Tell result that test failed.
@@ -280,23 +312,19 @@
         Called from the TestCase run() method when the test
         fails because e.g. an assert() method failed.
         """
-        self._testConcluded(test)
-        if isinstance(err[1], KnownFailure):
-            return self._addKnownFailure(test, err)
-        else:
-            unittest.TestResult.addFailure(self, test, err)
-            self.failure_count += 1
-            self.report_failure(test, err)
-            if self.stop_early:
-                self.stop()
-            self._cleanupLogFile(test)
+        self._post_mortem()
+        unittest.TestResult.addFailure(self, test, err)
+        self.failure_count += 1
+        self.report_failure(test, err)
+        if self.stop_early:
+            self.stop()
+        self._cleanupLogFile(test)
 
     def addSuccess(self, test):
         """Tell result that test completed successfully.
 
         Called from the TestCase run()
         """
-        self._testConcluded(test)
         if self._bench_history is not None:
             benchmark_time = self._extractBenchmarkTime(test)
             if benchmark_time is not None:
@@ -308,14 +336,7 @@
         unittest.TestResult.addSuccess(self, test)
         test._log_contents = ''
 
-    def _testConcluded(self, test):
-        """Common code when a test has finished.
-
-        Called regardless of whether it succeded, failed, etc.
-        """
-        pass
-
-    def _addKnownFailure(self, test, err):
+    def addExpectedFailure(self, test, err):
         self.known_failure_count += 1
         self.report_known_failure(test, err)
 
@@ -323,11 +344,11 @@
         """The test will not be run because of a missing feature.
         """
         # this can be called in two different ways: it may be that the
-        # test started running, and then raised (through addError)
+        # test started running, and then raised (through requireFeature)
         # UnavailableFeature.  Alternatively this method can be called
-        # while probing for features before running the tests; in that
-        # case we will see startTest and stopTest, but the test will never
-        # actually run.
+        # while probing for features before running the test code proper; in
+        # that case we will see startTest and stopTest, but the test will
+        # never actually run.
         self.unsupported.setdefault(str(feature), 0)
         self.unsupported[str(feature)] += 1
         self.report_unsupported(test, feature)
@@ -337,21 +358,9 @@
         self.skip_count += 1
         self.report_skip(test, reason)
 
-    def _addNotApplicable(self, test, skip_excinfo):
-        if isinstance(skip_excinfo[1], TestNotApplicable):
-            self.not_applicable_count += 1
-            self.report_not_applicable(test, skip_excinfo)
-        try:
-            test.tearDown()
-        except KeyboardInterrupt:
-            raise
-        except:
-            self.addError(test, test.exc_info())
-        else:
-            # seems best to treat this as success from point-of-view of unittest
-            # -- it actually does nothing so it barely matters :)
-            unittest.TestResult.addSuccess(self, test)
-            test._log_contents = ''
+    def addNotApplicable(self, test, reason):
+        self.not_applicable_count += 1
+        self.report_not_applicable(test, reason)
 
     def printErrorList(self, flavour, errors):
         for test, err in errors:
@@ -373,6 +382,11 @@
             self.stream.writeln(self.separator2)
             self.stream.writeln("%s" % err)
 
+    def _post_mortem(self):
+        """Start a PDB post mortem session."""
+        if os.environ.get('BZR_TEST_PDB', None):
+            import pdb;pdb.post_mortem()
+
     def progress(self, offset, whence):
         """The test is adjusting the count of tests to run."""
         if whence == SUBUNIT_SEEK_SET:
@@ -382,12 +396,12 @@
         else:
             raise errors.BzrError("Unknown whence %r" % whence)
 
-    def finished(self):
-        pass
-
     def report_cleaning_up(self):
         pass
 
+    def startTestRun(self):
+        self.startTime = time.time()
+
     def report_success(self, test):
         pass
 
@@ -420,15 +434,14 @@
         self.pb.update_latency = 0
         self.pb.show_transport_activity = False
 
-    def done(self):
+    def stopTestRun(self):
         # called when the tests that are going to run have run
         self.pb.clear()
-        super(TextTestResult, self).done()
-
-    def finished(self):
         self.pb.finished()
+        super(TextTestResult, self).stopTestRun()
 
-    def report_starting(self):
+    def startTestRun(self):
+        super(TextTestResult, self).startTestRun()
         self.pb.update('[test 0/%d] Starting' % (self.num_tests))
 
     def printErrors(self):
@@ -458,8 +471,8 @@
             a += ', %d err' % self.error_count
         if self.failure_count:
             a += ', %d fail' % self.failure_count
-        if self.unsupported:
-            a += ', %d missing' % len(self.unsupported)
+        # if self.unsupported:
+        #     a += ', %d missing' % len(self.unsupported)
         a += ']'
         return a
 
@@ -474,25 +487,25 @@
         return self._shortened_test_description(test)
 
     def report_error(self, test, err):
-        self.pb.note('ERROR: %s\n    %s\n',
+        ui.ui_factory.note('ERROR: %s\n    %s\n' % (
             self._test_description(test),
             err[1],
-            )
+            ))
 
     def report_failure(self, test, err):
-        self.pb.note('FAIL: %s\n    %s\n',
+        ui.ui_factory.note('FAIL: %s\n    %s\n' % (
             self._test_description(test),
             err[1],
-            )
+            ))
 
     def report_known_failure(self, test, err):
-        self.pb.note('XFAIL: %s\n%s\n',
-            self._test_description(test), err[1])
+        ui.ui_factory.note('XFAIL: %s\n%s\n' % (
+            self._test_description(test), err[1]))
 
     def report_skip(self, test, reason):
         pass
 
-    def report_not_applicable(self, test, skip_excinfo):
+    def report_not_applicable(self, test, reason):
         pass
 
     def report_unsupported(self, test, feature):
@@ -513,7 +526,8 @@
             result = a_string
         return result.ljust(final_width)
 
-    def report_starting(self):
+    def startTestRun(self):
+        super(VerboseTestResult, self).startTestRun()
         self.stream.write('running %d tests...\n' % self.num_tests)
 
     def report_test_start(self, test):
@@ -558,10 +572,9 @@
         self.stream.writeln(' SKIP %s\n%s'
                 % (self._testTimeString(test), reason))
 
-    def report_not_applicable(self, test, skip_excinfo):
-        self.stream.writeln('  N/A %s\n%s'
-                % (self._testTimeString(test),
-                   self._error_summary(skip_excinfo)))
+    def report_not_applicable(self, test, reason):
+        self.stream.writeln('  N/A %s\n    %s'
+                % (self._testTimeString(test), reason))
 
     def report_unsupported(self, test, feature):
         """test cannot be run because feature is missing."""
@@ -577,88 +590,57 @@
                  descriptions=0,
                  verbosity=1,
                  bench_history=None,
-                 list_only=False,
                  strict=False,
+                 result_decorators=None,
                  ):
+        """Create a TextTestRunner.
+
+        :param result_decorators: An optional list of decorators to apply
+            to the result object being used by the runner. Decorators are
+            applied left to right - the first element in the list is the 
+            innermost decorator.
+        """
         self.stream = unittest._WritelnDecorator(stream)
         self.descriptions = descriptions
         self.verbosity = verbosity
         self._bench_history = bench_history
-        self.list_only = list_only
         self._strict = strict
+        self._result_decorators = result_decorators or []
 
     def run(self, test):
         "Run the given test case or test suite."
-        startTime = time.time()
         if self.verbosity == 1:
             result_class = TextTestResult
         elif self.verbosity >= 2:
             result_class = VerboseTestResult
-        result = result_class(self.stream,
+        original_result = result_class(self.stream,
                               self.descriptions,
                               self.verbosity,
                               bench_history=self._bench_history,
                               strict=self._strict,
                               )
-        result.stop_early = self.stop_on_failure
-        result.report_starting()
-        if self.list_only:
-            if self.verbosity >= 2:
-                self.stream.writeln("Listing tests only ...\n")
-            run = 0
-            for t in iter_suite_tests(test):
-                self.stream.writeln("%s" % (t.id()))
-                run += 1
-            return None
-        else:
-            try:
-                import testtools
-            except ImportError:
-                test.run(result)
-            else:
-                if isinstance(test, testtools.ConcurrentTestSuite):
-                    # We need to catch bzr specific behaviors
-                    test.run(BZRTransformingResult(result))
-                else:
-                    test.run(result)
-            run = result.testsRun
-            actionTaken = "Ran"
-        stopTime = time.time()
-        timeTaken = stopTime - startTime
-        result.printErrors()
-        self.stream.writeln(result.separator2)
-        self.stream.writeln("%s %d test%s in %.3fs" % (actionTaken,
-                            run, run != 1 and "s" or "", timeTaken))
-        self.stream.writeln()
-        if not result.wasSuccessful():
-            self.stream.write("FAILED (")
-            failed, errored = map(len, (result.failures, result.errors))
-            if failed:
-                self.stream.write("failures=%d" % failed)
-            if errored:
-                if failed: self.stream.write(", ")
-                self.stream.write("errors=%d" % errored)
-            if result.known_failure_count:
-                if failed or errored: self.stream.write(", ")
-                self.stream.write("known_failure_count=%d" %
-                    result.known_failure_count)
-            self.stream.writeln(")")
-        else:
-            if result.known_failure_count:
-                self.stream.writeln("OK (known_failures=%d)" %
-                    result.known_failure_count)
-            else:
-                self.stream.writeln("OK")
-        if result.skip_count > 0:
-            skipped = result.skip_count
-            self.stream.writeln('%d test%s skipped' %
-                                (skipped, skipped != 1 and "s" or ""))
-        if result.unsupported:
-            for feature, count in sorted(result.unsupported.items()):
-                self.stream.writeln("Missing feature '%s' skipped %d tests." %
-                    (feature, count))
-        result.finished()
-        return result
+        # Signal to result objects that look at stop early policy to stop,
+        original_result.stop_early = self.stop_on_failure
+        result = original_result
+        for decorator in self._result_decorators:
+            result = decorator(result)
+            result.stop_early = self.stop_on_failure
+        try:
+            import testtools
+        except ImportError:
+            pass
+        else:
+            if isinstance(test, testtools.ConcurrentTestSuite):
+                # We need to catch bzr specific behaviors
+                result = BZRTransformingResult(result)
+        result.startTestRun()
+        try:
+            test.run(result)
+        finally:
+            result.stopTestRun()
+        # higher level code uses our extended protocol to determine
+        # what exit code to give.
+        return original_result
 
 
 def iter_suite_tests(suite):
@@ -700,6 +682,8 @@
 class UnavailableFeature(Exception):
     """A feature required for this test was not available.
 
+    This can be considered a specialised form of SkippedTest.
+
     The feature should be used to construct the exception.
     """
 
@@ -812,6 +796,7 @@
         self._cleanups = []
         self._bzr_test_setUp_run = False
         self._bzr_test_tearDown_run = False
+        self._directory_isolation = True
 
     def setUp(self):
         unittest.TestCase.setUp(self)
@@ -822,6 +807,7 @@
         self._benchcalls = []
         self._benchtime = None
         self._clear_hooks()
+        self._track_transports()
         self._track_locks()
         self._clear_debug_flags()
         TestCase._active_threads = threading.activeCount()
@@ -836,7 +822,13 @@
         active = threading.activeCount()
         leaked_threads = active - TestCase._active_threads
         TestCase._active_threads = active
-        if leaked_threads:
+        # If some tests make the number of threads *decrease*, we'll consider
+        # that they are just observing old threads dieing, not agressively kill
+        # random threads. So we don't report these tests as leaking. The risk
+        # is that we have false positives that way (the test see 2 threads
+        # going away but leak one) but it seems less likely than the actual
+        # false positives (the test see threads going away and does not leak).
+        if leaked_threads > 0:
             TestCase._leaking_threads_tests += 1
             if TestCase._first_thread_leaker_id is None:
                 TestCase._first_thread_leaker_id = self.id()
@@ -868,6 +860,14 @@
         # this hook should always be installed
         request._install_hook()
 
+    def disable_directory_isolation(self):
+        """Turn off directory isolation checks."""
+        self._directory_isolation = False
+
+    def enable_directory_isolation(self):
+        """Enable directory isolation checks."""
+        self._directory_isolation = True
+
     def _silenceUI(self):
         """Turn off UI for duration of test"""
         # by default the UI is off; tests can turn it on if they want it.
@@ -928,6 +928,132 @@
     def _lock_broken(self, result):
         self._lock_actions.append(('broken', result))
 
+    def permit_dir(self, name):
+        """Permit a directory to be used by this test. See permit_url."""
+        name_transport = get_transport(name)
+        self.permit_url(name)
+        self.permit_url(name_transport.base)
+
+    def permit_url(self, url):
+        """Declare that url is an ok url to use in this test.
+        
+        Do this for memory transports, temporary test directory etc.
+        
+        Do not do this for the current working directory, /tmp, or any other
+        preexisting non isolated url.
+        """
+        if not url.endswith('/'):
+            url += '/'
+        self._bzr_selftest_roots.append(url)
+
+    def permit_source_tree_branch_repo(self):
+        """Permit the source tree bzr is running from to be opened.
+
+        Some code such as bzrlib.version attempts to read from the bzr branch
+        that bzr is executing from (if any). This method permits that directory
+        to be used in the test suite.
+        """
+        path = self.get_source_path()
+        self.record_directory_isolation()
+        try:
+            try:
+                workingtree.WorkingTree.open(path)
+            except (errors.NotBranchError, errors.NoWorkingTree):
+                return
+        finally:
+            self.enable_directory_isolation()
+
+    def _preopen_isolate_transport(self, transport):
+        """Check that all transport openings are done in the test work area."""
+        while isinstance(transport, pathfilter.PathFilteringTransport):
+            # Unwrap pathfiltered transports
+            transport = transport.server.backing_transport.clone(
+                transport._filter('.'))
+        url = transport.base
+        # ReadonlySmartTCPServer_for_testing decorates the backing transport
+        # urls it is given by prepending readonly+. This is appropriate as the
+        # client shouldn't know that the server is readonly (or not readonly).
+        # We could register all servers twice, with readonly+ prepending, but
+        # that makes for a long list; this is about the same but easier to
+        # read.
+        if url.startswith('readonly+'):
+            url = url[len('readonly+'):]
+        self._preopen_isolate_url(url)
+
+    def _preopen_isolate_url(self, url):
+        if not self._directory_isolation:
+            return
+        if self._directory_isolation == 'record':
+            self._bzr_selftest_roots.append(url)
+            return
+        # This prevents all transports, including e.g. sftp ones backed on disk
+        # from working unless they are explicitly granted permission. We then
+        # depend on the code that sets up test transports to check that they are
+        # appropriately isolated and enable their use by calling
+        # self.permit_transport()
+        if not osutils.is_inside_any(self._bzr_selftest_roots, url):
+            raise errors.BzrError("Attempt to escape test isolation: %r %r"
+                % (url, self._bzr_selftest_roots))
+
+    def record_directory_isolation(self):
+        """Gather accessed directories to permit later access.
+        
+        This is used for tests that access the branch bzr is running from.
+        """
+        self._directory_isolation = "record"
+
+    def start_server(self, transport_server, backing_server=None):
+        """Start transport_server for this test.
+
+        This starts the server, registers a cleanup for it and permits the
+        server's urls to be used.
+        """
+        if backing_server is None:
+            transport_server.setUp()
+        else:
+            transport_server.setUp(backing_server)
+        self.addCleanup(transport_server.tearDown)
+        # Obtain a real transport because if the server supplies a password, it
+        # will be hidden from the base on the client side.
+        t = get_transport(transport_server.get_url())
+        # Some transport servers effectively chroot the backing transport;
+        # others like SFTPServer don't - users of the transport can walk up the
+        # transport to read the entire backing transport. This wouldn't matter
+        # except that the workdir tests are given - and that they expect the
+        # server's url to point at - is one directory under the safety net. So
+        # Branch operations into the transport will attempt to walk up one
+        # directory. Chrooting all servers would avoid this but also mean that
+        # we wouldn't be testing directly against non-root urls. Alternatively
+        # getting the test framework to start the server with a backing server
+        # at the actual safety net directory would work too, but this then
+        # means that the self.get_url/self.get_transport methods would need
+        # to transform all their results. On balance its cleaner to handle it
+        # here, and permit a higher url when we have one of these transports.
+        if t.base.endswith('/work/'):
+            # we have safety net/test root/work
+            t = t.clone('../..')
+        elif isinstance(transport_server, server.SmartTCPServer_for_testing):
+            # The smart server adds a path similar to work, which is traversed
+            # up from by the client. But the server is chrooted - the actual
+            # backing transport is not escaped from, and VFS requests to the
+            # root will error (because they try to escape the chroot).
+            t2 = t.clone('..')
+            while t2.base != t.base:
+                t = t2
+                t2 = t.clone('..')
+        self.permit_url(t.base)
+
+    def _track_transports(self):
+        """Install checks for transport usage."""
+        # TestCase has no safe place it can write to.
+        self._bzr_selftest_roots = []
+        # Currently the easiest way to be sure that nothing is going on is to
+        # hook into bzr dir opening. This leaves a small window of error for
+        # transport tests, but they are well known, and we can improve on this
+        # step.
+        bzrdir.BzrDir.hooks.install_named_hook("pre_open",
+            self._preopen_isolate_transport, "Check bzr directories are safe.")
+
     def _ndiff_strings(self, a, b):
         """Return ndiff between two strings containing lines.
 
@@ -970,9 +1096,9 @@
             return
         if message is None:
             message = "texts not equal:\n"
+        if a + '\n' == b:
+            message = 'first string is missing a final newline.\n'
         if a == b + '\n':
-            message = 'first string is missing a final newline.\n'
-        if a + '\n' == b:
             message = 'second string is missing a final newline.\n'
         raise AssertionError(message +
                              self._ndiff_strings(a, b))
@@ -989,12 +1115,23 @@
         :raises AssertionError: If the expected and actual stat values differ
             other than by atime.
         """
-        self.assertEqual(expected.st_size, actual.st_size)
-        self.assertEqual(expected.st_mtime, actual.st_mtime)
-        self.assertEqual(expected.st_ctime, actual.st_ctime)
-        self.assertEqual(expected.st_dev, actual.st_dev)
-        self.assertEqual(expected.st_ino, actual.st_ino)
-        self.assertEqual(expected.st_mode, actual.st_mode)
+        self.assertEqual(expected.st_size, actual.st_size,
+                         'st_size did not match')
+        self.assertEqual(expected.st_mtime, actual.st_mtime,
+                         'st_mtime did not match')
+        self.assertEqual(expected.st_ctime, actual.st_ctime,
+                         'st_ctime did not match')
+        if sys.platform != 'win32':
+            # On Win32 both 'dev' and 'ino' cannot be trusted. In python2.4 it
+            # is 'dev' that varies, in python 2.5 (6?) it is st_ino that is
+            # odd. Regardless we shouldn't actually try to assert anything
+            # about their values
+            self.assertEqual(expected.st_dev, actual.st_dev,
+                             'st_dev did not match')
+            self.assertEqual(expected.st_ino, actual.st_ino,
+                             'st_ino did not match')
+        self.assertEqual(expected.st_mode, actual.st_mode,
+                         'st_mode did not match')
 
     def assertLength(self, length, obj_with_len):
         """Assert that obj_with_len is of length length."""
@@ -1002,6 +1139,25 @@
             self.fail("Incorrect length: wanted %d, got %d for %r" % (
                 length, len(obj_with_len), obj_with_len))
 
+    def assertLogsError(self, exception_class, func, *args, **kwargs):
+        """Assert that func(*args, **kwargs) quietly logs a specific exception.
+        """
+        from bzrlib import trace
+        captured = []
+        orig_log_exception_quietly = trace.log_exception_quietly
+        try:
+            def capture():
+                orig_log_exception_quietly()
+                captured.append(sys.exc_info())
+            trace.log_exception_quietly = capture
+            func(*args, **kwargs)
+        finally:
+            trace.log_exception_quietly = orig_log_exception_quietly
+        self.assertLength(1, captured)
+        err = captured[0][1]
+        self.assertIsInstance(err, exception_class)
+        return err
+
     def assertPositive(self, val):
         """Assert that val is greater than 0."""
         self.assertTrue(val > 0, 'expected a positive value, but got %s' % val)
@@ -1368,6 +1524,7 @@
             'BZR_PROGRESS_BAR': None,
             'BZR_LOG': None,
             'BZR_PLUGIN_PATH': None,
+            'BZR_CONCURRENCY': None,
             # Make sure that any text ui tests are consistent regardless of
             # the environment the test case is run in; you may want tests that
             # test other combinations.  'dumb' is a reasonable guess for tests
@@ -1421,89 +1578,127 @@
     def _do_skip(self, result, reason):
         addSkip = getattr(result, 'addSkip', None)
         if not callable(addSkip):
-            result.addError(self, sys.exc_info())
+            result.addSuccess(result)
         else:
             addSkip(self, reason)
 
+    def _do_known_failure(self, result):
+        err = sys.exc_info()
+        addExpectedFailure = getattr(result, 'addExpectedFailure', None)
+        if addExpectedFailure is not None:
+            addExpectedFailure(self, err)
+        else:
+            result.addSuccess(self)
+
+    def _do_not_applicable(self, result, e):
+        if not e.args:
+            reason = 'No reason given'
+        else:
+            reason = e.args[0]
+        addNotApplicable = getattr(result, 'addNotApplicable', None)
+        if addNotApplicable is not None:
+            result.addNotApplicable(self, reason)
+        else:
+            self._do_skip(result, reason)
+
+    def _do_unsupported_or_skip(self, result, reason):
+        addNotSupported = getattr(result, 'addNotSupported', None)
+        if addNotSupported is not None:
+            result.addNotSupported(self, reason)
+        else:
+            self._do_skip(result, reason)
+
     def run(self, result=None):
         if result is None: result = self.defaultTestResult()
+        result.startTest(self)
+        try:
+            self._run(result)
+            return result
+        finally:
+            result.stopTest(self)
+
+    def _run(self, result):
         for feature in getattr(self, '_test_needs_features', []):
             if not feature.available():
-                result.startTest(self)
-                if getattr(result, 'addNotSupported', None):
-                    result.addNotSupported(self, feature)
-                else:
-                    result.addSuccess(self)
-                result.stopTest(self)
-                return result
+                return self._do_unsupported_or_skip(result, feature)
         try:
+            absent_attr = object()
+            # Python 2.5
+            method_name = getattr(self, '_testMethodName', absent_attr)
+            if method_name is absent_attr:
+                # Python 2.4
+                method_name = getattr(self, '_TestCase__testMethodName')
+            testMethod = getattr(self, method_name)
             try:
-                result.startTest(self)
-                absent_attr = object()
-                # Python 2.5
-                method_name = getattr(self, '_testMethodName', absent_attr)
-                if method_name is absent_attr:
-                    # Python 2.4
-                    method_name = getattr(self, '_TestCase__testMethodName')
-                testMethod = getattr(self, method_name)
-                try:
-                    try:
-                        self.setUp()
-                        if not self._bzr_test_setUp_run:
-                            self.fail(
-                                "test setUp did not invoke "
-                                "bzrlib.tests.TestCase's setUp")
-                    except KeyboardInterrupt:
-                        self._runCleanups()
-                        raise
-                    except TestSkipped, e:
-                        self._do_skip(result, e.args[0])
-                        self.tearDown()
-                        return result
-                    except:
-                        result.addError(self, sys.exc_info())
-                        self._runCleanups()
-                        return result
-
+                try:
+                    self.setUp()
+                    if not self._bzr_test_setUp_run:
+                        self.fail(
+                            "test setUp did not invoke "
+                            "bzrlib.tests.TestCase's setUp")
+                except KeyboardInterrupt:
+                    self._runCleanups()
+                    raise
+                except KnownFailure:
+                    self._do_known_failure(result)
+                    self.tearDown()
+                    return
+                except TestNotApplicable, e:
+                    self._do_not_applicable(result, e)
+                    self.tearDown()
+                    return
+                except TestSkipped, e:
+                    self._do_skip(result, e.args[0])
+                    self.tearDown()
+                    return result
+                except UnavailableFeature, e:
+                    self._do_unsupported_or_skip(result, e.args[0])
+                    self.tearDown()
+                    return
+                except:
+                    result.addError(self, sys.exc_info())
+                    self._runCleanups()
+                    return result
+
+                ok = False
+                try:
+                    testMethod()
+                    ok = True
+                except KnownFailure:
+                    self._do_known_failure(result)
+                except self.failureException:
+                    result.addFailure(self, sys.exc_info())
+                except TestNotApplicable, e:
+                    self._do_not_applicable(result, e)
+                except TestSkipped, e:
+                    if not e.args:
+                        reason = "No reason given."
+                    else:
+                        reason = e.args[0]
+                    self._do_skip(result, reason)
+                except UnavailableFeature, e:
+                    self._do_unsupported_or_skip(result, e.args[0])
+                except KeyboardInterrupt:
+                    self._runCleanups()
+                    raise
+                except:
+                    result.addError(self, sys.exc_info())
+
+                try:
+                    self.tearDown()
+                    if not self._bzr_test_tearDown_run:
+                        self.fail(
+                            "test tearDown did not invoke "
+                            "bzrlib.tests.TestCase's tearDown")
+                except KeyboardInterrupt:
+                    self._runCleanups()
+                    raise
+                except:
+                    result.addError(self, sys.exc_info())
+                    self._runCleanups()
                     ok = False
-                    try:
-                        testMethod()
-                        ok = True
-                    except self.failureException:
-                        result.addFailure(self, sys.exc_info())
-                    except TestSkipped, e:
-                        if not e.args:
-                            reason = "No reason given."
-                        else:
-                            reason = e.args[0]
-                        self._do_skip(result, reason)
-                    except KeyboardInterrupt:
-                        self._runCleanups()
-                        raise
-                    except:
-                        result.addError(self, sys.exc_info())
-
-                    try:
-                        self.tearDown()
-                        if not self._bzr_test_tearDown_run:
-                            self.fail(
-                                "test tearDown did not invoke "
-                                "bzrlib.tests.TestCase's tearDown")
-                    except KeyboardInterrupt:
-                        self._runCleanups()
-                        raise
-                    except:
-                        result.addError(self, sys.exc_info())
-                        self._runCleanups()
-                        ok = False
-                    if ok: result.addSuccess(self)
-                finally:
-                    result.stopTest(self)
+                if ok: result.addSuccess(self)
                 return result
-            except TestNotApplicable:
-                # Not moved from the result [yet].
-                self._runCleanups()
-                raise
             except KeyboardInterrupt:
                 self._runCleanups()
                 raise
@@ -1617,6 +1812,9 @@
 
     def _run_bzr_core(self, args, retcode, encoding, stdin,
             working_dir):
+        # Clear chk_map page cache, because the contents are likely to mask
+        # locking errors.
+        chk_map.clear_cache()
         if encoding is None:
             encoding = osutils.get_user_encoding()
         stdout = StringIOWrapper()
@@ -1639,10 +1837,22 @@
             os.chdir(working_dir)
 
         try:
-            result = self.apply_redirected(ui.ui_factory.stdin,
-                stdout, stderr,
-                bzrlib.commands.run_bzr_catch_user_errors,
-                args)
+            try:
+                result = self.apply_redirected(ui.ui_factory.stdin,
+                    stdout, stderr,
+                    bzrlib.commands.run_bzr_catch_user_errors,
+                    args)
+            except KeyboardInterrupt:
+                # Reraise KeyboardInterrupt with contents of redirected stdout
+                # and stderr as arguments, for tests which are interested in
+                # stdout and stderr and are expecting the exception.
+                out = stdout.getvalue()
+                err = stderr.getvalue()
+                if out:
+                    self.log('output:\n%r', out)
+                if err:
+                    self.log('errors:\n%r', err)
+                raise KeyboardInterrupt(out, err)
         finally:
             logger.removeHandler(handler)
             ui.ui_factory = old_ui_factory
@@ -1658,7 +1868,7 @@
         if retcode is not None:
             self.assertEquals(retcode, result,
                               message='Unexpected return code')
-        return out, err
+        return result, out, err
 
     def run_bzr(self, args, retcode=0, encoding=None, stdin=None,
                 working_dir=None, error_regexes=[], output_encoding=None):
@@ -1693,7 +1903,7 @@
         :keyword error_regexes: A list of expected error messages.  If
             specified they must be seen in the error output of the command.
         """
-        out, err = self._run_bzr_autosplit(
+        retcode, out, err = self._run_bzr_autosplit(
             args=args,
             retcode=retcode,
             encoding=encoding,
@@ -1850,9 +2060,13 @@
         """
         return Popen(*args, **kwargs)
 
+    def get_source_path(self):
+        """Return the path of the directory containing bzrlib."""
+        return os.path.dirname(os.path.dirname(bzrlib.__file__))
+
     def get_bzr_path(self):
         """Return the path of the 'bzr' executable for this test suite."""
-        bzr_path = os.path.dirname(os.path.dirname(bzrlib.__file__))+'/bzr'
+        bzr_path = self.get_source_path()+'/bzr'
         if not os.path.isfile(bzr_path):
             # We are probably installed. Assume sys.argv is the right file
             bzr_path = sys.argv[0]
@@ -2067,13 +2281,12 @@
         if self.__readonly_server is None:
             if self.transport_readonly_server is None:
                 # readonly decorator requested
-                # bring up the server
                 self.__readonly_server = ReadonlyServer()
-                self.__readonly_server.setUp(self.get_vfs_only_server())
             else:
+                # explicit readonly transport.
                 self.__readonly_server = self.create_transport_readonly_server()
-                self.__readonly_server.setUp(self.get_vfs_only_server())
-            self.addCleanup(self.__readonly_server.tearDown)
+            self.start_server(self.__readonly_server,
+                self.get_vfs_only_server())
         return self.__readonly_server
 
     def get_readonly_url(self, relpath=None):
@@ -2098,8 +2311,7 @@
         """
         if self.__vfs_server is None:
             self.__vfs_server = MemoryServer()
-            self.__vfs_server.setUp()
-            self.addCleanup(self.__vfs_server.tearDown)
+            self.start_server(self.__vfs_server)
         return self.__vfs_server
 
     def get_server(self):
@@ -2112,19 +2324,13 @@
         then the self.get_vfs_server is returned.
         """
         if self.__server is None:
-            if self.transport_server is None or self.transport_server is self.vfs_transport_factory:
-                return self.get_vfs_only_server()
+            if (self.transport_server is None or self.transport_server is
+                self.vfs_transport_factory):
+                self.__server = self.get_vfs_only_server()
             else:
                 # bring up a decorated means of access to the vfs only server.
                 self.__server = self.transport_server()
-                try:
-                    self.__server.setUp(self.get_vfs_only_server())
-                except TypeError, e:
-                    # This should never happen; the try:Except here is to assist
-                    # developers having to update code rather than seeing an
-                    # uninformative TypeError.
-                    raise Exception, "Old server API in use: %s, %s" % (self.__server, e)
-            self.addCleanup(self.__server.tearDown)
+                self.start_server(self.__server, self.get_vfs_only_server())
         return self.__server
 
     def _adjust_url(self, base, relpath):
@@ -2192,6 +2398,7 @@
         propagating. This method ensures than a test did not leaked.
         """
         root = TestCaseWithMemoryTransport.TEST_ROOT
+        self.permit_url(get_transport(root).base)
         wt = workingtree.WorkingTree.open(root)
         last_rev = wt.last_revision()
         if last_rev != 'null:':
@@ -2199,13 +2406,15 @@
             # recreate a new one or all the followng tests will fail.
             # If you need to inspect its content uncomment the following line
             # import pdb; pdb.set_trace()
-            _rmtree_temp_dir(root + '/.bzr')
+            _rmtree_temp_dir(root + '/.bzr', test_id=self.id())
             self._create_safety_net()
             raise AssertionError('%s/.bzr should not be modified' % root)
 
     def _make_test_root(self):
         if TestCaseWithMemoryTransport.TEST_ROOT is None:
-            root = osutils.mkdtemp(prefix='testbzr-', suffix='.tmp')
+            # Watch out for tricky test dir (on OSX /tmp -> /private/tmp)
+            root = osutils.realpath(osutils.mkdtemp(prefix='testbzr-',
+                                                    suffix='.tmp'))
             TestCaseWithMemoryTransport.TEST_ROOT = root
 
             self._create_safety_net()
@@ -2214,6 +2423,7 @@
             # specifically told when all tests are finished.  This will do.
             atexit.register(_rmtree_temp_dir, root)
 
+        self.permit_dir(TestCaseWithMemoryTransport.TEST_ROOT)
         self.addCleanup(self._check_safety_net)
 
     def makeAndChdirToTestDir(self):
@@ -2227,6 +2437,7 @@
         os.chdir(TestCaseWithMemoryTransport.TEST_ROOT)
         self.test_dir = TestCaseWithMemoryTransport.TEST_ROOT
         self.test_home_dir = self.test_dir + "/MemoryTransportMissingHomeDir"
+        self.permit_dir(self.test_dir)
 
     def make_branch(self, relpath, format=None):
         """Create a branch on the transport at relpath."""
@@ -2263,9 +2474,8 @@
 
     def make_smart_server(self, path):
         smart_server = server.SmartTCPServer_for_testing()
-        smart_server.setUp(self.get_server())
+        self.start_server(smart_server, self.get_server())
         remote_transport = get_transport(smart_server.get_url()).clone(path)
-        self.addCleanup(smart_server.tearDown)
         return remote_transport
 
     def make_branch_and_memory_tree(self, relpath, format=None):
@@ -2278,8 +2488,11 @@
         return branchbuilder.BranchBuilder(branch=branch)
 
     def overrideEnvironmentForTesting(self):
-        os.environ['HOME'] = self.test_home_dir
-        os.environ['BZR_HOME'] = self.test_home_dir
+        test_home_dir = self.test_home_dir
+        if isinstance(test_home_dir, unicode):
+            test_home_dir = test_home_dir.encode(sys.getfilesystemencoding())
+        os.environ['HOME'] = test_home_dir
+        os.environ['BZR_HOME'] = test_home_dir
 
     def setUp(self):
         super(TestCaseWithMemoryTransport, self).setUp()
@@ -2365,10 +2578,18 @@
             if os.path.exists(name):
                 name = name_prefix + '_' + str(i)
             else:
-                os.mkdir(name)
+                # now create test and home directories within this dir
+                self.test_base_dir = name
+                self.addCleanup(self.deleteTestDir)
+                os.mkdir(self.test_base_dir)
                 break
-        # now create test and home directories within this dir
-        self.test_base_dir = name
+        self.permit_dir(self.test_base_dir)
+        # 'sprouting' and 'init' of a branch both walk up the tree to find
+        # stacking policy to honour; create a bzr dir with an unshared
+        # repository (but not a branch - our code would be trying to escape
+        # then!) to stop them, and permit it to be read.
+        # control = bzrdir.BzrDir.create(self.test_base_dir)
+        # control.create_repository()
         self.test_home_dir = self.test_base_dir + '/home'
         os.mkdir(self.test_home_dir)
         self.test_dir = self.test_base_dir + '/work'
@@ -2380,11 +2601,10 @@
             f.write(self.id())
         finally:
             f.close()
-        self.addCleanup(self.deleteTestDir)
 
     def deleteTestDir(self):
         os.chdir(TestCaseWithMemoryTransport.TEST_ROOT)
-        _rmtree_temp_dir(self.test_base_dir)
+        _rmtree_temp_dir(self.test_base_dir, test_id=self.id())
 
     def build_tree(self, shape, line_endings='binary', transport=None):
         """Build a test tree according to a pattern.
@@ -2472,8 +2692,7 @@
         """
         if self.__vfs_server is None:
             self.__vfs_server = self.vfs_transport_factory()
-            self.__vfs_server.setUp()
-            self.addCleanup(self.__vfs_server.tearDown)
+            self.start_server(self.__vfs_server)
         return self.__vfs_server
 
     def make_branch_and_tree(self, relpath, format=None):
@@ -2486,6 +2705,15 @@
         repository will also be accessed locally. Otherwise a lightweight
         checkout is created and returned.
 
+        We do this because we can't physically create a tree in the local
+        path, with a branch reference to the transport_factory url, and
+        a branch + repository in the vfs_transport, unless the vfs_transport
+        namespace is distinct from the local disk - the two branch objects
+        would collide. While we could construct a tree with its branch object
+        pointing at the transport_factory transport in memory, reopening it
+        would behaving unexpectedly, and has in the past caused testing bugs
+        when we tried to do it that way.
+
         :param format: The BzrDirFormat.
         :returns: the WorkingTree.
         """
@@ -2543,6 +2771,14 @@
         super(TestCaseWithTransport, self).setUp()
         self.__vfs_server = None
 
+    def disable_missing_extensions_warning(self):
+        """Some tests expect a precise stderr content.
+
+        There is no point in forcing them to duplicate the extension related
+        warning.
+        """
+        config.GlobalConfig().set_user_option('ignore_missing_extensions', True)
+
 
 class ChrootedTestCase(TestCaseWithTransport):
     """A support class that provides readonly urls outside the local namespace.
@@ -2762,7 +2998,9 @@
               strict=False,
               runner_class=None,
               suite_decorators=None,
-              stream=None):
+              stream=None,
+              result_decorators=None,
+              ):
     """Run a test suite for bzr selftest.
 
     :param runner_class: The class of runner to use. Must support the
@@ -2783,8 +3021,8 @@
                             descriptions=0,
                             verbosity=verbosity,
                             bench_history=bench_history,
-                            list_only=list_only,
                             strict=strict,
+                            result_decorators=result_decorators,
                             )
     runner.stop_on_failure=stop_on_failure
     # built in decorator factories:
@@ -2805,10 +3043,15 @@
         decorators.append(CountingDecorator)
     for decorator in decorators:
         suite = decorator(suite)
+    if list_only:
+        # Done after test suite decoration to allow randomisation etc
+        # to take effect, though that is of marginal benefit.
+        if verbosity >= 2:
+            stream.write("Listing tests only ...\n")
+        for t in iter_suite_tests(suite):
+            stream.write("%s\n" % (t.id()))
+        return True
     result = runner.run(suite)
-    if list_only:
-        return True
-    result.done()
     if strict:
         return result.wasStrictlySuccessful()
     else:
@@ -3034,10 +3277,6 @@
     concurrency = osutils.local_concurrency()
     result = []
     from subunit import TestProtocolClient, ProtocolTestCase
-    try:
-        from subunit.test_results import AutoTimingTestResultDecorator
-    except ImportError:
-        AutoTimingTestResultDecorator = lambda x:x
     class TestInOtherProcess(ProtocolTestCase):
         # Should be in subunit, I think. RBC.
         def __init__(self, stream, pid):
@@ -3066,7 +3305,7 @@
                 sys.stdin.close()
                 sys.stdin = None
                 stream = os.fdopen(c2pwrite, 'wb', 1)
-                subunit_result = AutoTimingTestResultDecorator(
+                subunit_result = BzrAutoTimingTestResultDecorator(
                     TestProtocolClient(stream))
                 process_suite.run(subunit_result)
             finally:
@@ -3109,13 +3348,17 @@
         if not os.path.isfile(bzr_path):
             # We are probably installed. Assume sys.argv is the right file
             bzr_path = sys.argv[0]
+        bzr_path = [bzr_path]
+        if sys.platform == "win32":
+            # if we're on windows, we can't execute the bzr script directly
+            bzr_path = [sys.executable] + bzr_path
         fd, test_list_file_name = tempfile.mkstemp()
         test_list_file = os.fdopen(fd, 'wb', 1)
         for test in process_tests:
             test_list_file.write(test.id() + '\n')
         test_list_file.close()
         try:
-            argv = [bzr_path, 'selftest', '--load-list', test_list_file_name,
+            argv = bzr_path + ['selftest', '--load-list', test_list_file_name,
                 '--subunit']
             if '--no-plugins' in sys.argv:
                 argv.append('--no-plugins')
@@ -3131,7 +3374,7 @@
     return result
 
 
-class BZRTransformingResult(unittest.TestResult):
+class ForwardingResult(unittest.TestResult):
 
     def __init__(self, target):
         unittest.TestResult.__init__(self)
@@ -3143,6 +3386,27 @@
     def stopTest(self, test):
         self.result.stopTest(test)
 
+    def startTestRun(self):
+        self.result.startTestRun()
+
+    def stopTestRun(self):
+        self.result.stopTestRun()
+
+    def addSkip(self, test, reason):
+        self.result.addSkip(test, reason)
+
+    def addSuccess(self, test):
+        self.result.addSuccess(test)
+
+    def addError(self, test, err):
+        self.result.addError(test, err)
+
+    def addFailure(self, test, err):
+        self.result.addFailure(test, err)
+
+
+class BZRTransformingResult(ForwardingResult):
+
     def addError(self, test, err):
         feature = self._error_looks_like('UnavailableFeature: ', err)
         if feature is not None:
@@ -3153,17 +3417,11 @@
     def addFailure(self, test, err):
         known = self._error_looks_like('KnownFailure: ', err)
         if known is not None:
-            self.result._addKnownFailure(test, [KnownFailure,
-                                                KnownFailure(known), None])
+            self.result.addExpectedFailure(test,
+                [KnownFailure, KnownFailure(known), None])
         else:
             self.result.addFailure(test, err)
 
-    def addSkip(self, test, reason):
-        self.result.addSkip(test, reason)
-
-    def addSuccess(self, test):
-        self.result.addSuccess(test)
-
     def _error_looks_like(self, prefix, err):
         """Deserialize exception and returns the stringify value."""
         import subunit
@@ -3181,6 +3439,54 @@
         return value
 
 
+try:
+    from subunit.test_results import AutoTimingTestResultDecorator
+    # Expected failure should be seen as a success not a failure Once subunit
+    # provide native support for that, BZRTransformingResult and this class
+    # will become useless.
+    class BzrAutoTimingTestResultDecorator(AutoTimingTestResultDecorator):
+
+        def addExpectedFailure(self, test, err):
+            self._before_event()
+            return self._call_maybe("addExpectedFailure", self._degrade_skip,
+                                    test, err)
+except ImportError:
+    # Let's just define a no-op decorator
+    BzrAutoTimingTestResultDecorator = lambda x:x
+
+
+class ProfileResult(ForwardingResult):
+    """Generate profiling data for all activity between start and success.
+    
+    The profile data is appended to the test's _benchcalls attribute and can
+    be accessed by the forwarded-to TestResult.
+
+    While it might be cleaner do accumulate this in stopTest, addSuccess is
+    where our existing output support for lsprof is, and this class aims to
+    fit in with that: while it could be moved it's not necessary to accomplish
+    test profiling, nor would it be dramatically cleaner.
+    """
+
+    def startTest(self, test):
+        self.profiler = bzrlib.lsprof.BzrProfiler()
+        self.profiler.start()
+        ForwardingResult.startTest(self, test)
+
+    def addSuccess(self, test):
+        stats = self.profiler.stop()
+        try:
+            calls = test._benchcalls
+        except AttributeError:
+            test._benchcalls = []
+            calls = test._benchcalls
+        calls.append(((test.id(), "", ""), stats))
+        ForwardingResult.addSuccess(self, test)
+
+    def stopTest(self, test):
+        ForwardingResult.stopTest(self, test)
+        self.profiler = None
+
+
 # Controlled by "bzr selftest -E=..." option
 # Currently supported:
 #   -Eallow_debug           Will no longer clear debug.debug_flags() so it
@@ -3208,6 +3514,7 @@
              runner_class=None,
              suite_decorators=None,
              stream=None,
+             lsprof_tests=False,
              ):
     """Run the whole test suite under the enhanced runner"""
     # XXX: Very ugly way to do this...
@@ -3242,6 +3549,9 @@
         if starting_with:
             # But always filter as requested.
             suite = filter_suite_by_id_startswith(suite, starting_with)
+        result_decorators = []
+        if lsprof_tests:
+            result_decorators.append(ProfileResult)
         return run_suite(suite, 'testbzr', verbose=verbose, pattern=pattern,
                      stop_on_failure=stop_on_failure,
                      transport=transport,
@@ -3255,6 +3565,7 @@
                      runner_class=runner_class,
                      suite_decorators=suite_decorators,
                      stream=stream,
+                     result_decorators=result_decorators,
                      )
     finally:
         default_transport = old_transport
@@ -3416,6 +3727,212 @@
 test_prefix_alias_registry.register('bp', 'bzrlib.plugins')
 
 
+def _test_suite_testmod_names():
+    """Return the standard list of test module names to test."""
+    return [
+        'bzrlib.doc',
+        'bzrlib.tests.blackbox',
+        'bzrlib.tests.commands',
+        'bzrlib.tests.per_branch',
+        'bzrlib.tests.per_bzrdir',
+        'bzrlib.tests.per_foreign_vcs',
+        'bzrlib.tests.per_interrepository',
+        'bzrlib.tests.per_intertree',
+        'bzrlib.tests.per_inventory',
+        'bzrlib.tests.per_interbranch',
+        'bzrlib.tests.per_lock',
+        'bzrlib.tests.per_transport',
+        'bzrlib.tests.per_tree',
+        'bzrlib.tests.per_pack_repository',
+        'bzrlib.tests.per_repository',
+        'bzrlib.tests.per_repository_chk',
+        'bzrlib.tests.per_repository_reference',
+        'bzrlib.tests.per_uifactory',
+        'bzrlib.tests.per_versionedfile',
+        'bzrlib.tests.per_workingtree',
+        'bzrlib.tests.test__annotator',
+        'bzrlib.tests.test__chk_map',
+        'bzrlib.tests.test__dirstate_helpers',
+        'bzrlib.tests.test__groupcompress',
+        'bzrlib.tests.test__known_graph',
+        'bzrlib.tests.test__rio',
+        'bzrlib.tests.test__simple_set',
+        'bzrlib.tests.test__static_tuple',
+        'bzrlib.tests.test__walkdirs_win32',
+        'bzrlib.tests.test_ancestry',
+        'bzrlib.tests.test_annotate',
+        'bzrlib.tests.test_api',
+        'bzrlib.tests.test_atomicfile',
+        'bzrlib.tests.test_bad_files',
+        'bzrlib.tests.test_bencode',
+        'bzrlib.tests.test_bisect_multi',
+        'bzrlib.tests.test_branch',
+        'bzrlib.tests.test_branchbuilder',
+        'bzrlib.tests.test_btree_index',
+        'bzrlib.tests.test_bugtracker',
+        'bzrlib.tests.test_bundle',
+        'bzrlib.tests.test_bzrdir',
+        'bzrlib.tests.test__chunks_to_lines',
+        'bzrlib.tests.test_cache_utf8',
+        'bzrlib.tests.test_chk_map',
+        'bzrlib.tests.test_chk_serializer',
+        'bzrlib.tests.test_chunk_writer',
+        'bzrlib.tests.test_clean_tree',
+        'bzrlib.tests.test_cleanup',
+        'bzrlib.tests.test_commands',
+        'bzrlib.tests.test_commit',
+        'bzrlib.tests.test_commit_merge',
+        'bzrlib.tests.test_config',
+        'bzrlib.tests.test_conflicts',
+        'bzrlib.tests.test_counted_lock',
+        'bzrlib.tests.test_crash',
+        'bzrlib.tests.test_decorators',
+        'bzrlib.tests.test_delta',
+        'bzrlib.tests.test_debug',
+        'bzrlib.tests.test_deprecated_graph',
+        'bzrlib.tests.test_diff',
+        'bzrlib.tests.test_directory_service',
+        'bzrlib.tests.test_dirstate',
+        'bzrlib.tests.test_email_message',
+        'bzrlib.tests.test_eol_filters',
+        'bzrlib.tests.test_errors',
+        'bzrlib.tests.test_export',
+        'bzrlib.tests.test_extract',
+        'bzrlib.tests.test_fetch',
+        'bzrlib.tests.test_fifo_cache',
+        'bzrlib.tests.test_filters',
+        'bzrlib.tests.test_ftp_transport',
+        'bzrlib.tests.test_foreign',
+        'bzrlib.tests.test_generate_docs',
+        'bzrlib.tests.test_generate_ids',
+        'bzrlib.tests.test_globbing',
+        'bzrlib.tests.test_gpg',
+        'bzrlib.tests.test_graph',
+        'bzrlib.tests.test_groupcompress',
+        'bzrlib.tests.test_hashcache',
+        'bzrlib.tests.test_help',
+        'bzrlib.tests.test_hooks',
+        'bzrlib.tests.test_http',
+        'bzrlib.tests.test_http_response',
+        'bzrlib.tests.test_https_ca_bundle',
+        'bzrlib.tests.test_identitymap',
+        'bzrlib.tests.test_ignores',
+        'bzrlib.tests.test_index',
+        'bzrlib.tests.test_info',
+        'bzrlib.tests.test_inv',
+        'bzrlib.tests.test_inventory_delta',
+        'bzrlib.tests.test_knit',
+        'bzrlib.tests.test_lazy_import',
+        'bzrlib.tests.test_lazy_regex',
+        'bzrlib.tests.test_lock',
+        'bzrlib.tests.test_lockable_files',
+        'bzrlib.tests.test_lockdir',
+        'bzrlib.tests.test_log',
+        'bzrlib.tests.test_lru_cache',
+        'bzrlib.tests.test_lsprof',
+        'bzrlib.tests.test_mail_client',
+        'bzrlib.tests.test_memorytree',
+        'bzrlib.tests.test_merge',
+        'bzrlib.tests.test_merge3',
+        'bzrlib.tests.test_merge_core',
+        'bzrlib.tests.test_merge_directive',
+        'bzrlib.tests.test_missing',
+        'bzrlib.tests.test_msgeditor',
+        'bzrlib.tests.test_multiparent',
+        'bzrlib.tests.test_mutabletree',
+        'bzrlib.tests.test_nonascii',
+        'bzrlib.tests.test_options',
+        'bzrlib.tests.test_osutils',
+        'bzrlib.tests.test_osutils_encodings',
+        'bzrlib.tests.test_pack',
+        'bzrlib.tests.test_patch',
+        'bzrlib.tests.test_patches',
+        'bzrlib.tests.test_permissions',
+        'bzrlib.tests.test_plugins',
+        'bzrlib.tests.test_progress',
+        'bzrlib.tests.test_read_bundle',
+        'bzrlib.tests.test_reconcile',
+        'bzrlib.tests.test_reconfigure',
+        'bzrlib.tests.test_registry',
+        'bzrlib.tests.test_remote',
+        'bzrlib.tests.test_rename_map',
+        'bzrlib.tests.test_repository',
+        'bzrlib.tests.test_revert',
+        'bzrlib.tests.test_revision',
+        'bzrlib.tests.test_revisionspec',
+        'bzrlib.tests.test_revisiontree',
+        'bzrlib.tests.test_rio',
+        'bzrlib.tests.test_rules',
+        'bzrlib.tests.test_sampler',
+        'bzrlib.tests.test_script',
+        'bzrlib.tests.test_selftest',
+        'bzrlib.tests.test_serializer',
+        'bzrlib.tests.test_setup',
+        'bzrlib.tests.test_sftp_transport',
+        'bzrlib.tests.test_shelf',
+        'bzrlib.tests.test_shelf_ui',
+        'bzrlib.tests.test_smart',
+        'bzrlib.tests.test_smart_add',
+        'bzrlib.tests.test_smart_request',
+        'bzrlib.tests.test_smart_transport',
+        'bzrlib.tests.test_smtp_connection',
+        'bzrlib.tests.test_source',
+        'bzrlib.tests.test_ssh_transport',
+        'bzrlib.tests.test_status',
+        'bzrlib.tests.test_store',
+        'bzrlib.tests.test_strace',
+        'bzrlib.tests.test_subsume',
+        'bzrlib.tests.test_switch',
+        'bzrlib.tests.test_symbol_versioning',
+        'bzrlib.tests.test_tag',
+        'bzrlib.tests.test_testament',
+        'bzrlib.tests.test_textfile',
+        'bzrlib.tests.test_textmerge',
+        'bzrlib.tests.test_timestamp',
+        'bzrlib.tests.test_trace',
+        'bzrlib.tests.test_transactions',
+        'bzrlib.tests.test_transform',
+        'bzrlib.tests.test_transport',
+        'bzrlib.tests.test_transport_log',
+        'bzrlib.tests.test_tree',
+        'bzrlib.tests.test_treebuilder',
+        'bzrlib.tests.test_tsort',
+        'bzrlib.tests.test_tuned_gzip',
+        'bzrlib.tests.test_ui',
+        'bzrlib.tests.test_uncommit',
+        'bzrlib.tests.test_upgrade',
+        'bzrlib.tests.test_upgrade_stacked',
+        'bzrlib.tests.test_urlutils',
+        'bzrlib.tests.test_version',
+        'bzrlib.tests.test_version_info',
+        'bzrlib.tests.test_weave',
+        'bzrlib.tests.test_whitebox',
+        'bzrlib.tests.test_win32utils',
+        'bzrlib.tests.test_workingtree',
+        'bzrlib.tests.test_workingtree_4',
+        'bzrlib.tests.test_wsgi',
+        'bzrlib.tests.test_xml',
+        ]
+
+
+def _test_suite_modules_to_doctest():
+    """Return the list of modules to doctest."""   
+    return [
+        'bzrlib',
+        'bzrlib.branchbuilder',
+        'bzrlib.export',
+        'bzrlib.inventory',
+        'bzrlib.iterablefile',
+        'bzrlib.lockdir',
+        'bzrlib.merge3',
+        'bzrlib.option',
+        'bzrlib.symbol_versioning',
+        'bzrlib.tests',
+        'bzrlib.timestamp',
+        'bzrlib.version_info_formats.format_custom',
+        ]
+
+
 def test_suite(keep_only=None, starting_with=None):
     """Build and return TestSuite for the whole of bzrlib.
 
@@ -3427,184 +3944,6 @@
     This function can be replaced if you need to change the default test
     suite on a global basis, but it is not encouraged.
     """
-    testmod_names = [
-                   'bzrlib.doc',
-                   'bzrlib.tests.blackbox',
-                   'bzrlib.tests.commands',
-                   'bzrlib.tests.per_branch',
-                   'bzrlib.tests.per_bzrdir',
-                   'bzrlib.tests.per_interrepository',
-                   'bzrlib.tests.per_intertree',
-                   'bzrlib.tests.per_inventory',
-                   'bzrlib.tests.per_interbranch',
-                   'bzrlib.tests.per_lock',
-                   'bzrlib.tests.per_transport',
-                   'bzrlib.tests.per_tree',
-                   'bzrlib.tests.per_pack_repository',
-                   'bzrlib.tests.per_repository',
-                   'bzrlib.tests.per_repository_chk',
-                   'bzrlib.tests.per_repository_reference',
-                   'bzrlib.tests.per_versionedfile',
-                   'bzrlib.tests.per_workingtree',
-                   'bzrlib.tests.test__annotator',
-                   'bzrlib.tests.test__chk_map',
-                   'bzrlib.tests.test__dirstate_helpers',
-                   'bzrlib.tests.test__groupcompress',
-                   'bzrlib.tests.test__known_graph',
-                   'bzrlib.tests.test__rio',
-                   'bzrlib.tests.test__walkdirs_win32',
-                   'bzrlib.tests.test_ancestry',
-                   'bzrlib.tests.test_annotate',
-                   'bzrlib.tests.test_api',
-                   'bzrlib.tests.test_atomicfile',
-                   'bzrlib.tests.test_bad_files',
-                   'bzrlib.tests.test_bencode',
-                   'bzrlib.tests.test_bisect_multi',
-                   'bzrlib.tests.test_branch',
-                   'bzrlib.tests.test_branchbuilder',
-                   'bzrlib.tests.test_btree_index',
-                   'bzrlib.tests.test_bugtracker',
-                   'bzrlib.tests.test_bundle',
-                   'bzrlib.tests.test_bzrdir',
-                   'bzrlib.tests.test__chunks_to_lines',
-                   'bzrlib.tests.test_cache_utf8',
-                   'bzrlib.tests.test_chk_map',
-                   'bzrlib.tests.test_chk_serializer',
-                   'bzrlib.tests.test_chunk_writer',
-                   'bzrlib.tests.test_clean_tree',
-                   'bzrlib.tests.test_commands',
-                   'bzrlib.tests.test_commit',
-                   'bzrlib.tests.test_commit_merge',
-                   'bzrlib.tests.test_config',
-                   'bzrlib.tests.test_conflicts',
-                   'bzrlib.tests.test_counted_lock',
-                   'bzrlib.tests.test_crash',
-                   'bzrlib.tests.test_decorators',
-                   'bzrlib.tests.test_delta',
-                   'bzrlib.tests.test_debug',
-                   'bzrlib.tests.test_deprecated_graph',
-                   'bzrlib.tests.test_diff',
-                   'bzrlib.tests.test_directory_service',
-                   'bzrlib.tests.test_dirstate',
-                   'bzrlib.tests.test_email_message',
-                   'bzrlib.tests.test_eol_filters',
-                   'bzrlib.tests.test_errors',
-                   'bzrlib.tests.test_export',
-                   'bzrlib.tests.test_extract',
-                   'bzrlib.tests.test_fetch',
-                   'bzrlib.tests.test_fifo_cache',
-                   'bzrlib.tests.test_filters',
-                   'bzrlib.tests.test_ftp_transport',
-                   'bzrlib.tests.test_foreign',
-                   'bzrlib.tests.test_generate_docs',
-                   'bzrlib.tests.test_generate_ids',
-                   'bzrlib.tests.test_globbing',
-                   'bzrlib.tests.test_gpg',
-                   'bzrlib.tests.test_graph',
-                   'bzrlib.tests.test_groupcompress',
-                   'bzrlib.tests.test_hashcache',
-                   'bzrlib.tests.test_help',
-                   'bzrlib.tests.test_hooks',
-                   'bzrlib.tests.test_http',
-                   'bzrlib.tests.test_http_response',
-                   'bzrlib.tests.test_https_ca_bundle',
-                   'bzrlib.tests.test_identitymap',
-                   'bzrlib.tests.test_ignores',
-                   'bzrlib.tests.test_index',
-                   'bzrlib.tests.test_info',
-                   'bzrlib.tests.test_inv',
-                   'bzrlib.tests.test_inventory_delta',
-                   'bzrlib.tests.test_knit',
-                   'bzrlib.tests.test_lazy_import',
-                   'bzrlib.tests.test_lazy_regex',
-                   'bzrlib.tests.test_lock',
-                   'bzrlib.tests.test_lockable_files',
-                   'bzrlib.tests.test_lockdir',
-                   'bzrlib.tests.test_log',
-                   'bzrlib.tests.test_lru_cache',
-                   'bzrlib.tests.test_lsprof',
-                   'bzrlib.tests.test_mail_client',
-                   'bzrlib.tests.test_memorytree',
-                   'bzrlib.tests.test_merge',
-                   'bzrlib.tests.test_merge3',
-                   'bzrlib.tests.test_merge_core',
-                   'bzrlib.tests.test_merge_directive',
-                   'bzrlib.tests.test_missing',
-                   'bzrlib.tests.test_msgeditor',
-                   'bzrlib.tests.test_multiparent',
-                   'bzrlib.tests.test_mutabletree',
-                   'bzrlib.tests.test_nonascii',
-                   'bzrlib.tests.test_options',
-                   'bzrlib.tests.test_osutils',
-                   'bzrlib.tests.test_osutils_encodings',
-                   'bzrlib.tests.test_pack',
-                   'bzrlib.tests.test_patch',
-                   'bzrlib.tests.test_patches',
-                   'bzrlib.tests.test_permissions',
-                   'bzrlib.tests.test_plugins',
-                   'bzrlib.tests.test_progress',
-                   'bzrlib.tests.test_read_bundle',
-                   'bzrlib.tests.test_reconcile',
-                   'bzrlib.tests.test_reconfigure',
-                   'bzrlib.tests.test_registry',
-                   'bzrlib.tests.test_remote',
-                   'bzrlib.tests.test_rename_map',
-                   'bzrlib.tests.test_repository',
-                   'bzrlib.tests.test_revert',
-                   'bzrlib.tests.test_revision',
-                   'bzrlib.tests.test_revisionspec',
-                   'bzrlib.tests.test_revisiontree',
-                   'bzrlib.tests.test_rio',
-                   'bzrlib.tests.test_rules',
-                   'bzrlib.tests.test_sampler',
-                   'bzrlib.tests.test_selftest',
-                   'bzrlib.tests.test_serializer',
-                   'bzrlib.tests.test_setup',
-                   'bzrlib.tests.test_sftp_transport',
-                   'bzrlib.tests.test_shelf',
-                   'bzrlib.tests.test_shelf_ui',
-                   'bzrlib.tests.test_smart',
-                   'bzrlib.tests.test_smart_add',
-                   'bzrlib.tests.test_smart_request',
-                   'bzrlib.tests.test_smart_transport',
-                   'bzrlib.tests.test_smtp_connection',
-                   'bzrlib.tests.test_source',
-                   'bzrlib.tests.test_ssh_transport',
-                   'bzrlib.tests.test_status',
-                   'bzrlib.tests.test_store',
-                   'bzrlib.tests.test_strace',
-                   'bzrlib.tests.test_subsume',
-                   'bzrlib.tests.test_switch',
-                   'bzrlib.tests.test_symbol_versioning',
-                   'bzrlib.tests.test_tag',
-                   'bzrlib.tests.test_testament',
-                   'bzrlib.tests.test_textfile',
-                   'bzrlib.tests.test_textmerge',
-                   'bzrlib.tests.test_timestamp',
-                   'bzrlib.tests.test_trace',
-                   'bzrlib.tests.test_transactions',
-                   'bzrlib.tests.test_transform',
-                   'bzrlib.tests.test_transport',
-                   'bzrlib.tests.test_transport_log',
-                   'bzrlib.tests.test_tree',
-                   'bzrlib.tests.test_treebuilder',
-                   'bzrlib.tests.test_tsort',
-                   'bzrlib.tests.test_tuned_gzip',
-                   'bzrlib.tests.test_ui',
-                   'bzrlib.tests.test_uncommit',
-                   'bzrlib.tests.test_upgrade',
-                   'bzrlib.tests.test_upgrade_stacked',
-                   'bzrlib.tests.test_urlutils',
-                   'bzrlib.tests.test_version',
-                   'bzrlib.tests.test_version_info',
-                   'bzrlib.tests.test_weave',
-                   'bzrlib.tests.test_whitebox',
-                   'bzrlib.tests.test_win32utils',
-                   'bzrlib.tests.test_workingtree',
-                   'bzrlib.tests.test_workingtree_4',
-                   'bzrlib.tests.test_wsgi',
-                   'bzrlib.tests.test_xml',
-                   ]
 
     loader = TestUtil.TestLoader()
 
@@ -3639,24 +3978,9 @@
     suite = loader.suiteClass()
 
     # modules building their suite with loadTestsFromModuleNames
-    suite.addTest(loader.loadTestsFromModuleNames(testmod_names))
-
-    modules_to_doctest = [
-        'bzrlib',
-        'bzrlib.branchbuilder',
-        'bzrlib.export',
-        'bzrlib.inventory',
-        'bzrlib.iterablefile',
-        'bzrlib.lockdir',
-        'bzrlib.merge3',
-        'bzrlib.option',
-        'bzrlib.symbol_versioning',
-        'bzrlib.tests',
-        'bzrlib.timestamp',
-        'bzrlib.version_info_formats.format_custom',
-        ]
-
-    for mod in modules_to_doctest:
+    suite.addTest(loader.loadTestsFromModuleNames(_test_suite_testmod_names()))
+
+    for mod in _test_suite_modules_to_doctest():
         if not interesting_module(mod):
             # No tests to keep here, move along
             continue
@@ -3803,13 +4127,12 @@
     :param new_id: The id to assign to it.
     :return: The new test.
     """
-    from copy import deepcopy
-    new_test = deepcopy(test)
+    new_test = copy(test)
     new_test.id = lambda: new_id
     return new_test
 
 
-def _rmtree_temp_dir(dirname):
+def _rmtree_temp_dir(dirname, test_id=None):
     # If LANG=C we probably have created some bogus paths
     # which rmtree(unicode) will fail to delete
     # so make sure we are using rmtree(str) to delete everything
@@ -3827,6 +4150,9 @@
         # We don't want to fail here because some useful display will be lost
         # otherwise. Polluting the tmp dir is bad, but not giving all the
         # possible info to the test runner is even worse.
+        if test_id != None:
+            ui.ui_factory.clear_term()
+            sys.stderr.write('While running: %s\n' % (test_id,))
         sys.stderr.write('Unable to remove testing dir %s\n%s'
                          % (os.path.basename(dirname), e))
 
@@ -3970,6 +4296,23 @@
 HTTPSServerFeature = _HTTPSServerFeature()
 
 
+class _ParamikoFeature(Feature):
+    """Is paramiko available?"""
+
+    def _probe(self):
+        try:
+            from bzrlib.transport.sftp import SFTPAbsoluteServer
+            return True
+        except errors.ParamikoNotPresent:
+            return False
+
+    def feature_name(self):
+        return "Paramiko"
+
+
+ParamikoFeature = _ParamikoFeature()
+
+
 class _UnicodeFilename(Feature):
     """Does the filesystem support Unicode filenames?"""
 
@@ -4001,6 +4344,30 @@
 UTF8Filesystem = _UTF8Filesystem()
 
 
+class _BreakinFeature(Feature):
+    """Does this platform support the breakin feature?"""
+
+    def _probe(self):
+        from bzrlib import breakin
+        if breakin.determine_signal() is None:
+            return False
+        if sys.platform == 'win32':
+            # Windows doesn't have os.kill, and we catch the SIGBREAK signal.
+            # We trigger SIGBREAK via a Console api so we need ctypes to
+            # access the function
+            try:
+                import ctypes
+            except OSError:
+                return False
+        return True
+
+    def feature_name(self):
+        return "SIGQUIT or SIGBREAK w/ctypes on win32"
+
+
+BreakinFeature = _BreakinFeature()
+
+
 class _CaseInsCasePresFilenameFeature(Feature):
     """Is the file-system case insensitive, but case-preserving?"""
 
@@ -4073,13 +4440,9 @@
 # Only define SubUnitBzrRunner if subunit is available.
 try:
     from subunit import TestProtocolClient
-    try:
-        from subunit.test_results import AutoTimingTestResultDecorator
-    except ImportError:
-        AutoTimingTestResultDecorator = lambda x:x
     class SubUnitBzrRunner(TextTestRunner):
         def run(self, test):
-            result = AutoTimingTestResultDecorator(
+            result = BzrAutoTimingTestResultDecorator(
                 TestProtocolClient(self.stream))
             test.run(result)
             return result

=== modified file 'bzrlib/tests/blackbox/test_add.py'
--- bzrlib/tests/blackbox/test_add.py	2009-08-10 08:25:05 +0000
+++ bzrlib/tests/blackbox/test_add.py	2009-11-08 00:05:26 +0000
@@ -27,7 +27,6 @@
     SymlinkFeature
     )
 from bzrlib.tests.blackbox import ExternalBase
-from bzrlib.tests.test_win32utils import NeedsGlobExpansionFeature
 
 
 def load_tests(standard_tests, module, loader):
@@ -211,20 +210,6 @@
         err = self.run_bzr('add .bzr/crescent', retcode=3)[1]
         self.assertContainsRe(err, r'ERROR:.*\.bzr.*control file')
 
-    def test_add_with_wildcards(self):
-        self.requireFeature(NeedsGlobExpansionFeature)
-        self.make_branch_and_tree('.')
-        self.build_tree(['a1', 'a2', 'b', 'c33'])
-        self.run_bzr(['add', 'a?', 'c*'])
-        self.assertEquals(self.run_bzr('unknowns')[0], 'b\n')
-
-    def test_add_with_wildcards_unicode(self):
-        self.requireFeature(NeedsGlobExpansionFeature)
-        self.make_branch_and_tree('.')
-        self.build_tree([u'\u1234A', u'\u1235A', u'\u1235AA', 'cc'])
-        self.run_bzr(['add', u'\u1234?', u'\u1235*'])
-        self.assertEquals(self.run_bzr('unknowns')[0], 'cc\n')
-
     def test_add_via_symlink(self):
         self.requireFeature(SymlinkFeature)
         self.make_branch_and_tree('source')

=== modified file 'bzrlib/tests/blackbox/test_bound_branches.py'
--- bzrlib/tests/blackbox/test_bound_branches.py	2009-05-07 05:08:46 +0000
+++ bzrlib/tests/blackbox/test_bound_branches.py	2009-09-17 11:54:41 +0000
@@ -64,14 +64,13 @@
 class TestBoundBranches(TestCaseWithTransport):
 
     def create_branches(self):
-        self.build_tree(['base/', 'base/a', 'base/b'])
-
-        branch = self.init_meta_branch('base')
-        base_tree = branch.bzrdir.open_workingtree()
+        base_tree = self.make_branch_and_tree('base')
         base_tree.lock_write()
+        self.build_tree(['base/a', 'base/b'])
         base_tree.add(['a', 'b'])
         base_tree.commit('init')
         base_tree.unlock()
+        branch = base_tree.branch
 
         child_tree = branch.create_checkout('child')
 
@@ -86,12 +85,11 @@
             val, len(BzrDir.open(loc).open_branch().revision_history()))
 
     def test_simple_binding(self):
-        self.build_tree(['base/', 'base/a', 'base/b'])
-
-        branch = self.init_meta_branch('base')
-        tree = branch.bzrdir.open_workingtree()
+        tree = self.make_branch_and_tree('base')
+        self.build_tree(['base/a', 'base/b'])
         tree.add('a', 'b')
         tree.commit(message='init')
+        branch = tree.branch
 
         tree.bzrdir.sprout('child')
 
@@ -131,10 +129,6 @@
         error = self.run_bzr('bind', retcode=3)[1]
         self.assertContainsRe(error, 'old locations')
 
-    def init_meta_branch(self, path):
-        format = bzrdir.format_registry.make_bzrdir('default')
-        return BzrDir.create_branch_convenience(path, format=format)
-
     def test_bound_commit(self):
         child_tree = self.create_branches()[1]
 

=== modified file 'bzrlib/tests/blackbox/test_breakin.py'
--- bzrlib/tests/blackbox/test_breakin.py	2009-07-31 14:56:55 +0000
+++ bzrlib/tests/blackbox/test_breakin.py	2009-09-28 03:36:45 +0000
@@ -41,15 +41,8 @@
 
     def setUp(self):
         super(TestBreakin, self).setUp()
-        if breakin.determine_signal() is None:
-            raise tests.TestSkipped('this platform is missing SIGQUIT'
-                                    ' or SIGBREAK')
+        self.requireFeature(tests.BreakinFeature)
         if sys.platform == 'win32':
-            # Windows doesn't have os.kill, and we catch the SIGBREAK signal.
-            # We trigger SIGBREAK via a Console api so we need ctypes to access
-            # the function
-            if not have_ctypes:
-                raise tests.UnavailableFeature('ctypes')
             self._send_signal = self._send_signal_win32
         else:
             self._send_signal = self._send_signal_via_kill
@@ -61,7 +54,11 @@
             sig_num = signal.SIGKILL
         else:
             raise ValueError("unknown signal type: %s" % (sig_type,))
-        os.kill(pid, sig_num)
+        try:
+            os.kill(pid, sig_num)
+        except OSError, e:
+            if e.errno != errno.ESRCH:
+                raise
 
     def _send_signal_win32(self, pid, sig_type):
         """Send a 'signal' on Windows.
@@ -110,11 +107,10 @@
             raise tests.TestNotApplicable(
                 '%s raises a popup on OSX' % self.id())
 
-    def _wait_for_process(self, pid, sig=None):
+    def _wait_for_process(self, pid, sig=None, count=100):
         # We don't know quite how long waiting for the process 'pid' will take,
         # but if it's more than 10s then it's probably not going to work.
-        for i in range(100):
-            time.sleep(0.1)
+        for i in range(count):
             if sig is not None:
                 self._send_signal(pid, sig)
             # Use WNOHANG to ensure we don't get blocked, doing so, we may
@@ -127,7 +123,7 @@
                 #       instead. Most notably, the WNOHANG isn't allowed, so
                 #       this can hang indefinitely.
                 pid_killed, returncode = os.waitpid(pid, opts)
-                if (pid_killed, returncode) != (0, 0):
+                if pid_killed != 0 and returncode != 0:
                     if sig is not None:
                         # high bit in low byte says if core was dumped; we
                         # don't care
@@ -139,6 +135,8 @@
                     return True, None
                 else:
                     raise
+            if i + 1 != count:
+                time.sleep(0.1)
 
         return False, None
 
@@ -161,19 +159,18 @@
         # os.read(proc.stderr.fileno())?
         err = proc.stderr.readline()
         self.assertContainsRe(err, r'entering debugger')
+        # Try to shutdown cleanly;
         # Now that the debugger is entered, we can ask him to quit
         proc.stdin.write("q\n")
-        # We wait a bit to let the child process handles our query and avoid
-        # triggering deadlocks leading to hangs on multi-core hosts...
-        dead, sig = self._wait_for_process(proc.pid)
+        # But we don't really care if it doesn't.
+        dead, sig = self._wait_for_process(proc.pid, count=3)
         if not dead:
-            # The process didn't finish, let's kill it before reporting failure
-            dead, sig = self._wait_for_process(proc.pid, 'kill')
-            if dead:
-                raise tests.KnownFailure(
-                    "subprocess wasn't terminated, it had to be killed")
-            else:
-                self.fail("subprocess %d wasn't terminated by repeated SIGKILL",
+            # The process didn't finish, let's kill it.
+            dead, sig = self._wait_for_process(proc.pid, 'kill', count=10)
+            if not dead:
+                # process isn't gone, user will have to hunt it down and kill
+                # it.
+                self.fail("subprocess %d wasn't terminated by repeated SIGKILL" %
                           proc.pid)
 
     def test_breakin_harder(self):

=== modified file 'bzrlib/tests/blackbox/test_cat.py'
--- bzrlib/tests/blackbox/test_cat.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_cat.py	2009-09-18 09:09:36 +0000
@@ -22,9 +22,10 @@
 import os
 import sys
 
-from bzrlib.tests.blackbox import TestCaseWithTransport
-
-class TestCat(TestCaseWithTransport):
+from bzrlib import tests
+
+
+class TestCat(tests.TestCaseWithTransport):
 
     def test_cat(self):
         tree = self.make_branch_and_tree('branch')
@@ -68,6 +69,7 @@
 
     def test_cat_different_id(self):
         """'cat' works with old and new files"""
+        self.disable_missing_extensions_warning()
         tree = self.make_branch_and_tree('.')
         # the files are named after their path in the revision and
         # current trees later in the test case
@@ -182,8 +184,6 @@
         self.assertEqual('contents of README\n', out)
 
     def test_cat_nonexistent_branch(self):
-        if sys.platform == "win32":
-            location = "C:/i/do/not/exist"
-        else:
-            location = "/i/do/not/exist"
-        self.run_bzr_error(['^bzr: ERROR: Not a branch'], ['cat', location])
+        self.vfs_transport_factory = tests.MemoryServer
+        self.run_bzr_error(['^bzr: ERROR: Not a branch'],
+                           ['cat', self.get_url()])

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2009-08-26 03:20:32 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2009-11-19 06:28:13 +0000
@@ -25,6 +25,7 @@
     ignores,
     msgeditor,
     osutils,
+    tests,
     )
 from bzrlib.bzrdir import BzrDir
 from bzrlib.tests import (
@@ -170,6 +171,24 @@
         self.assertEqual(err, 'Committing to: %s\n'
                          'Committed revision 2.\n' % expected)
 
+    def test_commit_sanitizes_CR_in_message(self):
+        # See bug #433779, basically Emacs likes to pass '\r\n' style line
+        # endings to 'bzr commit -m ""' which breaks because we don't allow
+        # '\r' in commit messages. (Mostly because of issues where XML style
+        # formats arbitrarily strip it out of the data while parsing.)
+        # To make life easier for users, we just always translate '\r\n' =>
+        # '\n'. And '\r' => '\n'.
+        a_tree = self.make_branch_and_tree('a')
+        self.build_tree(['a/b'])
+        a_tree.add('b')
+        self.run_bzr(['commit',
+                      '-m', 'a string\r\n\r\nwith mixed\r\rendings\n'],
+                     working_dir='a')
+        rev_id = a_tree.branch.last_revision()
+        rev = a_tree.branch.repository.get_revision(rev_id)
+        self.assertEqualDiff('a string\n\nwith mixed\n\nendings\n',
+                             rev.message)
+
     def test_commit_merge_reports_all_modified_files(self):
         # the commit command should show all the files that are shown by
         # bzr diff or bzr status when committing, even when they were not
@@ -245,6 +264,9 @@
         self.run_bzr('commit -m ""', retcode=3)
 
     def test_unsupported_encoding_commit_message(self):
+        if sys.platform == 'win32':
+            raise tests.TestNotApplicable('Win32 parses arguments directly'
+                ' as Unicode, so we can\'t pass invalid non-ascii')
         tree = self.make_branch_and_tree('.')
         self.build_tree_contents([('foo.c', 'int main() {}')])
         tree.add('foo.c')
@@ -255,10 +277,6 @@
         if char is None:
             raise TestSkipped('Cannot find suitable non-ascii character'
                 'for user_encoding (%s)' % osutils.get_user_encoding())
-        # TODO: jam 2009-07-23 This test seems to fail on Windows now. My best
-        #       guess is that the change to use Unicode command lines means
-        #       that we no longer pay any attention to LANG=C when decoding the
-        #       commandline arguments.
         out,err = self.run_bzr_subprocess('commit -m "%s"' % char,
                                           retcode=1,
                                           env_changes={'LANG': 'C'})
@@ -590,6 +608,26 @@
         properties = last_rev.properties
         self.assertEqual('John Doe\nJane Rey', properties['authors'])
 
+    def test_commit_time(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/hello.txt'])
+        tree.add('hello.txt')
+        out, err = self.run_bzr("commit -m hello "
+            "--commit-time='2009-10-10 08:00:00 +0100' tree/hello.txt")
+        last_rev = tree.branch.repository.get_revision(tree.last_revision())
+        self.assertEqual(
+            'Sat 2009-10-10 08:00:00 +0100',
+            osutils.format_date(last_rev.timestamp, last_rev.timezone))
+        
+    def test_commit_time_bad_time(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/hello.txt'])
+        tree.add('hello.txt')
+        out, err = self.run_bzr("commit -m hello "
+            "--commit-time='NOT A TIME' tree/hello.txt", retcode=3)
+        self.assertStartsWith(
+            err, "bzr: ERROR: Could not parse --commit-time:")
+
     def test_partial_commit_with_renames_in_tree(self):
         # this test illustrates bug #140419
         t = self.make_branch_and_tree('.')

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2009-06-17 05:11:41 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2009-09-18 08:50:05 +0000
@@ -21,11 +21,10 @@
 import os
 import re
 
-import bzrlib
-from bzrlib import workingtree
-from bzrlib.branch import Branch
-from bzrlib.tests import TestSkipped
-from bzrlib.tests.blackbox import ExternalBase
+from bzrlib import (
+    tests,
+    workingtree,
+    )
 
 
 def subst_dates(string):
@@ -34,7 +33,7 @@
                   'YYYY-MM-DD HH:MM:SS +ZZZZ', string)
 
 
-class DiffBase(ExternalBase):
+class DiffBase(tests.TestCaseWithTransport):
     """Base class with common setup method"""
 
     def make_example_branch(self):
@@ -355,6 +354,7 @@
 
     def test_external_diff(self):
         """Test that we can spawn an external diff process"""
+        self.disable_missing_extensions_warning()
         # We have to use run_bzr_subprocess, because we need to
         # test writing directly to stdout, (there was a bug in
         # subprocess.py that we had to workaround).
@@ -366,7 +366,7 @@
                                            universal_newlines=True,
                                            retcode=None)
         if 'Diff is not installed on this machine' in err:
-            raise TestSkipped("No external 'diff' is available")
+            raise tests.TestSkipped("No external 'diff' is available")
         self.assertEqual('', err)
         # We have to skip the stuff in the middle, because it depends
         # on time.time()

=== modified file 'bzrlib/tests/blackbox/test_dpush.py'
--- bzrlib/tests/blackbox/test_dpush.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/blackbox/test_dpush.py	2009-10-02 14:35:30 +0000
@@ -20,48 +20,54 @@
 
 import os
 
-from bzrlib.branch import (
-    Branch,
-    InterBranch,
-    )
-from bzrlib.bzrdir import (
-    BzrDirFormat,
-    )
-from bzrlib.foreign import (
-    ForeignBranch,
-    ForeignRepository,
-    )
-from bzrlib.repository import (
-    Repository,
-    )
-from bzrlib.tests.blackbox import (
-    ExternalBase,
-    )
-from bzrlib.tests.test_foreign import (
-    DummyForeignVcsDirFormat,
-    InterToDummyVcsBranch,
-    )
-
-
-class TestDpush(ExternalBase):
+from bzrlib import (
+    branch,
+    bzrdir,
+    foreign,
+    tests,
+    workingtree,
+    )
+from bzrlib.tests import (
+    blackbox,
+    test_foreign,
+    )
+from bzrlib.tests.blackbox import test_push
+
+
+def load_tests(standard_tests, module, loader):
+    """Multiply tests for the dpush command."""
+    result = loader.suiteClass()
+
+    # one for each king of change
+    changes_tests, remaining_tests = tests.split_suite_by_condition(
+        standard_tests, tests.condition_isinstance((
+                TestDpushStrictWithChanges,
+                )))
+    changes_scenarios = [
+        ('uncommitted',
+         dict(_changes_type= '_uncommitted_changes')),
+        ('pending-merges',
+         dict(_changes_type= '_pending_merges')),
+        ('out-of-sync-trees',
+         dict(_changes_type= '_out_of_sync_trees')),
+        ]
+    tests.multiply_tests(changes_tests, changes_scenarios, result)
+    # No parametrization for the remaining tests
+    result.addTests(remaining_tests)
+
+    return result
+
+
+class TestDpush(blackbox.ExternalBase):
 
     def setUp(self):
-        BzrDirFormat.register_control_format(DummyForeignVcsDirFormat)
-        InterBranch.register_optimiser(InterToDummyVcsBranch)
-        self.addCleanup(self.unregister_format)
         super(TestDpush, self).setUp()
-
-    def unregister_format(self):
-        try:
-            BzrDirFormat.unregister_control_format(DummyForeignVcsDirFormat)
-        except ValueError:
-            pass
-        InterBranch.unregister_optimiser(InterToDummyVcsBranch)
+        test_foreign.register_dummy_foreign_for_test(self)
 
     def make_dummy_builder(self, relpath):
-        builder = self.make_branch_builder(relpath, 
-                format=DummyForeignVcsDirFormat())
-        builder.build_snapshot('revid', None, 
+        builder = self.make_branch_builder(
+            relpath, format=test_foreign.DummyForeignVcsDirFormat())
+        builder.build_snapshot('revid', None,
             [('add', ('', 'TREE_ROOT', 'directory', None)),
              ('add', ('foo', 'fooid', 'file', 'bar'))])
         return builder
@@ -85,9 +91,9 @@
         self.check_output("", "status dc")
 
     def test_dpush_new(self):
-        branch = self.make_dummy_builder('d').get_branch()
+        b = self.make_dummy_builder('d').get_branch()
 
-        dc = branch.bzrdir.sprout('dc', force_new_repo=True)
+        dc = b.bzrdir.sprout('dc', force_new_repo=True)
         self.build_tree_contents([("dc/foofile", "blaaaa")])
         dc_tree = dc.open_workingtree()
         dc_tree.add("foofile")
@@ -98,25 +104,27 @@
         self.check_output("", "status dc")
 
     def test_dpush_wt_diff(self):
-        branch = self.make_dummy_builder('d').get_branch()
+        b = self.make_dummy_builder('d').get_branch()
 
-        dc = branch.bzrdir.sprout('dc', force_new_repo=True)
+        dc = b.bzrdir.sprout('dc', force_new_repo=True)
         self.build_tree_contents([("dc/foofile", "blaaaa")])
         dc_tree = dc.open_workingtree()
         dc_tree.add("foofile")
         newrevid = dc_tree.commit('msg')
 
         self.build_tree_contents([("dc/foofile", "blaaaal")])
-        self.check_output("", "dpush -d dc d")
+        self.check_output("", "dpush -d dc d --no-strict")
         self.assertFileEqual("blaaaal", "dc/foofile")
+        # if the dummy vcs wasn't that dummy we could uncomment the line below
+        # self.assertFileEqual("blaaaa", "d/foofile")
         self.check_output('modified:\n  foofile\n', "status dc")
 
     def test_diverged(self):
         builder = self.make_dummy_builder('d')
 
-        branch = builder.get_branch()
+        b = builder.get_branch()
 
-        dc = branch.bzrdir.sprout('dc', force_new_repo=True)
+        dc = b.bzrdir.sprout('dc', force_new_repo=True)
         dc_tree = dc.open_workingtree()
 
         self.build_tree_contents([("dc/foo", "bar")])
@@ -128,3 +136,56 @@
         output, error = self.run_bzr("dpush -d dc d", retcode=3)
         self.assertEquals(output, "")
         self.assertContainsRe(error, "have diverged")
+
+
+class TestDpushStrictMixin(object):
+
+    def setUp(self):
+        test_foreign.register_dummy_foreign_for_test(self)
+        # Create an empty branch where we will be able to push
+        self.foreign = self.make_branch(
+            'to', format=test_foreign.DummyForeignVcsDirFormat())
+
+    def set_config_push_strict(self, value):
+        # set config var (any of bazaar.conf, locations.conf, branch.conf
+        # should do)
+        conf = self.tree.branch.get_config()
+        conf.set_user_option('dpush_strict', value)
+
+    _default_command = ['dpush', '../to']
+    _default_pushed_revid = False # Doesn't aplly for dpush
+
+    def assertPushSucceeds(self, args, pushed_revid=None):
+        self.run_bzr(self._default_command + args,
+                     working_dir=self._default_wd)
+        if pushed_revid is None:
+            # dpush change the revids, so we need to get back to it
+            branch_from = branch.Branch.open(self._default_wd)
+            pushed_revid = branch_from.last_revision()
+        branch_to = branch.Branch.open('to')
+        repo_to = branch_to.repository
+        self.assertTrue(repo_to.has_revision(pushed_revid))
+        self.assertEqual(branch_to.last_revision(), pushed_revid)
+
+
+
+class TestDpushStrictWithoutChanges(TestDpushStrictMixin,
+                                    test_push.TestPushStrictWithoutChanges):
+
+    def setUp(self):
+        test_push.TestPushStrictWithoutChanges.setUp(self)
+        TestDpushStrictMixin.setUp(self)
+
+
+class TestDpushStrictWithChanges(TestDpushStrictMixin,
+                                 test_push.TestPushStrictWithChanges):
+
+    _changes_type = None # Set by load_tests
+
+    def setUp(self):
+        test_push.TestPushStrictWithChanges.setUp(self)
+        TestDpushStrictMixin.setUp(self)
+
+    def test_push_with_revision(self):
+        raise tests.TestNotApplicable('dpush does not handle --revision')
+

=== modified file 'bzrlib/tests/blackbox/test_export.py'
--- bzrlib/tests/blackbox/test_export.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/blackbox/test_export.py	2009-11-25 00:14:05 +0000
@@ -141,7 +141,7 @@
         # forward slashes
         self.assertEqual(['test/a', 'test/b/', 'test/b/c', 'test/d/'], names)
 
-        file_attr = stat.S_IFREG
+        file_attr = stat.S_IFREG | export.zip_exporter.FILE_PERMISSIONS
         dir_attr = stat.S_IFDIR | export.zip_exporter.ZIP_DIRECTORY_BIT
 
         a_info = zfile.getinfo(names[0])

=== modified file 'bzrlib/tests/blackbox/test_filesystem_cicp.py'
--- bzrlib/tests/blackbox/test_filesystem_cicp.py	2009-04-06 08:17:53 +0000
+++ bzrlib/tests/blackbox/test_filesystem_cicp.py	2009-08-26 09:06:02 +0000
@@ -216,12 +216,19 @@
 
 
 class TestMisc(TestCICPBase):
+
     def test_status(self):
         wt = self._make_mixed_case_tree()
         self.run_bzr('add')
 
-        self.check_output('added:\n  CamelCaseParent/CamelCase\n  lowercaseparent/lowercase\n',
-                          'status camelcaseparent/camelcase LOWERCASEPARENT/LOWERCASE')
+        self.check_output(
+            """added:
+  CamelCaseParent/
+  CamelCaseParent/CamelCase
+  lowercaseparent/
+  lowercaseparent/lowercase
+""",
+            'status camelcaseparent/camelcase LOWERCASEPARENT/LOWERCASE')
 
     def test_ci(self):
         wt = self._make_mixed_case_tree()

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2009-08-17 03:47:03 +0000
+++ bzrlib/tests/blackbox/test_info.py	2009-09-17 11:54:41 +0000
@@ -29,7 +29,7 @@
     urlutils,
     )
 from bzrlib.osutils import format_date
-from bzrlib.tests import TestSkipped
+from bzrlib.tests import TestSkipped, MemoryServer
 from bzrlib.tests.blackbox import ExternalBase
 
 
@@ -40,10 +40,8 @@
         self._repo_strings = "2a or development-subtree"
 
     def test_info_non_existing(self):
-        if sys.platform == "win32":
-            location = "C:/i/do/not/exist/"
-        else:
-            location = "/i/do/not/exist/"
+        self.vfs_transport_factory = MemoryServer
+        location = self.get_url()
         out, err = self.run_bzr('info '+location, retcode=3)
         self.assertEqual(out, '')
         self.assertEqual(err, 'bzr: ERROR: Not a branch: "%s".\n' % location)
@@ -1328,6 +1326,10 @@
     def test_info_locking_oslocks(self):
         if sys.platform == "win32":
             raise TestSkipped("don't use oslocks on win32 in unix manner")
+        # This test tests old (all-in-one, OS lock using) behaviour which
+        # simply cannot work on windows (and is indeed why we changed our
+        # design. As such, don't try to remove the thisFailsStrictLockCheck
+        # call here.
         self.thisFailsStrictLockCheck()
 
         tree = self.make_branch_and_tree('branch',

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2009-08-12 22:16:29 +0000
+++ bzrlib/tests/blackbox/test_init.py	2009-11-08 02:23:13 +0000
@@ -22,6 +22,7 @@
 
 from bzrlib import (
     branch as _mod_branch,
+    osutils,
     urlutils,
     )
 from bzrlib.bzrdir import BzrDirMetaFormat1
@@ -74,8 +75,8 @@
 Using shared repository: %s
 """ % (self._default_label, urlutils.local_path_from_url(
             repo.bzrdir.root_transport.external_url())), out)
-        self.assertEndsWith(out, "bzrlib.tests.blackbox.test_init.TestInit."
-            "test_init_at_repository_root/work/repo/\n")
+        cwd = osutils.getcwd()
+        self.assertEndsWith(out, cwd + '/repo/\n')
         self.assertEqual('', err)
         newdir.open_branch()
         newdir.open_workingtree()

=== modified file 'bzrlib/tests/blackbox/test_locale.py'
--- bzrlib/tests/blackbox/test_locale.py	2009-08-17 22:16:49 +0000
+++ bzrlib/tests/blackbox/test_locale.py	2009-09-18 08:50:05 +0000
@@ -19,17 +19,19 @@
 import os
 import sys
 
-from bzrlib.tests import TestCaseWithTransport, TestSkipped
-
-
-class TestLocale(TestCaseWithTransport):
+from bzrlib import (
+    tests,
+    )
+
+
+class TestLocale(tests.TestCaseWithTransport):
 
     def setUp(self):
         super(TestLocale, self).setUp()
 
         if sys.platform in ('win32',):
-            raise TestSkipped('Windows does not respond to the LANG'
-                              ' env variable')
+            raise tests.TestSkipped('Windows does not respond to the LANG'
+                                    ' env variable')
 
         tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/a'])
@@ -41,6 +43,7 @@
         self.tree = tree
 
     def test_log_C(self):
+        self.disable_missing_extensions_warning()
         out, err = self.run_bzr_subprocess(
             '--no-aliases --no-plugins log -q --log-format=long tree',
                env_changes={'LANG':'C', 'BZR_PROGRESS_BAR':'none',

=== modified file 'bzrlib/tests/blackbox/test_ls.py'
--- bzrlib/tests/blackbox/test_ls.py	2009-05-18 07:48:02 +0000
+++ bzrlib/tests/blackbox/test_ls.py	2009-11-30 00:33:52 +0000
@@ -54,6 +54,7 @@
     def test_ls_basic(self):
         """Test the abilities of 'bzr ls'"""
         self.ls_equals('.bzrignore\na\n')
+        self.ls_equals('.bzrignore\na\n', './')
         self.ls_equals('?        .bzrignore\n'
                        '?        a\n',
                        '--verbose')

=== modified file 'bzrlib/tests/blackbox/test_merge.py'
--- bzrlib/tests/blackbox/test_merge.py	2009-08-06 06:58:09 +0000
+++ bzrlib/tests/blackbox/test_merge.py	2009-11-09 00:39:44 +0000
@@ -21,23 +21,26 @@
 
 import os
 
-from bzrlib import merge_directive
-from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
-from bzrlib.conflicts import ConflictList, ContentsConflict
-from bzrlib.osutils import abspath, file_kind, pathjoin
-from bzrlib.tests.blackbox import ExternalBase
-import bzrlib.urlutils as urlutils
-from bzrlib.workingtree import WorkingTree
-
-
-class TestMerge(ExternalBase):
+from bzrlib import (
+    branch,
+    bzrdir,
+    conflicts,
+    errors,
+    merge_directive,
+    osutils,
+    tests,
+    urlutils,
+    workingtree,
+    )
+
+
+class TestMerge(tests.TestCaseWithTransport):
 
     def example_branch(self, path='.'):
         tree = self.make_branch_and_tree(path)
         self.build_tree_contents([
-            (pathjoin(path, 'hello'), 'foo'),
-            (pathjoin(path, 'goodbye'), 'baz')])
+            (osutils.pathjoin(path, 'hello'), 'foo'),
+            (osutils.pathjoin(path, 'goodbye'), 'baz')])
         tree.add('hello')
         tree.commit(message='setup')
         tree.add('goodbye')
@@ -63,13 +66,11 @@
         return tree, other
 
     def test_merge_reprocess(self):
-        d = BzrDir.create_standalone_workingtree('.')
+        d = bzrdir.BzrDir.create_standalone_workingtree('.')
         d.commit('h')
         self.run_bzr('merge . --reprocess --merge-type weave')
 
     def test_merge(self):
-        from bzrlib.branch import Branch
-
         a_tree = self.example_branch('a')
         ancestor = a_tree.branch.revno()
         b_tree = a_tree.bzrdir.sprout('b').open_workingtree()
@@ -80,7 +81,7 @@
         # We can't merge when there are in-tree changes
         os.chdir('a')
         self.run_bzr('merge ../b', retcode=3)
-        a = WorkingTree.open('.')
+        a = workingtree.WorkingTree.open('.')
         a_tip = a.commit("Like an epidemic of u's")
         self.run_bzr('merge ../b -r last:1..last:1 --merge-type blooof',
                     retcode=3)
@@ -99,7 +100,7 @@
         self.run_bzr('merge ../b -r last:1')
         self.check_file_contents('goodbye', 'quux')
         # Merging a branch pulls its revision into the tree
-        b = Branch.open('../b')
+        b = branch.Branch.open('../b')
         b_tip = b.last_revision()
         self.failUnless(a.branch.repository.has_revision(b_tip))
         self.assertEqual([a_tip, b_tip], a.get_parent_ids())
@@ -249,8 +250,8 @@
 
         base = urlutils.local_path_from_url(branch_a.base)
         self.assertEndsWith(err, '+N  b\nAll changes applied successfully.\n')
-        self.assertEquals(abspath(branch_b.get_submit_branch()),
-                          abspath(parent))
+        self.assertEquals(osutils.abspath(branch_b.get_submit_branch()),
+                          osutils.abspath(parent))
         # test implicit --remember when committing new file
         self.build_tree(['e'])
         tree_b.add('e')
@@ -265,8 +266,8 @@
         out, err = self.run_bzr('merge ../branch_c --remember')
         self.assertEquals(out, '')
         self.assertEquals(err, '+N  c\nAll changes applied successfully.\n')
-        self.assertEquals(abspath(branch_b.get_submit_branch()),
-                          abspath(branch_c.bzrdir.root_transport.base))
+        self.assertEquals(osutils.abspath(branch_b.get_submit_branch()),
+                          osutils.abspath(branch_c.bzrdir.root_transport.base))
         # re-open tree as external run_bzr modified it
         tree_b = branch_b.bzrdir.open_workingtree()
         tree_b.commit('merge branch_c')
@@ -294,7 +295,7 @@
                                               tree_b.get_parent_ids()[0])
         self.assertEqualDiff(testament_a.as_text(),
                          testament_b.as_text())
-        tree_a.set_conflicts(ConflictList())
+        tree_a.set_conflicts(conflicts.ConflictList())
         tree_a.commit('message')
         # it is legal to attempt to merge an already-merged bundle
         output = self.run_bzr('merge ../bundle')[1]
@@ -349,7 +350,7 @@
         os.chdir('a')
         (out, err) = self.run_bzr('merge --pull ../b')
         self.assertContainsRe(out, 'Now on revision 2\\.')
-        tree_a = WorkingTree.open('.')
+        tree_a = workingtree.WorkingTree.open('.')
         self.assertEqual([self.id2], tree_a.get_parent_ids())
 
     def test_merge_kind_change(self):
@@ -363,14 +364,15 @@
         tree_a.commit('changed file to directory')
         os.chdir('tree_b')
         self.run_bzr('merge ../tree_a')
-        self.assertEqual('directory', file_kind('file'))
+        self.assertEqual('directory', osutils.file_kind('file'))
         tree_b.revert()
-        self.assertEqual('file', file_kind('file'))
+        self.assertEqual('file', osutils.file_kind('file'))
         self.build_tree_contents([('file', 'content_2')])
         tree_b.commit('content change')
         self.run_bzr('merge ../tree_a', retcode=1)
         self.assertEqual(tree_b.conflicts(),
-                         [ContentsConflict('file', file_id='file-id')])
+                         [conflicts.ContentsConflict('file',
+                                                     file_id='file-id')])
 
     def test_directive_cherrypick(self):
         source = self.make_branch_and_tree('source')
@@ -496,18 +498,6 @@
         out, err = self.run_bzr(['merge', '-d', 'a', 'b'])
         self.assertContainsRe(err, 'Warning: criss-cross merge encountered.')
 
-    def test_merge_force(self):
-        tree_a = self.make_branch_and_tree('a')
-        self.build_tree(['a/foo'])
-        tree_a.add(['foo'])
-        tree_a.commit('add file')
-        tree_b = tree_a.bzrdir.sprout('b').open_workingtree()
-        self.build_tree_contents([('a/foo', 'change 1')])
-        tree_a.commit('change file')
-        tree_b.merge_from_branch(tree_a.branch)
-        tree_a.commit('empty change to allow merge to run')
-        self.run_bzr(['merge', '../a', '--force'], working_dir='b')
-
     def test_merge_from_submit(self):
         tree_a = self.make_branch_and_tree('a')
         tree_b = tree_a.bzrdir.sprout('b').open_workingtree()
@@ -560,11 +550,11 @@
         tree_a.merge_from_branch(tree_b.branch)
         self.build_tree_contents([('a/file',
                                    'base-contents\nthis-contents\n')])
-        tree_a.set_conflicts(ConflictList())
+        tree_a.set_conflicts(conflicts.ConflictList())
         tree_b.merge_from_branch(tree_a.branch)
         self.build_tree_contents([('b/file',
                                    'base-contents\nother-contents\n')])
-        tree_b.set_conflicts(ConflictList())
+        tree_b.set_conflicts(conflicts.ConflictList())
         tree_a.commit('', rev_id='rev3a')
         tree_b.commit('', rev_id='rev3b')
         out, err = self.run_bzr(['merge', '-d', 'a', 'b', '--lca'], retcode=1)
@@ -598,3 +588,45 @@
         other.commit('rev1b')
         self.run_bzr('merge -d this other -r0..')
         self.failUnlessExists('this/other_file')
+
+    def test_merge_reversed_revision_range(self):
+        tree = self.make_branch_and_tree(".")
+        for f in ("a", "b"):
+            self.build_tree([f])
+            tree.add(f)
+            tree.commit("added "+f)
+        for context in (".", "", "a"):
+            self.run_bzr("merge -r 1..0 " + context)
+            self.failIfExists("a")
+            tree.revert()
+            self.failUnlessExists("a")
+
+
+class TestMergeForce(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestMergeForce, self).setUp()
+        self.tree_a = self.make_branch_and_tree('a')
+        self.build_tree(['a/foo'])
+        self.tree_a.add(['foo'])
+        self.tree_a.commit('add file')
+        self.tree_b = self.tree_a.bzrdir.sprout('b').open_workingtree()
+        self.build_tree_contents([('a/foo', 'change 1')])
+        self.tree_a.commit('change file')
+        self.tree_b.merge_from_branch(self.tree_a.branch)
+
+    def test_merge_force(self):
+        self.tree_a.commit('empty change to allow merge to run')
+        # Second merge on top of the uncommitted one
+        self.run_bzr(['merge', '../a', '--force'], working_dir='b')
+
+
+    def test_merge_with_uncommitted_changes(self):
+        self.run_bzr_error(['Working tree .* has uncommitted changes'],
+                           ['merge', '../a'], working_dir='b')
+
+    def test_merge_with_pending_merges(self):
+        # Revert the changes keeping the pending merge
+        self.run_bzr(['revert', 'b'])
+        self.run_bzr_error(['Working tree .* has uncommitted changes'],
+                           ['merge', '../a'], working_dir='b')

=== modified file 'bzrlib/tests/blackbox/test_mv.py'
--- bzrlib/tests/blackbox/test_mv.py	2009-07-16 01:36:57 +0000
+++ bzrlib/tests/blackbox/test_mv.py	2009-11-17 01:08:08 +0000
@@ -487,9 +487,17 @@
         self.assertEqual('bzr: ERROR: --after cannot be specified with'
                          ' --auto.\n', err)
 
+    def test_mv_quiet(self):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(['aaa'])
+        tree.add(['aaa'])
+        out, err = self.run_bzr('mv --quiet aaa bbb')
+        self.assertEqual(out, '')
+        self.assertEqual(err, '')
+
     def test_mv_readonly_lightweight_checkout(self):
         branch = self.make_branch('foo')
-        branch = bzrlib.branch.Branch.open('readonly+' + branch.base)
+        branch = bzrlib.branch.Branch.open(self.get_readonly_url('foo'))
         tree = branch.create_checkout('tree', lightweight=True)
         self.build_tree(['tree/path'])
         tree.add('path')

=== modified file 'bzrlib/tests/blackbox/test_outside_wt.py'
--- bzrlib/tests/blackbox/test_outside_wt.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_outside_wt.py	2009-09-19 16:14:10 +0000
@@ -23,6 +23,7 @@
 from bzrlib import (
     osutils,
     tests,
+    transport,
     urlutils,
     )
 
@@ -31,13 +32,14 @@
     """Test that bzr gives proper errors outside of a working tree."""
 
     def test_cwd_log(self):
-        tmp_dir = osutils.mkdtemp()
+        # Watch out for tricky test dir (on OSX /tmp -> /private/tmp)
+        tmp_dir = osutils.realpath(osutils.mkdtemp())
+        # We expect a read-to-root attempt to occur.
+        self.permit_url('file:///')
         self.addCleanup(lambda: osutils.rmtree(tmp_dir))
-        self.addCleanup(lambda: os.chdir('..'))
-        os.chdir(tmp_dir)
-        out, err = self.run_bzr('log', retcode=3)
+        out, err = self.run_bzr('log', retcode=3, working_dir=tmp_dir)
         self.assertEqual(u'bzr: ERROR: Not a branch: "%s/".\n'
-                         % (osutils.getcwd(),),
+                         % (tmp_dir,),
                          err)
 
     def test_url_log(self):
@@ -47,34 +49,34 @@
                          u' "%s".\n' % url, err)
 
     def test_diff_outside_tree(self):
-        tmp_dir = osutils.mkdtemp()
+        tree = self.make_branch_and_tree('branch1')
+        tree.commit('nothing')
+        tree.commit('nothing')
+        # A directory we can run commands from which we hope is not contained
+        # in a bzr tree (though if there is one at or above $TEMPDIR, this is
+        # false and may cause test failures).
+        # Watch out for tricky test dir (on OSX /tmp -> /private/tmp)
+        tmp_dir = osutils.realpath(osutils.mkdtemp())
         self.addCleanup(lambda: osutils.rmtree(tmp_dir))
-        self.addCleanup(lambda: os.chdir('..'))
-        os.chdir(tmp_dir)
-        self.run_bzr('init branch1')
-        self.run_bzr(['commit', '-m', 'nothing',
-                               '--unchanged', 'branch1'])
-        self.run_bzr(['commit', '-m', 'nothing',
-                               '--unchanged', 'branch1'])
-        this_dir = osutils.getcwd()
-        branch2 = "%s/branch2" % (this_dir,)
+        # We expect a read-to-root attempt to occur.
+        self.permit_url('file:///')
+        expected_error = u'bzr: ERROR: Not a branch: "%s/branch2/".\n' % tmp_dir
         # -r X..Y
-        out, err = self.run_bzr('diff -r revno:2:branch2..revno:1', retcode=3)
-        self.assertEquals('', out)
-        self.assertEqual(u'bzr: ERROR: Not a branch: "%s/".\n' % (branch2,),
-                         err)
+        out, err = self.run_bzr('diff -r revno:2:branch2..revno:1', retcode=3,
+            working_dir=tmp_dir)
+        self.assertEqual('', out)
+        self.assertEqual(expected_error, err)
         # -r X
-        out, err = self.run_bzr('diff -r revno:2:branch2', retcode=3)
-        self.assertEquals('', out)
-        self.assertEqual(u'bzr: ERROR: Not a branch: "%s/".\n' % (branch2,),
-                         err)
+        out, err = self.run_bzr('diff -r revno:2:branch2', retcode=3,
+            working_dir=tmp_dir)
+        self.assertEqual('', out)
+        self.assertEqual(expected_error, err)
         # -r X..
-        out, err = self.run_bzr('diff -r revno:2:branch2..', retcode=3)
-        self.assertEquals('', out)
-        self.assertEqual(u'bzr: ERROR: Not a branch: "%s/".\n' % (branch2,),
-                         err)
+        out, err = self.run_bzr('diff -r revno:2:branch2..', retcode=3,
+            working_dir=tmp_dir)
+        self.assertEqual('', out)
+        self.assertEqual(expected_error, err)
         # no -r at all.
-        out, err = self.run_bzr('diff', retcode=3)
-        self.assertEquals('', out)
-        self.assertEqual(u'bzr: ERROR: Not a branch: "%s/".\n' % (this_dir,),
-                         err)
+        out, err = self.run_bzr('diff', retcode=3, working_dir=tmp_dir)
+        self.assertEqual('', out)
+        self.assertEqual(u'bzr: ERROR: Not a branch: "%s/".\n' % tmp_dir, err)

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/blackbox/test_push.py	2009-12-03 02:24:54 +0000
@@ -253,6 +253,22 @@
         # upwards without agreement from bzr's network support maintainers.
         self.assertLength(11, self.hpss_calls)
 
+    def test_push_smart_incremental_acceptance(self):
+        self.setup_smart_server_with_call_log()
+        t = self.make_branch_and_tree('from')
+        rev_id1 = t.commit(allow_pointless=True, message='first commit')
+        rev_id2 = t.commit(allow_pointless=True, message='second commit')
+        self.run_bzr(
+            ['push', self.get_url('to-one'), '-r1'], working_dir='from')
+        self.reset_smart_call_log()
+        self.run_bzr(['push', self.get_url('to-one')], working_dir='from')
+        # This figure represent the amount of work to perform this use case. It
+        # is entirely ok to reduce this number if a test fails due to rpc_count
+        # being too low. If rpc_count increases, more network roundtrips have
+        # become necessary for this use case. Please do not adjust this number
+        # upwards without agreement from bzr's network support maintainers.
+        self.assertLength(11, self.hpss_calls)
+
     def test_push_smart_with_default_stacking_url_path_segment(self):
         # If the default stacked-on location is a path element then branches
         # we push there over the smart server are stacked and their
@@ -319,6 +335,17 @@
         # The push should have created target/a
         self.failUnlessExists('target/a')
 
+    def test_push_use_existing_into_empty_bzrdir(self):
+        """'bzr push --use-existing-dir' into a dir with an empty .bzr dir
+        fails.
+        """
+        tree = self.create_simple_tree()
+        self.build_tree(['target/', 'target/.bzr/'])
+        self.run_bzr_error(
+            ['Target directory ../target already contains a .bzr directory, '
+             'but it is not valid.'],
+            'push ../target --use-existing-dir', working_dir='tree')
+
     def test_push_onto_repo(self):
         """We should be able to 'bzr push' into an existing bzrdir."""
         tree = self.create_simple_tree()
@@ -576,9 +603,7 @@
     def setUp(self):
         tests.TestCaseWithTransport.setUp(self)
         self.memory_server = RedirectingMemoryServer()
-        self.memory_server.setUp()
-        self.addCleanup(self.memory_server.tearDown)
-
+        self.start_server(self.memory_server)
         # Make the branch and tree that we'll be pushing.
         t = self.make_branch_and_tree('tree')
         self.build_tree(['tree/file'])
@@ -681,6 +706,8 @@
 
     def setUp(self):
         super(TestPushStrictWithChanges, self).setUp()
+        # Apply the changes defined in load_tests: one of _uncommitted_changes,
+        # _pending_merges or _out_of_sync_trees
         getattr(self, self._changes_type)()
 
     def _uncommitted_changes(self):

=== modified file 'bzrlib/tests/blackbox/test_remove.py'
--- bzrlib/tests/blackbox/test_remove.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_remove.py	2009-09-07 08:52:04 +0000
@@ -61,15 +61,18 @@
         f.write("\nsome other new content!")
         f.close()
 
-    def run_bzr_remove_changed_files(self, error_regexes, files_to_remove):
+    def run_bzr_remove_changed_files(self, error_regexes, files_to_remove,
+                                     working_dir=None):
         error_regexes.extend(["Can't safely remove modified or unknown files:",
             'Use --keep to not delete them,'
             ' or --force to delete them regardless.'
             ])
         self.run_bzr_error(error_regexes,
-            ['remove'] + list(files_to_remove))
+                           ['remove'] + list(files_to_remove),
+                           working_dir=working_dir)
         #see if we can force it now
-        self.run_bzr(['remove', '--force'] + list(files_to_remove))
+        self.run_bzr(['remove', '--force'] + list(files_to_remove),
+                     working_dir=working_dir)
 
     def test_remove_new_no_files_specified(self):
         tree = self.make_branch_and_tree('.')
@@ -196,10 +199,9 @@
         self.run_bzr("commit -m 'added files'")
         self.changeFile(a)
         self.changeFile(c)
-        os.chdir('b')
-        self.run_bzr_remove_changed_files(['modified:[.\s]*a[.\s]*b/c'],
-            ['../a', 'c', '.', '../d'])
-        os.chdir('..')
+        self.run_bzr_remove_changed_files(
+            ['modified:[.\s]*a[.\s]*b/c'],
+            ['../a', 'c', '.', '../d'], working_dir='b')
         self.assertNotInWorkingTree(files)
         self.failIfExists(files)
 

=== modified file 'bzrlib/tests/blackbox/test_remove_tree.py'
--- bzrlib/tests/blackbox/test_remove_tree.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_remove_tree.py	2009-09-08 16:45:11 +0000
@@ -122,3 +122,30 @@
         self.run_bzr('remove-tree branch1 --force')
         self.failIfExists('branch1/foo')
         self.failUnlessExists('branch1/bar')
+
+    def test_remove_tree_pending_merges(self):
+        self.run_bzr(['branch', 'branch1', 'branch2'])
+        self.build_tree(['branch1/bar'])
+        self.tree.add('bar')
+        self.tree.commit('2')
+        self.failUnlessExists('branch1/bar')
+        self.run_bzr(['merge', '../branch1'], working_dir='branch2')
+        self.failUnlessExists('branch2/bar')
+        self.run_bzr(['revert', '.'], working_dir='branch2')
+        self.failIfExists('branch2/bar')
+        output = self.run_bzr_error(["Working tree .* has uncommitted changes"],
+                                    'remove-tree branch2', retcode=3)
+
+    def test_remove_tree_pending_merges_force(self):
+        self.run_bzr(['branch', 'branch1', 'branch2'])
+        self.build_tree(['branch1/bar'])
+        self.tree.add('bar')
+        self.tree.commit('2')
+        self.failUnlessExists('branch1/bar')
+        self.run_bzr(['merge', '../branch1'], working_dir='branch2')
+        self.failUnlessExists('branch2/bar')
+        self.run_bzr(['revert', '.'], working_dir='branch2')
+        self.failIfExists('branch2/bar')
+        self.run_bzr('remove-tree branch2 --force')
+        self.failIfExists('branch2/foo')
+        self.failIfExists('branch2/bar')

=== modified file 'bzrlib/tests/blackbox/test_selftest.py'
--- bzrlib/tests/blackbox/test_selftest.py	2009-08-24 05:23:11 +0000
+++ bzrlib/tests/blackbox/test_selftest.py	2009-08-24 22:32:53 +0000
@@ -172,3 +172,7 @@
             outputs_nothing(['selftest', '--list-only', '--exclude', 'selftest'])
         finally:
             tests.selftest = original_selftest
+
+    def test_lsprof_tests(self):
+        params = self.get_params_passed_to_core('selftest --lsprof-tests')
+        self.assertEqual(True, params[1]["lsprof_tests"])

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2009-07-01 15:17:33 +0000
+++ bzrlib/tests/blackbox/test_send.py	2009-11-28 00:48:03 +0000
@@ -67,7 +67,7 @@
 
     def get_MD(self, args, cmd=None, wd='branch'):
         out = StringIO(self.run_send(args, cmd=cmd, wd=wd)[0])
-        return merge_directive.MergeDirective.from_lines(out.readlines())
+        return merge_directive.MergeDirective.from_lines(out)
 
     def assertBundleContains(self, revs, args, cmd=None, wd='branch'):
         md = self.get_MD(args, cmd=cmd, wd=wd)
@@ -280,10 +280,8 @@
         self.assertEqual('rev3', md.revision_id)
 
     def test_nonexistant_branch(self):
-        if sys.platform == "win32":
-            location = "C:/i/do/not/exist/"
-        else:
-            location = "/i/do/not/exist/"
+        self.vfs_transport_factory = tests.MemoryServer
+        location = self.get_url('absentdir/')
         out, err = self.run_bzr(["send", "--from", location], retcode=3)
         self.assertEqual(out, '')
         self.assertEqual(err, 'bzr: ERROR: Not a branch: "%s".\n' % location)
@@ -324,8 +322,7 @@
         out, err = self.run_send(args)
         self.assertEquals(
             'Bundling %d revision(s).\n' % len(revs), err)
-        md = merge_directive.MergeDirective.from_lines(
-                StringIO(out).readlines())
+        md = merge_directive.MergeDirective.from_lines(StringIO(out))
         self.assertEqual('parent', md.base_revision_id)
         br = serializer.read_bundle(StringIO(md.get_raw_bundle()))
         self.assertEqual(set(revs), set(r.revision_id for r in br.revisions))
@@ -425,7 +422,7 @@
         self.assertSendFails([])
         self.assertSendSucceeds(['--no-strict'])
 
-    def test_push_strict_command_line_override_config(self):
+    def test_send_strict_command_line_override_config(self):
         self.set_config_send_strict('false')
         self.assertSendSucceeds([])
         self.assertSendFails(['--strict'])

=== modified file 'bzrlib/tests/blackbox/test_serve.py'
--- bzrlib/tests/blackbox/test_serve.py	2009-07-20 11:27:05 +0000
+++ bzrlib/tests/blackbox/test_serve.py	2009-11-25 13:21:52 +0000
@@ -18,6 +18,7 @@
 """Tests of the bzr serve command."""
 
 import os
+import os.path
 import signal
 import subprocess
 import sys
@@ -25,22 +26,72 @@
 import threading
 
 from bzrlib import (
+    builtins,
     errors,
     osutils,
     revision as _mod_revision,
-    transport,
+    urlutils,
     )
 from bzrlib.branch import Branch
 from bzrlib.bzrdir import BzrDir
-from bzrlib.errors import ParamikoNotPresent
 from bzrlib.smart import client, medium
-from bzrlib.smart.server import SmartTCPServer
-from bzrlib.tests import TestCaseWithTransport, TestSkipped
+from bzrlib.smart.server import BzrServerFactory, SmartTCPServer
+from bzrlib.tests import (
+    ParamikoFeature,
+    TestCaseWithMemoryTransport,
+    TestCaseWithTransport,
+    TestSkipped,
+    )
 from bzrlib.trace import mutter
 from bzrlib.transport import get_transport, remote
 
-
-class TestBzrServe(TestCaseWithTransport):
+class TestBzrServeBase(TestCaseWithTransport):
+
+    def run_bzr_serve_then_func(self, serve_args, retcode=0, func=None,
+                                *func_args, **func_kwargs):
+        """Run 'bzr serve', and run the given func in a thread once the server
+        has started.
+        
+        When 'func' terminates, the server will be terminated too.
+        
+        Returns stdout and stderr.
+        """
+        # install hook
+        def on_server_start(backing_urls, tcp_server):
+            t = threading.Thread(
+                target=on_server_start_thread, args=(tcp_server,))
+            t.start()
+        def on_server_start_thread(tcp_server):
+            try:
+                # Run func if set
+                self.tcp_server = tcp_server
+                if not func is None:
+                    try:
+                        func(*func_args, **func_kwargs)
+                    except Exception, e:
+                        # Log errors to make some test failures a little less
+                        # mysterious.
+                        mutter('func broke: %r', e)
+            finally:
+                # Then stop the server
+                mutter('interrupting...')
+                thread.interrupt_main()
+        SmartTCPServer.hooks.install_named_hook(
+            'server_started_ex', on_server_start,
+            'run_bzr_serve_then_func hook')
+        # start a TCP server
+        try:
+            out, err = self.run_bzr(['serve'] + list(serve_args))
+        except KeyboardInterrupt, e:
+            out, err = e.args
+        return out, err
+
+
+class TestBzrServe(TestBzrServeBase):
+
+    def setUp(self):
+        super(TestBzrServe, self).setUp()
+        self.disable_missing_extensions_warning()
 
     def assertInetServerShutsdownCleanly(self, process):
         """Shutdown the server process looking for errors."""
@@ -85,6 +136,7 @@
         # We use this url because while this is no valid URL to connect to this
         # server instance, the transport needs a URL.
         url = 'bzr://localhost/'
+        self.permit_url(url)
         client_medium = medium.SmartSimplePipesClientMedium(
             process.stdout, process.stdin, url)
         transport = remote.RemoteTransport(url, medium=client_medium)
@@ -105,7 +157,16 @@
         prefix = 'listening on port: '
         self.assertStartsWith(port_line, prefix)
         port = int(port_line[len(prefix):])
-        return process,'bzr://localhost:%d/' % port
+        url = 'bzr://localhost:%d/' % port
+        self.permit_url(url)
+        return process, url
+    
+    def test_bzr_serve_quiet(self):
+        self.make_branch('.')
+        args = ['--port', 'localhost:0', '--quiet']
+        out, err = self.run_bzr_serve_then_func(args, retcode=3)
+        self.assertEqual('', out)
+        self.assertEqual('', err)
 
     def test_bzr_serve_inet_readonly(self):
         """bzr server should provide a read only filesystem by default."""
@@ -154,97 +215,8 @@
         self.make_read_requests(branch)
         self.assertServerFinishesCleanly(process)
 
-    def test_bzr_connect_to_bzr_ssh(self):
-        """User acceptance that get_transport of a bzr+ssh:// behaves correctly.
-
-        bzr+ssh:// should cause bzr to run a remote bzr smart server over SSH.
-        """
-        try:
-            from bzrlib.transport.sftp import SFTPServer
-        except ParamikoNotPresent:
-            raise TestSkipped('Paramiko not installed')
-        from bzrlib.tests.stub_sftp import StubServer
-
-        # Make a branch
-        self.make_branch('a_branch')
-
-        # Start an SSH server
-        self.command_executed = []
-        # XXX: This is horrible -- we define a really dumb SSH server that
-        # executes commands, and manage the hooking up of stdin/out/err to the
-        # SSH channel ourselves.  Surely this has already been implemented
-        # elsewhere?
-        class StubSSHServer(StubServer):
-
-            test = self
-
-            def check_channel_exec_request(self, channel, command):
-                self.test.command_executed.append(command)
-                proc = subprocess.Popen(
-                    command, shell=True, stdin=subprocess.PIPE,
-                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-
-                # XXX: horribly inefficient, not to mention ugly.
-                # Start a thread for each of stdin/out/err, and relay bytes from
-                # the subprocess to channel and vice versa.
-                def ferry_bytes(read, write, close):
-                    while True:
-                        bytes = read(1)
-                        if bytes == '':
-                            close()
-                            break
-                        write(bytes)
-
-                file_functions = [
-                    (channel.recv, proc.stdin.write, proc.stdin.close),
-                    (proc.stdout.read, channel.sendall, channel.close),
-                    (proc.stderr.read, channel.sendall_stderr, channel.close)]
-                for read, write, close in file_functions:
-                    t = threading.Thread(
-                        target=ferry_bytes, args=(read, write, close))
-                    t.start()
-
-                return True
-
-        ssh_server = SFTPServer(StubSSHServer)
-        # XXX: We *don't* want to override the default SSH vendor, so we set
-        # _vendor to what _get_ssh_vendor returns.
-        ssh_server.setUp()
-        self.addCleanup(ssh_server.tearDown)
-        port = ssh_server._listener.port
-
-        # Access the branch via a bzr+ssh URL.  The BZR_REMOTE_PATH environment
-        # variable is used to tell bzr what command to run on the remote end.
-        path_to_branch = osutils.abspath('a_branch')
-
-        orig_bzr_remote_path = os.environ.get('BZR_REMOTE_PATH')
-        bzr_remote_path = self.get_bzr_path()
-        if sys.platform == 'win32':
-            bzr_remote_path = sys.executable + ' ' + self.get_bzr_path()
-        os.environ['BZR_REMOTE_PATH'] = bzr_remote_path
-        try:
-            if sys.platform == 'win32':
-                path_to_branch = os.path.splitdrive(path_to_branch)[1]
-            branch = Branch.open(
-                'bzr+ssh://fred:secret@localhost:%d%s' % (port, path_to_branch))
-            self.make_read_requests(branch)
-            # Check we can perform write operations
-            branch.bzrdir.root_transport.mkdir('foo')
-        finally:
-            # Restore the BZR_REMOTE_PATH environment variable back to its
-            # original state.
-            if orig_bzr_remote_path is None:
-                del os.environ['BZR_REMOTE_PATH']
-            else:
-                os.environ['BZR_REMOTE_PATH'] = orig_bzr_remote_path
-
-        self.assertEqual(
-            ['%s serve --inet --directory=/ --allow-writes'
-             % bzr_remote_path],
-            self.command_executed)
-
-
-class TestCmdServeChrooting(TestCaseWithTransport):
+
+class TestCmdServeChrooting(TestBzrServeBase):
 
     def test_serve_tcp(self):
         """'bzr serve' wraps the given --directory in a ChrootServer.
@@ -256,48 +228,14 @@
         t = self.get_transport()
         t.mkdir('server-root')
         self.run_bzr_serve_then_func(
-            ['--port', '0', '--directory', t.local_abspath('server-root'),
+            ['--port', '127.0.0.1:0',
+             '--directory', t.local_abspath('server-root'),
              '--allow-writes'],
-            self.when_server_started)
+            func=self.when_server_started)
         # The when_server_started method issued a find_repositoryV3 that should
         # fail with 'norepository' because there are no repositories inside the
         # --directory.
         self.assertEqual(('norepository',), self.client_resp)
-        
-    def run_bzr_serve_then_func(self, serve_args, func, *func_args,
-            **func_kwargs):
-        """Run 'bzr serve', and run the given func in a thread once the server
-        has started.
-        
-        When 'func' terminates, the server will be terminated too.
-        """
-        # install hook
-        def on_server_start(backing_urls, tcp_server):
-            t = threading.Thread(
-                target=on_server_start_thread, args=(tcp_server,))
-            t.start()
-        def on_server_start_thread(tcp_server):
-            try:
-                # Run func
-                self.tcp_server = tcp_server
-                try:
-                    func(*func_args, **func_kwargs)
-                except Exception, e:
-                    # Log errors to make some test failures a little less
-                    # mysterious.
-                    mutter('func broke: %r', e)
-            finally:
-                # Then stop the server
-                mutter('interrupting...')
-                thread.interrupt_main()
-        SmartTCPServer.hooks.install_named_hook(
-            'server_started_ex', on_server_start,
-            'run_bzr_serve_then_func hook')
-        # start a TCP server
-        try:
-            self.run_bzr(['serve'] + list(serve_args))
-        except KeyboardInterrupt:
-            pass
 
     def when_server_started(self):
         # Connect to the TCP server and issue some requests and see what comes
@@ -316,4 +254,64 @@
         client_medium.disconnect()
 
 
+class TestUserdirExpansion(TestCaseWithMemoryTransport):
+
+    def fake_expanduser(self, path):
+        """A simple, environment-independent, function for the duration of this
+        test.
+
+        Paths starting with a path segment of '~user' will expand to start with
+        '/home/user/'.  Every other path will be unchanged.
+        """
+        if path.split('/', 1)[0] == '~user':
+            return '/home/user' + path[len('~user'):]
+        return path
+
+    def make_test_server(self, base_path='/'):
+        """Make and setUp a BzrServerFactory, backed by a memory transport, and
+        creat '/home/user' in that transport.
+        """
+        bzr_server = BzrServerFactory(
+            self.fake_expanduser, lambda t: base_path)
+        mem_transport = self.get_transport()
+        mem_transport.mkdir_multi(['home', 'home/user'])
+        bzr_server.set_up(mem_transport, None, None, inet=True)
+        self.addCleanup(bzr_server.tear_down)
+        return bzr_server
+
+    def test_bzr_serve_expands_userdir(self):
+        bzr_server = self.make_test_server()
+        self.assertTrue(bzr_server.smart_server.backing_transport.has('~user'))
+
+    def test_bzr_serve_does_not_expand_userdir_outside_base(self):
+        bzr_server = self.make_test_server('/foo')
+        self.assertFalse(bzr_server.smart_server.backing_transport.has('~user'))
+
+    def test_get_base_path(self):
+        """cmd_serve will turn the --directory option into a LocalTransport
+        (optionally decorated with 'readonly+').  BzrServerFactory can
+        determine the original --directory from that transport.
+        """
+        # URLs always include the trailing slash, and get_base_path returns it
+        base_dir = osutils.abspath('/a/b/c') + '/'
+        base_url = urlutils.local_path_to_url(base_dir) + '/'
+        # Define a fake 'protocol' to capture the transport that cmd_serve
+        # passes to serve_bzr.
+        def capture_transport(transport, host, port, inet):
+            self.bzr_serve_transport = transport
+        cmd = builtins.cmd_serve()
+        # Read-only
+        cmd.run(directory=base_dir, protocol=capture_transport)
+        server_maker = BzrServerFactory()
+        self.assertEqual(
+            'readonly+%s' % base_url, self.bzr_serve_transport.base)
+        self.assertEqual(
+            base_dir, server_maker.get_base_path(self.bzr_serve_transport))
+        # Read-write
+        cmd.run(directory=base_dir, protocol=capture_transport,
+            allow_writes=True)
+        server_maker = BzrServerFactory()
+        self.assertEqual(base_url, self.bzr_serve_transport.base)
+        self.assertEqual(base_dir,
+            server_maker.get_base_path(self.bzr_serve_transport))
 

=== modified file 'bzrlib/tests/blackbox/test_shared_repository.py'
--- bzrlib/tests/blackbox/test_shared_repository.py	2009-08-12 23:52:15 +0000
+++ bzrlib/tests/blackbox/test_shared_repository.py	2009-09-23 23:58:10 +0000
@@ -119,4 +119,4 @@
         # being too low. If rpc_count increases, more network roundtrips have
         # become necessary for this use case. Please do not adjust this number
         # upwards without agreement from bzr's network support maintainers.
-        self.assertLength(16, self.hpss_calls)
+        self.assertLength(15, self.hpss_calls)

=== modified file 'bzrlib/tests/blackbox/test_split.py'
--- bzrlib/tests/blackbox/test_split.py	2009-06-08 02:02:08 +0000
+++ bzrlib/tests/blackbox/test_split.py	2009-08-27 21:48:33 +0000
@@ -31,7 +31,7 @@
         wt.add(['b', 'b/c'])
         wt.commit('rev1')
         self.run_bzr('split a/b')
-        self.run_bzr_error(('.* is not versioned',), 'split q')
+        self.run_bzr_error(('.* is not versioned',), 'split q', working_dir='a')
 
     def test_split_repo_failure(self):
         repo = self.make_repository('branch', shared=True, format='knit')

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2009-09-17 11:54:41 +0000
@@ -112,19 +112,6 @@
         self.run_bzr('revert')
         os.chdir('..')
 
-    def test_main_version(self):
-        """Check output from version command and master option is reasonable"""
-        # output is intentionally passed through to stdout so that we
-        # can see the version being tested
-        output = self.run_bzr('version')[0]
-        self.log('bzr version output:')
-        self.log(output)
-        self.assert_(output.startswith('Bazaar (bzr) '))
-        self.assertNotEqual(output.index('Canonical'), -1)
-        # make sure --version is consistent
-        tmp_output = self.run_bzr('--version')[0]
-        self.assertEquals(output, tmp_output)
-
     def example_branch(test):
         test.run_bzr('init')
         file('hello', 'wt').write('foo')

=== modified file 'bzrlib/tests/blackbox/test_uncommit.py'
--- bzrlib/tests/blackbox/test_uncommit.py	2009-04-04 02:50:01 +0000
+++ bzrlib/tests/blackbox/test_uncommit.py	2009-10-06 14:40:37 +0000
@@ -233,14 +233,14 @@
         tree3.commit('unchanged', rev_id='c3')
 
         wt.merge_from_branch(tree2.branch)
-        wt.merge_from_branch(tree3.branch)
+        wt.merge_from_branch(tree3.branch, force=True)
         wt.commit('merge b3, c3', rev_id='a3')
 
         tree2.commit('unchanged', rev_id='b4')
         tree3.commit('unchanged', rev_id='c4')
 
         wt.merge_from_branch(tree3.branch)
-        wt.merge_from_branch(tree2.branch)
+        wt.merge_from_branch(tree2.branch, force=True)
         wt.commit('merge b4, c4', rev_id='a4')
 
         self.assertEqual(['a4'], wt.get_parent_ids())

=== modified file 'bzrlib/tests/blackbox/test_version.py'
--- bzrlib/tests/blackbox/test_version.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_version.py	2009-09-17 11:54:41 +0000
@@ -31,7 +31,22 @@
 
 class TestVersion(TestCase):
 
+    def test_main_version(self):
+        """Check output from version command and master option is reasonable"""
+        # output is intentionally passed through to stdout so that we
+        # can see the version being tested
+        self.permit_source_tree_branch_repo()
+        output = self.run_bzr('version')[0]
+        self.log('bzr version output:')
+        self.log(output)
+        self.assert_(output.startswith('Bazaar (bzr) '))
+        self.assertNotEqual(output.index('Canonical'), -1)
+        # make sure --version is consistent
+        tmp_output = self.run_bzr('--version')[0]
+        self.assertEquals(output, tmp_output)
+
     def test_version(self):
+        self.permit_source_tree_branch_repo()
         out = self.run_bzr("version")[0]
         self.assertTrue(len(out) > 0)
         self.assertEqualDiff(out.splitlines()[0],
@@ -43,6 +58,7 @@
         self.assertContainsRe(out, r'(?m)^  Bazaar log file:.*\.bzr\.log')
 
     def test_version_short(self):
+        self.permit_source_tree_branch_repo()
         out = self.run_bzr(["version", "--short"])[0]
         self.assertEqualDiff(out, bzrlib.version_string + '\n')
 
@@ -50,6 +66,7 @@
 class TestVersionUnicodeOutput(TestCaseInTempDir):
 
     def _check(self, args):
+        self.permit_source_tree_branch_repo()
         # Even though trace._bzr_log_filename variable
         # is used only to keep actual log filename
         # and changing this variable in selftest
@@ -79,6 +96,7 @@
                               ' encoding %s' % (osutils.get_user_encoding(),))
 
         osutils.set_or_unset_env('BZR_HOME', str_val)
+        self.permit_source_tree_branch_repo()
         out = self.run_bzr("version")[0]
         self.assertTrue(len(out) > 0)
         self.assertContainsRe(out, r"(?m)^  Bazaar configuration: " + str_val)
@@ -98,6 +116,8 @@
         self.failUnlessExists(bzr_log)
 
     def test_dev_null(self):
+        # This test uses a subprocess to cause the log opening logic to
+        # execute. It would be better to just execute that logic directly.
         if sys.platform == 'win32':
             bzr_log = 'NUL'
         else:

=== modified file 'bzrlib/tests/ftp_server/pyftpdlib_based.py'
--- bzrlib/tests/ftp_server/pyftpdlib_based.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/ftp_server/pyftpdlib_based.py	2009-10-06 08:24:14 +0000
@@ -84,7 +84,7 @@
         line = self.fs.fs2ftp(path)
         if self.fs.isfile(self.fs.realpath(path)):
             why = "Not a directory: %s" % line
-            self.log('FAIL SIZE "%s". %s.' % (line, why))
+            self.log('FAIL NLST "%s". %s.' % (line, why))
             self.respond("550 %s."  %why)
         else:
             ftpserver.FTPHandler.ftp_NLST(self, path)
@@ -180,8 +180,7 @@
         self._port = self._ftp_server.socket.getsockname()[1]
         self._ftpd_starting = threading.Lock()
         self._ftpd_starting.acquire() # So it can be released by the server
-        self._ftpd_thread = threading.Thread(
-                target=self._run_server,)
+        self._ftpd_thread = threading.Thread(target=self._run_server,)
         self._ftpd_thread.start()
         # Wait for the server thread to start (i.e release the lock)
         self._ftpd_starting.acquire()
@@ -202,7 +201,11 @@
         self._ftpd_running = True
         self._ftpd_starting.release()
         while self._ftpd_running:
-            self._ftp_server.serve_forever(timeout=0.1, count=1)
+            try:
+                self._ftp_server.serve_forever(timeout=0.1, count=1)
+            except select.error, e:
+                if e.args[0] != errno.EBADF:
+                    raise
         self._ftp_server.close_all(ignore_all=True)
 
     def add_user(self, user, password):

=== modified file 'bzrlib/tests/http_server.py'
--- bzrlib/tests/http_server.py	2009-07-08 15:24:31 +0000
+++ bzrlib/tests/http_server.py	2009-11-18 17:36:36 +0000
@@ -462,7 +462,7 @@
                 raise httplib.UnknownProtocol(proto_vers)
             else:
                 self._httpd = self.create_httpd(serv_cls, rhandler)
-            host, self.port = self._httpd.socket.getsockname()
+            self.host, self.port = self._httpd.socket.getsockname()
         return self._httpd
 
     def _http_start(self):
@@ -494,13 +494,16 @@
             except socket.timeout:
                 pass
             except (socket.error, select.error), e:
-               if e[0] == errno.EBADF:
-                   # Starting with python-2.6, handle_request may raise socket
-                   # or select exceptions when the server is shut down (as we
-                   # do).
-                   pass
-               else:
-                   raise
+                if (e[0] == errno.EBADF
+                    or (sys.platform == 'win32' and e[0] == 10038)):
+                    # Starting with python-2.6, handle_request may raise socket
+                    # or select exceptions when the server is shut down (as we
+                    # do).
+                    # 10038 = WSAENOTSOCK
+                    # http://msdn.microsoft.com/en-us/library/ms740668%28VS.85%29.aspx
+                    pass
+                else:
+                    raise
 
     def _get_remote_url(self, path):
         path_parts = path.split(os.path.sep)

=== modified file 'bzrlib/tests/http_utils.py'
--- bzrlib/tests/http_utils.py	2009-05-04 14:48:21 +0000
+++ bzrlib/tests/http_utils.py	2009-08-27 22:17:35 +0000
@@ -133,8 +133,7 @@
         """Get the server instance for the secondary transport."""
         if self.__secondary_server is None:
             self.__secondary_server = self.create_transport_secondary_server()
-            self.__secondary_server.setUp()
-            self.addCleanup(self.__secondary_server.tearDown)
+            self.start_server(self.__secondary_server)
         return self.__secondary_server
 
 

=== modified file 'bzrlib/tests/lock_helpers.py'
--- bzrlib/tests/lock_helpers.py	2009-04-15 07:30:34 +0000
+++ bzrlib/tests/lock_helpers.py	2009-10-15 02:11:18 +0000
@@ -17,6 +17,7 @@
 """Helper functions/classes for testing locking"""
 
 from bzrlib import errors
+from bzrlib.decorators import only_raises
 
 
 class TestPreventLocking(errors.LockError):
@@ -68,6 +69,7 @@
             return self._other.lock_write()
         raise TestPreventLocking('lock_write disabled')
 
+    @only_raises(errors.LockNotHeld, errors.LockBroken)
     def unlock(self):
         self._sequence.append((self._other_id, 'ul', self._allow_unlock))
         if self._allow_unlock:

=== modified file 'bzrlib/tests/per_branch/test_locking.py'
--- bzrlib/tests/per_branch/test_locking.py	2009-07-10 10:46:00 +0000
+++ bzrlib/tests/per_branch/test_locking.py	2009-10-15 02:11:18 +0000
@@ -139,7 +139,7 @@
         try:
             self.assertTrue(b.is_locked())
             self.assertTrue(b.repository.is_locked())
-            self.assertRaises(TestPreventLocking, b.unlock)
+            self.assertLogsError(TestPreventLocking, b.unlock)
             if self.combined_control:
                 self.assertTrue(b.is_locked())
             else:
@@ -183,7 +183,7 @@
         try:
             self.assertTrue(b.is_locked())
             self.assertTrue(b.repository.is_locked())
-            self.assertRaises(TestPreventLocking, b.unlock)
+            self.assertLogsError(TestPreventLocking, b.unlock)
             self.assertTrue(b.is_locked())
             self.assertTrue(b.repository.is_locked())
 

=== modified file 'bzrlib/tests/per_branch/test_parent.py'
--- bzrlib/tests/per_branch/test_parent.py	2009-04-15 03:45:24 +0000
+++ bzrlib/tests/per_branch/test_parent.py	2009-11-08 03:00:33 +0000
@@ -96,11 +96,11 @@
         if sys.platform != 'win32':
             raise TestSkipped('windows-specific test')
         b = self.make_branch('.')
-        base_url = b.abspath('.')
+        base_url = b.bzrdir.transport.abspath('.')
         if not base_url.startswith('file:///'):
             raise TestNotApplicable('this test should be run with local base')
         base = urlutils.local_path_from_url(base_url)
-        other = 'file:///B:/path'
+        other = 'file:///D:/path'
         if base[0] != 'C':
             other = 'file:///C:/path'
         b.set_parent(other)

=== modified file 'bzrlib/tests/per_branch/test_permissions.py'
--- bzrlib/tests/per_branch/test_permissions.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/per_branch/test_permissions.py	2009-09-07 08:46:00 +0000
@@ -91,10 +91,10 @@
                                           ' permission logic')
         if sys.platform == 'win32':
             raise tests.TestNotApplicable('chmod has no effect on win32')
-        elif sys.platform == 'darwin':
-            # OS X creates temp dirs with the 'wheel' group, which users are
-            # not likely to be in, and this prevents us from setting the sgid
-            # bit
+        elif sys.platform == 'darwin' or sys.platform.startswith('freebsd'):
+            # OS X (and FreeBSD) create temp dirs with the 'wheel' group, which
+            # users are not likely to be in, and this prevents us from setting
+            # the sgid bit
             os.chown(self.test_dir, os.getuid(), os.getgid())
         # also, these are BzrBranch format specific things..
         t = self.make_branch_and_tree('.')

=== modified file 'bzrlib/tests/per_branch/test_push.py'
--- bzrlib/tests/per_branch/test_push.py	2009-08-14 00:55:42 +0000
+++ bzrlib/tests/per_branch/test_push.py	2009-09-24 05:31:23 +0000
@@ -394,8 +394,7 @@
         # Create a smart server that publishes whatever the backing VFS server
         # does.
         self.smart_server = server.SmartTCPServer_for_testing()
-        self.smart_server.setUp(self.get_server())
-        self.addCleanup(self.smart_server.tearDown)
+        self.start_server(self.smart_server, self.get_server())
         # Make two empty branches, 'empty' and 'target'.
         self.empty_branch = self.make_branch('empty')
         self.make_branch('target')
@@ -414,7 +413,7 @@
         target = Branch.open_from_transport(transport)
         self.empty_branch.push(target)
         self.assertEqual(
-            ['BzrDir.open',
+            ['BzrDir.open_2.1',
              'BzrDir.open_branchV2',
              'BzrDir.find_repositoryV3',
              'Branch.get_stacked_on_url',

=== modified file 'bzrlib/tests/per_bzrdir/test_bzrdir.py'
--- bzrlib/tests/per_bzrdir/test_bzrdir.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/per_bzrdir/test_bzrdir.py	2009-11-18 17:10:41 +0000
@@ -28,6 +28,7 @@
     bzrdir,
     check,
     errors,
+    gpg,
     lockdir,
     osutils,
     repository,
@@ -432,6 +433,27 @@
         target = dir.clone(self.get_url('target'), revision_id='2')
         raise TestSkipped('revision limiting not strict yet')
 
+    def test_clone_bzrdir_branch_and_repo_fixed_user_id(self):
+        # Bug #430868 is about an email containing '.sig'
+        os.environ['BZR_EMAIL'] = 'murphy@host.sighup.org'
+        tree = self.make_branch_and_tree('commit_tree')
+        self.build_tree(['commit_tree/foo'])
+        tree.add('foo')
+        rev1 = tree.commit('revision 1')
+        tree_repo = tree.branch.repository
+        tree_repo.lock_write()
+        tree_repo.start_write_group()
+        tree_repo.sign_revision(rev1, gpg.LoopbackGPGStrategy(None))
+        tree_repo.commit_write_group()
+        tree_repo.unlock()
+        target = self.make_branch('target')
+        tree.branch.repository.copy_content_into(target.repository)
+        tree.branch.copy_content_into(target)
+        self.assertTrue(target.repository.has_revision(rev1))
+        self.assertEqual(
+            tree_repo.get_signature_text(rev1),
+            target.repository.get_signature_text(rev1))
+
     def test_clone_bzrdir_branch_and_repo(self):
         tree = self.make_branch_and_tree('commit_tree')
         self.build_tree(['commit_tree/foo'])
@@ -756,13 +778,16 @@
                                      './.bzr/repository/inventory.knit',
                                      ])
         try:
+            local_inventory = dir.transport.local_abspath('inventory')
+        except errors.NotLocalUrl:
+            return
+        try:
             # If we happen to have a tree, we'll guarantee everything
             # except for the tree root is the same.
-            inventory_f = file(dir.transport.base+'inventory', 'rb')
+            inventory_f = file(local_inventory, 'rb')
+            self.addCleanup(inventory_f.close)
             self.assertContainsRe(inventory_f.read(),
-                                  '<inventory file_id="TREE_ROOT[^"]*"'
-                                  ' format="5">\n</inventory>\n')
-            inventory_f.close()
+                                  '<inventory format="5">\n</inventory>\n')
         except IOError, e:
             if e.errno != errno.ENOENT:
                 raise
@@ -1210,9 +1235,6 @@
             return
         self.assertNotEqual(repo.bzrdir.root_transport.base,
             made_repo.bzrdir.root_transport.base)
-        # New repositories are write locked.
-        self.assertTrue(made_repo.is_write_locked())
-        made_repo.unlock()
 
     def test_format_initialize_on_transport_ex_force_new_repo_False(self):
         t = self.get_transport('repo')
@@ -1245,9 +1267,6 @@
             # uninitialisable format
             return
         self.assertLength(1, repo._fallback_repositories)
-        # New repositories are write locked.
-        self.assertTrue(repo.is_write_locked())
-        repo.unlock()
 
     def test_format_initialize_on_transport_ex_default_stack_on(self):
         # When initialize_on_transport_ex uses a stacked-on branch because of
@@ -1270,6 +1289,7 @@
         repo_name = repo_fmt.repository_format.network_name()
         repo, control = self.assertInitializeEx(
             t, need_meta=True, repo_format_name=repo_name, stacked_on=None)
+        # self.addCleanup(repo.unlock)
         if control is None:
             # uninitialisable format
             return
@@ -1301,9 +1321,6 @@
             # must stay with the all-in-one-format.
             repo_name = self.bzrdir_format.network_name()
         self.assertEqual(repo_name, repo._format.network_name())
-        # New repositories are write locked.
-        self.assertTrue(repo.is_write_locked())
-        repo.unlock()
 
     def assertInitializeEx(self, t, need_meta=False, **kwargs):
         """Execute initialize_on_transport_ex and check it succeeded correctly.
@@ -1321,6 +1338,10 @@
             return None, None
         repo, control, require_stacking, repo_policy = \
             self.bzrdir_format.initialize_on_transport_ex(t, **kwargs)
+        if repo is not None:
+            # Repositories are open write-locked
+            self.assertTrue(repo.is_write_locked())
+            self.addCleanup(repo.unlock)
         self.assertIsInstance(control, bzrdir.BzrDir)
         opened = bzrdir.BzrDir.open(t.base)
         expected_format = self.bzrdir_format

=== added directory 'bzrlib/tests/per_foreign_vcs'
=== added file 'bzrlib/tests/per_foreign_vcs/__init__.py'
--- bzrlib/tests/per_foreign_vcs/__init__.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/per_foreign_vcs/__init__.py	2009-11-12 22:57:55 +0000
@@ -0,0 +1,50 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+
+"""Tests specific to foreign branch implementations.
+
+"""
+
+from bzrlib import (
+    foreign,
+    tests,
+    )
+
+
+def vcs_scenarios():
+    scenarios = []
+    for name, vcs in foreign.foreign_vcs_registry.iteritems():
+        scenarios.append((vcs.__class__.__name__, {
+            "branch_factory": vcs.branch_format.get_foreign_tests_branch_factory(),
+            "repository_factory": vcs.repository_format.get_foreign_tests_repository_factory(),
+            "branch_format": vcs.branch_format,
+            "repository_format": vcs.repository_format,
+            }))
+    return scenarios
+
+
+def load_tests(standard_tests, module, loader):
+    result = loader.suiteClass()
+    per_vcs_mod_names = [
+        'branch',
+        'repository',
+        ]
+    sub_tests = loader.loadTestsFromModuleNames(
+        ['bzrlib.tests.per_foreign_vcs.test_' + name
+         for name in per_vcs_mod_names])
+    tests.multiply_tests(sub_tests, vcs_scenarios(), result)
+    return result

=== added file 'bzrlib/tests/per_foreign_vcs/test_branch.py'
--- bzrlib/tests/per_foreign_vcs/test_branch.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/per_foreign_vcs/test_branch.py	2009-10-11 01:20:37 +0000
@@ -0,0 +1,151 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+
+"""Tests specific to Branch implementations that use foreign VCS'es."""
+
+
+from bzrlib.errors import (
+    UnstackableBranchFormat,
+    )
+from bzrlib.revision import (
+    NULL_REVISION,
+    )
+from bzrlib.tests import (
+    TestCase,
+    TestCaseWithTransport,
+    )
+
+
+class ForeignBranchFactory(object):
+    """Factory of branches for ForeignBranchTests."""
+
+    def make_empty_branch(self, transport):
+        """Create an empty branch with no commits in it."""
+        raise NotImplementedError(self.make_empty_branch)
+
+    def make_branch(self, transport):
+        """Create *some* branch, may be empty or not."""
+        return self.make_empty_branch(transport)
+
+
+class ForeignBranchTests(TestCaseWithTransport):
+    """Basic tests for foreign branch implementations.
+    
+    These tests mainly make sure that the implementation covers the required 
+    bits of the API and returns reasonable values. 
+    """
+    branch_factory = None # Set to an instance of ForeignBranchFactory by scenario
+
+    def make_empty_branch(self):
+        return self.branch_factory.make_empty_branch(self.get_transport())
+
+    def make_branch(self):
+        return self.branch_factory.make_branch(self.get_transport())
+
+    def test_set_parent(self):
+        """Test that setting the parent works."""
+        branch = self.make_branch()
+        branch.set_parent("foobar")
+
+    def test_break_lock(self):
+        """Test that break_lock() works, even if it is a no-op."""
+        branch = self.make_branch()
+        branch.break_lock()
+
+    def test_set_push_location(self):
+        """Test that setting the push location works."""
+        branch = self.make_branch()
+        branch.set_push_location("http://bar/bloe")
+
+    def test_repr_type(self):
+        branch = self.make_branch()
+        self.assertIsInstance(repr(branch), str)
+
+    def test_get_parent(self):
+        """Test that getting the parent location works, and returns None."""
+        # TODO: Allow this to be non-None when foreign branches add support 
+        #       for storing this URL.
+        branch = self.make_branch()
+        self.assertIs(None, branch.get_parent())
+
+    def test_get_push_location(self):
+        """Test that getting the push location works, and returns None."""
+        # TODO: Allow this to be non-None when foreign branches add support 
+        #       for storing this URL.
+        branch = self.make_branch()
+        self.assertIs(None, branch.get_push_location())
+
+    def test_attributes(self):
+        """Check that various required attributes are present."""
+        branch = self.make_branch()
+        self.assertIsNot(None, getattr(branch, "repository", None))
+        self.assertIsNot(None, getattr(branch, "mapping", None))
+        self.assertIsNot(None, getattr(branch, "_format", None))
+        self.assertIsNot(None, getattr(branch, "base", None))
+
+    def test__get_nick(self):
+        """Make sure _get_nick is implemented and returns a string."""
+        branch = self.make_branch()
+        self.assertIsInstance(branch._get_nick(local=False), str)
+        self.assertIsInstance(branch._get_nick(local=True), str)
+
+    def test_null_revid_revno(self):
+        """null: should return revno 0."""
+        branch = self.make_branch()
+        self.assertEquals(0, branch.revision_id_to_revno(NULL_REVISION))
+
+    def test_get_stacked_on_url(self):
+        """Test that get_stacked_on_url() behaves as expected.
+
+        Inter-Format stacking doesn't work yet, so all foreign implementations
+        should raise UnstackableBranchFormat at the moment.
+        """
+        branch = self.make_branch()
+        self.assertRaises(UnstackableBranchFormat, 
+                          branch.get_stacked_on_url)
+
+    def test_get_physical_lock_status(self):
+        branch = self.make_branch()
+        self.assertFalse(branch.get_physical_lock_status())
+
+    def test_last_revision_empty_branch(self):
+        branch = self.make_empty_branch()
+        self.assertEquals(NULL_REVISION, branch.last_revision())
+        self.assertEquals(0, branch.revno())
+        self.assertEquals((0, NULL_REVISION), branch.last_revision_info())
+
+
+class ForeignBranchFormatTests(TestCase):
+    """Basic tests for foreign branch format objects."""
+
+    branch_format = None # Set to a BranchFormat instance by adapter
+
+    def test_initialize(self):
+        """Test this format is not initializable.
+        
+        Remote branches may be initializable on their own, but none currently
+        support living in .bzr/branch.
+        """
+        self.assertRaises(NotImplementedError, self.branch_format.initialize, None)
+
+    def test_get_format_description_type(self):
+        self.assertIsInstance(self.branch_format.get_format_description(), str)
+
+    def test_network_name(self):
+        self.assertIsInstance(self.branch_format.network_name(), str)
+
+

=== added file 'bzrlib/tests/per_foreign_vcs/test_repository.py'
--- bzrlib/tests/per_foreign_vcs/test_repository.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/per_foreign_vcs/test_repository.py	2009-11-27 03:25:07 +0000
@@ -0,0 +1,88 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+
+"""Tests specific to Repository implementations that use foreign VCS'es."""
+
+
+from bzrlib.tests import (
+    TestCase,
+    TestCaseWithTransport,
+    )
+
+
+class TestRepositoryFormat(TestCase):
+
+    def test_format_string(self):
+        self.assertRaises(NotImplementedError,
+            self.repository_format.get_format_string)
+
+    def test_network_name(self):
+        self.assertIsInstance(self.repository_format.network_name(),
+            str)
+
+    def test_format_description(self):
+        self.assertIsInstance(self.repository_format.get_format_description(),
+            str)
+
+
+class ForeignRepositoryFactory(object):
+    """Factory of repository for ForeignRepositoryTests."""
+
+    def make_repository(self, transport):
+        """Create a new, valid, repository. May or may not contain
+        data."""
+        raise NotImplementedError(self.make_repository)
+
+
+class ForeignRepositoryTests(TestCaseWithTransport):
+    """Basic tests for foreign repository implementations.
+
+    These tests mainly make sure that the implementation covers the required
+    bits of the API and returns semi-reasonable values, that are
+    at least of the expected types and in the expected ranges.
+    """
+
+    # XXX: Some of these tests could be moved into a common testcase for
+    # both native and foreign repositories.
+
+    repository_factory = None # Set to an instance of ForeignRepositoryFactory by the scenario
+
+    def make_repository(self):
+        return self.repository_factory.make_repository(self.get_transport())
+
+    def test_make_working_trees(self):
+        """Test that Repository.make_working_trees() returns a boolean."""
+        repo = self.make_repository()
+        self.assertIsInstance(repo.make_working_trees(), bool)
+
+    def test_get_physical_lock_status(self):
+        """Test that a new repository is not locked by default."""
+        repo = self.make_repository()
+        self.assertFalse(repo.get_physical_lock_status())
+
+    def test_is_shared(self):
+        """Test that is_shared() returns a bool."""
+        repo = self.make_repository()
+        self.assertIsInstance(repo.is_shared(), bool)
+
+    def test_gather_stats(self):
+        """Test that gather_stats() will at least return a dictionary
+        with the required keys."""
+        repo = self.make_repository()
+        stats = repo.gather_stats()
+        self.assertIsInstance(stats, dict)
+        self.assertTrue(stats.has_key("revisions"))

=== modified file 'bzrlib/tests/per_interrepository/test_fetch.py'
--- bzrlib/tests/per_interrepository/test_fetch.py	2009-08-26 07:40:38 +0000
+++ bzrlib/tests/per_interrepository/test_fetch.py	2009-10-02 02:40:37 +0000
@@ -45,8 +45,16 @@
     )
 
 
+
 class TestInterRepository(TestCaseWithInterRepository):
 
+    def disable_commit_write_group_paranoia(self, repo):
+        pack_coll = getattr(repo, '_pack_collection', None)
+        if pack_coll is not None:
+            # Monkey-patch the pack collection instance to allow storing
+            # incomplete revisions.
+            pack_coll._check_new_inventories = lambda: []
+
     def test_fetch(self):
         tree_a = self.make_branch_and_tree('a')
         self.build_tree(['a/foo'])
@@ -126,6 +134,44 @@
             to_repo.texts.get_record_stream([('foo', revid)],
             'unordered', True).next().get_bytes_as('fulltext'))
 
+    def test_fetch_from_stacked_smart(self):
+        self.setup_smart_server_with_call_log()
+        self.test_fetch_from_stacked()
+
+    def test_fetch_from_stacked_smart_old(self):
+        self.setup_smart_server_with_call_log()
+        self.disable_verb('Repository.get_stream_1.19')
+        self.test_fetch_from_stacked()
+
+    def test_fetch_from_stacked(self):
+        """Fetch from a stacked branch succeeds."""
+        if not self.repository_format.supports_external_lookups:
+            raise TestNotApplicable("Need stacking support in the source.")
+        builder = self.make_branch_builder('full-branch')
+        builder.start_series()
+        builder.build_snapshot('first', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        builder.build_snapshot('second', ['first'], [
+            ('modify', ('file-id', 'second content\n'))])
+        builder.build_snapshot('third', ['second'], [
+            ('modify', ('file-id', 'third content\n'))])
+        builder.finish_series()
+        branch = builder.get_branch()
+        repo = self.make_repository('stacking-base')
+        trunk = repo.bzrdir.create_branch()
+        trunk.repository.fetch(branch.repository, 'second')
+        repo = self.make_repository('stacked')
+        stacked_branch = repo.bzrdir.create_branch()
+        stacked_branch.set_stacked_on_url(trunk.base)
+        stacked_branch.repository.fetch(branch.repository, 'third')
+        target = self.make_to_repository('target')
+        target.fetch(stacked_branch.repository, 'third')
+        target.lock_read()
+        self.addCleanup(target.unlock)
+        all_revs = set(['first', 'second', 'third'])
+        self.assertEqual(all_revs, set(target.get_parent_map(all_revs)))
+
     def test_fetch_parent_inventories_at_stacking_boundary_smart(self):
         self.setup_smart_server_with_call_log()
         self.test_fetch_parent_inventories_at_stacking_boundary()
@@ -365,11 +411,16 @@
         to_repo.lock_write()
         try:
             to_repo.start_write_group()
-            inv = tree.branch.repository.get_inventory('rev-one')
-            to_repo.add_inventory('rev-one', inv, [])
-            rev = tree.branch.repository.get_revision('rev-one')
-            to_repo.add_revision('rev-one', rev, inv=inv)
-            to_repo.commit_write_group()
+            try:
+                inv = tree.branch.repository.get_inventory('rev-one')
+                to_repo.add_inventory('rev-one', inv, [])
+                rev = tree.branch.repository.get_revision('rev-one')
+                to_repo.add_revision('rev-one', rev, inv=inv)
+                self.disable_commit_write_group_paranoia(to_repo)
+                to_repo.commit_write_group()
+            except:
+                to_repo.abort_write_group(suppress_errors=True)
+                raise
         finally:
             to_repo.unlock()
 
@@ -424,7 +475,7 @@
         source_tree.add(['id'], ['id'])
         source_tree.commit('a', rev_id='a')
         # now we manually insert a revision with an inventory referencing
-        # 'id' at revision 'b', but we do not insert revision b.
+        # file 'id' at revision 'b', but we do not insert revision b.
         # this should ensure that the new versions of files are being checked
         # for during pull operations
         inv = source.get_inventory('a')
@@ -442,6 +493,7 @@
                        revision_id='b')
         rev.parent_ids = ['a']
         source.add_revision('b', rev)
+        self.disable_commit_write_group_paranoia(source)
         source.commit_write_group()
         self.assertRaises(errors.RevisionNotPresent, target.fetch, source)
         self.assertFalse(target.has_revision('b'))

=== modified file 'bzrlib/tests/per_intertree/__init__.py'
--- bzrlib/tests/per_intertree/__init__.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_intertree/__init__.py	2009-11-12 23:10:43 +0000
@@ -163,7 +163,8 @@
                  optimiser._matching_from_tree_format,
                  optimiser._matching_to_tree_format,
                  optimiser.make_source_parent_tree_python_dirstate))
-        else:
+        elif (optimiser._matching_from_tree_format is not None and 
+              optimiser._matching_to_tree_format is not None):
             test_intertree_permutations.append(
                 (optimiser.__name__,
                  optimiser,

=== modified file 'bzrlib/tests/per_intertree/test_compare.py'
--- bzrlib/tests/per_intertree/test_compare.py	2009-08-26 03:20:32 +0000
+++ bzrlib/tests/per_intertree/test_compare.py	2009-10-02 05:43:41 +0000
@@ -948,6 +948,39 @@
                            (False, True))],
                          self.do_iter_changes(tree1, tree2))
 
+    def test_file_becomes_unversionable_bug_438569(self):
+        # This isn't strictly a intertree problem, but its the intertree code
+        # path that triggers all stat cache updates on both xml and dirstate
+        # trees.
+        # In bug 438569, a file becoming a fifo causes an assert. Fifo's are
+        # not versionable or diffable. For now, we simply stop cold when they
+        # are detected (because we don't know how far through the code the 
+        # assumption 'fifo's do not exist' goes). In future we could report 
+        # the kind change and have commit refuse to go futher, or something
+        # similar. One particular reason for choosing this approach is that
+        # there is no minikind for 'fifo' in dirstate today, so we can't 
+        # actually update records that way.
+        # To add confusion, the totally generic code path works - but it
+        # doesn't update persistent metadata. So this test permits InterTrees
+        # to either work, or fail with BadFileKindError.
+        self.requireFeature(tests.OsFifoFeature)
+        tree1 = self.make_branch_and_tree('1')
+        self.build_tree(['1/a'])
+        tree1.set_root_id('root-id')
+        tree1.add(['a'], ['a-id'])
+        tree2 = self.make_branch_and_tree('2')
+        os.mkfifo('2/a')
+        tree2.add(['a'], ['a-id'], ['file'])
+        try:
+            tree1, tree2 = self.mutable_trees_to_test_trees(self, tree1, tree2)
+        except (KeyError,):
+            raise tests.TestNotApplicable(
+                "Cannot represent a FIFO in this case %s" % self.id())
+        try:
+            self.do_iter_changes(tree1, tree2)
+        except errors.BadFileKindError:
+            pass
+
     def test_missing_in_target(self):
         """Test with the target files versioned but absent from disk."""
         tree1 = self.make_branch_and_tree('1')

=== modified file 'bzrlib/tests/per_inventory/__init__.py'
--- bzrlib/tests/per_inventory/__init__.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_inventory/__init__.py	2009-09-24 18:51:41 +0000
@@ -16,15 +16,52 @@
 
 """Tests for different inventory implementations"""
 
-from bzrlib.tests import multiply_tests
+from bzrlib import (
+    groupcompress,
+    tests,
+    )
 
 def load_tests(basic_tests, module, loader):
     """Generate suite containing all parameterized tests"""
     modules_to_test = [
         'bzrlib.tests.per_inventory.basics',
         ]
-    from bzrlib.inventory import Inventory
-    scenarios = [('Inventory', {'inventory_class':Inventory})]
+    from bzrlib.inventory import Inventory, CHKInventory
+
+    def inv_to_chk_inv(test, inv):
+        """CHKInventory needs a backing VF, so we create one."""
+        factory = groupcompress.make_pack_factory(True, True, 1)
+        trans = test.get_transport('chk-inv')
+        trans.ensure_base()
+        vf = factory(trans)
+        # We intentionally use a non-standard maximum_size, so that we are more
+        # likely to trigger splits, and get increased test coverage.
+        chk_inv = CHKInventory.from_inventory(vf, inv,
+                        maximum_size=100,
+                        search_key_name='hash-255-way')
+        return chk_inv
+    scenarios = [('Inventory', {'_inventory_class': Inventory,
+                                '_inv_to_test_inv': lambda test, inv: inv
+                               }),
+                 ('CHKInventory', {'_inventory_class': CHKInventory,
+                                   '_inv_to_test_inv': inv_to_chk_inv,
+                                  })]
     # add the tests for the sub modules
-    return multiply_tests(loader.loadTestsFromModuleNames(modules_to_test),
+    return tests.multiply_tests(
+        loader.loadTestsFromModuleNames(modules_to_test),
         scenarios, basic_tests)
+
+
+class TestCaseWithInventory(tests.TestCaseWithMemoryTransport):
+
+    _inventory_class = None # set by load_tests
+    _inv_to_test_inv = None # set by load_tests
+
+    def make_test_inventory(self):
+        """Return an instance of the Inventory class under test."""
+        return self._inventory_class()
+
+    def inv_to_test_inv(self, inv):
+        """Convert a regular Inventory object into an inventory under test."""
+        return self._inv_to_test_inv(self, inv)
+

=== modified file 'bzrlib/tests/per_inventory/basics.py'
--- bzrlib/tests/per_inventory/basics.py	2009-07-17 00:49:02 +0000
+++ bzrlib/tests/per_inventory/basics.py	2009-09-24 20:09:36 +0000
@@ -21,6 +21,8 @@
 
 from bzrlib import (
         errors,
+        inventory,
+        osutils,
         )
 
 from bzrlib.inventory import (
@@ -28,22 +30,36 @@
         InventoryEntry,
         InventoryFile,
         InventoryLink,
-        ROOT_ID,
         TreeReference,
         )
 
-from bzrlib.tests import (
-        TestCase,
-        )
-
-
-class TestInventory(TestCase):
-
-    def make_inventory(self, root_id):
-        return self.inventory_class(root_id=root_id)
+from bzrlib.tests.per_inventory import TestCaseWithInventory
+
+
+
+class TestInventory(TestCaseWithInventory):
+
+    def make_init_inventory(self):
+        inv = inventory.Inventory('tree-root')
+        inv.revision = 'initial-rev'
+        inv.root.revision = 'initial-rev'
+        return self.inv_to_test_inv(inv)
+
+    def make_file(self, file_id, name, parent_id, content='content\n',
+                  revision='new-test-rev'):
+        ie = InventoryFile(file_id, name, parent_id)
+        ie.text_sha1 = osutils.sha_string(content)
+        ie.text_size = len(content)
+        ie.revision = revision
+        return ie
+
+    def make_link(self, file_id, name, parent_id, target='link-target\n'):
+        ie = InventoryLink(file_id, name, parent_id)
+        ie.symlink_target = target
+        return ie
 
     def prepare_inv_with_nested_dirs(self):
-        inv = self.make_inventory('tree-root')
+        inv = inventory.Inventory('tree-root')
         for args in [('src', 'directory', 'src-id'),
                      ('doc', 'directory', 'doc-id'),
                      ('src/hello.c', 'file', 'hello-id'),
@@ -53,172 +69,98 @@
                      ('src/zz.c', 'file', 'zzc-id'),
                      ('src/sub/a', 'file', 'a-id'),
                      ('Makefile', 'file', 'makefile-id')]:
-            inv.add_path(*args)
-        return inv
-
-
-class TestInventoryUpdates(TestInventory):
-
-    def test_creation_from_root_id(self):
-        # iff a root id is passed to the constructor, a root directory is made
-        inv = self.make_inventory(root_id='tree-root')
-        self.assertNotEqual(None, inv.root)
-        self.assertEqual('tree-root', inv.root.file_id)
-
-    def test_add_path_of_root(self):
-        # if no root id is given at creation time, there is no root directory
-        inv = self.make_inventory(root_id=None)
-        self.assertIs(None, inv.root)
-        # add a root entry by adding its path
-        ie = inv.add_path("", "directory", "my-root")
-        self.assertEqual("my-root", ie.file_id)
-        self.assertIs(ie, inv.root)
-
-    def test_add_path(self):
-        inv = self.make_inventory(root_id='tree_root')
-        ie = inv.add_path('hello', 'file', 'hello-id')
-        self.assertEqual('hello-id', ie.file_id)
-        self.assertEqual('file', ie.kind)
-
-    def test_copy(self):
-        """Make sure copy() works and creates a deep copy."""
-        inv = self.make_inventory(root_id='some-tree-root')
-        ie = inv.add_path('hello', 'file', 'hello-id')
-        inv2 = inv.copy()
-        inv.root.file_id = 'some-new-root'
-        ie.name = 'file2'
-        self.assertEqual('some-tree-root', inv2.root.file_id)
-        self.assertEqual('hello', inv2['hello-id'].name)
-
-    def test_copy_empty(self):
-        """Make sure an empty inventory can be copied."""
-        inv = self.make_inventory(root_id=None)
-        inv2 = inv.copy()
-        self.assertIs(None, inv2.root)
-
-    def test_copy_copies_root_revision(self):
-        """Make sure the revision of the root gets copied."""
-        inv = self.make_inventory(root_id='someroot')
-        inv.root.revision = 'therev'
-        inv2 = inv.copy()
-        self.assertEquals('someroot', inv2.root.file_id)
-        self.assertEquals('therev', inv2.root.revision)
-
-    def test_create_tree_reference(self):
-        inv = self.make_inventory('tree-root-123')
-        inv.add(TreeReference('nested-id', 'nested', parent_id='tree-root-123',
-                              revision='rev', reference_revision='rev2'))
-
-    def test_error_encoding(self):
-        inv = self.make_inventory('tree-root')
-        inv.add(InventoryFile('a-id', u'\u1234', 'tree-root'))
-        e = self.assertRaises(errors.InconsistentDelta, inv.add,
-            InventoryFile('b-id', u'\u1234', 'tree-root'))
-        self.assertContainsRe(str(e), r'\\u1234')
-
-    def test_add_recursive(self):
-        parent = InventoryDirectory('src-id', 'src', 'tree-root')
-        child = InventoryFile('hello-id', 'hello.c', 'src-id')
-        parent.children[child.file_id] = child
-        inv = self.make_inventory('tree-root')
-        inv.add(parent)
-        self.assertEqual('src/hello.c', inv.id2path('hello-id'))
-
-
-class TestInventoryApplyDelta(TestInventory):
+            ie = inv.add_path(*args)
+            if args[1] == 'file':
+                ie.text_sha1 = osutils.sha_string('content\n')
+                ie.text_size = len('content\n')
+        return self.inv_to_test_inv(inv)
+
+
+class TestInventoryCreateByApplyDelta(TestInventory):
     """A subset of the inventory delta application tests.
 
     See test_inv which has comprehensive delta application tests for
-    inventories, dirstate, and repository based inventories, unlike the tests
-    here which only test in-memory implementations that can support a plain
-    'apply_delta'.
+    inventories, dirstate, and repository based inventories.
     """
-
-    def test_apply_delta_add(self):
-        inv = self.make_inventory('tree-root')
-        inv.apply_delta([
-            (None, "a", "a-id", InventoryFile('a-id', 'a', 'tree-root')),
-            ])
-        self.assertEqual('a', inv.id2path('a-id'))
-
-    def test_apply_delta_delete(self):
-        inv = self.make_inventory('tree-root')
-        inv.apply_delta([
-            (None, "a", "a-id", InventoryFile('a-id', 'a', 'tree-root')),
-            ])
-        self.assertEqual('a', inv.id2path('a-id'))
-        a_ie = inv['a-id']
-        inv.apply_delta([("a", None, "a-id", None)])
+    def test_add(self):
+        inv = self.make_init_inventory()
+        inv = inv.create_by_apply_delta([
+            (None, "a", "a-id", self.make_file('a-id', 'a', 'tree-root')),
+            ], 'new-test-rev')
+        self.assertEqual('a', inv.id2path('a-id'))
+
+    def test_delete(self):
+        inv = self.make_init_inventory()
+        inv = inv.create_by_apply_delta([
+            (None, "a", "a-id", self.make_file('a-id', 'a', 'tree-root')),
+            ], 'new-rev-1')
+        self.assertEqual('a', inv.id2path('a-id'))
+        inv = inv.create_by_apply_delta([
+            ("a", None, "a-id", None),
+            ], 'new-rev-2')
         self.assertRaises(errors.NoSuchId, inv.id2path, 'a-id')
 
-    def test_apply_delta_rename(self):
-        inv = self.make_inventory('tree-root')
-        inv.apply_delta([
-            (None, "a", "a-id", InventoryFile('a-id', 'a', 'tree-root')),
-            ])
+    def test_rename(self):
+        inv = self.make_init_inventory()
+        inv = inv.create_by_apply_delta([
+            (None, "a", "a-id", self.make_file('a-id', 'a', 'tree-root')),
+            ], 'new-rev-1')
         self.assertEqual('a', inv.id2path('a-id'))
         a_ie = inv['a-id']
-        b_ie = InventoryFile(a_ie.file_id, "b", a_ie.parent_id)
-        inv.apply_delta([("a", "b", "a-id", b_ie)])
+        b_ie = self.make_file(a_ie.file_id, "b", a_ie.parent_id)
+        inv = inv.create_by_apply_delta([("a", "b", "a-id", b_ie)], 'new-rev-2')
         self.assertEqual("b", inv.id2path('a-id'))
 
-    def test_apply_delta_illegal(self):
+    def test_illegal(self):
         # A file-id cannot appear in a delta more than once
-        inv = self.make_inventory('tree-root')
-        self.assertRaises(errors.InconsistentDelta, inv.apply_delta, [
-            ("a", "a", "id-1", InventoryFile('id-1', 'a', 'tree-root')),
-            ("a", "b", "id-1", InventoryFile('id-1', 'b', 'tree-root')),
-            ])
+        inv = self.make_init_inventory()
+        self.assertRaises(errors.InconsistentDelta, inv.create_by_apply_delta, [
+            (None, "a", "id-1", self.make_file('id-1', 'a', 'tree-root')),
+            (None, "b", "id-1", self.make_file('id-1', 'b', 'tree-root')),
+            ], 'new-rev-1')
 
 
 class TestInventoryReads(TestInventory):
 
     def test_is_root(self):
         """Ensure our root-checking code is accurate."""
-        inv = self.make_inventory('TREE_ROOT')
-        self.assertTrue(inv.is_root('TREE_ROOT'))
+        inv = self.make_init_inventory()
+        self.assertTrue(inv.is_root('tree-root'))
         self.assertFalse(inv.is_root('booga'))
-        inv.root.file_id = 'booga'
+        ie = inv['tree-root'].copy()
+        ie.file_id = 'booga'
+        inv = inv.create_by_apply_delta([("", None, "tree-root", None),
+                                         (None, "", "booga", ie)], 'new-rev-2')
         self.assertFalse(inv.is_root('TREE_ROOT'))
         self.assertTrue(inv.is_root('booga'))
-        # works properly even if no root is set
-        inv.root = None
-        self.assertFalse(inv.is_root('TREE_ROOT'))
-        self.assertFalse(inv.is_root('booga'))
 
     def test_ids(self):
         """Test detection of files within selected directories."""
-        inv = self.make_inventory(ROOT_ID)
+        inv = inventory.Inventory('TREE_ROOT')
         for args in [('src', 'directory', 'src-id'),
                      ('doc', 'directory', 'doc-id'),
                      ('src/hello.c', 'file'),
                      ('src/bye.c', 'file', 'bye-id'),
                      ('Makefile', 'file')]:
-            inv.add_path(*args)
+            ie = inv.add_path(*args)
+            if args[1] == 'file':
+                ie.text_sha1 = osutils.sha_string('content\n')
+                ie.text_size = len('content\n')
+        inv = self.inv_to_test_inv(inv)
         self.assertEqual(inv.path2id('src'), 'src-id')
         self.assertEqual(inv.path2id('src/bye.c'), 'bye-id')
-        self.assert_('src-id' in inv)
+        self.assertTrue('src-id' in inv)
 
     def test_non_directory_children(self):
         """Test path2id when a parent directory has no children"""
-        inv = self.make_inventory('tree_root')
-        inv.add(InventoryFile('file-id','file',
-                                        parent_id='tree_root'))
-        inv.add(InventoryLink('link-id','link',
-                                        parent_id='tree_root'))
+        inv = inventory.Inventory('tree-root')
+        inv.add(self.make_file('file-id','file', 'tree-root'))
+        inv.add(self.make_link('link-id','link', 'tree-root'))
         self.assertIs(None, inv.path2id('file/subfile'))
         self.assertIs(None, inv.path2id('link/subfile'))
 
     def test_iter_entries(self):
-        inv = self.make_inventory('tree-root')
-        for args in [('src', 'directory', 'src-id'),
-                     ('doc', 'directory', 'doc-id'),
-                     ('src/hello.c', 'file', 'hello-id'),
-                     ('src/bye.c', 'file', 'bye-id'),
-                     ('src/sub', 'directory', 'sub-id'),
-                     ('src/sub/a', 'file', 'a-id'),
-                     ('Makefile', 'file', 'makefile-id')]:
-            inv.add_path(*args)
+        inv = self.prepare_inv_with_nested_dirs()
 
         # Test all entries
         self.assertEqual([
@@ -230,6 +172,8 @@
             ('src/hello.c', 'hello-id'),
             ('src/sub', 'sub-id'),
             ('src/sub/a', 'a-id'),
+            ('src/zz.c', 'zzc-id'),
+            ('zz', 'zz-id'),
             ], [(path, ie.file_id) for path, ie in inv.iter_entries()])
 
         # Test a subdirectory
@@ -238,6 +182,7 @@
             ('hello.c', 'hello-id'),
             ('sub', 'sub-id'),
             ('sub/a', 'a-id'),
+            ('zz.c', 'zzc-id'),
             ], [(path, ie.file_id) for path, ie in inv.iter_entries(
             from_dir='src-id')])
 
@@ -247,6 +192,7 @@
             ('Makefile', 'makefile-id'),
             ('doc', 'doc-id'),
             ('src', 'src-id'),
+            ('zz', 'zz-id'),
             ], [(path, ie.file_id) for path, ie in inv.iter_entries(
             recursive=False)])
 
@@ -255,24 +201,23 @@
             ('bye.c', 'bye-id'),
             ('hello.c', 'hello-id'),
             ('sub', 'sub-id'),
+            ('zz.c', 'zzc-id'),
             ], [(path, ie.file_id) for path, ie in inv.iter_entries(
             from_dir='src-id', recursive=False)])
 
     def test_iter_just_entries(self):
-        inv = self.make_inventory('tree-root')
-        for args in [('src', 'directory', 'src-id'),
-                     ('doc', 'directory', 'doc-id'),
-                     ('src/hello.c', 'file', 'hello-id'),
-                     ('src/bye.c', 'file', 'bye-id'),
-                     ('Makefile', 'file', 'makefile-id')]:
-            inv.add_path(*args)
+        inv = self.prepare_inv_with_nested_dirs()
         self.assertEqual([
+            'a-id',
             'bye-id',
             'doc-id',
             'hello-id',
             'makefile-id',
             'src-id',
+            'sub-id',
             'tree-root',
+            'zz-id',
+            'zzc-id',
             ], sorted([ie.file_id for ie in inv.iter_just_entries()]))
 
     def test_iter_entries_by_dir(self):
@@ -387,3 +332,10 @@
             ('src/sub/a', 'a-id'),
             ('src/zz.c', 'zzc-id'),
             ], [(path, ie.file_id) for path, ie in new_inv.iter_entries()])
+
+    def test_inv_filter_entry_not_present(self):
+        inv = self.prepare_inv_with_nested_dirs()
+        new_inv = inv.filter(['not-present-id'])
+        self.assertEqual([
+            ('', 'tree-root'),
+            ], [(path, ie.file_id) for path, ie in new_inv.iter_entries()])

=== modified file 'bzrlib/tests/per_pack_repository.py'
--- bzrlib/tests/per_pack_repository.py	2009-08-14 00:55:42 +0000
+++ bzrlib/tests/per_pack_repository.py	2009-09-07 03:35:06 +0000
@@ -239,31 +239,38 @@
         self.assertTrue(large_pack_name in pack_names)
 
     def test_commit_write_group_returns_new_pack_names(self):
+        # This test doesn't need real disk.
+        self.vfs_transport_factory = tests.MemoryServer
         format = self.get_format()
-        tree = self.make_branch_and_tree('foo', format=format)
-        tree.commit('first post')
-        repo = tree.branch.repository
+        repo = self.make_repository('foo', format=format)
         repo.lock_write()
         try:
-            repo.start_write_group()
-            try:
-                inv = inventory.Inventory(revision_id="A")
-                inv.root.revision = "A"
-                repo.texts.add_lines((inv.root.file_id, "A"), [], [])
-                rev = _mod_revision.Revision(timestamp=0, timezone=None,
-                    committer="Foo Bar <foo@example.com>", message="Message",
-                    revision_id="A")
-                rev.parent_ids = ()
-                repo.add_revision("A", rev, inv=inv)
-            except:
-                repo.abort_write_group()
-                raise
-            else:
-                old_names = repo._pack_collection._names.keys()
-                result = repo.commit_write_group()
-                cur_names = repo._pack_collection._names.keys()
-                new_names = list(set(cur_names) - set(old_names))
-                self.assertEqual(new_names, result)
+            # All current pack repository styles autopack at 10 revisions; and
+            # autopack as well as regular commit write group needs to return
+            # the new pack name. Looping is a little ugly, but we don't have a
+            # clean way to test both the autopack logic and the normal code
+            # path without doing this loop.
+            for pos in range(10):
+                revid = str(pos)
+                repo.start_write_group()
+                try:
+                    inv = inventory.Inventory(revision_id=revid)
+                    inv.root.revision = revid
+                    repo.texts.add_lines((inv.root.file_id, revid), [], [])
+                    rev = _mod_revision.Revision(timestamp=0, timezone=None,
+                        committer="Foo Bar <foo@example.com>", message="Message",
+                        revision_id=revid)
+                    rev.parent_ids = ()
+                    repo.add_revision(revid, rev, inv=inv)
+                except:
+                    repo.abort_write_group()
+                    raise
+                else:
+                    old_names = repo._pack_collection._names.keys()
+                    result = repo.commit_write_group()
+                    cur_names = repo._pack_collection._names.keys()
+                    new_names = list(set(cur_names) - set(old_names))
+                    self.assertEqual(new_names, result)
         finally:
             repo.unlock()
 
@@ -271,8 +278,7 @@
         # failing to delete obsolete packs is not fatal
         format = self.get_format()
         server = fakenfs.FakeNFSServer()
-        server.setUp()
-        self.addCleanup(server.tearDown)
+        self.start_server(server)
         transport = get_transport(server.get_url())
         bzrdir = self.get_format().initialize_on_transport(transport)
         repo = bzrdir.create_repository()
@@ -965,7 +971,7 @@
             ('add', ('', 'root-id', 'directory', None))])
         builder.build_snapshot('B-id', ['A-id', 'ghost-id'], [])
         builder.finish_series()
-        repo = self.make_repository('target')
+        repo = self.make_repository('target', format=self.get_format())
         b = builder.get_branch()
         b.lock_read()
         self.addCleanup(b.unlock)
@@ -1003,8 +1009,19 @@
         source_repo, target_repo = self.create_source_and_target()
         target_repo.start_write_group()
         try:
-            stream = source_repo.revisions.get_record_stream([('B-id',)],
-                                                             'unordered', True)
+            # Copy all texts, inventories, and chks so that nothing is missing
+            # for revision B-id.
+            for vf_name in ['texts', 'chk_bytes', 'inventories']:
+                source_vf = getattr(source_repo, vf_name, None)
+                if source_vf is None:
+                    continue
+                target_vf = getattr(target_repo, vf_name)
+                stream = source_vf.get_record_stream(
+                    source_vf.keys(), 'unordered', True)
+                target_vf.insert_record_stream(stream)
+            # Copy just revision B-id
+            stream = source_repo.revisions.get_record_stream(
+                [('B-id',)], 'unordered', True)
             target_repo.revisions.insert_record_stream(stream)
             key_refs = target_repo.revisions._index._key_dependencies
             self.assertEqual([('B-id',)], sorted(key_refs.get_referrers()))
@@ -1020,8 +1037,7 @@
         # Create a smart server that publishes whatever the backing VFS server
         # does.
         self.smart_server = server.SmartTCPServer_for_testing()
-        self.smart_server.setUp(self.get_server())
-        self.addCleanup(self.smart_server.tearDown)
+        self.start_server(self.smart_server, self.get_server())
         # Log all HPSS calls into self.hpss_calls.
         client._SmartClient.hooks.install_named_hook(
             'call', self.capture_hpss_call, None)

=== modified file 'bzrlib/tests/per_repository/test_commit_builder.py'
--- bzrlib/tests/per_repository/test_commit_builder.py	2009-08-11 02:45:36 +0000
+++ bzrlib/tests/per_repository/test_commit_builder.py	2009-11-19 15:06:47 +0000
@@ -894,7 +894,13 @@
                 self.assertTrue(version_recorded)
             else:
                 self.assertFalse(version_recorded)
+            self.assertIs(None, builder.new_inventory)
             builder.finish_inventory()
+            inv_key = (builder._new_revision_id,)
+            inv_sha1 = tree.branch.repository.inventories.get_sha1s(
+                            [inv_key])[inv_key]
+            self.assertEqual(inv_sha1, builder.inv_sha1)
+            self.assertIs(None, builder.new_inventory)
             new_inventory = builder.revision_tree().inventory
             new_entry = new_inventory[file_id]
             if delta_against_basis:

=== modified file 'bzrlib/tests/per_repository/test_fileid_involved.py'
--- bzrlib/tests/per_repository/test_fileid_involved.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/per_repository/test_fileid_involved.py	2009-09-09 02:14:12 +0000
@@ -19,6 +19,8 @@
 import time
 
 from bzrlib import (
+    errors,
+    remote,
     revision as _mod_revision,
     tests,
     )
@@ -342,9 +344,23 @@
         self.addCleanup(b.unlock)
         b.repository.start_write_group()
         b.repository.add_revision('B-id', new_rev, new_inv)
+        self.disable_commit_write_group_paranoia(b.repository)
         b.repository.commit_write_group()
         return b
 
+    def disable_commit_write_group_paranoia(self, repo):
+        if isinstance(repo, remote.RemoteRepository):
+            # We can't easily disable the checks in a remote repo.
+            repo.abort_write_group()
+            raise TestSkipped(
+                "repository format does not support storing revisions with "
+                "missing texts.")
+        pack_coll = getattr(repo, '_pack_collection', None)
+        if pack_coll is not None:
+            # Monkey-patch the pack collection instance to allow storing
+            # incomplete revisions.
+            pack_coll._check_new_inventories = lambda: []
+
     def test_file_ids_include_ghosts(self):
         b = self.create_branch_with_ghost_text()
         repo = b.repository

=== modified file 'bzrlib/tests/per_repository/test_reconcile.py'
--- bzrlib/tests/per_repository/test_reconcile.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/per_repository/test_reconcile.py	2009-09-08 11:32:53 +0000
@@ -341,6 +341,9 @@
         repo.start_write_group()
         inv = Inventory(revision_id='wrong-first-parent')
         inv.root.revision = 'wrong-first-parent'
+        if repo.supports_rich_root():
+            root_id = inv.root.file_id
+            repo.texts.add_lines((root_id, 'wrong-first-parent'), [], [])
         sha1 = repo.add_inventory('wrong-first-parent', inv, ['2', '1'])
         rev = Revision(timestamp=0,
                        timezone=None,

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2009-08-18 22:03:18 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2009-11-11 22:46:53 +0000
@@ -52,6 +52,7 @@
     )
 from bzrlib.tests.per_repository import TestCaseWithRepository
 from bzrlib.transport import get_transport
+from bzrlib.transport.fakevfat import FakeVFATServer
 from bzrlib.upgrade import upgrade
 from bzrlib.workingtree import WorkingTree
 
@@ -76,11 +77,11 @@
         self.assertSubset([getattr(repo._format, attribute)], allowed_values)
 
     def test_attribute__fetch_order(self):
-        """Test the the _fetch_order attribute."""
+        """Test the _fetch_order attribute."""
         self.assertFormatAttribute('_fetch_order', ('topological', 'unordered'))
 
     def test_attribute__fetch_uses_deltas(self):
-        """Test the the _fetch_uses_deltas attribute."""
+        """Test the _fetch_uses_deltas attribute."""
         self.assertFormatAttribute('_fetch_uses_deltas', (True, False))
 
     def test_attribute_fast_deltas(self):
@@ -88,7 +89,7 @@
         self.assertFormatAttribute('fast_deltas', (True, False))
 
     def test_attribute__fetch_reconcile(self):
-        """Test the the _fetch_reconcile attribute."""
+        """Test the _fetch_reconcile attribute."""
         self.assertFormatAttribute('_fetch_reconcile', (True, False))
 
     def test_attribute_format_pack_compresses(self):
@@ -603,11 +604,11 @@
 
     def test_upgrade_from_format4(self):
         from bzrlib.tests.test_upgrade import _upgrade_dir_template
+        if isinstance(self.repository_format, remote.RemoteRepositoryFormat):
+            return # local conversion to/from RemoteObjects is irrelevant.
         if self.repository_format.get_format_description() \
             == "Repository format 4":
             raise TestSkipped('Cannot convert format-4 to itself')
-        if isinstance(self.repository_format, remote.RemoteRepositoryFormat):
-            return # local conversion to/from RemoteObjects is irrelevant.
         self.build_tree_contents(_upgrade_dir_template)
         old_repodir = bzrlib.bzrdir.BzrDir.open_unsupported('.')
         old_repo_format = old_repodir.open_repository()._format
@@ -760,8 +761,8 @@
         repo = self.make_repository('repo')
         repo.lock_write()
         self.addCleanup(repo.unlock)
-        self.addCleanup(repo.commit_write_group)
         repo.start_write_group()
+        self.addCleanup(repo.abort_write_group)
         inv = Inventory(revision_id='A')
         inv.root.revision = 'A'
         repo.add_inventory('A', inv, [])
@@ -788,6 +789,8 @@
         repo = self.make_repository('repo')
         repo.lock_write()
         repo.start_write_group()
+        root_id = inv.root.file_id
+        repo.texts.add_lines(('fixed-root', 'A'), [], [])
         repo.add_revision('A', Revision('A', committer='B', timestamp=0,
                           timezone=0, message='C'), inv=inv)
         repo.commit_write_group()
@@ -823,9 +826,8 @@
         be created at the given path."""
         repo = self.make_repository(path, shared=shared)
         smart_server = server.SmartTCPServer_for_testing()
-        smart_server.setUp(self.get_server())
+        self.start_server(smart_server, self.get_server())
         remote_transport = get_transport(smart_server.get_url()).clone(path)
-        self.addCleanup(smart_server.tearDown)
         remote_bzrdir = bzrdir.BzrDir.open_from_transport(remote_transport)
         remote_repo = remote_bzrdir.open_repository()
         return remote_repo
@@ -897,14 +899,6 @@
         local_repo = local_bzrdir.open_repository()
         self.assertEqual(remote_backing_repo._format, local_repo._format)
 
-    # XXX: this helper probably belongs on TestCaseWithTransport
-    def make_smart_server(self, path):
-        smart_server = server.SmartTCPServer_for_testing()
-        smart_server.setUp(self.get_server())
-        remote_transport = get_transport(smart_server.get_url()).clone(path)
-        self.addCleanup(smart_server.tearDown)
-        return remote_transport
-
     def test_clone_to_hpss(self):
         pre_metadir_formats = [RepositoryFormat5(), RepositoryFormat6()]
         if self.repository_format in pre_metadir_formats:
@@ -1225,6 +1219,9 @@
         repo.start_write_group()
         inv = Inventory(revision_id = 'ghost')
         inv.root.revision = 'ghost'
+        if repo.supports_rich_root():
+            root_id = inv.root.file_id
+            repo.texts.add_lines((root_id, 'ghost'), [], [])
         sha1 = repo.add_inventory('ghost', inv, [])
         rev = bzrlib.revision.Revision(timestamp=0,
                                        timezone=None,
@@ -1240,6 +1237,9 @@
 
         inv = Inventory(revision_id = 'the_ghost')
         inv.root.revision = 'the_ghost'
+        if repo.supports_rich_root():
+            root_id = inv.root.file_id
+            repo.texts.add_lines((root_id, 'the_ghost'), [], [])
         sha1 = repo.add_inventory('the_ghost', inv, [])
         rev = bzrlib.revision.Revision(timestamp=0,
                                        timezone=None,
@@ -1296,6 +1296,7 @@
         from bzrlib.remote import RemoteRepositoryFormat
         if isinstance(self.repository_format, RemoteRepositoryFormat):
             return
+        self.transport_server = FakeVFATServer
         FOO_ID = 'foo<:>ID'
         REV_ID = 'revid-1'
         # this makes a default format repository always, which is wrong:
@@ -1307,7 +1308,7 @@
         wt.add(['foo'], [FOO_ID])
         wt.commit('this is my new commit', rev_id=REV_ID)
         # now access over vfat; should be safe
-        branch = bzrdir.BzrDir.open('vfat+' + self.get_url('repo')).open_branch()
+        branch = bzrdir.BzrDir.open(self.get_url('repo')).open_branch()
         revtree = branch.repository.revision_tree(REV_ID)
         revtree.lock_read()
         self.addCleanup(revtree.unlock)

=== modified file 'bzrlib/tests/per_repository/test_write_group.py'
--- bzrlib/tests/per_repository/test_write_group.py	2009-08-17 04:18:57 +0000
+++ bzrlib/tests/per_repository/test_write_group.py	2009-10-15 02:11:18 +0000
@@ -28,9 +28,8 @@
     versionedfile,
     )
 from bzrlib.branch import BzrBranchFormat7
-from bzrlib.inventory import InventoryDirectory
 from bzrlib.transport import local, memory
-from bzrlib.tests import KnownFailure, TestNotApplicable
+from bzrlib.tests import TestNotApplicable
 from bzrlib.tests.per_repository import TestCaseWithRepository
 
 
@@ -85,7 +84,7 @@
         # don't need a specific exception for now - this is
         # really to be sure it's used right, not for signalling
         # semantic information.
-        self.assertRaises(errors.BzrError, repo.unlock)
+        self.assertLogsError(errors.BzrError, repo.unlock)
         # after this error occurs, the repository is unlocked, and the write
         # group is gone.  you've had your chance, and you blew it. ;-)
         self.assertFalse(repo.is_locked())

=== modified file 'bzrlib/tests/per_repository_chk/__init__.py'
--- bzrlib/tests/per_repository_chk/__init__.py	2009-04-09 20:23:07 +0000
+++ bzrlib/tests/per_repository_chk/__init__.py	2009-09-08 06:25:26 +0000
@@ -46,8 +46,8 @@
 
 class TestCaseWithRepositoryCHK(TestCaseWithRepository):
 
-    def make_repository(self, path):
-        TestCaseWithRepository.make_repository(self, path)
+    def make_repository(self, path, format=None):
+        TestCaseWithRepository.make_repository(self, path, format=format)
         return repository.Repository.open(self.get_transport(path).base)
 
 

=== modified file 'bzrlib/tests/per_repository_chk/test_supported.py'
--- bzrlib/tests/per_repository_chk/test_supported.py	2009-04-09 20:23:07 +0000
+++ bzrlib/tests/per_repository_chk/test_supported.py	2009-09-09 18:52:56 +0000
@@ -16,7 +16,12 @@
 
 """Tests for repositories that support CHK indices."""
 
-from bzrlib import osutils
+from bzrlib import (
+    btree_index,
+    errors,
+    osutils,
+    repository,
+    )
 from bzrlib.versionedfile import VersionedFiles
 from bzrlib.tests.per_repository_chk import TestCaseWithRepositoryCHK
 
@@ -104,3 +109,277 @@
             self.assertEqual(expected_set, repo.chk_bytes.keys())
         finally:
             repo.unlock()
+
+    def test_chk_bytes_are_fully_buffered(self):
+        repo = self.make_repository('.')
+        repo.lock_write()
+        self.addCleanup(repo.unlock)
+        repo.start_write_group()
+        try:
+            sha1, len, _ = repo.chk_bytes.add_lines((None,),
+                None, ["foo\n", "bar\n"], random_id=True)
+            self.assertEqual('4e48e2c9a3d2ca8a708cb0cc545700544efb5021',
+                sha1)
+            self.assertEqual(
+                set([('sha1:4e48e2c9a3d2ca8a708cb0cc545700544efb5021',)]),
+                repo.chk_bytes.keys())
+        except:
+            repo.abort_write_group()
+            raise
+        else:
+            repo.commit_write_group()
+        # This may not always be correct if we change away from BTreeGraphIndex
+        # in the future. But for now, lets check that chk_bytes are fully
+        # buffered
+        index = repo.chk_bytes._index._graph_index._indices[0]
+        self.assertIsInstance(index, btree_index.BTreeGraphIndex)
+        self.assertIs(type(index._leaf_node_cache), dict)
+        # Re-opening the repository should also have a repo with everything
+        # fully buffered
+        repo2 = repository.Repository.open(self.get_url())
+        repo2.lock_read()
+        self.addCleanup(repo2.unlock)
+        index = repo2.chk_bytes._index._graph_index._indices[0]
+        self.assertIsInstance(index, btree_index.BTreeGraphIndex)
+        self.assertIs(type(index._leaf_node_cache), dict)
+
+
+class TestCommitWriteGroupIntegrityCheck(TestCaseWithRepositoryCHK):
+    """Tests that commit_write_group prevents various kinds of invalid data
+    from being committed to a CHK repository.
+    """
+
+    def reopen_repo_and_resume_write_group(self, repo):
+        resume_tokens = repo.suspend_write_group()
+        repo.unlock()
+        reopened_repo = repo.bzrdir.open_repository()
+        reopened_repo.lock_write()
+        self.addCleanup(reopened_repo.unlock)
+        reopened_repo.resume_write_group(resume_tokens)
+        return reopened_repo
+
+    def test_missing_chk_root_for_inventory(self):
+        """commit_write_group fails with BzrCheckError when the chk root record
+        for a new inventory is missing.
+        """
+        repo = self.make_repository('damaged-repo')
+        builder = self.make_branch_builder('simple-branch')
+        builder.build_snapshot('A-id', None, [
+            ('add', ('', 'root-id', 'directory', None)),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        b = builder.get_branch()
+        b.lock_read()
+        self.addCleanup(b.unlock)
+        repo.lock_write()
+        repo.start_write_group()
+        # Now, add the objects manually
+        text_keys = [('file-id', 'A-id'), ('root-id', 'A-id')]
+        # Directly add the texts, inventory, and revision object for 'A-id' --
+        # but don't add the chk_bytes.
+        src_repo = b.repository
+        repo.texts.insert_record_stream(src_repo.texts.get_record_stream(
+            text_keys, 'unordered', True))
+        repo.inventories.insert_record_stream(
+            src_repo.inventories.get_record_stream(
+                [('A-id',)], 'unordered', True))
+        repo.revisions.insert_record_stream(
+            src_repo.revisions.get_record_stream(
+                [('A-id',)], 'unordered', True))
+        # Make sure the presence of the missing data in a fallback does not
+        # avoid the error.
+        repo.add_fallback_repository(b.repository)
+        self.assertRaises(errors.BzrCheckError, repo.commit_write_group)
+        reopened_repo = self.reopen_repo_and_resume_write_group(repo)
+        self.assertRaises(
+            errors.BzrCheckError, reopened_repo.commit_write_group)
+        reopened_repo.abort_write_group()
+
+    def test_missing_chk_root_for_unchanged_inventory(self):
+        """commit_write_group fails with BzrCheckError when the chk root record
+        for a new inventory is missing, even if the parent inventory is present
+        and has identical content (i.e. the same chk root).
+        
+        A stacked repository containing only a revision with an identical
+        inventory to its parent will still have the chk root records for those
+        inventories.
+
+        (In principle the chk records are unnecessary in this case, but in
+        practice bzr 2.0rc1 (at least) expects to find them.)
+        """
+        repo = self.make_repository('damaged-repo')
+        # Make a branch where the last two revisions have identical
+        # inventories.
+        builder = self.make_branch_builder('simple-branch')
+        builder.build_snapshot('A-id', None, [
+            ('add', ('', 'root-id', 'directory', None)),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        builder.build_snapshot('B-id', None, [])
+        builder.build_snapshot('C-id', None, [])
+        b = builder.get_branch()
+        b.lock_read()
+        self.addCleanup(b.unlock)
+        # check our setup: B-id and C-id should have identical chk root keys.
+        inv_b = b.repository.get_inventory('B-id')
+        inv_c = b.repository.get_inventory('C-id')
+        self.assertEqual(inv_b.id_to_entry.key(), inv_c.id_to_entry.key())
+        # Now, manually insert objects for a stacked repo with only revision
+        # C-id:
+        # We need ('revisions', 'C-id'), ('inventories', 'C-id'),
+        # ('inventories', 'B-id'), and the corresponding chk roots for those
+        # inventories.
+        repo.lock_write()
+        repo.start_write_group()
+        src_repo = b.repository
+        repo.inventories.insert_record_stream(
+            src_repo.inventories.get_record_stream(
+                [('B-id',), ('C-id',)], 'unordered', True))
+        repo.revisions.insert_record_stream(
+            src_repo.revisions.get_record_stream(
+                [('C-id',)], 'unordered', True))
+        # Make sure the presence of the missing data in a fallback does not
+        # avoid the error.
+        repo.add_fallback_repository(b.repository)
+        self.assertRaises(errors.BzrCheckError, repo.commit_write_group)
+        reopened_repo = self.reopen_repo_and_resume_write_group(repo)
+        self.assertRaises(
+            errors.BzrCheckError, reopened_repo.commit_write_group)
+        reopened_repo.abort_write_group()
+
+    def test_missing_chk_leaf_for_inventory(self):
+        """commit_write_group fails with BzrCheckError when the chk root record
+        for a parent inventory of a new revision is missing.
+        """
+        repo = self.make_repository('damaged-repo')
+        b = self.make_branch_with_multiple_chk_nodes()
+        src_repo = b.repository
+        src_repo.lock_read()
+        self.addCleanup(src_repo.unlock)
+        # Now, manually insert objects for a stacked repo with only revision
+        # C-id, *except* drop the non-root chk records.
+        inv_b = src_repo.get_inventory('B-id')
+        inv_c = src_repo.get_inventory('C-id')
+        chk_root_keys_only = [
+            inv_b.id_to_entry.key(), inv_b.parent_id_basename_to_file_id.key(),
+            inv_c.id_to_entry.key(), inv_c.parent_id_basename_to_file_id.key()]
+        all_chks = src_repo.chk_bytes.keys()
+        # Pick a non-root key to drop
+        key_to_drop = all_chks.difference(chk_root_keys_only).pop()
+        all_chks.discard(key_to_drop)
+        repo.lock_write()
+        repo.start_write_group()
+        repo.chk_bytes.insert_record_stream(
+            src_repo.chk_bytes.get_record_stream(
+                all_chks, 'unordered', True))
+        repo.texts.insert_record_stream(
+            src_repo.texts.get_record_stream(
+                src_repo.texts.keys(), 'unordered', True))
+        repo.inventories.insert_record_stream(
+            src_repo.inventories.get_record_stream(
+                [('B-id',), ('C-id',)], 'unordered', True))
+        repo.revisions.insert_record_stream(
+            src_repo.revisions.get_record_stream(
+                [('C-id',)], 'unordered', True))
+        # Make sure the presence of the missing data in a fallback does not
+        # avoid the error.
+        repo.add_fallback_repository(b.repository)
+        self.assertRaises(errors.BzrCheckError, repo.commit_write_group)
+        reopened_repo = self.reopen_repo_and_resume_write_group(repo)
+        self.assertRaises(
+            errors.BzrCheckError, reopened_repo.commit_write_group)
+        reopened_repo.abort_write_group()
+
+    def test_missing_chk_root_for_parent_inventory(self):
+        """commit_write_group fails with BzrCheckError when the chk root record
+        for a parent inventory of a new revision is missing.
+        """
+        repo = self.make_repository('damaged-repo')
+        b = self.make_branch_with_multiple_chk_nodes()
+        b.lock_read()
+        self.addCleanup(b.unlock)
+        # Now, manually insert objects for a stacked repo with only revision
+        # C-id, *except* the chk root entry for the parent inventory.
+        # We need ('revisions', 'C-id'), ('inventories', 'C-id'),
+        # ('inventories', 'B-id'), and the corresponding chk roots for those
+        # inventories.
+        inv_c = b.repository.get_inventory('C-id')
+        chk_keys_for_c_only = [
+            inv_c.id_to_entry.key(), inv_c.parent_id_basename_to_file_id.key()]
+        repo.lock_write()
+        repo.start_write_group()
+        src_repo = b.repository
+        repo.chk_bytes.insert_record_stream(
+            src_repo.chk_bytes.get_record_stream(
+                chk_keys_for_c_only, 'unordered', True))
+        repo.inventories.insert_record_stream(
+            src_repo.inventories.get_record_stream(
+                [('B-id',), ('C-id',)], 'unordered', True))
+        repo.revisions.insert_record_stream(
+            src_repo.revisions.get_record_stream(
+                [('C-id',)], 'unordered', True))
+        # Make sure the presence of the missing data in a fallback does not
+        # avoid the error.
+        repo.add_fallback_repository(b.repository)
+        self.assertRaises(errors.BzrCheckError, repo.commit_write_group)
+        reopened_repo = self.reopen_repo_and_resume_write_group(repo)
+        self.assertRaises(
+            errors.BzrCheckError, reopened_repo.commit_write_group)
+        reopened_repo.abort_write_group()
+
+    def make_branch_with_multiple_chk_nodes(self):
+        # add and modify files with very long file-ids, so that the chk map
+        # will need more than just a root node.
+        builder = self.make_branch_builder('simple-branch')
+        file_adds = []
+        file_modifies = []
+        for char in 'abc':
+            name = char * 10000
+            file_adds.append(
+                ('add', ('file-' + name, 'file-%s-id' % name, 'file',
+                         'content %s\n' % name)))
+            file_modifies.append(
+                ('modify', ('file-%s-id' % name, 'new content %s\n' % name)))
+        builder.build_snapshot('A-id', None, [
+            ('add', ('', 'root-id', 'directory', None))] +
+            file_adds)
+        builder.build_snapshot('B-id', None, [])
+        builder.build_snapshot('C-id', None, file_modifies)
+        return builder.get_branch()
+        
+    def test_missing_text_record(self):
+        """commit_write_group fails with BzrCheckError when a text is missing.
+        """
+        repo = self.make_repository('damaged-repo')
+        b = self.make_branch_with_multiple_chk_nodes()
+        src_repo = b.repository
+        src_repo.lock_read()
+        self.addCleanup(src_repo.unlock)
+        # Now, manually insert objects for a stacked repo with only revision
+        # C-id, *except* drop one changed text.
+        all_texts = src_repo.texts.keys()
+        all_texts.remove(('file-%s-id' % ('c'*10000,), 'C-id'))
+        repo.lock_write()
+        repo.start_write_group()
+        repo.chk_bytes.insert_record_stream(
+            src_repo.chk_bytes.get_record_stream(
+                src_repo.chk_bytes.keys(), 'unordered', True))
+        repo.texts.insert_record_stream(
+            src_repo.texts.get_record_stream(
+                all_texts, 'unordered', True))
+        repo.inventories.insert_record_stream(
+            src_repo.inventories.get_record_stream(
+                [('B-id',), ('C-id',)], 'unordered', True))
+        repo.revisions.insert_record_stream(
+            src_repo.revisions.get_record_stream(
+                [('C-id',)], 'unordered', True))
+        # Make sure the presence of the missing data in a fallback does not
+        # avoid the error.
+        repo.add_fallback_repository(b.repository)
+        self.assertRaises(errors.BzrCheckError, repo.commit_write_group)
+        reopened_repo = self.reopen_repo_and_resume_write_group(repo)
+        self.assertRaises(
+            errors.BzrCheckError, reopened_repo.commit_write_group)
+        reopened_repo.abort_write_group()
+
+
+
+

=== modified file 'bzrlib/tests/per_repository_reference/test_add_revision.py'
--- bzrlib/tests/per_repository_reference/test_add_revision.py	2009-04-09 20:23:07 +0000
+++ bzrlib/tests/per_repository_reference/test_add_revision.py	2009-09-08 14:51:23 +0000
@@ -40,6 +40,7 @@
             repo.start_write_group()
             try:
                 rev = tree.branch.repository.get_revision(revid)
+                repo.texts.add_lines((inv.root.file_id, revid), [], [])
                 repo.add_revision(revid, rev, inv=inv)
             except:
                 repo.abort_write_group()

=== modified file 'bzrlib/tests/per_repository_reference/test_add_signature_text.py'
--- bzrlib/tests/per_repository_reference/test_add_signature_text.py	2009-04-09 20:23:07 +0000
+++ bzrlib/tests/per_repository_reference/test_add_signature_text.py	2009-09-08 14:51:23 +0000
@@ -39,13 +39,13 @@
             repo.start_write_group()
             try:
                 rev = tree.branch.repository.get_revision(revid)
+                repo.texts.add_lines((inv.root.file_id, revid), [], [])
                 repo.add_revision(revid, rev, inv=inv)
                 repo.add_signature_text(revid, "text")
+                repo.commit_write_group()
             except:
                 repo.abort_write_group()
                 raise
-            else:
-                repo.commit_write_group()
         finally:
             repo.unlock()
         repo.get_signature_text(revid)

=== modified file 'bzrlib/tests/per_transport.py'
--- bzrlib/tests/per_transport.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_transport.py	2009-10-05 12:50:34 +0000
@@ -79,7 +79,7 @@
             permutations = get_transport_test_permutations(
                 reduce(getattr, (module).split('.')[1:], __import__(module)))
             for (klass, server_factory) in permutations:
-                scenario = (server_factory.__name__,
+                scenario = ('%s,%s' % (klass.__name__, server_factory.__name__),
                     {"transport_class":klass,
                      "transport_server":server_factory})
                 result.append(scenario)

=== modified file 'bzrlib/tests/per_tree/test_get_file_with_stat.py'
--- bzrlib/tests/per_tree/test_get_file_with_stat.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_tree/test_get_file_with_stat.py	2009-11-18 15:47:16 +0000
@@ -21,6 +21,7 @@
 from bzrlib.tests.per_tree import TestCaseWithTree
 
 
+
 class TestGetFileWithStat(TestCaseWithTree):
 
     def test_get_file_with_stat_id_only(self):
@@ -31,6 +32,7 @@
         tree.lock_read()
         self.addCleanup(tree.unlock)
         file_obj, statvalue = tree.get_file_with_stat('foo-id')
+        self.addCleanup(file_obj.close)
         if statvalue is not None:
             expected = os.lstat('foo')
             self.assertEqualStat(expected, statvalue)
@@ -44,7 +46,7 @@
         tree.lock_read()
         self.addCleanup(tree.unlock)
         file_obj, statvalue = tree.get_file_with_stat('foo-id', 'foo')
-        expected = os.lstat('foo')
+        self.addCleanup(file_obj.close)
         if statvalue is not None:
             expected = os.lstat('foo')
             self.assertEqualStat(expected, statvalue)

=== modified file 'bzrlib/tests/per_tree/test_path_content_summary.py'
--- bzrlib/tests/per_tree/test_path_content_summary.py	2009-08-26 05:34:10 +0000
+++ bzrlib/tests/per_tree/test_path_content_summary.py	2009-11-10 19:38:37 +0000
@@ -21,6 +21,7 @@
 from bzrlib import (
     osutils,
     tests,
+    transform,
     )
 
 from bzrlib.tests import per_tree
@@ -78,13 +79,13 @@
         self.assertEqual(('missing', None, None, None), summary)
 
     def test_file_content_summary_executable(self):
-        if not osutils.supports_executable():
-            raise tests.TestNotApplicable()
         tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/path'])
         tree.add(['path'])
-        current_mode = os.stat('tree/path').st_mode
-        os.chmod('tree/path', current_mode | 0100)
+        tt = transform.TreeTransform(tree)
+        self.addCleanup(tt.finalize)
+        tt.set_executability(True, tt.trans_id_tree_path('path'))
+        tt.apply()
         summary = self._convert_tree(tree).path_content_summary('path')
         self.assertEqual(4, len(summary))
         self.assertEqual('file', summary[0])
@@ -95,6 +96,28 @@
         self.assertSubset((summary[3],),
             (None, '0c352290ae1c26ca7f97d5b2906c4624784abd60'))
 
+    def test_file_content_summary_not_versioned(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/path'])
+        tree = self._convert_tree(tree)
+        summary = tree.path_content_summary('path')
+        self.assertEqual(4, len(summary))
+        if isinstance(tree, (per_tree.DirStateRevisionTree,
+                             per_tree.RevisionTree)):
+            self.assertEqual('missing', summary[0])
+            self.assertIs(None, summary[2])
+            self.assertIs(None, summary[3])
+        elif isinstance(tree, transform._PreviewTree):
+            self.expectFailure('PreviewTree returns "missing" for unversioned'
+                'files', self.assertEqual, 'file', summary[0])
+            self.assertEqual('file', summary[0])
+        else:
+            self.assertEqual('file', summary[0])
+            self.check_content_summary_size(tree, summary, 22)
+            self.assertEqual(False, summary[2])
+        self.assertSubset((summary[3],),
+            (None, '0c352290ae1c26ca7f97d5b2906c4624784abd60'))
+
     def test_file_content_summary_non_exec(self):
         tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/path'])

=== added directory 'bzrlib/tests/per_uifactory'
=== added file 'bzrlib/tests/per_uifactory/__init__.py'
--- bzrlib/tests/per_uifactory/__init__.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/per_uifactory/__init__.py	2009-09-23 06:29:46 +0000
@@ -0,0 +1,148 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests run per UIFactory."""
+
+# Testing UIFactories is a bit interesting because we require they all support a
+# common interface, but the way they implement it can vary very widely.  Between
+# text, batch-mode, graphical and other potential UIFactories, the requirements
+# to set up a factory, to make it respond to requests, and to simulate user
+# input can vary a lot.
+#
+# We want tests that therefore allow for the evaluation of the result to vary
+# per implementation, but we want to check that the supported facilities are
+# the same across all UIFactorys, unless they're specifically skipped.
+#
+# Our normal approach is to use test scenarios but that seems to just end up
+# creating test-like objects inside the scenario.  Therefore we fall back to
+# the older method of putting the common tests in a mixin.
+#
+# Plugins that add new UIFactorys can create their own subclasses.
+
+
+from cStringIO import StringIO
+import unittest
+
+
+from bzrlib import (
+    tests,
+    ui,
+    )
+
+
+class UIFactoryTestMixin(object):
+    """Common tests for UIFactories.
+
+    These are supposed to be expressed with no assumptions about how the
+    UIFactory implements the method, only that it does implement them (or
+    fails cleanly), and that the concrete subclass will make arrangements to
+    build a factory and to examine its behaviour.
+
+    Note that this is *not* a TestCase, because it can't be directly run, but
+    the concrete subclasses should be.
+    """
+
+    def test_note(self):
+        self.factory.note("a note to the user")
+        self._check_note("a note to the user")
+
+    def test_show_error(self):
+        msg = 'an error occurred'
+        self.factory.show_error(msg)
+        self._check_show_error(msg)
+
+    def test_show_message(self):
+        msg = 'a message'
+        self.factory.show_message(msg)
+        self._check_show_message(msg)
+
+    def test_show_warning(self):
+        msg = 'a warning'
+        self.factory.show_warning(msg)
+        self._check_show_warning(msg)
+
+
+class TestTextUIFactory(tests.TestCase, UIFactoryTestMixin):
+
+    def setUp(self):
+        super(TestTextUIFactory, self).setUp()
+        self.stdin = StringIO()
+        self.stdout = StringIO()
+        self.stderr = StringIO()
+        self.factory = ui.text.TextUIFactory(self.stdin, self.stdout,
+            self.stderr)
+
+    def _check_note(self, note_text):
+        self.assertEquals("%s\n" % note_text,
+            self.stdout.getvalue())
+
+    def _check_show_error(self, msg):
+        self.assertEquals("bzr: error: %s\n" % msg,
+            self.stderr.getvalue())
+        self.assertEquals("", self.stdout.getvalue())
+
+    def _check_show_message(self, msg):
+        self.assertEquals("%s\n" % msg,
+            self.stdout.getvalue())
+        self.assertEquals("", self.stderr.getvalue())
+
+    def _check_show_warning(self, msg):
+        self.assertEquals("bzr: warning: %s\n" % msg,
+            self.stderr.getvalue())
+        self.assertEquals("", self.stdout.getvalue())
+
+
+class TestSilentUIFactory(tests.TestCase, UIFactoryTestMixin):
+    # discards output, therefore tests for output expect nothing
+
+    def setUp(self):
+        super(TestSilentUIFactory, self).setUp()
+        self.factory = ui.SilentUIFactory()
+
+    def _check_note(self, note_text):
+        # it's just discarded
+        pass
+
+    def _check_show_error(self, msg):
+        pass
+
+    def _check_show_message(self, msg):
+        pass
+
+    def _check_show_warning(self, msg):
+        pass
+
+
+class TestCannedInputUIFactory(tests.TestCase, UIFactoryTestMixin):
+    # discards output, reads input from variables
+
+    def setUp(self):
+        super(TestCannedInputUIFactory, self).setUp()
+        self.factory = ui.CannedInputUIFactory([])
+
+    def _check_note(self, note_text):
+        pass
+
+    def _check_show_error(self, msg):
+        pass
+
+    def _check_show_message(self, msg):
+        pass
+
+    def _check_show_warning(self, msg):
+        pass
+
+

=== modified file 'bzrlib/tests/per_versionedfile.py'
--- bzrlib/tests/per_versionedfile.py	2009-08-26 16:44:27 +0000
+++ bzrlib/tests/per_versionedfile.py	2009-10-26 06:44:40 +0000
@@ -1581,6 +1581,10 @@
         # All texts should be output.
         self.assertEqual(set(keys), seen)
 
+    def test_clear_cache(self):
+        files = self.get_versionedfiles()
+        files.clear_cache()
+
     def test_construct(self):
         """Each parameterised test can be constructed on a transport."""
         files = self.get_versionedfiles()
@@ -2434,6 +2438,43 @@
         else:
             self.assertIdenticalVersionedFile(source, files)
 
+    def test_insert_record_stream_long_parent_chain_out_of_order(self):
+        """An out of order stream can either error or work."""
+        if not self.graph:
+            raise TestNotApplicable('ancestry info only relevant with graph.')
+        # Create a reasonably long chain of records based on each other, where
+        # most will be deltas.
+        source = self.get_versionedfiles('source')
+        parents = ()
+        keys = []
+        content = [('same same %d\n' % n) for n in range(500)]
+        for letter in 'abcdefghijklmnopqrstuvwxyz':
+            key = ('key-' + letter,)
+            if self.key_length == 2:
+                key = ('prefix',) + key
+            content.append('content for ' + letter + '\n')
+            source.add_lines(key, parents, content)
+            keys.append(key)
+            parents = (key,)
+        # Create a stream of these records, excluding the first record that the
+        # rest ultimately depend upon, and insert it into a new vf.
+        streams = []
+        for key in reversed(keys):
+            streams.append(source.get_record_stream([key], 'unordered', False))
+        deltas = chain(*streams[:-1])
+        files = self.get_versionedfiles()
+        try:
+            files.insert_record_stream(deltas)
+        except RevisionNotPresent:
+            # Must not have corrupted the file.
+            files.check()
+        else:
+            # Must only report either just the first key as a missing parent,
+            # no key as missing (for nodelta scenarios).
+            missing = set(files.get_missing_compression_parent_keys())
+            missing.discard(keys[0])
+            self.assertEqual(set(), missing)
+
     def get_knit_delta_source(self):
         """Get a source that can produce a stream with knit delta records,
         regardless of this test's scenario.

=== modified file 'bzrlib/tests/per_workingtree/test_commit.py'
--- bzrlib/tests/per_workingtree/test_commit.py	2009-08-04 11:40:59 +0000
+++ bzrlib/tests/per_workingtree/test_commit.py	2009-09-07 23:14:05 +0000
@@ -611,3 +611,26 @@
         revid = tree.commit('first post')
         committed_tree = tree.basis_tree()
         self.assertTrue(committed_tree.has_filename("newfile"))
+
+    def test_post_commit_hook(self):
+        """Make sure a post_commit hook is called after a commit."""
+        def post_commit_hook_test_params(params):
+            self.assertTrue(isinstance(params,
+                mutabletree.PostCommitHookParams))
+            self.assertTrue(isinstance(params.mutable_tree,
+                mutabletree.MutableTree))
+            open(tree.abspath("newfile"), 'w').write("data")
+            params.mutable_tree.add(["newfile"])
+        def restoreDefaults():
+            mutabletree.MutableTree.hooks['post_commit'] = []
+        self.addCleanup(restoreDefaults)
+        tree = self.make_branch_and_tree('.')
+        mutabletree.MutableTree.hooks.install_named_hook(
+            'post_commit',
+            post_commit_hook_test_params,
+            None)
+        self.assertFalse(tree.has_filename("newfile"))
+        revid = tree.commit('first post')
+        self.assertTrue(tree.has_filename("newfile"))
+        committed_tree = tree.basis_tree()
+        self.assertFalse(committed_tree.has_filename("newfile"))

=== modified file 'bzrlib/tests/per_workingtree/test_content_filters.py'
--- bzrlib/tests/per_workingtree/test_content_filters.py	2009-09-01 03:52:39 +0000
+++ bzrlib/tests/per_workingtree/test_content_filters.py	2009-10-28 23:34:13 +0000
@@ -16,7 +16,11 @@
 
 """Tests for content filtering conformance"""
 
+import os
+
+from bzrlib.bzrdir import BzrDir
 from bzrlib.filters import ContentFilter
+from bzrlib.switch import switch
 from bzrlib.workingtree import WorkingTree
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
@@ -64,8 +68,7 @@
 
 class TestWorkingTreeWithContentFilters(TestCaseWithWorkingTree):
 
-    def create_cf_tree(self, txt_reader, txt_writer, dir='.',
-        two_revisions=False):
+    def create_cf_tree(self, txt_reader, txt_writer, dir='.'):
         tree = self.make_branch_and_tree(dir)
         def _content_filter_stack(path=None, file_id=None):
             if path.endswith('.txt'):
@@ -78,16 +81,48 @@
             (dir + '/file2.bin', 'Foo Bin')])
         tree.add(['file1.txt', 'file2.bin'])
         tree.commit('commit raw content')
-        # Commit another revision with changed text, if requested
-        if two_revisions:
-            self.build_tree_contents([(dir + '/file1.txt', 'Foo ROCKS!')])
-            tree.commit("changed file1.txt")
         txt_fileid = tree.path2id('file1.txt')
         bin_fileid = tree.path2id('file2.bin')
         return tree, txt_fileid, bin_fileid
 
+    def create_cf_tree_with_two_revisions(self, txt_reader, txt_writer,
+        dir='.'):
+        tree = self.make_branch_and_tree(dir)
+        def _content_filter_stack(path=None, file_id=None):
+            if path.endswith('.txt'):
+                return [ContentFilter(txt_reader, txt_writer)]
+            else:
+                return []
+        tree._content_filter_stack = _content_filter_stack
+        self.build_tree_contents([
+            (dir + '/file1.txt', 'Foo Txt'),
+            (dir + '/file2.bin', 'Foo Bin'),
+            (dir + '/file3.txt', 'Bar Txt'),
+            ])
+        tree.add(['file1.txt', 'file2.bin', 'file3.txt'])
+        tree.commit('commit raw content')
+        fileid_1 = tree.path2id('file1.txt')
+        fileid_2 = tree.path2id('file2.bin')
+        fileid_3 = tree.path2id('file3.txt')
+        # Commit another revision with various changes. We make sure
+        # the change includes a modification, an addition and a deletion.
+        # Renames are more complex and need a separate set of tests later.
+        self.build_tree_contents([
+            (dir + '/file1.txt', 'Foo ROCKS!'),
+            (dir + '/file4.txt', 'Hello World'),
+            ])
+        tree.add(['file4.txt'])
+        tree.remove(['file3.txt'], keep_files=False)
+        tree.commit("change, add and rename stuff")
+        fileid_4 = tree.path2id('file4.txt')
+        return tree, fileid_1, fileid_2, fileid_3, fileid_4
+
     def patch_in_content_filter(self):
-        # Patch in a custom, symmetric content filter stack
+        # Patch in a custom, symmetric content filter stack. It's pretty gross
+        # that we need to monkey-patch a class method to do this, bit it's
+        # the easiest way currently given we don't have easy access to the
+        # WorkingTree after it is created but before the filter stack is used
+        # to populate content.
         self.real_content_filter_stack = WorkingTree._content_filter_stack
         def restore_real_content_filter_stack():
             WorkingTree._content_filter_stack = self.real_content_filter_stack
@@ -223,45 +258,124 @@
 
     def test_content_filtering_applied_on_pull(self):
         # Create a source branch with two revisions
-        source, txt_fileid, bin_fileid = self.create_cf_tree(
-            txt_reader=None, txt_writer=None, dir='source', two_revisions=True)
+        source, fileid_1, fileid_2, fileid_3, fileid_4 = \
+            self.create_cf_tree_with_two_revisions(txt_reader=None,
+            txt_writer=None, dir='source')
         if not source.supports_content_filtering():
             return
         self.assertFileEqual("Foo ROCKS!", 'source/file1.txt')
-        self.assert_basis_content("Foo ROCKS!", source, txt_fileid)
+        self.assert_basis_content("Foo ROCKS!", source, fileid_1)
 
         # Now patch in content filtering and branch from revision 1
         self.patch_in_content_filter()
         self.run_bzr('branch -r1 source target')
         target = WorkingTree.open('target')
+        self.assert_basis_content("Foo Txt", target, fileid_1)
         self.assertFileEqual("fOO tXT", 'target/file1.txt')
-        self.assert_basis_content("Foo Txt", target, txt_fileid)
+        self.assert_basis_content("Foo Bin", target, fileid_2)
+        self.assertFileEqual("Foo Bin", 'target/file2.bin')
+        self.assert_basis_content("Bar Txt", target, fileid_3)
+        self.assertFileEqual("bAR tXT", 'target/file3.txt')
 
         # Pull the latter change and check the target tree is updated
         self.run_bzr('pull -d target')
+        self.assert_basis_content("Foo ROCKS!", target, fileid_1)
         self.assertFileEqual("fOO rocks!", 'target/file1.txt')
-        self.assert_basis_content("Foo ROCKS!", target, txt_fileid)
+        self.assert_basis_content("Foo Bin", target, fileid_2)
+        self.assert_basis_content("Hello World", target, fileid_4)
+        self.assertFileEqual("hELLO wORLD", 'target/file4.txt')
 
     def test_content_filtering_applied_on_merge(self):
         # Create a source branch with two revisions
-        source, txt_fileid, bin_fileid = self.create_cf_tree(
-            txt_reader=None, txt_writer=None, dir='source', two_revisions=True)
+        source, fileid_1, fileid_2, fileid_3, fileid_4 = \
+            self.create_cf_tree_with_two_revisions(txt_reader=None,
+            txt_writer=None, dir='source')
         if not source.supports_content_filtering():
             return
+        self.assert_basis_content("Foo ROCKS!", source, fileid_1)
         self.assertFileEqual("Foo ROCKS!", 'source/file1.txt')
-        self.assert_basis_content("Foo ROCKS!", source, txt_fileid)
+        self.assert_basis_content("Foo Bin", source, fileid_2)
+        self.assert_basis_content("Hello World", source, fileid_4)
+        self.assertFileEqual("Hello World", 'source/file4.txt')
 
         # Now patch in content filtering and branch from revision 1
         self.patch_in_content_filter()
         self.run_bzr('branch -r1 source target')
         target = WorkingTree.open('target')
+        self.assert_basis_content("Foo Txt", target, fileid_1)
         self.assertFileEqual("fOO tXT", 'target/file1.txt')
-        self.assert_basis_content("Foo Txt", target, txt_fileid)
+        self.assertFileEqual("Foo Bin", 'target/file2.bin')
+        self.assertFileEqual("bAR tXT", 'target/file3.txt')
 
         # Merge the latter change and check the target tree is updated
         self.run_bzr('merge -d target source')
         self.assertFileEqual("fOO rocks!", 'target/file1.txt')
+        self.assertFileEqual("hELLO wORLD", 'target/file4.txt')
 
         # Commit the merge and check the right content is stored
         target.commit("merge file1.txt changes from source")
-        self.assert_basis_content("Foo ROCKS!", target, txt_fileid)
+        self.assert_basis_content("Foo ROCKS!", target, fileid_1)
+        self.assert_basis_content("Hello World", target, fileid_4)
+
+    def test_content_filtering_applied_on_switch(self):
+        # Create a source branch with two revisions
+        source, fileid_1, fileid_2, fileid_3, fileid_4 = \
+            self.create_cf_tree_with_two_revisions(txt_reader=None,
+            txt_writer=None, dir='branch-a')
+        if not source.supports_content_filtering():
+            return
+
+        # Now patch in content filtering and branch from revision 1
+        self.patch_in_content_filter()
+        self.run_bzr('branch -r1 branch-a branch-b')
+
+        # Now create a lightweight checkout referring to branch-b
+        self.run_bzr('checkout --lightweight branch-b checkout')
+        self.assertFileEqual("fOO tXT", 'checkout/file1.txt')
+
+        # Switch it to branch-b and check the tree is updated
+        checkout_control_dir = BzrDir.open_containing('checkout')[0]
+        switch(checkout_control_dir, source.branch)
+        self.assertFileEqual("fOO rocks!", 'checkout/file1.txt')
+        self.assertFileEqual("hELLO wORLD", 'checkout/file4.txt')
+
+    def test_content_filtering_applied_on_revert_delete(self):
+        # Create a source branch with content filtering
+        source, txt_fileid, bin_fileid = self.create_cf_tree(
+            txt_reader=_uppercase, txt_writer=_lowercase, dir='source')
+        if not source.supports_content_filtering():
+            return
+        self.assertFileEqual("Foo Txt", 'source/file1.txt')
+        self.assert_basis_content("FOO TXT", source, txt_fileid)
+
+        # Now delete the file, revert it and check the content
+        os.unlink('source/file1.txt')
+        self.assertFalse(os.path.exists('source/file1.txt'))
+        source.revert(['file1.txt'])
+        self.assertTrue(os.path.exists('source/file1.txt'))
+        # Note: we don't get back exactly what was in the tree
+        # previously because lower(upper(text)) is a lossy transformation
+        self.assertFileEqual("foo txt", 'source/file1.txt')
+
+    def test_content_filtering_applied_on_revert_rename(self):
+        # Create a source branch with content filtering
+        source, txt_fileid, bin_fileid = self.create_cf_tree(
+            txt_reader=_uppercase, txt_writer=_lowercase, dir='source')
+        if not source.supports_content_filtering():
+            return
+        self.assertFileEqual("Foo Txt", 'source/file1.txt')
+        self.assert_basis_content("FOO TXT", source, txt_fileid)
+
+        # Now modify & rename a file, revert it and check the content
+        self.build_tree_contents([
+            ('source/file1.txt', 'Foo Txt with new content')])
+        source.rename_one('file1.txt', 'file1.bin')
+        self.assertTrue(os.path.exists('source/file1.bin'))
+        self.assertFalse(os.path.exists('source/file1.txt'))
+        self.assertFileEqual("Foo Txt with new content", 'source/file1.bin')
+        source.revert(['file1.bin'])
+        self.assertFalse(os.path.exists('source/file1.bin'))
+        self.assertTrue(os.path.exists('source/file1.txt'))
+        # Note: we don't get back exactly what was in the tree
+        # previously because lower(upper(text)) is a lossy transformation
+        self.assertFileEqual("foo txt", 'source/file1.txt')

=== modified file 'bzrlib/tests/per_workingtree/test_flush.py'
--- bzrlib/tests/per_workingtree/test_flush.py	2009-07-31 17:42:29 +0000
+++ bzrlib/tests/per_workingtree/test_flush.py	2009-08-25 23:38:10 +0000
@@ -16,7 +16,9 @@
 
 """Tests for WorkingTree.flush."""
 
+import sys
 from bzrlib import errors, inventory
+from bzrlib.tests import TestSkipped
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 
@@ -31,8 +33,14 @@
             tree.unlock()
 
     def test_flush_when_inventory_is_modified(self):
+        if sys.platform == "win32":
+            raise TestSkipped("don't use oslocks on win32 in unix manner")
         # This takes a write lock on the source tree, then opens a second copy
-        # and tries to grab a read lock, which is a bit bogus
+        # and tries to grab a read lock. This works on Unix and is a reasonable
+        # way to detect when the file is actually written to, but it won't work
+        # (as a test) on Windows. It might be nice to instead stub out the
+        # functions used to write and that way do both less work and also be
+        # able to execute on Windows.
         self.thisFailsStrictLockCheck()
         # when doing a flush the inventory should be written if needed.
         # we test that by changing the inventory (using

=== modified file 'bzrlib/tests/per_workingtree/test_locking.py'
--- bzrlib/tests/per_workingtree/test_locking.py	2009-07-31 17:42:29 +0000
+++ bzrlib/tests/per_workingtree/test_locking.py	2009-08-25 23:38:10 +0000
@@ -16,11 +16,14 @@
 
 """Tests for the (un)lock interfaces on all working tree implemenations."""
 
+import sys
+
 from bzrlib import (
     branch,
     errors,
     lockdir,
     )
+from bzrlib.tests import TestSkipped
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 
@@ -105,8 +108,14 @@
 
         :param methodname: The lock method to use to establish locks.
         """
-        # This write locks the local tree, and then grabs a read lock on a
-        # copy, which is bogus and the test just needs to be rewritten.
+        if sys.platform == "win32":
+            raise TestSkipped("don't use oslocks on win32 in unix manner")
+        # This helper takes a write lock on the source tree, then opens a
+        # second copy and tries to grab a read lock. This works on Unix and is
+        # a reasonable way to detect when the file is actually written to, but
+        # it won't work (as a test) on Windows. It might be nice to instead
+        # stub out the functions used to write and that way do both less work
+        # and also be able to execute on Windows.
         self.thisFailsStrictLockCheck()
         # when unlocking the last lock count from tree_write_lock,
         # the tree should do a flush().

=== modified file 'bzrlib/tests/per_workingtree/test_parents.py'
--- bzrlib/tests/per_workingtree/test_parents.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_workingtree/test_parents.py	2009-09-09 01:05:31 +0000
@@ -392,6 +392,14 @@
             try:
                 if shape.root.revision is None:
                     shape.root.revision = revid
+                # Create the text records for this inventory.
+                for path, ie in shape.iter_entries():
+                    if ie.text_size:
+                        lines = ['a' * ie.text_size]
+                    else:
+                        lines = []
+                    tree.branch.repository.texts.add_lines(
+                        (ie.file_id, ie.revision), [], lines)
                 sha1 = tree.branch.repository.add_inventory(revid, shape, [])
                 rev = Revision(timestamp=0,
                                timezone=None,
@@ -400,11 +408,10 @@
                                inventory_sha1=sha1,
                                revision_id=revid)
                 tree.branch.repository.add_revision(revid, rev)
+                tree.branch.repository.commit_write_group()
             except:
                 tree.branch.repository.abort_write_group()
                 raise
-            else:
-                tree.branch.repository.commit_write_group()
         finally:
             tree.unlock()
 

=== modified file 'bzrlib/tests/per_workingtree/test_set_root_id.py'
--- bzrlib/tests/per_workingtree/test_set_root_id.py	2009-08-21 01:48:13 +0000
+++ bzrlib/tests/per_workingtree/test_set_root_id.py	2009-09-11 07:55:48 +0000
@@ -16,13 +16,18 @@
 
 """Tests for WorkingTree.set_root_id"""
 
+import sys
+
 from bzrlib import inventory
+from bzrlib.tests import TestSkipped
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 
 class TestSetRootId(TestCaseWithWorkingTree):
 
     def test_set_and_read_unicode(self):
+        if sys.platform == "win32":
+            raise TestSkipped("don't use oslocks on win32 in unix manner")
         # This test tests that setting the root doesn't flush, so it
         # deliberately tests concurrent access that isn't possible on windows.
         self.thisFailsStrictLockCheck()

=== modified file 'bzrlib/tests/per_workingtree/test_smart_add.py'
--- bzrlib/tests/per_workingtree/test_smart_add.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_workingtree/test_smart_add.py	2009-11-08 04:49:06 +0000
@@ -17,6 +17,7 @@
 """Test that we can use smart_add on all Tree implementations."""
 
 from cStringIO import StringIO
+import sys
 
 from bzrlib import (
     add,
@@ -51,6 +52,23 @@
         self.assertEqual([('', 'V', 'directory'), ('a', 'V', 'file')],
                          files)
 
+    def assertFilenameSkipped(self, filename):
+        tree = self.make_branch_and_tree('tree')
+        try:
+            self.build_tree(['tree/'+filename])
+        except errors.NoSuchFile:
+            if sys.platform == 'win32':
+                raise tests.TestNotApplicable('Cannot create files named %r on'
+                    ' win32' % (filename,))
+        tree.smart_add(['tree'])
+        self.assertEqual(None, tree.path2id(filename))
+
+    def test_path_containing_newline_skips(self):
+        self.assertFilenameSkipped('a\nb')
+
+    def test_path_containing_carriagereturn_skips(self):
+        self.assertFilenameSkipped('a\rb')
+
     def test_save_false(self):
         """Dry-run add doesn't permanently affect the tree."""
         wt = self.make_branch_and_tree('.')

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2009-11-08 05:28:57 +0000
@@ -513,30 +513,37 @@
 
     def test_merge_revert(self):
         from bzrlib.merge import merge_inner
-        self.thisFailsStrictLockCheck()
         this = self.make_branch_and_tree('b1')
-        open('b1/a', 'wb').write('a test\n')
-        this.add('a')
-        open('b1/b', 'wb').write('b test\n')
-        this.add('b')
+        self.build_tree_contents([('b1/a', 'a test\n'), ('b1/b', 'b test\n')])
+        this.add(['a', 'b'])
         this.commit(message='')
         base = this.bzrdir.clone('b2').open_workingtree()
-        open('b2/a', 'wb').write('b test\n')
+        self.build_tree_contents([('b2/a', 'b test\n')])
         other = this.bzrdir.clone('b3').open_workingtree()
-        open('b3/a', 'wb').write('c test\n')
-        open('b3/c', 'wb').write('c test\n')
+        self.build_tree_contents([('b3/a', 'c test\n'), ('b3/c', 'c test\n')])
         other.add('c')
 
-        open('b1/b', 'wb').write('q test\n')
-        open('b1/d', 'wb').write('d test\n')
+        self.build_tree_contents([('b1/b', 'q test\n'), ('b1/d', 'd test\n')])
+        # Note: If we don't lock this before calling merge_inner, then we get a
+        #       lock-contention failure. This probably indicates something
+        #       weird going on inside merge_inner. Probably something about
+        #       calling bt = this_tree.basis_tree() in one lock, and then
+        #       locking both this_tree and bt separately, causing a dirstate
+        #       locking race.
+        this.lock_write()
+        self.addCleanup(this.unlock)
         merge_inner(this.branch, other, base, this_tree=this)
-        self.assertNotEqual(open('b1/a', 'rb').read(), 'a test\n')
+        a = open('b1/a', 'rb')
+        try:
+            self.assertNotEqual(a.read(), 'a test\n')
+        finally:
+            a.close()
         this.revert()
-        self.assertEqual(open('b1/a', 'rb').read(), 'a test\n')
-        self.assertIs(os.path.exists('b1/b.~1~'), True)
-        self.assertIs(os.path.exists('b1/c'), False)
-        self.assertIs(os.path.exists('b1/a.~1~'), False)
-        self.assertIs(os.path.exists('b1/d'), True)
+        self.assertFileEqual('a test\n', 'b1/a')
+        self.failUnlessExists('b1/b.~1~')
+        self.failIfExists('b1/c')
+        self.failIfExists('b1/a.~1~')
+        self.failUnlessExists('b1/d')
 
     def test_update_updates_bound_branch_no_local_commits(self):
         # doing an update in a tree updates the branch its bound to too.

=== added file 'bzrlib/tests/script.py'
--- bzrlib/tests/script.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/script.py	2009-11-08 20:28:36 +0000
@@ -0,0 +1,450 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Shell-like test scripts.
+
+See developers/testing.html for more explanations.
+"""
+
+import doctest
+import errno
+import glob
+import os
+import shlex
+from cStringIO import StringIO
+
+from bzrlib import (
+    osutils,
+    tests,
+    )
+
+
+def split(s):
+    """Split a command line respecting quotes."""
+    scanner = shlex.shlex(s)
+    scanner.quotes = '\'"`'
+    scanner.whitespace_split = True
+    for t in list(scanner):
+        yield t
+
+
+def _script_to_commands(text, file_name=None):
+    """Turn a script into a list of commands with their associated IOs.
+
+    Each command appears on a line by itself starting with '$ '. It can be
+    associated with an input that will feed it and an expected output.
+
+    Comments starts with '#' until the end of line.
+    Empty lines are ignored.
+
+    Input and output are full lines terminated by a '\n'.
+
+    Input lines start with '<'.
+    Output lines start with nothing.
+    Error lines start with '2>'.
+    """
+
+    commands = []
+
+    def add_command(cmd, input, output, error):
+        if cmd is not None:
+            if input is not None:
+                input = ''.join(input)
+            if output is not None:
+                output = ''.join(output)
+            if error is not None:
+                error = ''.join(error)
+            commands.append((cmd, input, output, error))
+
+    cmd_cur = None
+    cmd_line = 1
+    lineno = 0
+    input, output, error = None, None, None
+    for line in text.split('\n'):
+        lineno += 1
+        # Keep a copy for error reporting
+        orig = line
+        comment =  line.find('#')
+        if comment >= 0:
+            # Delete comments
+            line = line[0:comment]
+            line = line.rstrip()
+        if line == '':
+            # Ignore empty lines
+            continue
+        if line.startswith('$'):
+            # Time to output the current command
+            add_command(cmd_cur, input, output, error)
+            # And start a new one
+            cmd_cur = list(split(line[1:]))
+            cmd_line = lineno
+            input, output, error = None, None, None
+        elif line.startswith('<'):
+            if input is None:
+                if cmd_cur is None:
+                    raise SyntaxError('No command for that input',
+                                      (file_name, lineno, 1, orig))
+                input = []
+            input.append(line[1:] + '\n')
+        elif line.startswith('2>'):
+            if error is None:
+                if cmd_cur is None:
+                    raise SyntaxError('No command for that error',
+                                      (file_name, lineno, 1, orig))
+                error = []
+            error.append(line[2:] + '\n')
+        else:
+            if output is None:
+                if cmd_cur is None:
+                    raise SyntaxError('No command for that output',
+                                      (file_name, lineno, 1, orig))
+                output = []
+            output.append(line + '\n')
+    # Add the last seen command
+    add_command(cmd_cur, input, output, error)
+    return commands
+
+
+def _scan_redirection_options(args):
+    """Recognize and process input and output redirections.
+
+    :param args: The command line arguments
+
+    :return: A tuple containing: 
+        - The file name redirected from or None
+        - The file name redirected to or None
+        - The mode to open the output file or None
+        - The reamining arguments
+    """
+    def redirected_file_name(direction, name, args):
+        if name == '':
+            try:
+                name = args.pop(0)
+            except IndexError:
+                # We leave the error handling to higher levels, an empty name
+                # can't be legal.
+                name = ''
+        return name
+
+    remaining = []
+    in_name = None
+    out_name, out_mode = None, None
+    while args:
+        arg = args.pop(0)
+        if arg.startswith('<'):
+            in_name = redirected_file_name('<', arg[1:], args)
+        elif arg.startswith('>>'):
+            out_name = redirected_file_name('>>', arg[2:], args)
+            out_mode = 'ab+'
+        elif arg.startswith('>',):
+            out_name = redirected_file_name('>', arg[1:], args)
+            out_mode = 'wb+'
+        else:
+            remaining.append(arg)
+    return in_name, out_name, out_mode, remaining
+
+
+class ScriptRunner(object):
+    """Run a shell-like script from a test.
+    
+    Can be used as:
+
+    from bzrlib.tests import script
+
+    ...
+
+        def test_bug_nnnnn(self):
+            sr = script.ScriptRunner()
+            sr.run_script(self, '''
+            $ bzr init
+            $ bzr do-this
+            # Boom, error
+            ''')
+    """
+
+    def __init__(self):
+        self.output_checker = doctest.OutputChecker()
+        self.check_options = doctest.ELLIPSIS
+
+    def run_script(self, test_case, text):
+        """Run a shell-like script as a test.
+
+        :param test_case: A TestCase instance that should provide the fail(),
+            assertEqualDiff and _run_bzr_core() methods as well as a 'test_dir'
+            attribute used as a jail root.
+
+        :param text: A shell-like script (see _script_to_commands for syntax).
+        """
+        for cmd, input, output, error in _script_to_commands(text):
+            self.run_command(test_case, cmd, input, output, error)
+
+    def run_command(self, test_case, cmd, input, output, error):
+        mname = 'do_' + cmd[0]
+        method = getattr(self, mname, None)
+        if method is None:
+            raise SyntaxError('Command not found "%s"' % (cmd[0],),
+                              None, 1, ' '.join(cmd))
+        if input is None:
+            str_input = ''
+        else:
+            str_input = ''.join(input)
+        args = list(self._pre_process_args(cmd[1:]))
+        retcode, actual_output, actual_error = method(test_case,
+                                                      str_input, args)
+
+        self._check_output(output, actual_output, test_case)
+        self._check_output(error, actual_error, test_case)
+        if retcode and not error and actual_error:
+            test_case.fail('In \n\t%s\nUnexpected error: %s'
+                           % (' '.join(cmd), actual_error))
+        return retcode, actual_output, actual_error
+
+    def _check_output(self, expected, actual, test_case):
+        if expected is None:
+            # Specifying None means: any output is accepted
+            return
+        if actual is None:
+            test_case.fail('We expected output: %r, but found None'
+                           % (expected,))
+        matching = self.output_checker.check_output(
+            expected, actual, self.check_options)
+        if not matching:
+            # Note that we can't use output_checker.output_difference() here
+            # because... the API is broken ('expected' must be a doctest
+            # specific object of which a 'want' attribute will be our
+            # 'expected' parameter. So we just fallback to our good old
+            # assertEqualDiff since we know there *are* differences and the
+            # output should be decently readable.
+            test_case.assertEqualDiff(expected, actual)
+
+    def _pre_process_args(self, args):
+        new_args = []
+        for arg in args:
+            # Strip the simple and double quotes since we don't care about
+            # them.  We leave the backquotes in place though since they have a
+            # different semantic.
+            if arg[0] in  ('"', "'") and arg[0] == arg[-1]:
+                yield arg[1:-1]
+            else:
+                if glob.has_magic(arg):
+                    matches = glob.glob(arg)
+                    if matches:
+                        # We care more about order stability than performance
+                        # here
+                        matches.sort()
+                        for m in matches:
+                            yield m
+                else:
+                    yield arg
+
+    def _read_input(self, input, in_name):
+        if in_name is not None:
+            infile = open(in_name, 'rb')
+            try:
+                # Command redirection takes precedence over provided input
+                input = infile.read()
+            finally:
+                infile.close()
+        return input
+
+    def _write_output(self, output, out_name, out_mode):
+        if out_name is not None:
+            outfile = open(out_name, out_mode)
+            try:
+                outfile.write(output)
+            finally:
+                outfile.close()
+            output = None
+        return output
+
+    def do_bzr(self, test_case, input, args):
+        retcode, out, err = test_case._run_bzr_core(
+            args, retcode=None, encoding=None, stdin=input, working_dir=None)
+        return retcode, out, err
+
+    def do_cat(self, test_case, input, args):
+        (in_name, out_name, out_mode, args) = _scan_redirection_options(args)
+        if args and in_name is not None:
+            raise SyntaxError('Specify a file OR use redirection')
+
+        inputs = []
+        if input:
+            inputs.append(input)
+        input_names = args
+        if in_name:
+            args.append(in_name)
+        for in_name in input_names:
+            try:
+                inputs.append(self._read_input(None, in_name))
+            except IOError, e:
+                # Some filenames are illegal on Windows and generate EINVAL
+                # rather than just saying the filename doesn't exist
+                if e.errno in (errno.ENOENT, errno.EINVAL):
+                    return (1, None,
+                            '%s: No such file or directory\n' % (in_name,))
+                raise
+        # Basically cat copy input to output
+        output = ''.join(inputs)
+        # Handle output redirections
+        try:
+            output = self._write_output(output, out_name, out_mode)
+        except IOError, e:
+            # If out_name cannot be created, we may get 'ENOENT', however if
+            # out_name is something like '', we can get EINVAL
+            if e.errno in (errno.ENOENT, errno.EINVAL):
+                return 1, None, '%s: No such file or directory\n' % (out_name,)
+            raise
+        return 0, output, None
+
+    def do_echo(self, test_case, input, args):
+        (in_name, out_name, out_mode, args) = _scan_redirection_options(args)
+        if input or in_name:
+            raise SyntaxError('echo doesn\'t read from stdin')
+        if args:
+            input = ' '.join(args)
+        # Always append a \n'
+        input += '\n'
+        # Process output
+        output = input
+        # Handle output redirections
+        try:
+            output = self._write_output(output, out_name, out_mode)
+        except IOError, e:
+            if e.errno in (errno.ENOENT, errno.EINVAL):
+                return 1, None, '%s: No such file or directory\n' % (out_name,)
+            raise
+        return 0, output, None
+
+    def _get_jail_root(self, test_case):
+        return test_case.test_dir
+
+    def _ensure_in_jail(self, test_case, path):
+        jail_root = self._get_jail_root(test_case)
+        if not osutils.is_inside(jail_root, osutils.normalizepath(path)):
+            raise ValueError('%s is not inside %s' % (path, jail_root))
+
+    def do_cd(self, test_case, input, args):
+        if len(args) > 1:
+            raise SyntaxError('Usage: cd [dir]')
+        if len(args) == 1:
+            d = args[0]
+            self._ensure_in_jail(test_case, d)
+        else:
+            # The test "home" directory is the root of its jail
+            d = self._get_jail_root(test_case)
+        os.chdir(d)
+        return 0, None, None
+
+    def do_mkdir(self, test_case, input, args):
+        if not args or len(args) != 1:
+            raise SyntaxError('Usage: mkdir dir')
+        d = args[0]
+        self._ensure_in_jail(test_case, d)
+        os.mkdir(d)
+        return 0, None, None
+
+    def do_rm(self, test_case, input, args):
+        err = None
+
+        def error(msg, path):
+            return  "rm: cannot remove '%s': %s\n" % (path, msg)
+
+        force, recursive = False, False
+        opts = None
+        if args and args[0][0] == '-':
+            opts = args.pop(0)[1:]
+            if 'f' in opts:
+                force = True
+                opts = opts.replace('f', '', 1)
+            if 'r' in opts:
+                recursive = True
+                opts = opts.replace('r', '', 1)
+        if not args or opts:
+            raise SyntaxError('Usage: rm [-fr] path+')
+        for p in args:
+            self._ensure_in_jail(test_case, p)
+            # FIXME: Should we put that in osutils ?
+            try:
+                os.remove(p)
+            except OSError, e:
+                # Various OSes raises different exceptions (linux: EISDIR,
+                #   win32: EACCES, OSX: EPERM) when invoked on a directory
+                if e.errno in (errno.EISDIR, errno.EPERM, errno.EACCES):
+                    if recursive:
+                        osutils.rmtree(p)
+                    else:
+                        err = error('Is a directory', p)
+                        break
+                elif e.errno == errno.ENOENT:
+                    if not force:
+                        err =  error('No such file or directory', p)
+                        break
+                else:
+                    raise
+        if err:
+            retcode = 1
+        else:
+            retcode = 0
+        return retcode, None, err
+
+
+class TestCaseWithMemoryTransportAndScript(tests.TestCaseWithMemoryTransport):
+    """Helper class to experiment shell-like test and memory fs.
+
+    This not intended to be used outside of experiments in implementing memoy
+    based file systems and evolving bzr so that test can use only memory based
+    resources.
+    """
+
+    def setUp(self):
+        super(TestCaseWithMemoryTransportAndScript, self).setUp()
+        self.script_runner = ScriptRunner()
+
+    def run_script(self, script):
+        return self.script_runner.run_script(self, script)
+
+    def run_command(self, cmd, input, output, error):
+        return self.script_runner.run_command(self, cmd, input, output, error)
+
+
+class TestCaseWithTransportAndScript(tests.TestCaseWithTransport):
+    """Helper class to quickly define shell-like tests.
+
+    Can be used as:
+
+    from bzrlib.tests import script
+
+
+    class TestBug(script.TestCaseWithTransportAndScript):
+
+        def test_bug_nnnnn(self):
+            self.run_script('''
+            $ bzr init
+            $ bzr do-this
+            # Boom, error
+            ''')
+    """
+
+    def setUp(self):
+        super(TestCaseWithTransportAndScript, self).setUp()
+        self.script_runner = ScriptRunner()
+
+    def run_script(self, script):
+        return self.script_runner.run_script(self, script)
+
+    def run_command(self, cmd, input, output, error):
+        return self.script_runner.run_command(self, cmd, input, output, error)
+

=== modified file 'bzrlib/tests/ssl_certs/create_ssls.py'
--- bzrlib/tests/ssl_certs/create_ssls.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/ssl_certs/create_ssls.py	2009-11-26 14:17:19 +0000
@@ -46,6 +46,13 @@
     Popen,
     PIPE,
     )
+import sys
+
+# We want to use the right bzrlib: the one we are part of
+# FIXME: The fllowing is correct but looks a bit ugly 
+_dir = os.path.dirname
+our_bzr = _dir(_dir(_dir(_dir(os.path.realpath(__file__)))))
+sys.path.insert(0, our_bzr)
 
 from bzrlib import (
     osutils,
@@ -105,7 +112,7 @@
     server_locality='LocalHost',
     server_organization='Testing Ltd',
     server_section='https server',
-    server_name='localhost', # Always accessed under that name
+    server_name='127.0.0.1', # Always accessed under that name
     server_email='https_server@locahost',
     server_optional_company_name='',
     )

=== modified file 'bzrlib/tests/ssl_certs/server.crt'
--- bzrlib/tests/ssl_certs/server.crt	2008-01-05 22:09:47 +0000
+++ bzrlib/tests/ssl_certs/server.crt	2009-11-26 14:17:19 +0000
@@ -2,32 +2,32 @@
 MIIFpDCCA4wCAQEwDQYJKoZIhvcNAQEFBQAwgZMxCzAJBgNVBAYTAkJaMREwDwYD
 VQQIEwhJbnRlcm5ldDEPMA0GA1UEBxMGQmF6YWFyMRQwEgYDVQQKEwtEaXN0cmli
 dXRlZDEMMAoGA1UECxMDVkNTMR8wHQYDVQQDExZNYXN0ZXIgb2YgY2VydGlmaWNh
-dGVzMRswGQYJKoZIhvcNAQkBFgxjZXJ0QG5vLnNwYW0wHhcNMDgwMTA1MjIwNjQ1
-WhcNMTgwMTAyMjIwNjQ1WjCBmzELMAkGA1UEBhMCTEgxETAPBgNVBAgTCEludGVy
+dGVzMRswGQYJKoZIhvcNAQkBFgxjZXJ0QG5vLnNwYW0wHhcNMDkxMTI2MTMyMjE4
+WhcNMTkxMTI0MTMyMjE4WjCBmzELMAkGA1UEBhMCTEgxETAPBgNVBAgTCEludGVy
 bmV0MRIwEAYDVQQHEwlMb2NhbEhvc3QxFDASBgNVBAoTC1Rlc3RpbmcgTHRkMRUw
-EwYDVQQLEwxodHRwcyBzZXJ2ZXIxEjAQBgNVBAMTCWxvY2FsaG9zdDEkMCIGCSqG
+EwYDVQQLEwxodHRwcyBzZXJ2ZXIxEjAQBgNVBAMTCTEyNy4wLjAuMTEkMCIGCSqG
 SIb3DQEJARYVaHR0cHNfc2VydmVyQGxvY2Fob3N0MIICIjANBgkqhkiG9w0BAQEF
-AAOCAg8AMIICCgKCAgEAsvSNdobG/oO97vhO7xcHpQfpx2QHwYOn+Im0FMTXbTPd
-Bre4wkjEC2KxOjH6MGBEQM02h8SUAWCcvX+HyLBkZRtgeueZZaf2iqc+Tr24ueMa
-f8elqz1tuaua7zyuR+uUgZyxX7rgbuVDUYNt5qVN8uXUSbCtVgxHa3extD7fbvD8
-t9P/QUItx5EBBEeWVhtVffgI35OWMwsJhiwK68ka0kTLJJhZyqAQujKnZf0uHyAv
-Vkai1fYtjklBVLnxwvJZOwnQto3RF1AmuMgj7T6RwDjTR43DioHtTJotrPZfQaAF
-3tVC30Vy8pm0ojFdxUdKPgEMOLBWizXWc3lzWn02CE0awHxwIYNVNLODX3sU/ou8
-OqOIMDRK451xE5S5WOXciWLknY/ene2r4g/pPFYNrwc/9eZ0AYIhE7Jm7b+D3WvL
-z3CrhYul/XmPsXBHBnxkrjvtrj0yDZyHZnMpygqL7Cr9/2V9FwMFPNTNY5Sifmcx
-l6orvx8oe6Q98XwGD575wWU6BwIrpriSa2HWrVIDwwbSCeZ8NULXe8fnC8zInckj
-tzz8osqRv4af+XXoht5zJtt8fUc7o4Xiq4Yyzlj3lJMHWcP+GqzCbJ0c/OY6C/ml
-C6YbMeCwv+/gAs3Xw1eSzimDqxh/kIw6SgBUGoQVffOzaJo917cMyYycLDDN9/8C
-AwEAATANBgkqhkiG9w0BAQUFAAOCAgEAmPprAO6iZZaruR2qeekooeCINXbiGY92
-0Er+jLU2fulOWwDDh7nGMjNM8jz0NKxcjRJ26GLHsQS4lLrD6B6fQb2vBm47oMFX
-pzyeQotvO0uqvMZMNls8tJxKEy7+NVMf+UI/gVTiqIUgnl6hJ3pO2FoDoIG2rwGO
-mAZAc0Xu1w8B0F77umFhlzcK0jKyTGXRIqO8lFYdRpXcIT8wATGxTTyGApWw2nh9
-CWZviX9Fsz6l7qr85ckcrvtzb4e/qtY/oV/y469FtoI2Tz1Iq94Et0zpZMsCfgbd
-TI9IxnPkLd59WbwMghlBtMv7tbXSGCSnSKieZVbf/hGfwVK30dCGS3X0hsF60ADd
-/wh01QgxfXgAktOvCnsMUrfMcElEvE1lgCSqtYw5AL5+nDf3FUwJbr47l8BCk589
-OAN0ijrnUPHNHL83eLuxb26V8B7LRt61HfQOAXBcpwTHyewnOXq0zj5lzkgAU8Sj
-55FObSd2/gvOVw9rr3eC0evgMpDAsOfeupE2BB/VwTRrbRrETiqskWa8EnvqKPkM
-ESIRsstLlUIKbxhSHHaRrtY6FbcN5nXEz4kOXz/tYKuxuPnZz9Wih5YBWcboKxut
-OMrdjUeDnckLAw1rJI+H8+jPkyOqCpcOpLI9xJxmuYJhufjbB/B8ddNT1/pjceze
-uR7coWvplKU=
+AAOCAg8AMIICCgKCAgEAq2uwbT6Zs/gC5ytKiAZfXGNVMQyGLuetgUrfQTbOL+/p
+4sK97hhWk/qbJRQVy8qQ5o4JKmTwAmf/exGxh94E3eacC9EEIdI3A0I2dbno9qAu
+zBXXacjqcKT/PczIN9U1/+S0e5vOssCtvVFWzdbG7vTg3Shs5BG8y1Ue8CDUtczB
+8gGjbQWkugzAqK8IogeMKkCGmiWFzRubHwL9HH5tYm1w5EHJzx/avepOyTKKBQpF
+A0sza0IYwEIuREMWcN64YPqs/OkLFmGCfpMCZvOmsmwGTxf+MoDNiqBco67xBuaK
+e4pSUf1f1PrbgHpEJq68QuCsRgWFYig0jRkh06ox5beyV9n/bQ/bA7W60JT/NUo9
+uNtFgC2ui2yHA5c3ozW+Muk7tS42r9Sde3gW/81c+kZbVS87EM42XQFMP1stAR8W
+XMwzlVnjrbQ/ERwt+OoGbOt9woHeEKpi9chmFtDR5irY3uJoP9/+9D51glxRGQql
+kpNc/FL4VYbmCZY8QCeEXHaxl1MeuZCI6ovGHojpUvFNQK+7qFOhbK0G8me7o+ly
+P/qCbjTTvom/Kvg9kFtAvwuz6ErWYKh0xZQxNhFl3uGtxycAti0+5O6l/lLUQwv8
+n79IWawWDTy4s8kYfWBiH8NNQBLib6tlllzt7LXtcPJjTkZ1finT5YFqweQCiR8C
+AwEAATANBgkqhkiG9w0BAQUFAAOCAgEAutvkG9R7oxOiRNHhMnDtcMFS92PdgrFU
+eAANojT2eC359K+vzIG19EReq6OEk8pLjbzehVW808hxtdMaMOQc3Np4AHl9Z4Sp
+YEMpRsfIbjwgM02aT7Ig5ZztRjKq78G5WzQq71Q5tzK9gCotGYH5B9QEbEpEjnb0
+UGaGi4bB+/WJsAuxKt5UyvN1h4n6oJYY4/Dy20H0LfnzjGOayuOoRaZt8cBFS0XQ
+8Gp6WAJwl8CJms84XL8IN6Zj6fYCWPP4fT6kiu7VHof+/zK99ajkEKaykl7mkyEk
+NfpaGIgVsPgd6BkWDavbW7DJg0LNlPry+Mh5MNAcHNaGUpJ5mYoazLBDw9rd70ss
+70TgT1te7WyB2yHbKLHdKDtRshfemXZaScVxoWsRrlDJQQn+1CiBWAmuVgZNiAIY
+gqM5kcFiLPP8hjw1GzPcSwjg8uxyM1lY6m1KLwdO2hW+iZCj1vhz//lBBHmYYTqk
+8EwtbWJ7XVQaLVRhAc1HIIA6TSAPiP7Dgn2rhQHcqODYSmfieXPQetlFhXNJG508
+voSrJMpsKQOId+2Ua00Wi6ajsje00vklG7IzvLY7MdeiSxNrXLNGlSjHI9/+ea0E
+lHJQbJUjR/kXNT/2WBnjBkSVclsz5Xx2dAf3kU0AlUA+b962Y/fxlma5wd8PIHx6
+tW5I+uMneHg=
 -----END CERTIFICATE-----

=== modified file 'bzrlib/tests/ssl_certs/server.csr'
--- bzrlib/tests/ssl_certs/server.csr	2008-01-05 22:09:47 +0000
+++ bzrlib/tests/ssl_certs/server.csr	2009-11-26 14:17:19 +0000
@@ -1,29 +1,29 @@
 -----BEGIN CERTIFICATE REQUEST-----
 MIIFBjCCAu4CAQAwgZsxCzAJBgNVBAYTAkxIMREwDwYDVQQIEwhJbnRlcm5ldDES
 MBAGA1UEBxMJTG9jYWxIb3N0MRQwEgYDVQQKEwtUZXN0aW5nIEx0ZDEVMBMGA1UE
-CxMMaHR0cHMgc2VydmVyMRIwEAYDVQQDEwlsb2NhbGhvc3QxJDAiBgkqhkiG9w0B
+CxMMaHR0cHMgc2VydmVyMRIwEAYDVQQDEwkxMjcuMC4wLjExJDAiBgkqhkiG9w0B
 CQEWFWh0dHBzX3NlcnZlckBsb2NhaG9zdDCCAiIwDQYJKoZIhvcNAQEBBQADggIP
-ADCCAgoCggIBALL0jXaGxv6Dve74Tu8XB6UH6cdkB8GDp/iJtBTE120z3Qa3uMJI
-xAtisTox+jBgREDNNofElAFgnL1/h8iwZGUbYHrnmWWn9oqnPk69uLnjGn/Hpas9
-bbmrmu88rkfrlIGcsV+64G7lQ1GDbealTfLl1EmwrVYMR2t3sbQ+327w/LfT/0FC
-LceRAQRHllYbVX34CN+TljMLCYYsCuvJGtJEyySYWcqgELoyp2X9Lh8gL1ZGotX2
-LY5JQVS58cLyWTsJ0LaN0RdQJrjII+0+kcA400eNw4qB7UyaLaz2X0GgBd7VQt9F
-cvKZtKIxXcVHSj4BDDiwVos11nN5c1p9NghNGsB8cCGDVTSzg197FP6LvDqjiDA0
-SuOdcROUuVjl3Ili5J2P3p3tq+IP6TxWDa8HP/XmdAGCIROyZu2/g91ry89wq4WL
-pf15j7FwRwZ8ZK477a49Mg2ch2ZzKcoKi+wq/f9lfRcDBTzUzWOUon5nMZeqK78f
-KHukPfF8Bg+e+cFlOgcCK6a4kmth1q1SA8MG0gnmfDVC13vH5wvMyJ3JI7c8/KLK
-kb+Gn/l16IbecybbfH1HO6OF4quGMs5Y95STB1nD/hqswmydHPzmOgv5pQumGzHg
-sL/v4ALN18NXks4pg6sYf5CMOkoAVBqEFX3zs2iaPde3DMmMnCwwzff/AgMBAAGg
+ADCCAgoCggIBAKtrsG0+mbP4AucrSogGX1xjVTEMhi7nrYFK30E2zi/v6eLCve4Y
+VpP6myUUFcvKkOaOCSpk8AJn/3sRsYfeBN3mnAvRBCHSNwNCNnW56PagLswV12nI
+6nCk/z3MyDfVNf/ktHubzrLArb1RVs3Wxu704N0obOQRvMtVHvAg1LXMwfIBo20F
+pLoMwKivCKIHjCpAhpolhc0bmx8C/Rx+bWJtcORByc8f2r3qTskyigUKRQNLM2tC
+GMBCLkRDFnDeuGD6rPzpCxZhgn6TAmbzprJsBk8X/jKAzYqgXKOu8QbminuKUlH9
+X9T624B6RCauvELgrEYFhWIoNI0ZIdOqMeW3slfZ/20P2wO1utCU/zVKPbjbRYAt
+rotshwOXN6M1vjLpO7UuNq/UnXt4Fv/NXPpGW1UvOxDONl0BTD9bLQEfFlzMM5VZ
+4620PxEcLfjqBmzrfcKB3hCqYvXIZhbQ0eYq2N7iaD/f/vQ+dYJcURkKpZKTXPxS
++FWG5gmWPEAnhFx2sZdTHrmQiOqLxh6I6VLxTUCvu6hToWytBvJnu6Ppcj/6gm40
+076Jvyr4PZBbQL8Ls+hK1mCodMWUMTYRZd7hrccnALYtPuTupf5S1EML/J+/SFms
+Fg08uLPJGH1gYh/DTUAS4m+rZZZc7ey17XDyY05GdX4p0+WBasHkAokfAgMBAAGg
 JTAjBgkqhkiG9w0BCQcxFhMUQ2hhbGxlbmdlIGZvciB0aGUgQ0EwDQYJKoZIhvcN
-AQEFBQADggIBAKMiuMHoAeRVk/wC5Mize0EYf5E8xYwLAkx/nTOIkNcBSmbejHsW
-kwI86+FSiUlo+ndK6UYSiFhtb8kTw299hKt5PQqkz2/FYozOvS2YEXpzJDXOHmXL
-u5vNHq0TkjgkT5F+4m6nlgLSCssQWDsyoCF5gB58D9BMyG02NKnJ9M6/Matsvz6m
-7BnQwclVPSvpYiF5FSwnYdiZAbftt+BFqgHaKqYhLnMUtX8tLjSNCBgdaItSb+Vc
-icGJuIOTqTFSH8PATd50WNXqnJxZsFZmcRKmJ8h6mNqmv6tcJ4iLPFfMLuMFskG/
-L9O4FC9vLtfhCuAGtoaWRJPQ6oYC/3HL97fn3SudwAY+u5tp7CqAzFvMkMJ0gQeI
-8xIkwFkajUCHqV0Gug9Bx+B24YTNPzYiiJ0yIlyTh4R7D9PFv3a9RMOq6bvCwexJ
-02soRu9jijTwklD6jECa/gm40s8ChFo+c3YAF2MjFk1zjd7xT+jW8Pp0uEP9ig6H
-4n+gakpvSRFz2l1DZq3rfofyqBFOdVJRJ3IWc+n79K/E7zCTSA68vfYutMj+wuzW
-mSs0vBFu+2BQDHaCwq9R9vAhh2YLJZ9v6mID5PvqFGCJ2drNaTktR9xLfpmve6oC
-mn8mlI+pUaCd52XdgpYCTlXsnieaPOEWycSxnML8UxwoFk05K+oumg6F
+AQEFBQADggIBAGeE6ml7EshJvPvOv+I8DrcjzHiAO4+0w/weknWfS/ndAafkLBa7
+5TMFhnBFHQ9/XbvctyNCc5u5OQfRxQwJccV4OUiTPPXqN4UWWSzxIw8zVM/8MdiH
+yaVFYqr2gyAKlcCvKavWNKMXVdeoOFnAwA7rfgtA2mMNM0ZoSJr/PISkzN6ZFyh2
+VSCrVdBZ1pTMslIKqWkRgqeqlrRhEVXZIljrG5+vVVnzfxycPjeN3VD5US8Pr9B0
+im6sbDTn2z5pRTkVWc/cL1F7spxsa67KVqwwHx9GNojo7SY/NNeWQTaTe3uVa/Hp
+VXRAcutovboGVcMhu92Udz+bpn2XpbNZnWJGRkRZRLWG2Z+k/REGhMk+5LuMh/+N
+uumIThiNtCPeg3/esVxlAqDokteqnoE0XHtcBUTacvedgmxASV98Wu+Rx7MnVgTf
+29wGb132ZSRMEzoB0hSm9tjB2DVI/O1+YOcPDhoLHpfkUE+qXQTWPKCvrZCspJp9
+UYkWVTfbRJavXOOi8tRHvt0AfxEnyq3o1H7veqDxL0NMuXvNAL2fEt0Av1zfyHyS
+Ch+NpByF9m2BMG0TUrrMhtb83X+Rb7VOC6sbs8H+ste9DOwh2930T1eFsb0/32R8
+ix0EMI5Yi60RLcL9WOjdQ1JAMeO6+dywL8WpjyAyUegeMxwlzZCMRSvv
 -----END CERTIFICATE REQUEST-----

=== modified file 'bzrlib/tests/ssl_certs/server_with_pass.key'
--- bzrlib/tests/ssl_certs/server_with_pass.key	2008-01-05 22:09:47 +0000
+++ bzrlib/tests/ssl_certs/server_with_pass.key	2009-11-26 14:17:19 +0000
@@ -1,54 +1,54 @@
 -----BEGIN RSA PRIVATE KEY-----
 Proc-Type: 4,ENCRYPTED
-DEK-Info: DES-EDE3-CBC,F62A242FE077370D
+DEK-Info: DES-EDE3-CBC,60937C843264DF9B
 
-VzZiKGEsk27MopuxsH8hHDK1RPC6JBv2r/6936HAeOtVZu94ws9u2MAQ8E/tH1vD
-ggilBOPV4elonv3IzdoIxWFsvnuUvuf8rkXIrE/pP8FxunhihXnpz/fMK62jSYXe
-T46xTA6hEqG2EVs9mtGyfeFN8ZA7D5yciuK1t3bstWrIwH1n0h5fOztsWmP1w99D
-aHz2VtfJS4/+G1wMI3cwj4pdsGbHvEYRbxMhgsZ+e9qFmugm1jk1l1rV4C/fO5wL
-bclNDYX5EcYTkYEIqHo223wFNIlsOmod5bIsa7lv0tz+Vct0R7BLNkGlqE3G3ofu
-5Ek32YH3nvGkHhGUuY6n0FhSJJLjh9+2GrMimr+8tCPVAemM35Xe/VyN87kOWhuG
-UjfEms0//HbkO0jyoD/x0SpBuX2+cjMAyqCob6HkNXtWC9X7ZO6L36gBHs7DYKTz
-cX7Y9ram2PRb1Z1np5NigZ/Cestviy7uG1obfQbhPII/kovEV1K494Nbkmw5YvLK
-Np9zAay1eZZW+THn6kC8OhwnOQtRpj7SLpjclFMNj9uhfB6Dxo53q2dV0lwc+T1b
-aBCjy3A6R12meTCoPbGg2MqBA2aURPSRGKlYu09WvreX3tiM3GFOBfVIDiBulPT1
-RSWFM4IoXOg7WKHd1pXdO7WNV88Yi2iwFx4KASPOUMSvm8wq5NbE6TZ0oSuKiCNh
-szMTGsF2l7JZamW7MK19xom/ZxuZc0UzRzTD2Rp41EeRaX0GdPYz183AT1r/aT9S
-kzKRMG22tJBx7WIhs6T+/KqTQO2jI14G2XcaclhGG5u320ghm8UgEwg6hMFiPuhC
-dSO9wknjfunF6W/gyKbf36XSn9n4Yvx8YECuEQd5BligKyuUtIg0zn6Mwg2J1qYq
-N3yeZhNDcC7DZDLd8Lhu1NfWfzxiSoHeOUVGRApnUMMLtKoLPJpwz5qXTc6tLBky
-czlUAckRDS6f2lb9xPQm95pLg3wGmgvLcWn3ut5Rh+QwZ2GhJu3lbeQLd9rEtTHc
-+qg2B/tLxOfjPNcaWCkDCi7P1B7I8U2E6teNxVEEHRiK5zIeC/g0WXehaVnjzwkt
-L6fuxRiuBwe9m0cwVJuI33+1Y4CuWKsaBqlg/dHXCH3Ij3Iv9DU0Yary9uEkon7D
-BSDFZWJLvFpjnW/g0la0ow5Y6KTw2QyI8F8NbzKZIp647loclYeoN95RzF/rfB7I
-JJhvvuH7sT3EoN6fi8Dlq5IBVLMONN2BKFSheRI0Gui5bIY0+REijcgqZiwryGIk
-298pnfHSxeP39wQQvXfwMIl3r3XWxSWt9jDz5T3X4fxDJcp2GsW+Z5KZ158lX6g6
-I41JMHp6cKeg7NGdK52EW6ejD1blLL3vXt4MvRcnqvhDvJMbMSFhDhD0rFcPRERx
-q1Hw9Wc6V+isqmUcmmjULU3i/D7ksCuaHFsf7A/8EICbJG2jercRktBIm1CxzEvo
-IRnI53O5xINHb/JHIW6Vv9nyC5Bmc+dVojRpd3FOcxyuSLULo7VcDSWhU3j3dr+t
-TpF1Cm0dWGOeCHy1dVmMIEGd04WZdYguSlBkRSkvuZV14Y9DddRtsS/XiFm3ek3q
-tY0h3u6sx363Ap+pSz4XMy+P6nHRMr1ucBpAAy87vL8Oce6tUAwV2OR9laVBOafS
-kG2FSXY4ievLBT4qsBEnDIkiYxA3uA2bF5nnIlSE4Mv7BgKWjRqPnY6JTKR3eFd6
-YVXLd79z03iPJlnCCPga3RUWhjWDc3BvUCAv2yvzdARRCQga/Gtsi3aHAoSDMxgf
-YnUKmik1mboR50uvMfC6tstgI9yZ+ackYQQnuewDa/lN17Aq7HqGo5sf6rLMa82B
-x2UtEsYoTN477AGYOTzpQEoyb2uWpxw4qumLqsbSXzyw9jJzQ+/1c2jePzoatSdO
-QNE8tVRylusboL45fXtYetFV4EoqNdDgAsXLa75ooLInS+oh+gHeuxtJJXxa3deJ
-JXoqkP1TMExsRpVNnvN93FG6JEvYSbaUS9TZGc8+mZcQ7WWfkJnZjnOGtczkHG5a
-b1X8N28MGBkw00mdoCxJ573fvl4NmYeJC6clX8vU/nzG7u3duhjYGqacPktuX5/X
-/eKRJJ6OyLJm/S+cWNmFoaRCy95WDPbyZyUby/+aV57prbXMFar3+NTTBK+y0pmI
-/6q832eqj6IIHsL6VgFq2+l3abXcS2h6MIJjYLmURWAnWDednCDauEFrzzp6jo68
-2sZZOiW5drULi5tirtC3+mC4ERlcylcHZIfdCDyXifKvKJ3Ch/kDR/zvAMVIwicJ
-iMT/n8/5PidW217rtZlz5gjd3EunpdRQuNnNa8Ap2v4ddfUSeGI2UAOEt2rtfteu
-7pJF6wkP9QkYhJWKOBHbL8RxdATnhyVSMWo1iYM/zthOP8+IpZVDzl5uwr1gi4zf
-NQAQy7dxZKRO91GSeUX+BMxgAmDzwh24sbzpw/dTCGbiKTkujWchhAcJXXoq+LFb
-o9zWQ7/zz5g6L6yW6iuDGVJ/87mHX851/QVJfyP5lNURqkSOfsGMqjoz04bLOuxc
-znuAs/R6gc2jwwfF0rhDHJyLJQsuAFCxbAV7qc0kqcihhh34kqDujq9tQEdP65M5
-E6qfBjVoaPHFXeR+XaCPyMygJDHv5eaU2qojvq12CehcOKL66wMXt20A59C2ZDZp
-9cWg8KEej7vlfsA8JzkwcIYMWnHDUDViGqM/ifwQ95uSjEy+7HZVrQFFpcr1f/XF
-tJe/nArOxGf9d4VVbShKOleg2139fed6mfobJklHlFkzL2T5DgNCFc6iYSI3c2DQ
-Lh3mdwwjsVWh5kE5r0PCYSkhlg41DfrZTHx0pbRdix63jD4AsuMZ1+vT9taxUSYZ
-mTc4ELu8kH2I/Qm/8tVPnkjUxxApL7PIpvlnF3SbYNkd3AIbgtSWz782KpghKPmk
-SnIYXWQXlOtiliU2Wek+ntr5oguSKo5HmIfkF8Ad9SsEN8GxkmmQKOM9cO1ueDch
-7MP6KTE8wumSXl82hbiZK1GaErXGLenKKTrw0fqKY8mUiB/ciCqyLzgOtgVfAkPj
-T2/YQQp42Ppw1r3sJwObi0gvuHT+KQSBGTOmBCxKCi0s61T/Yolosy7b5eoUQEKR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 -----END RSA PRIVATE KEY-----

=== modified file 'bzrlib/tests/ssl_certs/server_without_pass.key'
--- bzrlib/tests/ssl_certs/server_without_pass.key	2008-01-05 22:09:47 +0000
+++ bzrlib/tests/ssl_certs/server_without_pass.key	2009-11-26 14:17:19 +0000
@@ -1,51 +1,51 @@
 -----BEGIN RSA PRIVATE KEY-----
-MIIJJwIBAAKCAgEAsvSNdobG/oO97vhO7xcHpQfpx2QHwYOn+Im0FMTXbTPdBre4
-wkjEC2KxOjH6MGBEQM02h8SUAWCcvX+HyLBkZRtgeueZZaf2iqc+Tr24ueMaf8el
-qz1tuaua7zyuR+uUgZyxX7rgbuVDUYNt5qVN8uXUSbCtVgxHa3extD7fbvD8t9P/
-QUItx5EBBEeWVhtVffgI35OWMwsJhiwK68ka0kTLJJhZyqAQujKnZf0uHyAvVkai
-1fYtjklBVLnxwvJZOwnQto3RF1AmuMgj7T6RwDjTR43DioHtTJotrPZfQaAF3tVC
-30Vy8pm0ojFdxUdKPgEMOLBWizXWc3lzWn02CE0awHxwIYNVNLODX3sU/ou8OqOI
-MDRK451xE5S5WOXciWLknY/ene2r4g/pPFYNrwc/9eZ0AYIhE7Jm7b+D3WvLz3Cr
-hYul/XmPsXBHBnxkrjvtrj0yDZyHZnMpygqL7Cr9/2V9FwMFPNTNY5Sifmcxl6or
-vx8oe6Q98XwGD575wWU6BwIrpriSa2HWrVIDwwbSCeZ8NULXe8fnC8zInckjtzz8
-osqRv4af+XXoht5zJtt8fUc7o4Xiq4Yyzlj3lJMHWcP+GqzCbJ0c/OY6C/mlC6Yb
-MeCwv+/gAs3Xw1eSzimDqxh/kIw6SgBUGoQVffOzaJo917cMyYycLDDN9/8CAwEA
-AQKCAgBbtFaJ1qdC5d//Bd/tRa/1Mgjq1Kfk0sLQ6kAOJJEAtQMe3icf6IoOC5Um
-bVX4VFylmIPJL0NpMUkhEqlSfpHz/gOC+AvzvA7rHqkfULnJCEgcEwMirWf9LaNH
-1aC52k9P3CxJEkrQiUvmCaPX/f3j60LOQGuTHNe8iqnV5CI7h+L5kPnNR0yOaBBN
-USIJHhjBZMmnSMo/ffhzeT5fdb744af4KNpaq4vm3u5JpWRtLuETJT9sxaqyr3d7
-I45wiCCR0IXUBviPKdOt/WHrwZSPHI+oq0z5PXuNNbUSXW6TAp3/gumx4LT2/S1D
-sGiNH+s7uu24XyT6UayDoEkspd15qCTfoqZX6CSgFAzu06NB5S7OBuFYG3Y33Fi7
-1LrlQiAjo0GrvJMAGOwGsYJxxCn4M6avrl+8eTLSQ7U4gz2AmnwbFsX5FaGThin8
-myZlwUk0mCTXoDr4AO+WG9HhLworsdZsBn82liQWHLBt+Xv4NVbnt7pPvmf+VqER
-q9KWGxSCbm3vQMVJPrtfBcEpCmYdZZZYFJbmcdz/homh9QRZY4rto+CK/Cza0SPe
-aN/OIVDmCCoe8dSeNYOfGe79K8lMalhrwjxsBD6x5Og9AyfFczeSHASBgQ3QC2JJ
-qcB19eaQRIqw+VMjYqmPdRN0A25KAWekQpUfKDidR1IBn0w2gQKCAQEA2T+Bfgt1
-7Mz8TTHEGr0NBaypDBPLXY0sKyu0aCkqV1HKxyMEPuNMqbE+6raYz6QCoDfn1d4/
-wwPCdUzPI+JAVjEjEFtRJYJdT6OCj9dW94gBKx/lF6/nAMt8i0U5foVJt/TAjyDK
-zIx1EM9vGMKj3wfENJOj6WCdKbtBlHkotZHxGkSF/262Lbo02/maUdQAbY1j3Tly
-M583U0as78oUczUT575TG1RYwofN0YF/gzQJpPoYIhg75wWCvog+sbJonp3FslMn
-3ifdK6eZI7fTTr8SrNNulf8Iwonbdz/a09yJnuPL7tI0Ea5tqrgeNwTHKxW/Jf3o
-cMjlGq74VShNbQKCAQEA0uBuYUJwsQZEaGo4tDzyjpfG2JZt43Afdgwb3rMb61CG
-PFdBRcVQMu8NwnXQuQ9TobQ9trPrwW/rt0Bx2BQ6uLGPU743XA6UB8q+goCCdMVW
-GImcObwFOMOqZfEHFn04+1/a+Sf/dRRPv40uGMPKDpK8im8xGNEKhIQWYIFNAy5E
-IpYljGZFCC/r34E+0bmkBM+U///XmrgS6WWkRTl06GBrmuXlmhScz5GmHiKN33Yv
-cDJVUh2M3SxHKtYrcJTfdM1rX8iZR/9BPNC5qCDUVJJD9BuCXXtPzfGeKQYqNDf9
-OwVsuyXDfjp+zJ90BB0seum5Ozi5wMdTjb1TMUgTmwKCAQAQlMJDZoiHnFWdZrD7
-AXbe+gClBVW+PCok2V8ZnBq5M2rwrAGE80BEq1yL+YfMQU5aACpXrnDbZ4wN++DL
-cldKvNFaTD3zSPHqRCaQ5/ShS+Ya7oJDvo85Bk7pKk1rFK09txaDVhNkbUv6DnsC
-PsjXGvaktKgMBe2446vrsxuiUBNA1/4KMt8AuneSWoimujGWKvZ2Sg4nVn2Yg4pr
-etb4vBJa27HoIhXsMwVIekPLNcuOpe/1mjfoOAl0lV2DnoRRpuUR6Trfv9cnn9EW
-Ys9j8T1xp2mHVUHL502y2lLPXMO8NtK31Z9XwiJop0jXFixFY5GFSs3U3eBumvAl
-P8A5AoIBABW7b2Syli6IONCR8doRVeYAGkwD5LtFuNhPkye2SbBMkijxzRZFqWg2
-XrKltab8v1+w1ZNYo3lB8YbnK1RbcVnLYrv8pHPmRLcw28VTPR6Pn7nTpLgGentJ
-Hux2lIZqzU6KqGR5DMiiGT3ibNe8hbxOvwN9RhAKqwzRGAVGDgu/3uG5m5EGkSKw
-3ZwhE7pFaXPdeLuRQET/p2NKSE2iCDxSg4RpIOpqKWby2a3NXdWjtmvXpBdcWEIK
-6CKwA7YMgaLl8KTkZXeYBL8hu6BqEbfNgxdLJno/1Q+iUOxlaEANbRmCC5yV3bnK
-iXrJDAnIf+cC40YJKIuHf0LiOgqgJPUCggEANq8cFcQSuqa3k3Xr1RUJN2sbWKvW
-oR1KqfF61gm5AJ+0lLLtLpr7asQctlAqDAktk6cBdcZ2PhYduF9YHX5anCdMRCvJ
-FK+u6AvrEo0g2C9Z7AqZ/zcV5XOJ9C+yqIig/FZmCfx1EZvBQgs6Bivl13uZfZHX
-kYRa9sTMURf5vgbEsK+P1aQ4fHikhv45xFGA0nFyIUAjaaxrwoRzJtO3doFu7Fhg
-frLDYzU4djn73Qw7NofOWfRK7IF8yCmtF9IeDe11HGtj5Si5RqEhVGtCyHUQw8uu
-z3Cc2xf2HPtiqNO4cnXFA1r9ay6KMNVs1MGF2WoGgDk+EXAmjD+W7i/BeQ==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==
 -----END RSA PRIVATE KEY-----

=== modified file 'bzrlib/tests/test__chk_map.py'
--- bzrlib/tests/test__chk_map.py	2009-04-09 20:23:07 +0000
+++ bzrlib/tests/test__chk_map.py	2009-10-20 22:13:23 +0000
@@ -20,6 +20,8 @@
     chk_map,
     tests,
     )
+from bzrlib.static_tuple import StaticTuple
+stuple = StaticTuple
 
 
 def load_tests(standard_tests, module, loader):
@@ -67,25 +69,25 @@
         self.assertEqual(expected, actual, 'actual: %r' % (actual,))
 
     def test_simple_16(self):
-        self.assertSearchKey16('8C736521', ('foo',))
-        self.assertSearchKey16('8C736521\x008C736521', ('foo', 'foo'))
-        self.assertSearchKey16('8C736521\x0076FF8CAA', ('foo', 'bar'))
-        self.assertSearchKey16('ED82CD11', ('abcd',))
+        self.assertSearchKey16('8C736521', stuple('foo',))
+        self.assertSearchKey16('8C736521\x008C736521', stuple('foo', 'foo'))
+        self.assertSearchKey16('8C736521\x0076FF8CAA', stuple('foo', 'bar'))
+        self.assertSearchKey16('ED82CD11', stuple('abcd',))
 
     def test_simple_255(self):
-        self.assertSearchKey255('\x8cse!', ('foo',))
-        self.assertSearchKey255('\x8cse!\x00\x8cse!', ('foo', 'foo'))
-        self.assertSearchKey255('\x8cse!\x00v\xff\x8c\xaa', ('foo', 'bar'))
+        self.assertSearchKey255('\x8cse!', stuple('foo',))
+        self.assertSearchKey255('\x8cse!\x00\x8cse!', stuple('foo', 'foo'))
+        self.assertSearchKey255('\x8cse!\x00v\xff\x8c\xaa', stuple('foo', 'bar'))
         # The standard mapping for these would include '\n', so it should be
         # mapped to '_'
-        self.assertSearchKey255('\xfdm\x93_\x00P_\x1bL', ('<', 'V'))
+        self.assertSearchKey255('\xfdm\x93_\x00P_\x1bL', stuple('<', 'V'))
 
     def test_255_does_not_include_newline(self):
         # When mapping via _search_key_255, we should never have the '\n'
         # character, but all other 255 values should be present
         chars_used = set()
         for char_in in range(256):
-            search_key = self.module._search_key_255((chr(char_in),))
+            search_key = self.module._search_key_255(stuple(chr(char_in),))
             chars_used.update(search_key)
         all_chars = set([chr(x) for x in range(256)])
         unused_chars = all_chars.symmetric_difference(chars_used)
@@ -113,10 +115,11 @@
 
     def test_deserialise_empty(self):
         node = self.module._deserialise_leaf_node(
-            "chkleaf:\n10\n1\n0\n\n", ("sha1:1234",))
+            "chkleaf:\n10\n1\n0\n\n", stuple("sha1:1234",))
         self.assertEqual(0, len(node))
         self.assertEqual(10, node.maximum_size)
         self.assertEqual(("sha1:1234",), node.key())
+        self.assertIsInstance(node.key(), StaticTuple)
         self.assertIs(None, node._search_prefix)
         self.assertIs(None, node._common_serialised_prefix)
 
@@ -194,7 +197,8 @@
 
     def assertDeserialiseErrors(self, text):
         self.assertRaises((ValueError, IndexError),
-            self.module._deserialise_internal_node, text, 'not-a-real-sha')
+            self.module._deserialise_internal_node, text,
+                stuple('not-a-real-sha',))
 
     def test_raises_on_non_internal(self):
         self.assertDeserialiseErrors('')
@@ -211,7 +215,7 @@
 
     def test_deserialise_one(self):
         node = self.module._deserialise_internal_node(
-            "chknode:\n10\n1\n1\n\na\x00sha1:abcd\n", ('sha1:1234',))
+            "chknode:\n10\n1\n1\n\na\x00sha1:abcd\n", stuple('sha1:1234',))
         self.assertIsInstance(node, chk_map.InternalNode)
         self.assertEqual(1, len(node))
         self.assertEqual(10, node.maximum_size)
@@ -221,7 +225,7 @@
 
     def test_deserialise_with_prefix(self):
         node = self.module._deserialise_internal_node(
-            "chknode:\n10\n1\n1\npref\na\x00sha1:abcd\n", ('sha1:1234',))
+            "chknode:\n10\n1\n1\npref\na\x00sha1:abcd\n", stuple('sha1:1234',))
         self.assertIsInstance(node, chk_map.InternalNode)
         self.assertEqual(1, len(node))
         self.assertEqual(10, node.maximum_size)
@@ -230,7 +234,7 @@
         self.assertEqual({'prefa': ('sha1:abcd',)}, node._items)
 
         node = self.module._deserialise_internal_node(
-            "chknode:\n10\n1\n1\npref\n\x00sha1:abcd\n", ('sha1:1234',))
+            "chknode:\n10\n1\n1\npref\n\x00sha1:abcd\n", stuple('sha1:1234',))
         self.assertIsInstance(node, chk_map.InternalNode)
         self.assertEqual(1, len(node))
         self.assertEqual(10, node.maximum_size)
@@ -240,7 +244,8 @@
 
     def test_deserialise_pref_with_null(self):
         node = self.module._deserialise_internal_node(
-            "chknode:\n10\n1\n1\npref\x00fo\n\x00sha1:abcd\n", ('sha1:1234',))
+            "chknode:\n10\n1\n1\npref\x00fo\n\x00sha1:abcd\n",
+            stuple('sha1:1234',))
         self.assertIsInstance(node, chk_map.InternalNode)
         self.assertEqual(1, len(node))
         self.assertEqual(10, node.maximum_size)
@@ -250,7 +255,8 @@
 
     def test_deserialise_with_null_pref(self):
         node = self.module._deserialise_internal_node(
-            "chknode:\n10\n1\n1\npref\x00fo\n\x00\x00sha1:abcd\n", ('sha1:1234',))
+            "chknode:\n10\n1\n1\npref\x00fo\n\x00\x00sha1:abcd\n",
+            stuple('sha1:1234',))
         self.assertIsInstance(node, chk_map.InternalNode)
         self.assertEqual(1, len(node))
         self.assertEqual(10, node.maximum_size)

=== modified file 'bzrlib/tests/test__dirstate_helpers.py'
--- bzrlib/tests/test__dirstate_helpers.py	2009-06-22 15:39:42 +0000
+++ bzrlib/tests/test__dirstate_helpers.py	2009-11-08 05:00:24 +0000
@@ -743,13 +743,17 @@
 
     def test_trailing_garbage(self):
         tree, state, expected = self.create_basic_dirstate()
-        # We can modify the file as long as it hasn't been read yet.
+        # On Linux, we can write extra data as long as we haven't read yet, but
+        # on Win32, if you've opened the file with FILE_SHARE_READ, trying to
+        # open it in append mode will fail.
+        state.unlock()
         f = open('dirstate', 'ab')
         try:
             # Add bogus trailing garbage
             f.write('bogus\n')
         finally:
             f.close()
+            state.lock_read()
         e = self.assertRaises(errors.DirstateCorrupt,
                               state._read_dirblocks_if_needed)
         # Make sure we mention the bogus characters in the error

=== modified file 'bzrlib/tests/test__known_graph.py'
--- bzrlib/tests/test__known_graph.py	2009-08-26 16:03:59 +0000
+++ bzrlib/tests/test__known_graph.py	2009-12-01 14:40:13 +0000
@@ -99,12 +99,27 @@
 
     def test_children_ancestry1(self):
         graph = self.make_known_graph(test_graph.ancestry_1)
-        self.assertEqual(['rev1'], graph._nodes[NULL_REVISION].child_keys)
+        self.assertEqual(['rev1'], graph.get_child_keys(NULL_REVISION))
         self.assertEqual(['rev2a', 'rev2b'],
-                         sorted(graph._nodes['rev1'].child_keys))
-        self.assertEqual(['rev3'], sorted(graph._nodes['rev2a'].child_keys))
-        self.assertEqual(['rev4'], sorted(graph._nodes['rev3'].child_keys))
-        self.assertEqual(['rev4'], sorted(graph._nodes['rev2b'].child_keys))
+                         sorted(graph.get_child_keys('rev1')))
+        self.assertEqual(['rev3'], graph.get_child_keys('rev2a'))
+        self.assertEqual(['rev4'], graph.get_child_keys('rev3'))
+        self.assertEqual(['rev4'], graph.get_child_keys('rev2b'))
+        self.assertRaises(KeyError, graph.get_child_keys, 'not_in_graph')
+
+    def test_parent_ancestry1(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        self.assertEqual([NULL_REVISION], graph.get_parent_keys('rev1'))
+        self.assertEqual(['rev1'], graph.get_parent_keys('rev2a'))
+        self.assertEqual(['rev1'], graph.get_parent_keys('rev2b'))
+        self.assertEqual(['rev2a'], graph.get_parent_keys('rev3'))
+        self.assertEqual(['rev2b', 'rev3'],
+                         sorted(graph.get_parent_keys('rev4')))
+        self.assertRaises(KeyError, graph.get_child_keys, 'not_in_graph')
+    
+    def test_parent_with_ghost(self):
+        graph = self.make_known_graph(test_graph.with_ghost)
+        self.assertEqual(None, graph.get_parent_keys('g'))
 
     def test_gdfo_ancestry_1(self):
         graph = self.make_known_graph(test_graph.ancestry_1)
@@ -139,6 +154,73 @@
         self.assertGDFO(graph, 'a', 5)
         self.assertGDFO(graph, 'c', 5)
 
+    def test_add_existing_node(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        # Add a node that already exists with identical content
+        # This is a 'no-op'
+        self.assertGDFO(graph, 'rev4', 5)
+        graph.add_node('rev4', ['rev3', 'rev2b'])
+        self.assertGDFO(graph, 'rev4', 5)
+        # This also works if we use a tuple rather than a list
+        graph.add_node('rev4', ('rev3', 'rev2b'))
+
+    def test_add_existing_node_mismatched_parents(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        self.assertRaises(ValueError, graph.add_node, 'rev4',
+                          ['rev2b', 'rev3'])
+
+    def test_add_node_with_ghost_parent(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        graph.add_node('rev5', ['rev2b', 'revGhost'])
+        self.assertGDFO(graph, 'rev5', 4)
+        self.assertGDFO(graph, 'revGhost', 1)
+
+    def test_add_new_root(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        graph.add_node('rev5', [])
+        self.assertGDFO(graph, 'rev5', 1)
+
+    def test_add_with_all_ghost_parents(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        graph.add_node('rev5', ['ghost'])
+        self.assertGDFO(graph, 'rev5', 2)
+        self.assertGDFO(graph, 'ghost', 1)
+
+    def test_gdfo_after_add_node(self):
+        graph = self.make_known_graph(test_graph.ancestry_1)
+        self.assertEqual([], graph.get_child_keys('rev4'))
+        graph.add_node('rev5', ['rev4'])
+        self.assertEqual(['rev4'], graph.get_parent_keys('rev5'))
+        self.assertEqual(['rev5'], graph.get_child_keys('rev4'))
+        self.assertEqual([], graph.get_child_keys('rev5'))
+        self.assertGDFO(graph, 'rev5', 6)
+        graph.add_node('rev6', ['rev2b'])
+        graph.add_node('rev7', ['rev6'])
+        graph.add_node('rev8', ['rev7', 'rev5'])
+        self.assertGDFO(graph, 'rev5', 6)
+        self.assertGDFO(graph, 'rev6', 4)
+        self.assertGDFO(graph, 'rev7', 5)
+        self.assertGDFO(graph, 'rev8', 7)
+
+    def test_fill_in_ghost(self):
+        graph = self.make_known_graph(test_graph.with_ghost)
+        # Add in a couple nodes and then fill in the 'ghost' so that it should
+        # cause renumbering of children nodes
+        graph.add_node('x', [])
+        graph.add_node('y', ['x'])
+        graph.add_node('z', ['y'])
+        graph.add_node('g', ['z'])
+        self.assertGDFO(graph, 'f', 2)
+        self.assertGDFO(graph, 'e', 3)
+        self.assertGDFO(graph, 'x', 1)
+        self.assertGDFO(graph, 'y', 2)
+        self.assertGDFO(graph, 'z', 3)
+        self.assertGDFO(graph, 'g', 4)
+        self.assertGDFO(graph, 'b', 4)
+        self.assertGDFO(graph, 'd', 5)
+        self.assertGDFO(graph, 'a', 5)
+        self.assertGDFO(graph, 'c', 6)
+
 
 class TestKnownGraphHeads(TestCaseWithKnownGraph):
 
@@ -245,6 +327,14 @@
         self.assertEqual(set(['a', 'c']), graph.heads(['a', 'c', 'e', 'g']))
         self.assertEqual(set(['a', 'c']), graph.heads(['a', 'c', 'f']))
 
+    def test_filling_in_ghosts_resets_head_cache(self):
+        graph = self.make_known_graph(test_graph.with_ghost)
+        self.assertEqual(set(['e', 'g']), graph.heads(['e', 'g']))
+        # 'g' is filled in, and decends from 'e', so the heads result is now
+        # different
+        graph.add_node('g', ['e'])
+        self.assertEqual(set(['g']), graph.heads(['e', 'g']))
+
 
 class TestKnownGraphTopoSort(TestCaseWithKnownGraph):
 
@@ -768,3 +858,70 @@
                 },
                 'E',
                 [])
+
+
+class TestKnownGraphStableReverseTopoSort(TestCaseWithKnownGraph):
+    """Test the sort order returned by gc_sort."""
+
+    def assertSorted(self, expected, parent_map):
+        graph = self.make_known_graph(parent_map)
+        value = graph.gc_sort()
+        if expected != value:
+            self.assertEqualDiff(pprint.pformat(expected),
+                                 pprint.pformat(value))
+
+    def test_empty(self):
+        self.assertSorted([], {})
+
+    def test_single(self):
+        self.assertSorted(['a'], {'a':()})
+        self.assertSorted([('a',)], {('a',):()})
+        self.assertSorted([('F', 'a')], {('F', 'a'):()})
+
+    def test_linear(self):
+        self.assertSorted(['c', 'b', 'a'], {'a':(), 'b':('a',), 'c':('b',)})
+        self.assertSorted([('c',), ('b',), ('a',)],
+                          {('a',):(), ('b',): (('a',),), ('c',): (('b',),)})
+        self.assertSorted([('F', 'c'), ('F', 'b'), ('F', 'a')],
+                          {('F', 'a'):(), ('F', 'b'): (('F', 'a'),),
+                           ('F', 'c'): (('F', 'b'),)})
+
+    def test_mixed_ancestries(self):
+        # Each prefix should be sorted separately
+        self.assertSorted([('F', 'c'), ('F', 'b'), ('F', 'a'),
+                           ('G', 'c'), ('G', 'b'), ('G', 'a'),
+                           ('Q', 'c'), ('Q', 'b'), ('Q', 'a'),
+                          ],
+                          {('F', 'a'):(), ('F', 'b'): (('F', 'a'),),
+                           ('F', 'c'): (('F', 'b'),),
+                           ('G', 'a'):(), ('G', 'b'): (('G', 'a'),),
+                           ('G', 'c'): (('G', 'b'),),
+                           ('Q', 'a'):(), ('Q', 'b'): (('Q', 'a'),),
+                           ('Q', 'c'): (('Q', 'b'),),
+                          })
+
+    def test_stable_sorting(self):
+        # the sort order should be stable even when extra nodes are added
+        self.assertSorted(['b', 'c', 'a'],
+                          {'a':(), 'b':('a',), 'c':('a',)})
+        self.assertSorted(['b', 'c', 'd', 'a'],
+                          {'a':(), 'b':('a',), 'c':('a',), 'd':('a',)})
+        self.assertSorted(['b', 'c', 'd', 'a'],
+                          {'a':(), 'b':('a',), 'c':('a',), 'd':('a',)})
+        self.assertSorted(['Z', 'b', 'c', 'd', 'a'],
+                          {'a':(), 'b':('a',), 'c':('a',), 'd':('a',),
+                           'Z':('a',)})
+        self.assertSorted(['e', 'b', 'c', 'f', 'Z', 'd', 'a'],
+                          {'a':(), 'b':('a',), 'c':('a',), 'd':('a',),
+                           'Z':('a',),
+                           'e':('b', 'c', 'd'),
+                           'f':('d', 'Z'),
+                           })
+
+    def test_skip_ghost(self):
+        self.assertSorted(['b', 'c', 'a'],
+                          {'a':(), 'b':('a', 'ghost'), 'c':('a',)})
+
+    def test_skip_mainline_ghost(self):
+        self.assertSorted(['b', 'c', 'a'],
+                          {'a':(), 'b':('ghost', 'a'), 'c':('a',)})

=== added file 'bzrlib/tests/test__simple_set.py'
--- bzrlib/tests/test__simple_set.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test__simple_set.py	2009-10-14 15:53:34 +0000
@@ -0,0 +1,391 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests for the StaticTupleInterned type."""
+
+import sys
+
+from bzrlib import (
+    errors,
+    osutils,
+    tests,
+    )
+
+try:
+    from bzrlib import _simple_set_pyx
+except ImportError:
+    _simple_set_pyx = None
+
+
+class _Hashable(object):
+    """A simple object which has a fixed hash value.
+
+    We could have used an 'int', but it turns out that Int objects don't
+    implement tp_richcompare...
+    """
+
+    def __init__(self, the_hash):
+        self.hash = the_hash
+
+    def __hash__(self):
+        return self.hash
+
+    def __eq__(self, other):
+        if not isinstance(other, _Hashable):
+            return NotImplemented
+        return other.hash == self.hash
+
+
+class _BadSecondHash(_Hashable):
+
+    def __init__(self, the_hash):
+        _Hashable.__init__(self, the_hash)
+        self._first = True
+
+    def __hash__(self):
+        if self._first:
+            self._first = False
+            return self.hash
+        else:
+            raise ValueError('I can only be hashed once.')
+
+
+class _BadCompare(_Hashable):
+
+    def __eq__(self, other):
+        raise RuntimeError('I refuse to play nice')
+
+
+class _NoImplementCompare(_Hashable):
+
+    def __eq__(self, other):
+        return NotImplemented
+
+
+# Even though this is an extension, we don't permute the tests for a python
+# version. As the plain python version is just a dict or set
+
+class _CompiledSimpleSet(tests.Feature):
+
+    def _probe(self):
+        if _simple_set_pyx is None:
+            return False
+        return True
+
+    def feature_name(self):
+        return 'bzrlib._simple_set_pyx'
+
+CompiledSimpleSet = _CompiledSimpleSet()
+
+
+class TestSimpleSet(tests.TestCase):
+
+    _test_needs_features = [CompiledSimpleSet]
+    module = _simple_set_pyx
+
+    def assertIn(self, obj, container):
+        self.assertTrue(obj in container,
+            '%s not found in %s' % (obj, container))
+
+    def assertNotIn(self, obj, container):
+        self.assertTrue(obj not in container,
+            'We found %s in %s' % (obj, container))
+
+    def assertFillState(self, used, fill, mask, obj):
+        self.assertEqual((used, fill, mask), (obj.used, obj.fill, obj.mask))
+
+    def assertLookup(self, offset, value, obj, key):
+        self.assertEqual((offset, value), obj._test_lookup(key))
+
+    def assertRefcount(self, count, obj):
+        """Assert that the refcount for obj is what we expect.
+
+        Note that this automatically adjusts for the fact that calling
+        assertRefcount actually creates a new pointer, as does calling
+        sys.getrefcount. So pass the expected value *before* the call.
+        """
+        # I'm not sure why the offset is 3, but I've check that in the caller,
+        # an offset of 1 works, which is expected. Not sure why assertRefcount
+        # is incrementing/decrementing 2 times
+        self.assertEqual(count, sys.getrefcount(obj)-3)
+
+    def test_initial(self):
+        obj = self.module.SimpleSet()
+        self.assertEqual(0, len(obj))
+        st = ('foo', 'bar')
+        self.assertFillState(0, 0, 0x3ff, obj)
+
+    def test__lookup(self):
+        # These are carefully chosen integers to force hash collisions in the
+        # algorithm, based on the initial set size of 1024
+        obj = self.module.SimpleSet()
+        self.assertLookup(643, '<null>', obj, _Hashable(643))
+        self.assertLookup(643, '<null>', obj, _Hashable(643 + 1024))
+        self.assertLookup(643, '<null>', obj, _Hashable(643 + 50*1024))
+
+    def test__lookup_collision(self):
+        obj = self.module.SimpleSet()
+        k1 = _Hashable(643)
+        k2 = _Hashable(643 + 1024)
+        self.assertLookup(643, '<null>', obj, k1)
+        self.assertLookup(643, '<null>', obj, k2)
+        obj.add(k1)
+        self.assertLookup(643, k1, obj, k1)
+        self.assertLookup(644, '<null>', obj, k2)
+
+    def test__lookup_after_resize(self):
+        obj = self.module.SimpleSet()
+        k1 = _Hashable(643)
+        k2 = _Hashable(643 + 1024)
+        obj.add(k1)
+        obj.add(k2)
+        self.assertLookup(643, k1, obj, k1)
+        self.assertLookup(644, k2, obj, k2)
+        obj._py_resize(2047) # resized to 2048
+        self.assertEqual(2048, obj.mask + 1)
+        self.assertLookup(643, k1, obj, k1)
+        self.assertLookup(643+1024, k2, obj, k2)
+        obj._py_resize(1023) # resized back to 1024
+        self.assertEqual(1024, obj.mask + 1)
+        self.assertLookup(643, k1, obj, k1)
+        self.assertLookup(644, k2, obj, k2)
+
+    def test_get_set_del_with_collisions(self):
+        obj = self.module.SimpleSet()
+
+        h1 = 643
+        h2 = 643 + 1024
+        h3 = 643 + 1024*50
+        h4 = 643 + 1024*25
+        h5 = 644
+        h6 = 644 + 1024
+
+        k1 = _Hashable(h1)
+        k2 = _Hashable(h2)
+        k3 = _Hashable(h3)
+        k4 = _Hashable(h4)
+        k5 = _Hashable(h5)
+        k6 = _Hashable(h6)
+        self.assertLookup(643, '<null>', obj, k1)
+        self.assertLookup(643, '<null>', obj, k2)
+        self.assertLookup(643, '<null>', obj, k3)
+        self.assertLookup(643, '<null>', obj, k4)
+        self.assertLookup(644, '<null>', obj, k5)
+        self.assertLookup(644, '<null>', obj, k6)
+        obj.add(k1)
+        self.assertIn(k1, obj)
+        self.assertNotIn(k2, obj)
+        self.assertNotIn(k3, obj)
+        self.assertNotIn(k4, obj)
+        self.assertLookup(643, k1, obj, k1)
+        self.assertLookup(644, '<null>', obj, k2)
+        self.assertLookup(644, '<null>', obj, k3)
+        self.assertLookup(644, '<null>', obj, k4)
+        self.assertLookup(644, '<null>', obj, k5)
+        self.assertLookup(644, '<null>', obj, k6)
+        self.assertIs(k1, obj[k1])
+        self.assertIs(k2, obj.add(k2))
+        self.assertIs(k2, obj[k2])
+        self.assertLookup(643, k1, obj, k1)
+        self.assertLookup(644, k2, obj, k2)
+        self.assertLookup(646, '<null>', obj, k3)
+        self.assertLookup(646, '<null>', obj, k4)
+        self.assertLookup(645, '<null>', obj, k5)
+        self.assertLookup(645, '<null>', obj, k6)
+        self.assertLookup(643, k1, obj, _Hashable(h1))
+        self.assertLookup(644, k2, obj, _Hashable(h2))
+        self.assertLookup(646, '<null>', obj, _Hashable(h3))
+        self.assertLookup(646, '<null>', obj, _Hashable(h4))
+        self.assertLookup(645, '<null>', obj, _Hashable(h5))
+        self.assertLookup(645, '<null>', obj, _Hashable(h6))
+        obj.add(k3)
+        self.assertIs(k3, obj[k3])
+        self.assertIn(k1, obj)
+        self.assertIn(k2, obj)
+        self.assertIn(k3, obj)
+        self.assertNotIn(k4, obj)
+
+        obj.discard(k1)
+        self.assertLookup(643, '<dummy>', obj, k1)
+        self.assertLookup(644, k2, obj, k2)
+        self.assertLookup(646, k3, obj, k3)
+        self.assertLookup(643, '<dummy>', obj, k4)
+        self.assertNotIn(k1, obj)
+        self.assertIn(k2, obj)
+        self.assertIn(k3, obj)
+        self.assertNotIn(k4, obj)
+
+    def test_add(self):
+        obj = self.module.SimpleSet()
+        self.assertFillState(0, 0, 0x3ff, obj)
+        # We use this clumsy notation, because otherwise the refcounts are off.
+        # I'm guessing the python compiler sees it is a static tuple, and adds
+        # it to the function variables, or somesuch
+        k1 = tuple(['foo'])
+        self.assertRefcount(1, k1)
+        self.assertIs(k1, obj.add(k1))
+        self.assertFillState(1, 1, 0x3ff, obj)
+        self.assertRefcount(2, k1)
+        ktest = obj[k1]
+        self.assertRefcount(3, k1)
+        self.assertIs(k1, ktest)
+        del ktest
+        self.assertRefcount(2, k1)
+        k2 = tuple(['foo'])
+        self.assertRefcount(1, k2)
+        self.assertIsNot(k1, k2)
+        # doesn't add anything, so the counters shouldn't be adjusted
+        self.assertIs(k1, obj.add(k2))
+        self.assertFillState(1, 1, 0x3ff, obj)
+        self.assertRefcount(2, k1) # not changed
+        self.assertRefcount(1, k2) # not incremented
+        self.assertIs(k1, obj[k1])
+        self.assertIs(k1, obj[k2])
+        self.assertRefcount(2, k1)
+        self.assertRefcount(1, k2)
+        # Deleting an entry should remove the fill, but not the used
+        obj.discard(k1)
+        self.assertFillState(0, 1, 0x3ff, obj)
+        self.assertRefcount(1, k1)
+        k3 = tuple(['bar'])
+        self.assertRefcount(1, k3)
+        self.assertIs(k3, obj.add(k3))
+        self.assertFillState(1, 2, 0x3ff, obj)
+        self.assertRefcount(2, k3)
+        self.assertIs(k2, obj.add(k2))
+        self.assertFillState(2, 2, 0x3ff, obj)
+        self.assertRefcount(1, k1)
+        self.assertRefcount(2, k2)
+        self.assertRefcount(2, k3)
+
+    def test_discard(self):
+        obj = self.module.SimpleSet()
+        k1 = tuple(['foo'])
+        k2 = tuple(['foo'])
+        k3 = tuple(['bar'])
+        self.assertRefcount(1, k1)
+        self.assertRefcount(1, k2)
+        self.assertRefcount(1, k3)
+        obj.add(k1)
+        self.assertRefcount(2, k1)
+        self.assertEqual(0, obj.discard(k3))
+        self.assertRefcount(1, k3)
+        obj.add(k3)
+        self.assertRefcount(2, k3)
+        self.assertEqual(1, obj.discard(k3))
+        self.assertRefcount(1, k3)
+
+    def test__resize(self):
+        obj = self.module.SimpleSet()
+        k1 = ('foo',)
+        k2 = ('bar',)
+        k3 = ('baz',)
+        obj.add(k1)
+        obj.add(k2)
+        obj.add(k3)
+        obj.discard(k2)
+        self.assertFillState(2, 3, 0x3ff, obj)
+        self.assertEqual(1024, obj._py_resize(500))
+        # Doesn't change the size, but does change the content
+        self.assertFillState(2, 2, 0x3ff, obj)
+        obj.add(k2)
+        obj.discard(k3)
+        self.assertFillState(2, 3, 0x3ff, obj)
+        self.assertEqual(4096, obj._py_resize(4095))
+        self.assertFillState(2, 2, 0xfff, obj)
+        self.assertIn(k1, obj)
+        self.assertIn(k2, obj)
+        self.assertNotIn(k3, obj)
+        obj.add(k2)
+        self.assertIn(k2, obj)
+        obj.discard(k2)
+        self.assertEqual((591, '<dummy>'), obj._test_lookup(k2))
+        self.assertFillState(1, 2, 0xfff, obj)
+        self.assertEqual(2048, obj._py_resize(1024))
+        self.assertFillState(1, 1, 0x7ff, obj)
+        self.assertEqual((591, '<null>'), obj._test_lookup(k2))
+
+    def test_second_hash_failure(self):
+        obj = self.module.SimpleSet()
+        k1 = _BadSecondHash(200)
+        k2 = _Hashable(200)
+        # Should only call hash() one time
+        obj.add(k1)
+        self.assertFalse(k1._first)
+        self.assertRaises(ValueError, obj.add, k2)
+
+    def test_richcompare_failure(self):
+        obj = self.module.SimpleSet()
+        k1 = _Hashable(200)
+        k2 = _BadCompare(200)
+        obj.add(k1)
+        # Tries to compare with k1, fails
+        self.assertRaises(RuntimeError, obj.add, k2)
+
+    def test_richcompare_not_implemented(self):
+        obj = self.module.SimpleSet()
+        # Even though their hashes are the same, tp_richcompare returns
+        # NotImplemented, which means we treat them as not equal
+        k1 = _NoImplementCompare(200)
+        k2 = _NoImplementCompare(200)
+        self.assertLookup(200, '<null>', obj, k1)
+        self.assertLookup(200, '<null>', obj, k2)
+        self.assertIs(k1, obj.add(k1))
+        self.assertLookup(200, k1, obj, k1)
+        self.assertLookup(201, '<null>', obj, k2)
+        self.assertIs(k2, obj.add(k2))
+        self.assertIs(k1, obj[k1])
+
+    def test_add_and_remove_lots_of_items(self):
+        obj = self.module.SimpleSet()
+        chars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz1234567890'
+        for i in chars:
+            for j in chars:
+                k = (i, j)
+                obj.add(k)
+        num = len(chars)*len(chars)
+        self.assertFillState(num, num, 0x1fff, obj)
+        # Now delete all of the entries and it should shrink again
+        for i in chars:
+            for j in chars:
+                k = (i, j)
+                obj.discard(k)
+        # It should be back to 1024 wide mask, though there may still be some
+        # dummy values in there
+        self.assertFillState(0, obj.fill, 0x3ff, obj)
+        # but there should be fewer than 1/5th dummy entries
+        self.assertTrue(obj.fill < 1024 / 5)
+
+    def test__iter__(self):
+        obj = self.module.SimpleSet()
+        k1 = ('1',)
+        k2 = ('1', '2')
+        k3 = ('3', '4')
+        obj.add(k1)
+        obj.add(k2)
+        obj.add(k3)
+        all = set()
+        for key in obj:
+            all.add(key)
+        self.assertEqual(sorted([k1, k2, k3]), sorted(all))
+        iterator = iter(obj)
+        iterator.next()
+        obj.add(('foo',))
+        # Set changed size
+        self.assertRaises(RuntimeError, iterator.next)
+        # And even removing an item still causes it to fail
+        obj.discard(k2)
+        self.assertRaises(RuntimeError, iterator.next)

=== added file 'bzrlib/tests/test__static_tuple.py'
--- bzrlib/tests/test__static_tuple.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test__static_tuple.py	2009-11-28 21:54:08 +0000
@@ -0,0 +1,673 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""Tests for the StaticTuple type."""
+
+import cPickle
+import gc
+import sys
+
+from bzrlib import (
+    _static_tuple_py,
+    debug,
+    errors,
+    osutils,
+    static_tuple,
+    tests,
+    )
+
+
+def load_tests(standard_tests, module, loader):
+    """Parameterize tests for all versions of groupcompress."""
+    scenarios = [
+        ('python', {'module': _static_tuple_py}),
+    ]
+    suite = loader.suiteClass()
+    if CompiledStaticTuple.available():
+        from bzrlib import _static_tuple_c
+        scenarios.append(('C', {'module': _static_tuple_c}))
+    else:
+        # the compiled module isn't available, so we add a failing test
+        class FailWithoutFeature(tests.TestCase):
+            def test_fail(self):
+                self.requireFeature(CompiledStaticTuple)
+        suite.addTest(loader.loadTestsFromTestCase(FailWithoutFeature))
+    result = tests.multiply_tests(standard_tests, scenarios, suite)
+    return result
+
+
+class _CompiledStaticTuple(tests.Feature):
+
+    def _probe(self):
+        try:
+            import bzrlib._static_tuple_c
+        except ImportError:
+            return False
+        return True
+
+    def feature_name(self):
+        return 'bzrlib._static_tuple_c'
+
+CompiledStaticTuple = _CompiledStaticTuple()
+
+
+class _Meliae(tests.Feature):
+
+    def _probe(self):
+        try:
+            from meliae import scanner
+        except ImportError:
+            return False
+        return True
+
+    def feature_name(self):
+        return "Meliae - python memory debugger"
+
+Meliae = _Meliae()
+
+
+class TestStaticTuple(tests.TestCase):
+
+    def assertRefcount(self, count, obj):
+        """Assert that the refcount for obj is what we expect.
+
+        Note that this automatically adjusts for the fact that calling
+        assertRefcount actually creates a new pointer, as does calling
+        sys.getrefcount. So pass the expected value *before* the call.
+        """
+        # I don't understand why it is getrefcount()-3 here, but it seems to be
+        # correct. If I check in the calling function, with:
+        # self.assertEqual(count, sys.getrefcount(obj)-1)
+        # Then it works fine. Something about passing it to assertRefcount is
+        # actually double-incrementing (and decrementing) the refcount
+        self.assertEqual(count, sys.getrefcount(obj)-3)
+
+    def test_create(self):
+        k = self.module.StaticTuple('foo')
+        k = self.module.StaticTuple('foo', 'bar')
+
+    def test_create_bad_args(self):
+        args_256 = ['a']*256
+        # too many args
+        self.assertRaises(ValueError, self.module.StaticTuple, *args_256)
+        args_300 = ['a']*300
+        self.assertRaises(ValueError, self.module.StaticTuple, *args_300)
+        # not a string
+        self.assertRaises(TypeError, self.module.StaticTuple, object())
+
+    def test_concat(self):
+        st1 = self.module.StaticTuple('foo')
+        st2 = self.module.StaticTuple('bar')
+        st3 = self.module.StaticTuple('foo', 'bar')
+        st4 = st1 + st2
+        self.assertEqual(st3, st4)
+        self.assertIsInstance(st4, self.module.StaticTuple)
+
+    def test_concat_with_tuple(self):
+        st1 = self.module.StaticTuple('foo')
+        t2 = ('bar',)
+        st3 = self.module.StaticTuple('foo', 'bar')
+        st4 = self.module.StaticTuple('bar', 'foo')
+        st5 = st1 + t2
+        st6 = t2 + st1
+        self.assertEqual(st3, st5)
+        self.assertIsInstance(st5, self.module.StaticTuple)
+        self.assertEqual(st4, st6)
+        if self.module is _static_tuple_py:
+            # _static_tuple_py has StaticTuple(tuple), so tuple thinks it
+            # already knows how to concatenate, as such we can't "inject" our
+            # own concatenation...
+            self.assertIsInstance(st6, tuple)
+        else:
+            self.assertIsInstance(st6, self.module.StaticTuple)
+
+    def test_concat_with_bad_tuple(self):
+        st1 = self.module.StaticTuple('foo')
+        t2 = (object(),)
+        # Using st1.__add__ doesn't give the same results as doing the '+' form
+        self.assertRaises(TypeError, lambda: st1 + t2)
+
+    def test_concat_with_non_tuple(self):
+        st1 = self.module.StaticTuple('foo')
+        self.assertRaises(TypeError, lambda: st1 + 10)
+        
+    def test_as_tuple(self):
+        k = self.module.StaticTuple('foo')
+        t = k.as_tuple()
+        self.assertEqual(('foo',), t)
+        self.assertIsInstance(t, tuple)
+        self.assertFalse(isinstance(t, self.module.StaticTuple))
+        k = self.module.StaticTuple('foo', 'bar')
+        t = k.as_tuple()
+        self.assertEqual(('foo', 'bar'), t)
+        k2 = self.module.StaticTuple(1, k)
+        t = k2.as_tuple()
+        self.assertIsInstance(t, tuple)
+        # For pickling to work, we need to keep the sub-items as StaticTuple so
+        # that it knows that they also need to be converted.
+        self.assertIsInstance(t[1], self.module.StaticTuple)
+        self.assertEqual((1, ('foo', 'bar')), t)
+
+    def test_as_tuples(self):
+        k1 = self.module.StaticTuple('foo', 'bar')
+        t = static_tuple.as_tuples(k1)
+        self.assertIsInstance(t, tuple)
+        self.assertEqual(('foo', 'bar'), t)
+        k2 = self.module.StaticTuple(1, k1)
+        t = static_tuple.as_tuples(k2)
+        self.assertIsInstance(t, tuple)
+        self.assertIsInstance(t[1], tuple)
+        self.assertEqual((1, ('foo', 'bar')), t)
+        mixed = (1, k1)
+        t = static_tuple.as_tuples(mixed)
+        self.assertIsInstance(t, tuple)
+        self.assertIsInstance(t[1], tuple)
+        self.assertEqual((1, ('foo', 'bar')), t)
+
+    def test_len(self):
+        k = self.module.StaticTuple()
+        self.assertEqual(0, len(k))
+        k = self.module.StaticTuple('foo')
+        self.assertEqual(1, len(k))
+        k = self.module.StaticTuple('foo', 'bar')
+        self.assertEqual(2, len(k))
+        k = self.module.StaticTuple('foo', 'bar', 'b', 'b', 'b', 'b', 'b')
+        self.assertEqual(7, len(k))
+        args = ['foo']*255
+        k = self.module.StaticTuple(*args)
+        self.assertEqual(255, len(k))
+
+    def test_hold_other_static_tuples(self):
+        k = self.module.StaticTuple('foo', 'bar')
+        k2 = self.module.StaticTuple(k, k)
+        self.assertEqual(2, len(k2))
+        self.assertIs(k, k2[0])
+        self.assertIs(k, k2[1])
+
+    def test_getitem(self):
+        k = self.module.StaticTuple('foo', 'bar', 'b', 'b', 'b', 'b', 'z')
+        self.assertEqual('foo', k[0])
+        self.assertEqual('foo', k[0])
+        self.assertEqual('foo', k[0])
+        self.assertEqual('z', k[6])
+        self.assertEqual('z', k[-1])
+        self.assertRaises(IndexError, k.__getitem__, 7)
+        self.assertRaises(IndexError, k.__getitem__, 256+7)
+        self.assertRaises(IndexError, k.__getitem__, 12024)
+        # Python's [] resolver handles the negative arguments, so we can't
+        # really test StaticTuple_item() with negative values.
+        self.assertRaises(TypeError, k.__getitem__, 'not-an-int')
+        self.assertRaises(TypeError, k.__getitem__, '5')
+
+    def test_refcount(self):
+        f = 'fo' + 'oo'
+        num_refs = sys.getrefcount(f) - 1 #sys.getrefcount() adds one
+        k = self.module.StaticTuple(f)
+        self.assertRefcount(num_refs + 1, f)
+        b = k[0]
+        self.assertRefcount(num_refs + 2, f)
+        b = k[0]
+        self.assertRefcount(num_refs + 2, f)
+        c = k[0]
+        self.assertRefcount(num_refs + 3, f)
+        del b, c
+        self.assertRefcount(num_refs + 1, f)
+        del k
+        self.assertRefcount(num_refs, f)
+
+    def test__repr__(self):
+        k = self.module.StaticTuple('foo', 'bar', 'baz', 'bing')
+        self.assertEqual("StaticTuple('foo', 'bar', 'baz', 'bing')", repr(k))
+
+    def assertCompareEqual(self, k1, k2):
+        self.assertTrue(k1 == k2)
+        self.assertTrue(k1 <= k2)
+        self.assertTrue(k1 >= k2)
+        self.assertFalse(k1 != k2)
+        self.assertFalse(k1 < k2)
+        self.assertFalse(k1 > k2)
+
+    def test_holds_None(self):
+        k1 = self.module.StaticTuple(None)
+        # You cannot subclass None anyway
+
+    def test_holds_int(self):
+        k1 = self.module.StaticTuple(1)
+        class subint(int):
+            pass
+        # But not a subclass, because subint could introduce refcycles
+        self.assertRaises(TypeError, self.module.StaticTuple, subint(2))
+
+    def test_holds_long(self):
+        k1 = self.module.StaticTuple(2L**65)
+        class sublong(long):
+            pass
+        # But not a subclass
+        self.assertRaises(TypeError, self.module.StaticTuple, sublong(1))
+
+    def test_holds_float(self):
+        k1 = self.module.StaticTuple(1.2)
+        class subfloat(float):
+            pass
+        self.assertRaises(TypeError, self.module.StaticTuple, subfloat(1.5))
+
+    def test_holds_str(self):
+        k1 = self.module.StaticTuple('astring')
+        class substr(str):
+            pass
+        self.assertRaises(TypeError, self.module.StaticTuple, substr('a'))
+
+    def test_holds_unicode(self):
+        k1 = self.module.StaticTuple(u'\xb5')
+        class subunicode(unicode):
+            pass
+        self.assertRaises(TypeError, self.module.StaticTuple,
+                          subunicode(u'\xb5'))
+
+    def test_hold_bool(self):
+        k1 = self.module.StaticTuple(True)
+        k2 = self.module.StaticTuple(False)
+        # Cannot subclass bool
+
+    def test_compare_same_obj(self):
+        k1 = self.module.StaticTuple('foo', 'bar')
+        self.assertCompareEqual(k1, k1)
+        k2 = self.module.StaticTuple(k1, k1)
+        self.assertCompareEqual(k2, k2)
+        k3 = self.module.StaticTuple('foo', 1, None, u'\xb5', 1.2, 2**65, True,
+                                     k1)
+        self.assertCompareEqual(k3, k3)
+
+    def test_compare_equivalent_obj(self):
+        k1 = self.module.StaticTuple('foo', 'bar')
+        k2 = self.module.StaticTuple('foo', 'bar')
+        self.assertCompareEqual(k1, k2)
+        k3 = self.module.StaticTuple(k1, k2)
+        k4 = self.module.StaticTuple(k2, k1)
+        self.assertCompareEqual(k1, k2)
+        k5 = self.module.StaticTuple('foo', 1, None, u'\xb5', 1.2, 2**65, True,
+                                     k1)
+        k6 = self.module.StaticTuple('foo', 1, None, u'\xb5', 1.2, 2**65, True,
+                                     k1)
+        self.assertCompareEqual(k5, k6)
+        k7 = self.module.StaticTuple(None)
+        k8 = self.module.StaticTuple(None)
+        self.assertCompareEqual(k7, k8)
+
+    def test_compare_similar_obj(self):
+        k1 = self.module.StaticTuple('foo' + ' bar', 'bar' + ' baz')
+        k2 = self.module.StaticTuple('fo' + 'o bar', 'ba' + 'r baz')
+        self.assertCompareEqual(k1, k2)
+        k3 = self.module.StaticTuple('foo ' + 'bar', 'bar ' + 'baz')
+        k4 = self.module.StaticTuple('f' + 'oo bar', 'b' + 'ar baz')
+        k5 = self.module.StaticTuple(k1, k2)
+        k6 = self.module.StaticTuple(k3, k4)
+        self.assertCompareEqual(k5, k6)
+
+    def assertCompareDifferent(self, k_small, k_big):
+        self.assertFalse(k_small == k_big)
+        self.assertFalse(k_small >= k_big)
+        self.assertFalse(k_small > k_big)
+        self.assertTrue(k_small != k_big)
+        self.assertTrue(k_small <= k_big)
+        self.assertTrue(k_small < k_big)
+
+    def assertCompareNoRelation(self, k1, k2):
+        """Run the comparison operators, make sure they do something.
+
+        However, we don't actually care what comes first or second. This is
+        stuff like cross-class comparisons. We don't want to segfault/raise an
+        exception, but we don't care about the sort order.
+        """
+        self.assertFalse(k1 == k2)
+        self.assertTrue(k1 != k2)
+        # Do the comparison, but we don't care about the result
+        k1 >= k2
+        k1 > k2
+        k1 <= k2
+        k1 < k2
+
+    def test_compare_vs_none(self):
+        k1 = self.module.StaticTuple('baz', 'bing')
+        self.assertCompareDifferent(None, k1)
+    
+    def test_compare_cross_class(self):
+        k1 = self.module.StaticTuple('baz', 'bing')
+        self.assertCompareNoRelation(10, k1)
+        self.assertCompareNoRelation('baz', k1)
+
+    def test_compare_all_different_same_width(self):
+        k1 = self.module.StaticTuple('baz', 'bing')
+        k2 = self.module.StaticTuple('foo', 'bar')
+        self.assertCompareDifferent(k1, k2)
+        k3 = self.module.StaticTuple(k1, k2)
+        k4 = self.module.StaticTuple(k2, k1)
+        self.assertCompareDifferent(k3, k4)
+        k5 = self.module.StaticTuple(1)
+        k6 = self.module.StaticTuple(2)
+        self.assertCompareDifferent(k5, k6)
+        k7 = self.module.StaticTuple(1.2)
+        k8 = self.module.StaticTuple(2.4)
+        self.assertCompareDifferent(k7, k8)
+        k9 = self.module.StaticTuple(u's\xb5')
+        k10 = self.module.StaticTuple(u's\xe5')
+        self.assertCompareDifferent(k9, k10)
+
+    def test_compare_some_different(self):
+        k1 = self.module.StaticTuple('foo', 'bar')
+        k2 = self.module.StaticTuple('foo', 'zzz')
+        self.assertCompareDifferent(k1, k2)
+        k3 = self.module.StaticTuple(k1, k1)
+        k4 = self.module.StaticTuple(k1, k2)
+        self.assertCompareDifferent(k3, k4)
+        k5 = self.module.StaticTuple('foo', None)
+        self.assertCompareDifferent(k5, k1)
+        self.assertCompareDifferent(k5, k2)
+
+    def test_compare_diff_width(self):
+        k1 = self.module.StaticTuple('foo')
+        k2 = self.module.StaticTuple('foo', 'bar')
+        self.assertCompareDifferent(k1, k2)
+        k3 = self.module.StaticTuple(k1)
+        k4 = self.module.StaticTuple(k1, k2)
+        self.assertCompareDifferent(k3, k4)
+
+    def test_compare_different_types(self):
+        k1 = self.module.StaticTuple('foo', 'bar')
+        k2 = self.module.StaticTuple('foo', 1, None, u'\xb5', 1.2, 2**65, True,
+                                     k1)
+        self.assertCompareNoRelation(k1, k2)
+        k3 = self.module.StaticTuple('foo')
+        self.assertCompareDifferent(k3, k1)
+        k4 = self.module.StaticTuple(None)
+        self.assertCompareDifferent(k4, k1)
+        k5 = self.module.StaticTuple(1)
+        self.assertCompareNoRelation(k1, k5)
+
+    def test_compare_to_tuples(self):
+        k1 = self.module.StaticTuple('foo')
+        self.assertCompareEqual(k1, ('foo',))
+        self.assertCompareEqual(('foo',), k1)
+        self.assertCompareDifferent(k1, ('foo', 'bar'))
+        self.assertCompareDifferent(k1, ('foo', 10))
+
+        k2 = self.module.StaticTuple('foo', 'bar')
+        self.assertCompareEqual(k2, ('foo', 'bar'))
+        self.assertCompareEqual(('foo', 'bar'), k2)
+        self.assertCompareDifferent(k2, ('foo', 'zzz'))
+        self.assertCompareDifferent(('foo',), k2)
+        self.assertCompareDifferent(('foo', 'aaa'), k2)
+        self.assertCompareDifferent(('baz', 'bing'), k2)
+        self.assertCompareDifferent(('foo', 10), k2)
+
+        k3 = self.module.StaticTuple(k1, k2)
+        self.assertCompareEqual(k3, (('foo',), ('foo', 'bar')))
+        self.assertCompareEqual((('foo',), ('foo', 'bar')), k3)
+        self.assertCompareEqual(k3, (k1, ('foo', 'bar')))
+        self.assertCompareEqual((k1, ('foo', 'bar')), k3)
+
+    def test_compare_mixed_depths(self):
+        stuple = self.module.StaticTuple
+        k1 = stuple(stuple('a',), stuple('b',))
+        k2 = stuple(stuple(stuple('c',), stuple('d',)),
+                    stuple('b',))
+        # This requires comparing a StaticTuple to a 'string', and then
+        # interpreting that value in the next higher StaticTuple. This used to
+        # generate a PyErr_BadIternalCall. We now fall back to *something*.
+        self.assertCompareNoRelation(k1, k2)
+
+    def test_hash(self):
+        k = self.module.StaticTuple('foo')
+        self.assertEqual(hash(k), hash(('foo',)))
+        k = self.module.StaticTuple('foo', 'bar', 'baz', 'bing')
+        as_tuple = ('foo', 'bar', 'baz', 'bing')
+        self.assertEqual(hash(k), hash(as_tuple))
+        x = {k: 'foo'}
+        # Because k == , it replaces the slot, rather than having both
+        # present in the dict.
+        self.assertEqual('foo', x[as_tuple])
+        x[as_tuple] = 'bar'
+        self.assertEqual({as_tuple: 'bar'}, x)
+
+        k2 = self.module.StaticTuple(k)
+        as_tuple2 = (('foo', 'bar', 'baz', 'bing'),)
+        self.assertEqual(hash(k2), hash(as_tuple2))
+
+        k3 = self.module.StaticTuple('foo', 1, None, u'\xb5', 1.2, 2**65, True,
+                                     k)
+        as_tuple3 = ('foo', 1, None, u'\xb5', 1.2, 2**65, True, k)
+        self.assertEqual(hash(as_tuple3), hash(k3))
+
+    def test_slice(self):
+        k = self.module.StaticTuple('foo', 'bar', 'baz', 'bing')
+        self.assertEqual(('foo', 'bar'), k[:2])
+        self.assertEqual(('baz',), k[2:-1])
+        try:
+            val = k[::2]
+        except TypeError:
+            # C implementation raises a TypeError, we don't need the
+            # implementation yet, so allow this to pass
+            pass
+        else:
+            # Python implementation uses a regular Tuple, so make sure it gives
+            # the right result
+            self.assertEqual(('foo', 'baz'), val)
+
+    def test_referents(self):
+        # We implement tp_traverse so that things like 'meliae' can measure the
+        # amount of referenced memory. Unfortunately gc.get_referents() first
+        # checks the IS_GC flag before it traverses anything. We could write a
+        # helper func, but that won't work for the generic implementation...
+        self.requireFeature(Meliae)
+        from meliae import scanner
+        strs = ['foo', 'bar', 'baz', 'bing']
+        k = self.module.StaticTuple(*strs)
+        if self.module is _static_tuple_py:
+            refs = strs + [self.module.StaticTuple]
+        else:
+            refs = strs
+        self.assertEqual(sorted(refs), sorted(scanner.get_referents(k)))
+
+    def test_nested_referents(self):
+        self.requireFeature(Meliae)
+        from meliae import scanner
+        strs = ['foo', 'bar', 'baz', 'bing']
+        k1 = self.module.StaticTuple(*strs[:2])
+        k2 = self.module.StaticTuple(*strs[2:])
+        k3 = self.module.StaticTuple(k1, k2)
+        refs = [k1, k2]
+        if self.module is _static_tuple_py:
+            refs.append(self.module.StaticTuple)
+        self.assertEqual(sorted(refs),
+                         sorted(scanner.get_referents(k3)))
+
+    def test_empty_is_singleton(self):
+        key = self.module.StaticTuple()
+        self.assertIs(key, self.module._empty_tuple)
+
+    def test_intern(self):
+        unique_str1 = 'unique str ' + osutils.rand_chars(20)
+        unique_str2 = 'unique str ' + osutils.rand_chars(20)
+        key = self.module.StaticTuple(unique_str1, unique_str2)
+        self.assertFalse(key in self.module._interned_tuples)
+        key2 = self.module.StaticTuple(unique_str1, unique_str2)
+        self.assertEqual(key, key2)
+        self.assertIsNot(key, key2)
+        key3 = key.intern()
+        self.assertIs(key, key3)
+        self.assertTrue(key in self.module._interned_tuples)
+        self.assertEqual(key, self.module._interned_tuples[key])
+        key2 = key2.intern()
+        self.assertIs(key, key2)
+
+    def test__c_intern_handles_refcount(self):
+        if self.module is _static_tuple_py:
+            return # Not applicable
+        unique_str1 = 'unique str ' + osutils.rand_chars(20)
+        unique_str2 = 'unique str ' + osutils.rand_chars(20)
+        key = self.module.StaticTuple(unique_str1, unique_str2)
+        self.assertRefcount(1, key)
+        self.assertFalse(key in self.module._interned_tuples)
+        self.assertFalse(key._is_interned())
+        key2 = self.module.StaticTuple(unique_str1, unique_str2)
+        self.assertRefcount(1, key)
+        self.assertRefcount(1, key2)
+        self.assertEqual(key, key2)
+        self.assertIsNot(key, key2)
+
+        key3 = key.intern()
+        self.assertIs(key, key3)
+        self.assertTrue(key in self.module._interned_tuples)
+        self.assertEqual(key, self.module._interned_tuples[key])
+        # key and key3, but we 'hide' the one in _interned_tuples
+        self.assertRefcount(2, key)
+        del key3
+        self.assertRefcount(1, key)
+        self.assertTrue(key._is_interned())
+        self.assertRefcount(1, key2)
+        key3 = key2.intern()
+        # key3 now points to key as well, and *not* to key2
+        self.assertRefcount(2, key)
+        self.assertRefcount(1, key2)
+        self.assertIs(key, key3)
+        self.assertIsNot(key3, key2)
+        del key2
+        del key3
+        self.assertRefcount(1, key)
+
+    def test__c_keys_are_not_immortal(self):
+        if self.module is _static_tuple_py:
+            return # Not applicable
+        unique_str1 = 'unique str ' + osutils.rand_chars(20)
+        unique_str2 = 'unique str ' + osutils.rand_chars(20)
+        key = self.module.StaticTuple(unique_str1, unique_str2)
+        self.assertFalse(key in self.module._interned_tuples)
+        self.assertRefcount(1, key)
+        key = key.intern()
+        self.assertRefcount(1, key)
+        self.assertTrue(key in self.module._interned_tuples)
+        self.assertTrue(key._is_interned())
+        del key
+        # Create a new entry, which would point to the same location
+        key = self.module.StaticTuple(unique_str1, unique_str2)
+        self.assertRefcount(1, key)
+        # This old entry in _interned_tuples should be gone
+        self.assertFalse(key in self.module._interned_tuples)
+        self.assertFalse(key._is_interned())
+
+    def test__c_has_C_API(self):
+        if self.module is _static_tuple_py:
+            return
+        self.assertIsNot(None, self.module._C_API)
+
+    def test_from_sequence_tuple(self):
+        st = self.module.StaticTuple.from_sequence(('foo', 'bar'))
+        self.assertIsInstance(st, self.module.StaticTuple)
+        self.assertEqual(('foo', 'bar'), st)
+
+    def test_from_sequence_str(self):
+        st = self.module.StaticTuple.from_sequence('foo')
+        self.assertIsInstance(st, self.module.StaticTuple)
+        self.assertEqual(('f', 'o', 'o'), st)
+
+    def test_from_sequence_list(self):
+        st = self.module.StaticTuple.from_sequence(['foo', 'bar'])
+        self.assertIsInstance(st, self.module.StaticTuple)
+        self.assertEqual(('foo', 'bar'), st)
+
+    def test_from_sequence_static_tuple(self):
+        st = self.module.StaticTuple('foo', 'bar')
+        st2 = self.module.StaticTuple.from_sequence(st)
+        # If the source is a StaticTuple already, we return the exact object
+        self.assertIs(st, st2)
+
+    def test_from_sequence_not_sequence(self):
+        self.assertRaises(TypeError,
+                          self.module.StaticTuple.from_sequence, object())
+        self.assertRaises(TypeError,
+                          self.module.StaticTuple.from_sequence, 10)
+
+    def test_from_sequence_incorrect_args(self):
+        self.assertRaises(TypeError,
+                          self.module.StaticTuple.from_sequence, object(), 'a')
+        self.assertRaises(TypeError,
+                          self.module.StaticTuple.from_sequence, foo='a')
+
+    def test_from_sequence_iterable(self):
+        st = self.module.StaticTuple.from_sequence(iter(['foo', 'bar']))
+        self.assertIsInstance(st, self.module.StaticTuple)
+        self.assertEqual(('foo', 'bar'), st)
+
+    def test_from_sequence_generator(self):
+        def generate_tuple():
+            yield 'foo'
+            yield 'bar'
+        st = self.module.StaticTuple.from_sequence(generate_tuple())
+        self.assertIsInstance(st, self.module.StaticTuple)
+        self.assertEqual(('foo', 'bar'), st)
+
+    def test_pickle(self):
+        st = self.module.StaticTuple('foo', 'bar')
+        pickled = cPickle.dumps(st)
+        unpickled = cPickle.loads(pickled)
+        self.assertEqual(unpickled, st)
+
+    def test_pickle_empty(self):
+        st = self.module.StaticTuple()
+        pickled = cPickle.dumps(st)
+        unpickled = cPickle.loads(pickled)
+        self.assertIs(st, unpickled)
+
+    def test_pickle_nested(self):
+        st = self.module.StaticTuple('foo', self.module.StaticTuple('bar'))
+        pickled = cPickle.dumps(st)
+        unpickled = cPickle.loads(pickled)
+        self.assertEqual(unpickled, st)
+
+    def test_static_tuple_thunk(self):
+        # Make sure the right implementation is available from
+        # bzrlib.static_tuple.StaticTuple.
+        if self.module is _static_tuple_py:
+            if CompiledStaticTuple.available():
+                # We will be using the C version
+                return
+        self.assertIs(static_tuple.StaticTuple,
+                      self.module.StaticTuple)
+
+
+class TestEnsureStaticTuple(tests.TestCase):
+
+    def test_is_static_tuple(self):
+        st = static_tuple.StaticTuple('foo')
+        st2 = static_tuple.expect_static_tuple(st)
+        self.assertIs(st, st2)
+
+    def test_is_tuple(self):
+        t = ('foo',)
+        st = static_tuple.expect_static_tuple(t)
+        self.assertIsInstance(st, static_tuple.StaticTuple)
+        self.assertEqual(t, st)
+
+    def test_flagged_is_static_tuple(self):
+        debug.debug_flags.add('static_tuple')
+        st = static_tuple.StaticTuple('foo')
+        st2 = static_tuple.expect_static_tuple(st)
+        self.assertIs(st, st2)
+
+    def test_flagged_is_tuple(self):
+        debug.debug_flags.add('static_tuple')
+        t = ('foo',)
+        self.assertRaises(TypeError, static_tuple.expect_static_tuple, t)

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2009-08-17 21:15:40 +0000
+++ bzrlib/tests/test_branch.py	2009-09-04 13:43:21 +0000
@@ -504,6 +504,23 @@
         a = "%d revisions pulled" % r
         self.assertEqual(a, "10 revisions pulled")
 
+    def test_report_changed(self):
+        r = PullResult()
+        r.old_revid = "old-revid"
+        r.old_revno = 10
+        r.new_revid = "new-revid"
+        r.new_revno = 20
+        f = StringIO()
+        r.report(f)
+        self.assertEqual("Now on revision 20.\n", f.getvalue())
+
+    def test_report_unchanged(self):
+        r = PullResult()
+        r.old_revid = "same-revid"
+        r.new_revid = "same-revid"
+        f = StringIO()
+        r.report(f)
+        self.assertEqual("No revisions to pull.\n", f.getvalue())
 
 
 class _StubLockable(object):

=== modified file 'bzrlib/tests/test_btree_index.py'
--- bzrlib/tests/test_btree_index.py	2009-08-13 19:56:26 +0000
+++ bzrlib/tests/test_btree_index.py	2009-11-07 01:58:11 +0000
@@ -23,6 +23,8 @@
 from bzrlib import (
     btree_index,
     errors,
+    fifo_cache,
+    lru_cache,
     osutils,
     tests,
     )
@@ -122,6 +124,12 @@
 
 class TestBTreeBuilder(BTreeTestCase):
 
+    def test_clear_cache(self):
+        builder = btree_index.BTreeBuilder(reference_lists=0, key_elements=1)
+        # This is a no-op, but we need the api to be consistent with other
+        # BTreeGraphIndex apis.
+        builder.clear_cache()
+
     def test_empty_1_0(self):
         builder = btree_index.BTreeBuilder(key_elements=1, reference_lists=0)
         # NamedTemporaryFile dies on builder.finish().read(). weird.
@@ -153,7 +161,7 @@
         temp_file = builder.finish()
         content = temp_file.read()
         del temp_file
-        self.assertEqual(158, len(content))
+        self.assertEqual(131, len(content))
         self.assertEqual(
             "B+Tree Graph Index 2\nnode_ref_lists=0\nkey_elements=1\nlen=5\n"
             "row_lengths=1\n",
@@ -177,7 +185,7 @@
         temp_file = builder.finish()
         content = temp_file.read()
         del temp_file
-        self.assertEqual(264, len(content))
+        self.assertEqual(238, len(content))
         self.assertEqual(
             "B+Tree Graph Index 2\nnode_ref_lists=2\nkey_elements=2\nlen=10\n"
             "row_lengths=1\n",
@@ -243,7 +251,7 @@
         temp_file = builder.finish()
         content = temp_file.read()
         del temp_file
-        self.assertEqual(181, len(content))
+        self.assertEqual(155, len(content))
         self.assertEqual(
             "B+Tree Graph Index 2\nnode_ref_lists=0\nkey_elements=1\nlen=10\n"
             "row_lengths=1\n",
@@ -351,23 +359,19 @@
         # Test the parts of the index that take up memory are doing so
         # predictably.
         self.assertEqual(1, len(builder._nodes))
-        self.assertEqual(1, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         builder.add_node(*nodes[1])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(1, len(builder._backing_indices))
         self.assertEqual(2, builder._backing_indices[0].key_count())
         # now back to memory
         builder.add_node(*nodes[2])
         self.assertEqual(1, len(builder._nodes))
-        self.assertEqual(1, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         # And spills to a second backing index combing all
         builder.add_node(*nodes[3])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(2, len(builder._backing_indices))
         self.assertEqual(None, builder._backing_indices[0])
@@ -376,7 +380,6 @@
         builder.add_node(*nodes[4])
         builder.add_node(*nodes[5])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(2, len(builder._backing_indices))
         self.assertEqual(2, builder._backing_indices[0].key_count())
@@ -440,23 +443,19 @@
         # Test the parts of the index that take up memory are doing so
         # predictably.
         self.assertEqual(1, len(builder._nodes))
-        self.assertEqual(1, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         builder.add_node(*nodes[1])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(1, len(builder._backing_indices))
         self.assertEqual(2, builder._backing_indices[0].key_count())
         # now back to memory
         builder.add_node(*nodes[2])
         self.assertEqual(1, len(builder._nodes))
-        self.assertEqual(1, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         # And spills to a second backing index but doesn't combine
         builder.add_node(*nodes[3])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(2, len(builder._backing_indices))
         for backing_index in builder._backing_indices:
@@ -465,7 +464,6 @@
         builder.add_node(*nodes[4])
         builder.add_node(*nodes[5])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(3, len(builder._backing_indices))
         for backing_index in builder._backing_indices:
@@ -530,11 +528,9 @@
         builder.add_node(*nodes[0])
         # Test the parts of the index that take up memory are doing so
         # predictably.
-        self.assertEqual(1, len(builder._keys))
         self.assertEqual(1, len(builder._nodes))
         self.assertIs(None, builder._nodes_by_key)
         builder.add_node(*nodes[1])
-        self.assertEqual(0, len(builder._keys))
         self.assertEqual(0, len(builder._nodes))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(1, len(builder._backing_indices))
@@ -543,7 +539,6 @@
         old = dict(builder._get_nodes_by_key()) #Build up the nodes by key dict
         builder.add_node(*nodes[2])
         self.assertEqual(1, len(builder._nodes))
-        self.assertEqual(1, len(builder._keys))
         self.assertIsNot(None, builder._nodes_by_key)
         self.assertNotEqual({}, builder._nodes_by_key)
         # We should have a new entry
@@ -551,7 +546,6 @@
         # And spills to a second backing index combing all
         builder.add_node(*nodes[3])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(2, len(builder._backing_indices))
         self.assertEqual(None, builder._backing_indices[0])
@@ -560,7 +554,6 @@
         builder.add_node(*nodes[4])
         builder.add_node(*nodes[5])
         self.assertEqual(0, len(builder._nodes))
-        self.assertEqual(0, len(builder._keys))
         self.assertIs(None, builder._nodes_by_key)
         self.assertEqual(2, len(builder._backing_indices))
         self.assertEqual(2, builder._backing_indices[0].key_count())
@@ -637,6 +630,27 @@
         size = trans.put_file('index', stream)
         return btree_index.BTreeGraphIndex(trans, 'index', size)
 
+    def test_clear_cache(self):
+        nodes = self.make_nodes(160, 2, 2)
+        index = self.make_index(ref_lists=2, key_elements=2, nodes=nodes)
+        self.assertEqual(1, len(list(index.iter_entries([nodes[30][0]]))))
+        self.assertEqual([1, 4], index._row_lengths)
+        self.assertIsNot(None, index._root_node)
+        internal_node_pre_clear = index._internal_node_cache.keys()
+        self.assertTrue(len(index._leaf_node_cache) > 0)
+        index.clear_cache()
+        # We don't touch _root_node or _internal_node_cache, both should be
+        # small, and can save a round trip or two
+        self.assertIsNot(None, index._root_node)
+        # NOTE: We don't want to affect the _internal_node_cache, as we expect
+        #       it will be small, and if we ever do touch this index again, it
+        #       will save round-trips.  This assertion isn't very strong,
+        #       becuase without a 3-level index, we don't have any internal
+        #       nodes cached.
+        self.assertEqual(internal_node_pre_clear,
+                         index._internal_node_cache.keys())
+        self.assertEqual(0, len(index._leaf_node_cache))
+
     def test_trivial_constructor(self):
         transport = get_transport('trace+' + self.get_url(''))
         index = btree_index.BTreeGraphIndex(transport, 'index', None)
@@ -689,7 +703,7 @@
         # The entire index should have been read, as it is one page long.
         self.assertEqual([('readv', 'index', [(0, size)], False, None)],
             transport._activity)
-        self.assertEqual(1199, size)
+        self.assertEqual(1173, size)
 
     def test__read_nodes_no_size_one_page_reads_once(self):
         self.make_index(nodes=[(('key',), 'value', ())])
@@ -743,7 +757,7 @@
         # The entire index should have been read linearly.
         self.assertEqual([('readv', 'index', [(0, size)], False, None)],
             transport._activity)
-        self.assertEqual(1514, size)
+        self.assertEqual(1488, size)
 
     def test_validate_two_pages(self):
         builder = btree_index.BTreeBuilder(key_elements=2, reference_lists=2)
@@ -1115,6 +1129,43 @@
         self.assertEqual({}, parent_map)
         self.assertEqual(set([('one',), ('two',)]), missing_keys)
 
+    def test_supports_unlimited_cache(self):
+        builder = btree_index.BTreeBuilder(reference_lists=0, key_elements=1)
+        # We need enough nodes to cause a page split (so we have both an
+        # internal node and a couple leaf nodes. 500 seems to be enough.)
+        nodes = self.make_nodes(500, 1, 0)
+        for node in nodes:
+            builder.add_node(*node)
+        stream = builder.finish()
+        trans = get_transport(self.get_url())
+        size = trans.put_file('index', stream)
+        index = btree_index.BTreeGraphIndex(trans, 'index', size)
+        self.assertEqual(500, index.key_count())
+        # We have an internal node
+        self.assertEqual(2, len(index._row_lengths))
+        # We have at least 2 leaf nodes
+        self.assertTrue(index._row_lengths[-1] >= 2)
+        self.assertIsInstance(index._leaf_node_cache, lru_cache.LRUCache)
+        self.assertEqual(btree_index._NODE_CACHE_SIZE,
+                         index._leaf_node_cache._max_cache)
+        self.assertIsInstance(index._internal_node_cache, fifo_cache.FIFOCache)
+        self.assertEqual(100, index._internal_node_cache._max_cache)
+        # No change if unlimited_cache=False is passed
+        index = btree_index.BTreeGraphIndex(trans, 'index', size,
+                                            unlimited_cache=False)
+        self.assertIsInstance(index._leaf_node_cache, lru_cache.LRUCache)
+        self.assertEqual(btree_index._NODE_CACHE_SIZE,
+                         index._leaf_node_cache._max_cache)
+        self.assertIsInstance(index._internal_node_cache, fifo_cache.FIFOCache)
+        self.assertEqual(100, index._internal_node_cache._max_cache)
+        index = btree_index.BTreeGraphIndex(trans, 'index', size,
+                                            unlimited_cache=True)
+        self.assertIsInstance(index._leaf_node_cache, dict)
+        self.assertIs(type(index._internal_node_cache), dict)
+        # Exercise the lookup code
+        entries = set(index.iter_entries([n[0] for n in nodes]))
+        self.assertEqual(500, len(entries))
+
 
 class TestBTreeNodes(BTreeTestCase):
 

=== modified file 'bzrlib/tests/test_bundle.py'
--- bzrlib/tests/test_bundle.py	2009-08-04 14:10:09 +0000
+++ bzrlib/tests/test_bundle.py	2009-08-27 22:17:35 +0000
@@ -1830,9 +1830,8 @@
         """
         from bzrlib.tests.blackbox.test_push import RedirectingMemoryServer
         server = RedirectingMemoryServer()
-        server.setUp()
+        self.start_server(server)
         url = server.get_url() + 'infinite-loop'
-        self.addCleanup(server.tearDown)
         self.assertRaises(errors.NotABundle, read_mergeable_from_url, url)
 
     def test_smart_server_connection_reset(self):
@@ -1841,8 +1840,7 @@
         """
         # Instantiate a server that will provoke a ConnectionReset
         sock_server = _DisconnectingTCPServer()
-        sock_server.setUp()
-        self.addCleanup(sock_server.tearDown)
+        self.start_server(sock_server)
         # We don't really care what the url is since the server will close the
         # connection without interpreting it
         url = sock_server.get_url()

=== modified file 'bzrlib/tests/test_bzrdir.py'
--- bzrlib/tests/test_bzrdir.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/test_bzrdir.py	2009-09-17 11:54:41 +0000
@@ -1152,7 +1152,9 @@
     _transport = HttpTransport_urllib
 
     def _qualified_url(self, host, port):
-        return 'http+urllib://%s:%s' % (host, port)
+        result = 'http+urllib://%s:%s' % (host, port)
+        self.permit_url(result)
+        return result
 
 
 
@@ -1162,7 +1164,9 @@
     """Tests redirections for pycurl implementation"""
 
     def _qualified_url(self, host, port):
-        return 'http+pycurl://%s:%s' % (host, port)
+        result = 'http+pycurl://%s:%s' % (host, port)
+        self.permit_url(result)
+        return result
 
 
 class TestHTTPRedirections_nosmart(TestHTTPRedirections,
@@ -1172,7 +1176,9 @@
     _transport = NoSmartTransportDecorator
 
     def _qualified_url(self, host, port):
-        return 'nosmart+http://%s:%s' % (host, port)
+        result = 'nosmart+http://%s:%s' % (host, port)
+        self.permit_url(result)
+        return result
 
 
 class TestHTTPRedirections_readonly(TestHTTPRedirections,
@@ -1182,7 +1188,9 @@
     _transport = ReadonlyTransportDecorator
 
     def _qualified_url(self, host, port):
-        return 'readonly+http://%s:%s' % (host, port)
+        result = 'readonly+http://%s:%s' % (host, port)
+        self.permit_url(result)
+        return result
 
 
 class TestDotBzrHidden(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_chk_map.py'
--- bzrlib/tests/test_chk_map.py	2009-07-16 23:28:49 +0000
+++ bzrlib/tests/test_chk_map.py	2009-10-21 20:53:21 +0000
@@ -31,6 +31,7 @@
     LeafNode,
     Node,
     )
+from bzrlib.static_tuple import StaticTuple
 
 
 class TestNode(tests.TestCase):
@@ -831,13 +832,13 @@
         # 'ab' and 'ac' nodes
         chkmap.map(('aad',), 'v')
         self.assertIsInstance(chkmap._root_node._items['aa'], InternalNode)
-        self.assertIsInstance(chkmap._root_node._items['ab'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['ac'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['ab'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['ac'], StaticTuple)
         # Unmapping 'acd' can notice that 'aa' is an InternalNode and not have
         # to map in 'ab'
         chkmap.unmap(('acd',))
         self.assertIsInstance(chkmap._root_node._items['aa'], InternalNode)
-        self.assertIsInstance(chkmap._root_node._items['ab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['ab'], StaticTuple)
 
     def test_unmap_without_fitting_doesnt_page_in(self):
         store = self.get_chk_bytes()
@@ -860,8 +861,8 @@
         chkmap.map(('aaf',), 'v')
         # At this point, the previous nodes should not be paged in, but the
         # newly added nodes would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aac'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
@@ -869,8 +870,8 @@
         # Now unmapping one of the new nodes will use only the already-paged-in
         # nodes to determine that we don't need to do more.
         chkmap.unmap(('aaf',))
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aac'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
@@ -897,9 +898,9 @@
         chkmap.map(('aad',), 'v')
         # At this point, the previous nodes should not be paged in, but the
         # newly added node would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         # Unmapping the new node will check the existing nodes to see if they
         # would fit.
@@ -937,9 +938,9 @@
         chkmap.map(('aad',), 'v')
         # At this point, the previous nodes should not be paged in, but the
         # newly added node would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         # Now clear the page cache, and only include 2 of the children in the
         # cache
@@ -954,7 +955,7 @@
         # Unmapping the new node will check the nodes from the page cache
         # first, and not have to read in 'aaa'
         chkmap.unmap(('aad',))
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aab'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aac'], LeafNode)
 
@@ -974,9 +975,9 @@
         chkmap.map(('aaf',), 'val')
         # At this point, the previous nodes should not be paged in, but the
         # newly added node would be
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aad'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aaf'], LeafNode)
@@ -984,9 +985,9 @@
         # Unmapping a new node will see the other nodes that are already in
         # memory, and not need to page in anything else
         chkmap.unmap(('aad',))
-        self.assertIsInstance(chkmap._root_node._items['aaa'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aab'], tuple)
-        self.assertIsInstance(chkmap._root_node._items['aac'], tuple)
+        self.assertIsInstance(chkmap._root_node._items['aaa'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aab'], StaticTuple)
+        self.assertIsInstance(chkmap._root_node._items['aac'], StaticTuple)
         self.assertIsInstance(chkmap._root_node._items['aae'], LeafNode)
         self.assertIsInstance(chkmap._root_node._items['aaf'], LeafNode)
 
@@ -1031,8 +1032,8 @@
             {('a',): 'content here', ('b',): 'more content'},
             chk_bytes=basis._store, maximum_size=10)
         list(target.iter_changes(basis))
-        self.assertIsInstance(target._root_node, tuple)
-        self.assertIsInstance(basis._root_node, tuple)
+        self.assertIsInstance(target._root_node, StaticTuple)
+        self.assertIsInstance(basis._root_node, StaticTuple)
 
     def test_iter_changes_ab_ab_changed_values_shown(self):
         basis = self._get_map({('a',): 'content here', ('b',): 'more content'},
@@ -1144,9 +1145,12 @@
 
     def test_iteritems_keys_prefixed_by_2_width_nodes_hashed(self):
         search_key_func = chk_map.search_key_registry.get('hash-16-way')
-        self.assertEqual('E8B7BE43\x00E8B7BE43', search_key_func(('a', 'a')))
-        self.assertEqual('E8B7BE43\x0071BEEFF9', search_key_func(('a', 'b')))
-        self.assertEqual('71BEEFF9\x0000000000', search_key_func(('b', '')))
+        self.assertEqual('E8B7BE43\x00E8B7BE43',
+                         search_key_func(StaticTuple('a', 'a')))
+        self.assertEqual('E8B7BE43\x0071BEEFF9',
+                         search_key_func(StaticTuple('a', 'b')))
+        self.assertEqual('71BEEFF9\x0000000000',
+                         search_key_func(StaticTuple('b', '')))
         chkmap = self._get_map(
             {("a","a"):"content here", ("a", "b",):"more content",
              ("b", ""): 'boring content'},
@@ -1449,41 +1453,6 @@
                              , chkmap._dump_tree())
 
 
-class TestSearchKeyFuncs(tests.TestCase):
-
-    def assertSearchKey16(self, expected, key):
-        self.assertEqual(expected, chk_map._search_key_16(key))
-
-    def assertSearchKey255(self, expected, key):
-        actual = chk_map._search_key_255(key)
-        self.assertEqual(expected, actual, 'actual: %r' % (actual,))
-
-    def test_simple_16(self):
-        self.assertSearchKey16('8C736521', ('foo',))
-        self.assertSearchKey16('8C736521\x008C736521', ('foo', 'foo'))
-        self.assertSearchKey16('8C736521\x0076FF8CAA', ('foo', 'bar'))
-        self.assertSearchKey16('ED82CD11', ('abcd',))
-
-    def test_simple_255(self):
-        self.assertSearchKey255('\x8cse!', ('foo',))
-        self.assertSearchKey255('\x8cse!\x00\x8cse!', ('foo', 'foo'))
-        self.assertSearchKey255('\x8cse!\x00v\xff\x8c\xaa', ('foo', 'bar'))
-        # The standard mapping for these would include '\n', so it should be
-        # mapped to '_'
-        self.assertSearchKey255('\xfdm\x93_\x00P_\x1bL', ('<', 'V'))
-
-    def test_255_does_not_include_newline(self):
-        # When mapping via _search_key_255, we should never have the '\n'
-        # character, but all other 255 values should be present
-        chars_used = set()
-        for char_in in range(256):
-            search_key = chk_map._search_key_255((chr(char_in),))
-            chars_used.update(search_key)
-        all_chars = set([chr(x) for x in range(256)])
-        unused_chars = all_chars.symmetric_difference(chars_used)
-        self.assertEqual(set('\n'), unused_chars)
-
-
 class TestLeafNode(TestCaseWithStore):
 
     def test_current_size_empty(self):
@@ -1908,18 +1877,19 @@
         search_key_func = chk_map.search_key_registry.get('hash-255-way')
         node = InternalNode(search_key_func=search_key_func)
         leaf1 = LeafNode(search_key_func=search_key_func)
-        leaf1.map(None, ('foo bar',), 'quux')
+        leaf1.map(None, StaticTuple('foo bar',), 'quux')
         leaf2 = LeafNode(search_key_func=search_key_func)
-        leaf2.map(None, ('strange',), 'beast')
-        self.assertEqual('\xbeF\x014', search_key_func(('foo bar',)))
-        self.assertEqual('\x85\xfa\xf7K', search_key_func(('strange',)))
+        leaf2.map(None, StaticTuple('strange',), 'beast')
+        self.assertEqual('\xbeF\x014', search_key_func(StaticTuple('foo bar',)))
+        self.assertEqual('\x85\xfa\xf7K', search_key_func(StaticTuple('strange',)))
         node.add_node("\xbe", leaf1)
         # This sets up a path that should not be followed - it will error if
         # the code tries to.
         node._items['\xbe'] = None
         node.add_node("\x85", leaf2)
         self.assertEqual([(('strange',), 'beast')],
-            sorted(node.iteritems(None, [('strange',), ('weird',)])))
+            sorted(node.iteritems(None, [StaticTuple('strange',),
+                                         StaticTuple('weird',)])))
 
     def test_iteritems_partial_empty(self):
         node = InternalNode()
@@ -1932,7 +1902,7 @@
         # Ensure test validity: nothing paged in below the root.
         self.assertEqual(2,
             len([value for value in node._items.values()
-                if type(value) == tuple]))
+                if type(value) is StaticTuple]))
         # now, mapping to k3 should add a k3 leaf
         prefix, nodes = node.map(None, ('k3',), 'quux')
         self.assertEqual("k", prefix)
@@ -1971,7 +1941,7 @@
         # Ensure test validity: nothing paged in below the root.
         self.assertEqual(2,
             len([value for value in node._items.values()
-                if type(value) == tuple]))
+                if type(value) is StaticTuple]))
         # now, mapping to k23 causes k22 ('k2' in node) to split into k22 and
         # k23, which for simplicity in the current implementation generates
         # a new internal node between node, and k22/k23.
@@ -2016,9 +1986,12 @@
         node = InternalNode(search_key_func=search_key_func)
         node._key_width = 2
         node._node_width = 4
-        self.assertEqual('E8B7BE43\x0071BEEFF9', search_key_func(('a', 'b')))
-        self.assertEqual('E8B7', node._search_prefix_filter(('a', 'b')))
-        self.assertEqual('E8B7', node._search_prefix_filter(('a',)))
+        self.assertEqual('E8B7BE43\x0071BEEFF9', search_key_func(
+            StaticTuple('a', 'b')))
+        self.assertEqual('E8B7', node._search_prefix_filter(
+            StaticTuple('a', 'b')))
+        self.assertEqual('E8B7', node._search_prefix_filter(
+            StaticTuple('a',)))
 
     def test_unmap_k23_from_k1_k22_k23_gives_k1_k22_tree_new(self):
         chkmap = self._get_map(

=== added file 'bzrlib/tests/test_cleanup.py'
--- bzrlib/tests/test_cleanup.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_cleanup.py	2009-10-26 06:23:14 +0000
@@ -0,0 +1,280 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+from cStringIO import StringIO
+import re
+
+from bzrlib.cleanup import (
+    _do_with_cleanups,
+    _run_cleanup,
+    OperationWithCleanups,
+    )
+from bzrlib.tests import TestCase
+from bzrlib import (
+    debug,
+    trace,
+    )
+
+
+class CleanupsTestCase(TestCase):
+
+    def setUp(self):
+        super(CleanupsTestCase, self).setUp()
+        self.call_log = []
+
+    def no_op_cleanup(self):
+        self.call_log.append('no_op_cleanup')
+
+    def assertLogContains(self, regex):
+        log = self._get_log(keep_log_file=True)
+        self.assertContainsRe(log, regex, re.DOTALL)
+
+    def failing_cleanup(self):
+        self.call_log.append('failing_cleanup')
+        raise Exception("failing_cleanup goes boom!")
+
+
+class TestRunCleanup(CleanupsTestCase):
+
+    def test_no_errors(self):
+        """The function passed to _run_cleanup is run."""
+        self.assertTrue(_run_cleanup(self.no_op_cleanup))
+        self.assertEqual(['no_op_cleanup'], self.call_log)
+
+    def test_cleanup_with_args_kwargs(self):
+        def func_taking_args_kwargs(*args, **kwargs):
+            self.call_log.append(('func', args, kwargs))
+        _run_cleanup(func_taking_args_kwargs, 'an arg', kwarg='foo')
+        self.assertEqual(
+            [('func', ('an arg',), {'kwarg': 'foo'})], self.call_log)
+
+    def test_cleanup_error(self):
+        """An error from the cleanup function is logged by _run_cleanup, but not
+        propagated.
+
+        This is there's no way for _run_cleanup to know if there's an existing
+        exception in this situation::
+            try:
+              some_func()
+            finally:
+              _run_cleanup(cleanup_func)
+        So, the best _run_cleanup can do is always log errors but never raise
+        them.
+        """
+        self.assertFalse(_run_cleanup(self.failing_cleanup))
+        self.assertLogContains('Cleanup failed:.*failing_cleanup goes boom')
+
+    def test_cleanup_error_debug_flag(self):
+        """The -Dcleanup debug flag causes cleanup errors to be reported to the
+        user.
+        """
+        log = StringIO()
+        trace.push_log_file(log)
+        debug.debug_flags.add('cleanup')
+        self.assertFalse(_run_cleanup(self.failing_cleanup))
+        self.assertContainsRe(
+            log.getvalue(),
+            "bzr: warning: Cleanup failed:.*failing_cleanup goes boom")
+
+    def test_prior_error_cleanup_succeeds(self):
+        """Calling _run_cleanup from a finally block will not interfere with an
+        exception from the try block.
+        """
+        def failing_operation():
+            try:
+                1/0
+            finally:
+                _run_cleanup(self.no_op_cleanup)
+        self.assertRaises(ZeroDivisionError, failing_operation)
+        self.assertEqual(['no_op_cleanup'], self.call_log)
+
+    def test_prior_error_cleanup_fails(self):
+        """Calling _run_cleanup from a finally block will not interfere with an
+        exception from the try block even when the cleanup itself raises an
+        exception.
+
+        The cleanup exception will be logged.
+        """
+        def failing_operation():
+            try:
+                1/0
+            finally:
+                _run_cleanup(self.failing_cleanup)
+        self.assertRaises(ZeroDivisionError, failing_operation)
+        self.assertLogContains('Cleanup failed:.*failing_cleanup goes boom')
+
+
+class TestDoWithCleanups(CleanupsTestCase):
+
+    def trivial_func(self):
+        self.call_log.append('trivial_func')
+        return 'trivial result'
+
+    def test_runs_func(self):
+        """_do_with_cleanups runs the function it is given, and returns the
+        result.
+        """
+        result = _do_with_cleanups([], self.trivial_func)
+        self.assertEqual('trivial result', result)
+
+    def test_runs_cleanups(self):
+        """Cleanup functions are run (in the given order)."""
+        cleanup_func_1 = (self.call_log.append, ('cleanup 1',), {})
+        cleanup_func_2 = (self.call_log.append, ('cleanup 2',), {})
+        _do_with_cleanups([cleanup_func_1, cleanup_func_2], self.trivial_func)
+        self.assertEqual(
+            ['trivial_func', 'cleanup 1', 'cleanup 2'], self.call_log)
+
+    def failing_func(self):
+        self.call_log.append('failing_func')
+        1/0
+
+    def test_func_error_propagates(self):
+        """Errors from the main function are propagated (after running
+        cleanups).
+        """
+        self.assertRaises(
+            ZeroDivisionError, _do_with_cleanups,
+            [(self.no_op_cleanup, (), {})], self.failing_func)
+        self.assertEqual(['failing_func', 'no_op_cleanup'], self.call_log)
+
+    def test_func_error_trumps_cleanup_error(self):
+        """Errors from the main function a propagated even if a cleanup raises
+        an error.
+
+        The cleanup error is be logged.
+        """
+        self.assertRaises(
+            ZeroDivisionError, _do_with_cleanups,
+            [(self.failing_cleanup, (), {})], self.failing_func)
+        self.assertLogContains('Cleanup failed:.*failing_cleanup goes boom')
+
+    def test_func_passes_and_error_from_cleanup(self):
+        """An error from a cleanup is propagated when the main function doesn't
+        raise an error.  Later cleanups are still executed.
+        """
+        exc = self.assertRaises(
+            Exception, _do_with_cleanups,
+            [(self.failing_cleanup, (), {}), (self.no_op_cleanup, (), {})],
+            self.trivial_func)
+        self.assertEqual('failing_cleanup goes boom!', exc.args[0])
+        self.assertEqual(
+            ['trivial_func', 'failing_cleanup', 'no_op_cleanup'],
+            self.call_log)
+
+    def test_multiple_cleanup_failures(self):
+        """When multiple cleanups fail (as tends to happen when something has
+        gone wrong), the first error is propagated, and subsequent errors are
+        logged.
+        """
+        cleanups = self.make_two_failing_cleanup_funcs()
+        self.assertRaises(ErrorA, _do_with_cleanups, cleanups,
+            self.trivial_func)
+        self.assertLogContains('Cleanup failed:.*ErrorB')
+        log = self._get_log(keep_log_file=True)
+        self.assertFalse('ErrorA' in log)
+
+    def make_two_failing_cleanup_funcs(self):
+        def raise_a():
+            raise ErrorA('Error A')
+        def raise_b():
+            raise ErrorB('Error B')
+        return [(raise_a, (), {}), (raise_b, (), {})]
+
+    def test_multiple_cleanup_failures_debug_flag(self):
+        log = StringIO()
+        trace.push_log_file(log)
+        debug.debug_flags.add('cleanup')
+        cleanups = self.make_two_failing_cleanup_funcs()
+        self.assertRaises(ErrorA, _do_with_cleanups, cleanups,
+            self.trivial_func)
+        self.assertContainsRe(
+            log.getvalue(), "bzr: warning: Cleanup failed:.*Error B\n")
+        self.assertEqual(1, log.getvalue().count('bzr: warning:'),
+                log.getvalue())
+
+    def test_func_and_cleanup_errors_debug_flag(self):
+        log = StringIO()
+        trace.push_log_file(log)
+        debug.debug_flags.add('cleanup')
+        cleanups = self.make_two_failing_cleanup_funcs()
+        self.assertRaises(ZeroDivisionError, _do_with_cleanups, cleanups,
+            self.failing_func)
+        self.assertContainsRe(
+            log.getvalue(), "bzr: warning: Cleanup failed:.*Error A\n")
+        self.assertContainsRe(
+            log.getvalue(), "bzr: warning: Cleanup failed:.*Error B\n")
+        self.assertEqual(2, log.getvalue().count('bzr: warning:'))
+
+    def test_func_may_mutate_cleanups(self):
+        """The main func may mutate the cleanups before it returns.
+        
+        This allows a function to gradually add cleanups as it acquires
+        resources, rather than planning all the cleanups up-front.  The
+        OperationWithCleanups helper relies on this working.
+        """
+        cleanups_list = []
+        def func_that_adds_cleanups():
+            self.call_log.append('func_that_adds_cleanups')
+            cleanups_list.append((self.no_op_cleanup, (), {}))
+            return 'result'
+        result = _do_with_cleanups(cleanups_list, func_that_adds_cleanups)
+        self.assertEqual('result', result)
+        self.assertEqual(
+            ['func_that_adds_cleanups', 'no_op_cleanup'], self.call_log)
+
+    def test_cleanup_error_debug_flag(self):
+        """The -Dcleanup debug flag causes cleanup errors to be reported to the
+        user.
+        """
+        log = StringIO()
+        trace.push_log_file(log)
+        debug.debug_flags.add('cleanup')
+        self.assertRaises(ZeroDivisionError, _do_with_cleanups,
+            [(self.failing_cleanup, (), {})], self.failing_func)
+        self.assertContainsRe(
+            log.getvalue(),
+            "bzr: warning: Cleanup failed:.*failing_cleanup goes boom")
+        self.assertEqual(1, log.getvalue().count('bzr: warning:'))
+
+
+class ErrorA(Exception): pass
+class ErrorB(Exception): pass
+
+
+class TestOperationWithCleanups(CleanupsTestCase):
+
+    def test_cleanup_ordering(self):
+        """Cleanups are added in LIFO order.
+
+        So cleanups added before run is called are run last, and the last
+        cleanup added during the func is run first.
+        """
+        call_log = []
+        def func(op, foo):
+            call_log.append(('func called', foo))
+            op.add_cleanup(call_log.append, 'cleanup 2')
+            op.add_cleanup(call_log.append, 'cleanup 1')
+            return 'result'
+        owc = OperationWithCleanups(func)
+        owc.add_cleanup(call_log.append, 'cleanup 4')
+        owc.add_cleanup(call_log.append, 'cleanup 3')
+        result = owc.run('foo')
+        self.assertEqual('result', result)
+        self.assertEqual(
+            [('func called', 'foo'), 'cleanup 1', 'cleanup 2', 'cleanup 3',
+            'cleanup 4'], call_log)
+

=== modified file 'bzrlib/tests/test_commit.py'
--- bzrlib/tests/test_commit.py	2009-08-17 03:58:18 +0000
+++ bzrlib/tests/test_commit.py	2009-10-29 05:54:49 +0000
@@ -484,7 +484,7 @@
         other_bzrdir = master_branch.bzrdir.sprout('other')
         other_tree = other_bzrdir.open_workingtree()
 
-        # do a commit to the the other branch changing the content file so
+        # do a commit to the other branch changing the content file so
         # that our commit after merging will have a merged revision in the
         # content file history.
         self.build_tree_contents([('other/content_file', 'change in other\n')])

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2009-08-20 04:53:23 +0000
+++ bzrlib/tests/test_config.py	2009-10-31 01:43:48 +0000
@@ -25,6 +25,7 @@
     branch,
     bzrdir,
     config,
+    diff,
     errors,
     osutils,
     mail_client,
@@ -42,6 +43,7 @@
 [DEFAULT]
 email=Erik B\u00e5gfors <erik@bagfors.nu>
 editor=vim
+change_editor=vimdiff -of @new_path @old_path
 gpg_signing_command=gnome-gpg
 log_format=short
 user_global_option=something
@@ -208,6 +210,10 @@
         self._calls.append('_get_signature_checking')
         return self._signatures
 
+    def _get_change_editor(self):
+        self._calls.append('_get_change_editor')
+        return 'vimdiff -fo @new_path @old_path'
+
 
 bool_config = """[DEFAULT]
 active = true
@@ -314,6 +320,14 @@
         my_config = config.Config()
         self.assertEqual('long', my_config.log_format())
 
+    def test_get_change_editor(self):
+        my_config = InstrumentedConfig()
+        change_editor = my_config.get_change_editor('old_tree', 'new_tree')
+        self.assertEqual(['_get_change_editor'], my_config._calls)
+        self.assertIs(diff.DiffFromTool, change_editor.__class__)
+        self.assertEqual(['vimdiff', '-fo', '@new_path', '@old_path'],
+                         change_editor.command_template)
+
 
 class TestConfigPath(tests.TestCase):
 
@@ -625,6 +639,18 @@
         my_config = self._get_sample_config()
         self.assertEqual(sample_long_alias, my_config.get_alias('ll'))
 
+    def test_get_change_editor(self):
+        my_config = self._get_sample_config()
+        change_editor = my_config.get_change_editor('old', 'new')
+        self.assertIs(diff.DiffFromTool, change_editor.__class__)
+        self.assertEqual('vimdiff -of @new_path @old_path',
+                         ' '.join(change_editor.command_template))
+
+    def test_get_no_change_editor(self):
+        my_config = self._get_empty_config()
+        change_editor = my_config.get_change_editor('old', 'new')
+        self.assertIs(None, change_editor)
+
 
 class TestGlobalConfigSavingOptions(tests.TestCaseInTempDir):
 

=== modified file 'bzrlib/tests/test_crash.py'
--- bzrlib/tests/test_crash.py	2009-08-20 04:45:48 +0000
+++ bzrlib/tests/test_crash.py	2009-08-28 12:38:01 +0000
@@ -18,20 +18,17 @@
 from StringIO import StringIO
 import sys
 
-
-from bzrlib.crash import (
-    report_bug,
-    _write_apport_report_to_file,
+from bzrlib import (
+    crash,
+    tests,
     )
-from bzrlib.tests import TestCase
-from bzrlib.tests.features import ApportFeature
-
-
-class TestApportReporting(TestCase):
-
-    def setUp(self):
-        TestCase.setUp(self)
-        self.requireFeature(ApportFeature)
+
+from bzrlib.tests import features
+
+
+class TestApportReporting(tests.TestCase):
+
+    _test_needs_features = [features.ApportFeature]
 
     def test_apport_report_contents(self):
         try:
@@ -39,19 +36,13 @@
         except AssertionError, e:
             pass
         outf = StringIO()
-        _write_apport_report_to_file(sys.exc_info(),
-            outf)
+        crash._write_apport_report_to_file(sys.exc_info(), outf)
         report = outf.getvalue()
 
-        self.assertContainsRe(report,
-            '(?m)^BzrVersion:')
+        self.assertContainsRe(report, '(?m)^BzrVersion:')
         # should be in the traceback
-        self.assertContainsRe(report,
-            'my error')
-        self.assertContainsRe(report,
-            'AssertionError')
-        self.assertContainsRe(report,
-            'test_apport_report_contents')
+        self.assertContainsRe(report, 'my error')
+        self.assertContainsRe(report, 'AssertionError')
+        self.assertContainsRe(report, 'test_apport_report_contents')
         # should also be in there
-        self.assertContainsRe(report,
-            '(?m)^CommandLine:.*selftest')
+        self.assertContainsRe(report, '(?m)^CommandLine:')

=== modified file 'bzrlib/tests/test_decorators.py'
--- bzrlib/tests/test_decorators.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_decorators.py	2009-10-02 06:12:20 +0000
@@ -23,11 +23,15 @@
 from bzrlib.tests import TestCase
 
 
-def create_decorator_sample(style, except_in_unlock=False):
+class SampleUnlockError(Exception):
+    pass
+
+
+def create_decorator_sample(style, unlock_error=None):
     """Create a DecoratorSample object, using specific lock operators.
 
     :param style: The type of lock decorators to use (fast/pretty/None)
-    :param except_in_unlock: If True, raise an exception during unlock
+    :param unlock_error: If specified, an error to raise from unlock.
     :return: An instantiated DecoratorSample object.
     """
 
@@ -58,10 +62,11 @@
         def lock_write(self):
             self.actions.append('lock_write')
 
+        @decorators.only_raises(SampleUnlockError)
         def unlock(self):
-            if except_in_unlock:
+            if unlock_error:
                 self.actions.append('unlock_fail')
-                raise KeyError('during unlock')
+                raise unlock_error
             else:
                 self.actions.append('unlock')
 
@@ -119,28 +124,28 @@
 
     def test_read_lock_raises_original_error(self):
         sam = create_decorator_sample(self._decorator_style,
-                                      except_in_unlock=True)
+                                      unlock_error=SampleUnlockError())
         self.assertRaises(TypeError, sam.fail_during_read)
         self.assertEqual(['lock_read', 'fail_during_read', 'unlock_fail'],
                          sam.actions)
 
     def test_write_lock_raises_original_error(self):
         sam = create_decorator_sample(self._decorator_style,
-                                      except_in_unlock=True)
+                                      unlock_error=SampleUnlockError())
         self.assertRaises(TypeError, sam.fail_during_write)
         self.assertEqual(['lock_write', 'fail_during_write', 'unlock_fail'],
                          sam.actions)
 
     def test_read_lock_raises_unlock_error(self):
         sam = create_decorator_sample(self._decorator_style,
-                                      except_in_unlock=True)
-        self.assertRaises(KeyError, sam.frob)
+                                      unlock_error=SampleUnlockError())
+        self.assertRaises(SampleUnlockError, sam.frob)
         self.assertEqual(['lock_read', 'frob', 'unlock_fail'], sam.actions)
 
     def test_write_lock_raises_unlock_error(self):
         sam = create_decorator_sample(self._decorator_style,
-                                      except_in_unlock=True)
-        self.assertRaises(KeyError, sam.bank, 'bar', biz='bing')
+                                      unlock_error=SampleUnlockError())
+        self.assertRaises(SampleUnlockError, sam.bank, 'bar', biz='bing')
         self.assertEqual(['lock_write', ('bank', 'bar', 'bing'),
                           'unlock_fail'], sam.actions)
 
@@ -276,3 +281,21 @@
         finally:
             decorators.needs_read_lock = cur_read
             decorators.needs_write_lock = cur_write
+
+
+class TestOnlyRaisesDecorator(TestCase):
+
+    def raise_ZeroDivisionError(self):
+        1/0
+        
+    def test_raises_approved_error(self):
+        decorator = decorators.only_raises(ZeroDivisionError)
+        decorated_meth = decorator(self.raise_ZeroDivisionError)
+        self.assertRaises(ZeroDivisionError, decorated_meth)
+
+    def test_quietly_logs_unapproved_errors(self):
+        decorator = decorators.only_raises(IOError)
+        decorated_meth = decorator(self.raise_ZeroDivisionError)
+        self.assertLogsError(ZeroDivisionError, decorated_meth)
+        
+

=== modified file 'bzrlib/tests/test_diff.py'
--- bzrlib/tests/test_diff.py	2009-03-31 00:12:10 +0000
+++ bzrlib/tests/test_diff.py	2009-10-31 01:16:23 +0000
@@ -32,6 +32,7 @@
     external_diff,
     internal_diff,
     show_diff_trees,
+    get_trees_and_branches_to_diff,
     )
 from bzrlib.errors import BinaryFile, NoDiff, ExecutableMissing
 import bzrlib.osutils as osutils
@@ -41,6 +42,8 @@
 import bzrlib._patiencediff_py
 from bzrlib.tests import (Feature, TestCase, TestCaseWithTransport,
                           TestCaseInTempDir, TestSkipped)
+from bzrlib.revisiontree import RevisionTree
+from bzrlib.revisionspec import RevisionSpec
 
 
 class _AttribFeature(Feature):
@@ -1296,13 +1299,13 @@
     def test_from_string(self):
         diff_obj = DiffFromTool.from_string('diff', None, None, None)
         self.addCleanup(diff_obj.finish)
-        self.assertEqual(['diff', '%(old_path)s', '%(new_path)s'],
+        self.assertEqual(['diff', '@old_path', '@new_path'],
             diff_obj.command_template)
 
     def test_from_string_u5(self):
         diff_obj = DiffFromTool.from_string('diff -u\\ 5', None, None, None)
         self.addCleanup(diff_obj.finish)
-        self.assertEqual(['diff', '-u 5', '%(old_path)s', '%(new_path)s'],
+        self.assertEqual(['diff', '-u 5', '@old_path', '@new_path'],
                          diff_obj.command_template)
         self.assertEqual(['diff', '-u 5', 'old-path', 'new-path'],
                          diff_obj._get_command('old-path', 'new-path'))
@@ -1310,7 +1313,7 @@
     def test_execute(self):
         output = StringIO()
         diff_obj = DiffFromTool(['python', '-c',
-                                 'print "%(old_path)s %(new_path)s"'],
+                                 'print "@old_path @new_path"'],
                                 None, None, output)
         self.addCleanup(diff_obj.finish)
         diff_obj._execute('old', 'new')
@@ -1335,7 +1338,7 @@
         tree.lock_read()
         self.addCleanup(tree.unlock)
         diff_obj = DiffFromTool(['python', '-c',
-                                 'print "%(old_path)s %(new_path)s"'],
+                                 'print "@old_path @new_path"'],
                                 tree, tree, output)
         diff_obj._prepare_files('file-id', 'file', 'file')
         self.assertReadableByAttrib(diff_obj._root, 'old\\file', r'old\\file')
@@ -1367,7 +1370,7 @@
         tree.lock_read()
         self.addCleanup(tree.unlock)
         diff_obj = DiffFromTool(['python', '-c',
-                                 'print "%(old_path)s %(new_path)s"'],
+                                 'print "@old_path @new_path"'],
                                 old_tree, tree, output)
         self.addCleanup(diff_obj.finish)
         self.assertContainsRe(diff_obj._root, 'bzr-diff-[^/]*')
@@ -1382,3 +1385,46 @@
             self.assertTrue(os.path.samefile('tree/newname', new_path))
         # make sure we can create files with the same parent directories
         diff_obj._prepare_files('file2-id', 'oldname2', 'newname2')
+
+
+class TestGetTreesAndBranchesToDiff(TestCaseWithTransport):
+
+    def test_basic(self):
+        tree = self.make_branch_and_tree('tree')
+        (old_tree, new_tree,
+         old_branch, new_branch,
+         specific_files, extra_trees) = \
+            get_trees_and_branches_to_diff(['tree'], None, None, None)
+
+        self.assertIsInstance(old_tree, RevisionTree)
+        #print dir (old_tree)
+        self.assertEqual(_mod_revision.NULL_REVISION, old_tree.get_revision_id())
+        self.assertEqual(tree.basedir, new_tree.basedir)
+        self.assertEqual(tree.branch.base, old_branch.base)
+        self.assertEqual(tree.branch.base, new_branch.base)
+        self.assertIs(None, specific_files)
+        self.assertIs(None, extra_trees)
+
+    def test_with_rev_specs(self):
+        tree = self.make_branch_and_tree('tree')
+        self.build_tree_contents([('tree/file', 'oldcontent')])
+        tree.add('file', 'file-id')
+        tree.commit('old tree', timestamp=0, rev_id="old-id")
+        self.build_tree_contents([('tree/file', 'newcontent')])
+        tree.commit('new tree', timestamp=0, rev_id="new-id")
+
+        revisions = [RevisionSpec.from_string('1'),
+                     RevisionSpec.from_string('2')]
+        (old_tree, new_tree,
+         old_branch, new_branch,
+         specific_files, extra_trees) = \
+            get_trees_and_branches_to_diff(['tree'], revisions, None, None)
+
+        self.assertIsInstance(old_tree, RevisionTree)
+        self.assertEqual("old-id", old_tree.get_revision_id())
+        self.assertIsInstance(new_tree, RevisionTree)
+        self.assertEqual("new-id", new_tree.get_revision_id())
+        self.assertEqual(tree.branch.base, old_branch.base)
+        self.assertEqual(tree.branch.base, new_branch.base)
+        self.assertIs(None, specific_files)
+        self.assertEqual(tree.basedir, extra_trees[0].basedir)

=== modified file 'bzrlib/tests/test_directory_service.py'
--- bzrlib/tests/test_directory_service.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_directory_service.py	2009-11-10 04:58:31 +0000
@@ -16,18 +16,23 @@
 
 """Test directory service implementation"""
 
-from bzrlib import errors
+from bzrlib import (
+    errors,
+    urlutils,
+    )
 from bzrlib.directory_service import DirectoryServiceRegistry, directories
 from bzrlib.tests import TestCase, TestCaseWithTransport
 from bzrlib.transport import get_transport
-from bzrlib import urlutils
 
 
 class FooService(object):
     """A directory service that maps the name to a FILE url"""
 
+    # eg 'file:///foo' on Linux, or 'file:///C:/foo' on Windows
+    base = urlutils.local_path_to_url('/foo')
+
     def look_up(self, name, url):
-        return 'file:///foo' + name
+        return self.base + name
 
 
 class TestDirectoryLookup(TestCase):
@@ -43,14 +48,15 @@
         self.assertEqual('bar', suffix)
 
     def test_dereference(self):
-        self.assertEqual('file:///foobar',
+        self.assertEqual(FooService.base + 'bar',
                          self.registry.dereference('foo:bar'))
         self.assertEqual('baz:qux', self.registry.dereference('baz:qux'))
 
     def test_get_transport(self):
         directories.register('foo:', FooService, 'Map foo URLs to http urls')
         self.addCleanup(lambda: directories.remove('foo:'))
-        self.assertEqual('file:///foobar/', get_transport('foo:bar').base)
+        self.assertEqual(FooService.base + 'bar/',
+                         get_transport('foo:bar').base)
 
 
 class TestAliasDirectory(TestCaseWithTransport):

=== modified file 'bzrlib/tests/test_foreign.py'
--- bzrlib/tests/test_foreign.py	2009-08-17 07:54:34 +0000
+++ bzrlib/tests/test_foreign.py	2009-10-19 00:54:12 +0000
@@ -20,28 +20,15 @@
 
 from bzrlib import (
     branch,
+    bzrdir,
     errors,
     foreign,
     lockable_files,
     lockdir,
+    revision,
+    tests,
     trace,
     )
-from bzrlib.bzrdir import (
-    BzrDir,
-    BzrDirFormat,
-    BzrDirMeta1,
-    BzrDirMetaFormat1,
-    format_registry,
-    )
-from bzrlib.inventory import Inventory
-from bzrlib.revision import (
-    NULL_REVISION,
-    Revision,
-    )
-from bzrlib.tests import (
-    TestCase,
-    TestCaseWithTransport,
-    )
 
 # This is the dummy foreign revision control system, used 
 # mainly here in the testsuite to test the foreign VCS infrastructure.
@@ -87,10 +74,14 @@
         self.mapping_registry = DummyForeignVcsMappingRegistry()
         self.mapping_registry.register("v1", DummyForeignVcsMapping(self),
                                        "Version 1")
+        self.abbreviation = "dummy"
 
     def show_foreign_revid(self, foreign_revid):
         return { "dummy ding": "%s/%s\\%s" % foreign_revid }
 
+    def serialize_foreign_revid(self, foreign_revid):
+        return "%s|%s|%s" % foreign_revid
+
 
 class DummyForeignVcsBranch(branch.BzrBranch6,foreign.ForeignBranch):
     """A Dummy VCS Branch."""
@@ -136,7 +127,7 @@
                     (str(rev.timestamp), str(rev.timezone), 
                         str(self.target.revno())))
                 parent_revno, parent_revid= self.target.last_revision_info()
-                if parent_revid == NULL_REVISION:
+                if parent_revid == revision.NULL_REVISION:
                     parent_revids = []
                 else:
                     parent_revids = [parent_revid]
@@ -192,7 +183,7 @@
             raise errors.NotBranchError(path=transport.base)
 
 
-class DummyForeignVcsDirFormat(BzrDirMetaFormat1):
+class DummyForeignVcsDirFormat(bzrdir.BzrDirMetaFormat1):
     """BzrDirFormat for the dummy foreign VCS."""
 
     @classmethod
@@ -239,7 +230,7 @@
         return DummyForeignVcsDir(transport, self)
 
 
-class DummyForeignVcsDir(BzrDirMeta1):
+class DummyForeignVcsDir(bzrdir.BzrDirMeta1):
 
     def __init__(self, _transport, _format):
         self._format = _format
@@ -254,7 +245,7 @@
 
     def cloning_metadir(self, stacked=False):
         """Produce a metadir suitable for cloning with."""
-        return format_registry.make_bzrdir("default")
+        return bzrdir.format_registry.make_bzrdir("default")
 
     def sprout(self, url, revision_id=None, force_new_repo=False,
                recurse='down', possible_transports=None,
@@ -268,7 +259,18 @@
                 hardlink=hardlink, stacked=stacked, source_branch=source_branch)
 
 
-class ForeignVcsRegistryTests(TestCase):
+def register_dummy_foreign_for_test(testcase):
+    bzrdir.BzrDirFormat.register_control_format(DummyForeignVcsDirFormat)
+    testcase.addCleanup(bzrdir.BzrDirFormat.unregister_control_format,
+                        DummyForeignVcsDirFormat)
+    # We need to register the optimiser to make the dummy appears really
+    # different from a regular bzr repository.
+    branch.InterBranch.register_optimiser(InterToDummyVcsBranch)
+    testcase.addCleanup(branch.InterBranch.unregister_optimiser,
+                        InterToDummyVcsBranch)
+
+
+class ForeignVcsRegistryTests(tests.TestCase):
     """Tests for the ForeignVcsRegistry class."""
 
     def test_parse_revision_id_no_dash(self):
@@ -289,7 +291,7 @@
                           reg.parse_revision_id("dummy-v1:some-foreign-revid"))
 
 
-class ForeignRevisionTests(TestCase):
+class ForeignRevisionTests(tests.TestCase):
     """Tests for the ForeignRevision class."""
 
     def test_create(self):
@@ -301,7 +303,7 @@
         self.assertEquals(mapp, rev.mapping)
 
 
-class WorkingTreeFileUpdateTests(TestCaseWithTransport):
+class WorkingTreeFileUpdateTests(tests.TestCaseWithTransport):
     """Tests for update_workingtree_fileids()."""
 
     def test_update_workingtree(self):
@@ -325,26 +327,17 @@
             wt.unlock()
 
 
-class DummyForeignVcsTests(TestCaseWithTransport):
+class DummyForeignVcsTests(tests.TestCaseWithTransport):
     """Very basic test for DummyForeignVcs."""
 
     def setUp(self):
-        BzrDirFormat.register_control_format(DummyForeignVcsDirFormat)
-        branch.InterBranch.register_optimiser(InterToDummyVcsBranch)
-        self.addCleanup(self.unregister)
         super(DummyForeignVcsTests, self).setUp()
-
-    def unregister(self):
-        try:
-            BzrDirFormat.unregister_control_format(DummyForeignVcsDirFormat)
-        except ValueError:
-            pass
-        branch.InterBranch.unregister_optimiser(InterToDummyVcsBranch)
+        register_dummy_foreign_for_test(self)
 
     def test_create(self):
         """Test we can create dummies."""
         self.make_branch_and_tree("d", format=DummyForeignVcsDirFormat())
-        dir = BzrDir.open("d")
+        dir = bzrdir.BzrDir.open("d")
         self.assertEquals("A Dummy VCS Dir", dir._format.get_format_string())
         dir.open_repository()
         dir.open_branch()
@@ -353,17 +346,18 @@
     def test_sprout(self):
         """Test we can clone dummies and that the format is not preserved."""
         self.make_branch_and_tree("d", format=DummyForeignVcsDirFormat())
-        dir = BzrDir.open("d")
+        dir = bzrdir.BzrDir.open("d")
         newdir = dir.sprout("e")
-        self.assertNotEquals("A Dummy VCS Dir", newdir._format.get_format_string())
+        self.assertNotEquals("A Dummy VCS Dir",
+                             newdir._format.get_format_string())
 
     def test_lossy_push_empty(self):
         source_tree = self.make_branch_and_tree("source")
         target_tree = self.make_branch_and_tree("target", 
             format=DummyForeignVcsDirFormat())
         pushresult = source_tree.branch.lossy_push(target_tree.branch)
-        self.assertEquals(NULL_REVISION, pushresult.old_revid)
-        self.assertEquals(NULL_REVISION, pushresult.new_revid)
+        self.assertEquals(revision.NULL_REVISION, pushresult.old_revid)
+        self.assertEquals(revision.NULL_REVISION, pushresult.new_revid)
         self.assertEquals({}, pushresult.revidmap)
 
     def test_lossy_push_simple(self):
@@ -378,7 +372,7 @@
             pushresult = source_tree.branch.lossy_push(target_tree.branch)
         finally:
             target_tree.branch.unlock()
-        self.assertEquals(NULL_REVISION, pushresult.old_revid)
+        self.assertEquals(revision.NULL_REVISION, pushresult.old_revid)
         self.assertEquals({revid1:target_tree.branch.last_revision()}, 
                            pushresult.revidmap)
         self.assertEquals(pushresult.revidmap[revid1], pushresult.new_revid)

=== modified file 'bzrlib/tests/test_globbing.py'
--- bzrlib/tests/test_globbing.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_globbing.py	2009-11-11 21:38:02 +0000
@@ -18,6 +18,7 @@
 from bzrlib.globbing import (
     Globster,
     _OrderedGlobster,
+    normalize_pattern
     )
 from bzrlib.tests import (
     TestCase,
@@ -318,3 +319,30 @@
         globster = _OrderedGlobster(reversed(patterns))
         self.assertEqual(u'bar.*', globster.match('bar.foo'))
         self.assertEqual(None, globster.match('foo.bar'))
+
+
+class TestNormalizePattern(TestCase):
+
+    def test_backslashes(self):
+        """tests that backslashes are converted to forward slashes, multiple
+        backslashes are collapsed to single forward slashes and trailing
+        backslashes are removed"""
+        self.assertEqual(u'/', normalize_pattern(u'\\'))
+        self.assertEqual(u'/', normalize_pattern(u'\\\\'))
+        self.assertEqual(u'/foo/bar', normalize_pattern(u'\\foo\\bar'))
+        self.assertEqual(u'foo/bar', normalize_pattern(u'foo\\bar\\'))
+        self.assertEqual(u'/foo/bar', normalize_pattern(u'\\\\foo\\\\bar\\\\'))
+
+    def test_forward_slashes(self):
+        """tests that multiple foward slashes are collapsed to single forward
+        slashes and trailing forward slashes are removed"""
+        self.assertEqual(u'/', normalize_pattern(u'/'))
+        self.assertEqual(u'/', normalize_pattern(u'//'))
+        self.assertEqual(u'/foo/bar', normalize_pattern(u'/foo/bar'))
+        self.assertEqual(u'foo/bar', normalize_pattern(u'foo/bar/'))
+        self.assertEqual(u'/foo/bar', normalize_pattern(u'//foo//bar//'))
+
+    def test_mixed_slashes(self):
+        """tests that multiple mixed slashes are collapsed to single forward
+        slashes and trailing mixed slashes are removed"""
+        self.assertEqual(u'/foo/bar', normalize_pattern(u'\\/\\foo//\\///bar/\\\\/'))

=== modified file 'bzrlib/tests/test_graph.py'
--- bzrlib/tests/test_graph.py	2009-08-04 04:36:34 +0000
+++ bzrlib/tests/test_graph.py	2009-11-30 03:16:22 +0000
@@ -1582,6 +1582,24 @@
         self.assertCollapsed(d, d)
 
 
+class TestGraphThunkIdsToKeys(tests.TestCase):
+
+    def test_heads(self):
+        # A
+        # |\
+        # B C
+        # |/
+        # D
+        d = {('D',): [('B',), ('C',)], ('C',):[('A',)],
+             ('B',): [('A',)], ('A',): []}
+        g = _mod_graph.Graph(_mod_graph.DictParentsProvider(d))
+        graph_thunk = _mod_graph.GraphThunkIdsToKeys(g)
+        self.assertEqual(['D'], sorted(graph_thunk.heads(['D', 'A'])))
+        self.assertEqual(['D'], sorted(graph_thunk.heads(['D', 'B'])))
+        self.assertEqual(['D'], sorted(graph_thunk.heads(['D', 'C'])))
+        self.assertEqual(['B', 'C'], sorted(graph_thunk.heads(['B', 'C'])))
+
+
 class TestPendingAncestryResultGetKeys(TestCaseWithMemoryTransport):
     """Tests for bzrlib.graph.PendingAncestryResult."""
 

=== modified file 'bzrlib/tests/test_groupcompress.py'
--- bzrlib/tests/test_groupcompress.py	2009-06-29 14:51:13 +0000
+++ bzrlib/tests/test_groupcompress.py	2009-10-19 15:06:58 +0000
@@ -418,8 +418,12 @@
         # And the decompressor is finalized
         self.assertIs(None, block._z_content_decompressor)
 
-    def test_partial_decomp_no_known_length(self):
+    def test__ensure_all_content(self):
         content_chunks = []
+        # We need a sufficient amount of data so that zlib.decompress has
+        # partial decompression to work with. Most auto-generated data
+        # compresses a bit too well, we want a combination, so we combine a sha
+        # hash with compressible data.
         for i in xrange(2048):
             next_content = '%d\nThis is a bit of duplicate text\n' % (i,)
             content_chunks.append(next_content)
@@ -433,30 +437,13 @@
         block._z_content = z_content
         block._z_content_length = len(z_content)
         block._compressor_name = 'zlib'
-        block._content_length = None # Don't tell the decompressed length
+        block._content_length = 158634
         self.assertIs(None, block._content)
-        block._ensure_content(100)
-        self.assertIsNot(None, block._content)
-        # We have decompressed at least 100 bytes
-        self.assertTrue(len(block._content) >= 100)
-        # We have not decompressed the whole content
-        self.assertTrue(len(block._content) < 158634)
-        self.assertEqualDiff(content[:len(block._content)], block._content)
-        # ensuring content that we already have shouldn't cause any more data
-        # to be extracted
-        cur_len = len(block._content)
-        block._ensure_content(cur_len - 10)
-        self.assertEqual(cur_len, len(block._content))
-        # Now we want a bit more content
-        cur_len += 10
-        block._ensure_content(cur_len)
-        self.assertTrue(len(block._content) >= cur_len)
-        self.assertTrue(len(block._content) < 158634)
-        self.assertEqualDiff(content[:len(block._content)], block._content)
-        # And now lets finish
-        block._ensure_content()
+        # The first _ensure_content got all of the required data
+        block._ensure_content(158634)
         self.assertEqualDiff(content, block._content)
-        # And the decompressor is finalized
+        # And we should have released the _z_content_decompressor since it was
+        # fully consumed
         self.assertIs(None, block._z_content_decompressor)
 
     def test__dump(self):
@@ -472,7 +459,8 @@
                          ], block._dump())
 
 
-class TestCaseWithGroupCompressVersionedFiles(tests.TestCaseWithTransport):
+class TestCaseWithGroupCompressVersionedFiles(
+        tests.TestCaseWithMemoryTransport):
 
     def make_test_vf(self, create_graph, keylength=1, do_cleanup=True,
                      dir='.', inconsistency_fatal=True):
@@ -538,7 +526,7 @@
                     'as-requested', False)]
         self.assertEqual([('b',), ('a',), ('d',), ('c',)], keys)
 
-    def test_insert_record_stream_re_uses_blocks(self):
+    def test_insert_record_stream_reuses_blocks(self):
         vf = self.make_test_vf(True, dir='source')
         def grouped_stream(revision_ids, first_parents=()):
             parents = first_parents
@@ -582,8 +570,14 @@
         vf2 = self.make_test_vf(True, dir='target')
         # ordering in 'groupcompress' order, should actually swap the groups in
         # the target vf, but the groups themselves should not be disturbed.
-        vf2.insert_record_stream(vf.get_record_stream(
-            [(r,) for r in 'abcdefgh'], 'groupcompress', False))
+        def small_size_stream():
+            for record in vf.get_record_stream([(r,) for r in 'abcdefgh'],
+                                               'groupcompress', False):
+                record._manager._full_enough_block_size = \
+                    record._manager._block._content_length
+                yield record
+                        
+        vf2.insert_record_stream(small_size_stream())
         stream = vf2.get_record_stream([(r,) for r in 'abcdefgh'],
                                        'groupcompress', False)
         vf2.writer.end()
@@ -594,6 +588,44 @@
                              record._manager._block._z_content)
         self.assertEqual(8, num_records)
 
+    def test_insert_record_stream_packs_on_the_fly(self):
+        vf = self.make_test_vf(True, dir='source')
+        def grouped_stream(revision_ids, first_parents=()):
+            parents = first_parents
+            for revision_id in revision_ids:
+                key = (revision_id,)
+                record = versionedfile.FulltextContentFactory(
+                    key, parents, None,
+                    'some content that is\n'
+                    'identical except for\n'
+                    'revision_id:%s\n' % (revision_id,))
+                yield record
+                parents = (key,)
+        # One group, a-d
+        vf.insert_record_stream(grouped_stream(['a', 'b', 'c', 'd']))
+        # Second group, e-h
+        vf.insert_record_stream(grouped_stream(['e', 'f', 'g', 'h'],
+                                               first_parents=(('d',),)))
+        # Now copy the blocks into another vf, and see that the
+        # insert_record_stream rebuilt a new block on-the-fly because of
+        # under-utilization
+        vf2 = self.make_test_vf(True, dir='target')
+        vf2.insert_record_stream(vf.get_record_stream(
+            [(r,) for r in 'abcdefgh'], 'groupcompress', False))
+        stream = vf2.get_record_stream([(r,) for r in 'abcdefgh'],
+                                       'groupcompress', False)
+        vf2.writer.end()
+        num_records = 0
+        # All of the records should be recombined into a single block
+        block = None
+        for record in stream:
+            num_records += 1
+            if block is None:
+                block = record._manager._block
+            else:
+                self.assertIs(block, record._manager._block)
+        self.assertEqual(8, num_records)
+
     def test__insert_record_stream_no_reuse_block(self):
         vf = self.make_test_vf(True, dir='source')
         def grouped_stream(revision_ids, first_parents=()):
@@ -701,20 +733,140 @@
                               " \('b',\) \('42 32 0 8', \(\(\),\)\) \('74 32"
                               " 0 8', \(\(\('a',\),\),\)\)")
 
+    def test_clear_cache(self):
+        vf = self.make_source_with_b(True, 'source')
+        vf.writer.end()
+        for record in vf.get_record_stream([('a',), ('b',)], 'unordered',
+                                           True):
+            pass
+        self.assertTrue(len(vf._group_cache) > 0)
+        vf.clear_cache()
+        self.assertEqual(0, len(vf._group_cache))
+
+
+
+class StubGCVF(object):
+    def __init__(self, canned_get_blocks=None):
+        self._group_cache = {}
+        self._canned_get_blocks = canned_get_blocks or []
+    def _get_blocks(self, read_memos):
+        return iter(self._canned_get_blocks)
+    
+
+class Test_BatchingBlockFetcher(TestCaseWithGroupCompressVersionedFiles):
+    """Simple whitebox unit tests for _BatchingBlockFetcher."""
+    
+    def test_add_key_new_read_memo(self):
+        """Adding a key with an uncached read_memo new to this batch adds that
+        read_memo to the list of memos to fetch.
+        """
+        # locations are: index_memo, ignored, parents, ignored
+        # where index_memo is: (idx, offset, len, factory_start, factory_end)
+        # and (idx, offset, size) is known as the 'read_memo', identifying the
+        # raw bytes needed.
+        read_memo = ('fake index', 100, 50)
+        locations = {
+            ('key',): (read_memo + (None, None), None, None, None)}
+        batcher = groupcompress._BatchingBlockFetcher(StubGCVF(), locations)
+        total_size = batcher.add_key(('key',))
+        self.assertEqual(50, total_size)
+        self.assertEqual([('key',)], batcher.keys)
+        self.assertEqual([read_memo], batcher.memos_to_get)
+
+    def test_add_key_duplicate_read_memo(self):
+        """read_memos that occur multiple times in a batch will only be fetched
+        once.
+        """
+        read_memo = ('fake index', 100, 50)
+        # Two keys, both sharing the same read memo (but different overall
+        # index_memos).
+        locations = {
+            ('key1',): (read_memo + (0, 1), None, None, None),
+            ('key2',): (read_memo + (1, 2), None, None, None)}
+        batcher = groupcompress._BatchingBlockFetcher(StubGCVF(), locations)
+        total_size = batcher.add_key(('key1',))
+        total_size = batcher.add_key(('key2',))
+        self.assertEqual(50, total_size)
+        self.assertEqual([('key1',), ('key2',)], batcher.keys)
+        self.assertEqual([read_memo], batcher.memos_to_get)
+
+    def test_add_key_cached_read_memo(self):
+        """Adding a key with a cached read_memo will not cause that read_memo
+        to be added to the list to fetch.
+        """
+        read_memo = ('fake index', 100, 50)
+        gcvf = StubGCVF()
+        gcvf._group_cache[read_memo] = 'fake block'
+        locations = {
+            ('key',): (read_memo + (None, None), None, None, None)}
+        batcher = groupcompress._BatchingBlockFetcher(gcvf, locations)
+        total_size = batcher.add_key(('key',))
+        self.assertEqual(0, total_size)
+        self.assertEqual([('key',)], batcher.keys)
+        self.assertEqual([], batcher.memos_to_get)
+
+    def test_yield_factories_empty(self):
+        """An empty batch yields no factories."""
+        batcher = groupcompress._BatchingBlockFetcher(StubGCVF(), {})
+        self.assertEqual([], list(batcher.yield_factories()))
+
+    def test_yield_factories_calls_get_blocks(self):
+        """Uncached memos are retrieved via get_blocks."""
+        read_memo1 = ('fake index', 100, 50)
+        read_memo2 = ('fake index', 150, 40)
+        gcvf = StubGCVF(
+            canned_get_blocks=[
+                (read_memo1, groupcompress.GroupCompressBlock()),
+                (read_memo2, groupcompress.GroupCompressBlock())])
+        locations = {
+            ('key1',): (read_memo1 + (None, None), None, None, None),
+            ('key2',): (read_memo2 + (None, None), None, None, None)}
+        batcher = groupcompress._BatchingBlockFetcher(gcvf, locations)
+        batcher.add_key(('key1',))
+        batcher.add_key(('key2',))
+        factories = list(batcher.yield_factories(full_flush=True))
+        self.assertLength(2, factories)
+        keys = [f.key for f in factories]
+        kinds = [f.storage_kind for f in factories]
+        self.assertEqual([('key1',), ('key2',)], keys)
+        self.assertEqual(['groupcompress-block', 'groupcompress-block'], kinds)
+
+    def test_yield_factories_flushing(self):
+        """yield_factories holds back on yielding results from the final block
+        unless passed full_flush=True.
+        """
+        fake_block = groupcompress.GroupCompressBlock()
+        read_memo = ('fake index', 100, 50)
+        gcvf = StubGCVF()
+        gcvf._group_cache[read_memo] = fake_block
+        locations = {
+            ('key',): (read_memo + (None, None), None, None, None)}
+        batcher = groupcompress._BatchingBlockFetcher(gcvf, locations)
+        batcher.add_key(('key',))
+        self.assertEqual([], list(batcher.yield_factories()))
+        factories = list(batcher.yield_factories(full_flush=True))
+        self.assertLength(1, factories)
+        self.assertEqual(('key',), factories[0].key)
+        self.assertEqual('groupcompress-block', factories[0].storage_kind)
+
 
 class TestLazyGroupCompress(tests.TestCaseWithTransport):
 
     _texts = {
         ('key1',): "this is a text\n"
-                   "with a reasonable amount of compressible bytes\n",
+                   "with a reasonable amount of compressible bytes\n"
+                   "which can be shared between various other texts\n",
         ('key2',): "another text\n"
-                   "with a reasonable amount of compressible bytes\n",
+                   "with a reasonable amount of compressible bytes\n"
+                   "which can be shared between various other texts\n",
         ('key3',): "yet another text which won't be extracted\n"
-                   "with a reasonable amount of compressible bytes\n",
+                   "with a reasonable amount of compressible bytes\n"
+                   "which can be shared between various other texts\n",
         ('key4',): "this will be extracted\n"
                    "but references most of its bytes from\n"
                    "yet another text which won't be extracted\n"
-                   "with a reasonable amount of compressible bytes\n",
+                   "with a reasonable amount of compressible bytes\n"
+                   "which can be shared between various other texts\n",
     }
     def make_block(self, key_to_text):
         """Create a GroupCompressBlock, filling it with the given texts."""
@@ -732,6 +884,13 @@
         start, end = locations[key]
         manager.add_factory(key, (), start, end)
 
+    def make_block_and_full_manager(self, texts):
+        locations, block = self.make_block(texts)
+        manager = groupcompress._LazyGroupContentManager(block)
+        for key in sorted(texts):
+            self.add_key_to_manager(key, locations, block, manager)
+        return block, manager
+
     def test_get_fulltexts(self):
         locations, block = self.make_block(self._texts)
         manager = groupcompress._LazyGroupContentManager(block)
@@ -788,8 +947,8 @@
         header_len = int(header_len)
         block_len = int(block_len)
         self.assertEqual('groupcompress-block', storage_kind)
-        self.assertEqual(33, z_header_len)
-        self.assertEqual(25, header_len)
+        self.assertEqual(34, z_header_len)
+        self.assertEqual(26, header_len)
         self.assertEqual(len(block_bytes), block_len)
         z_header = rest[:z_header_len]
         header = zlib.decompress(z_header)
@@ -829,13 +988,7 @@
         self.assertEqual([('key1',), ('key4',)], result_order)
 
     def test__check_rebuild_no_changes(self):
-        locations, block = self.make_block(self._texts)
-        manager = groupcompress._LazyGroupContentManager(block)
-        # Request all the keys, which ensures that we won't rebuild
-        self.add_key_to_manager(('key1',), locations, block, manager)
-        self.add_key_to_manager(('key2',), locations, block, manager)
-        self.add_key_to_manager(('key3',), locations, block, manager)
-        self.add_key_to_manager(('key4',), locations, block, manager)
+        block, manager = self.make_block_and_full_manager(self._texts)
         manager._check_rebuild_block()
         self.assertIs(block, manager._block)
 
@@ -866,3 +1019,50 @@
             self.assertEqual(('key4',), record.key)
             self.assertEqual(self._texts[record.key],
                              record.get_bytes_as('fulltext'))
+
+    def test_check_is_well_utilized_all_keys(self):
+        block, manager = self.make_block_and_full_manager(self._texts)
+        self.assertFalse(manager.check_is_well_utilized())
+        # Though we can fake it by changing the recommended minimum size
+        manager._full_enough_block_size = block._content_length
+        self.assertTrue(manager.check_is_well_utilized())
+        # Setting it just above causes it to fail
+        manager._full_enough_block_size = block._content_length + 1
+        self.assertFalse(manager.check_is_well_utilized())
+        # Setting the mixed-block size doesn't do anything, because the content
+        # is considered to not be 'mixed'
+        manager._full_enough_mixed_block_size = block._content_length
+        self.assertFalse(manager.check_is_well_utilized())
+
+    def test_check_is_well_utilized_mixed_keys(self):
+        texts = {}
+        f1k1 = ('f1', 'k1')
+        f1k2 = ('f1', 'k2')
+        f2k1 = ('f2', 'k1')
+        f2k2 = ('f2', 'k2')
+        texts[f1k1] = self._texts[('key1',)]
+        texts[f1k2] = self._texts[('key2',)]
+        texts[f2k1] = self._texts[('key3',)]
+        texts[f2k2] = self._texts[('key4',)]
+        block, manager = self.make_block_and_full_manager(texts)
+        self.assertFalse(manager.check_is_well_utilized())
+        manager._full_enough_block_size = block._content_length
+        self.assertTrue(manager.check_is_well_utilized())
+        manager._full_enough_block_size = block._content_length + 1
+        self.assertFalse(manager.check_is_well_utilized())
+        manager._full_enough_mixed_block_size = block._content_length
+        self.assertTrue(manager.check_is_well_utilized())
+
+    def test_check_is_well_utilized_partial_use(self):
+        locations, block = self.make_block(self._texts)
+        manager = groupcompress._LazyGroupContentManager(block)
+        manager._full_enough_block_size = block._content_length
+        self.add_key_to_manager(('key1',), locations, block, manager)
+        self.add_key_to_manager(('key2',), locations, block, manager)
+        # Just using the content from key1 and 2 is not enough to be considered
+        # 'complete'
+        self.assertFalse(manager.check_is_well_utilized())
+        # However if we add key3, then we have enough, as we only require 75%
+        # consumption
+        self.add_key_to_manager(('key4',), locations, block, manager)
+        self.assertTrue(manager.check_is_well_utilized())

=== modified file 'bzrlib/tests/test_hooks.py'
--- bzrlib/tests/test_hooks.py	2009-04-06 22:31:35 +0000
+++ bzrlib/tests/test_hooks.py	2009-11-03 09:32:17 +0000
@@ -16,7 +16,11 @@
 
 """Tests for the core Hooks logic."""
 
-from bzrlib import branch, errors
+from bzrlib import (
+    branch,
+    errors,
+    tests,
+    )
 from bzrlib.hooks import (
     HookPoint,
     Hooks,
@@ -24,14 +28,9 @@
     known_hooks_key_to_object,
     known_hooks_key_to_parent_and_attribute,
     )
-from bzrlib.errors import (
-    UnknownHook,
-    )
-
-from bzrlib.tests import TestCase
-
-
-class TestHooks(TestCase):
+
+
+class TestHooks(tests.TestCase):
 
     def test_create_hook_first(self):
         hooks = Hooks()
@@ -80,7 +79,6 @@
             "~~~~~~~~~~~~~~~\n"
             "\n"
             "Introduced in: 1.4\n"
-            "Deprecated in: Not deprecated\n"
             "\n"
             "Invoked after the tip of a branch changes. Called with a\n"
             "ChangeBranchTipParams object.\n"
@@ -89,7 +87,6 @@
             "~~~~~~~~~~~~~~\n"
             "\n"
             "Introduced in: 1.6\n"
-            "Deprecated in: Not deprecated\n"
             "\n"
             "Invoked before the tip of a branch changes. Called with a\n"
             "ChangeBranchTipParams object. Hooks should raise TipChangeRejected to\n"
@@ -97,7 +94,7 @@
 
     def test_install_named_hook_raises_unknown_hook(self):
         hooks = Hooks()
-        self.assertRaises(UnknownHook, hooks.install_named_hook, 'silly',
+        self.assertRaises(errors.UnknownHook, hooks.install_named_hook, 'silly',
                           None, "")
 
     def test_install_named_hook_appends_known_hook(self):
@@ -113,7 +110,7 @@
         self.assertEqual("demo", hooks.get_hook_name(None))
 
 
-class TestHook(TestCase):
+class TestHook(tests.TestCase):
 
     def test___init__(self):
         doc = ("Invoked after changing the tip of a branch object. Called with"
@@ -133,7 +130,6 @@
             "~~~~~~~~~~~~~~~\n"
             "\n"
             "Introduced in: 0.15\n"
-            "Deprecated in: Not deprecated\n"
             "\n"
             "Invoked after changing the tip of a branch object. Called with a\n"
             "bzrlib.branch.PostChangeBranchTipParams object\n", hook.docs())
@@ -157,7 +153,7 @@
             callback_repr, repr(hook))
 
 
-class TestHookRegistry(TestCase):
+class TestHookRegistry(tests.TestCase):
 
     def test_items_are_reasonable_keys(self):
         # All the items in the known_hooks registry need to map from
@@ -173,6 +169,7 @@
             new_hooks = factory()
             self.assertIsInstance(obj, Hooks)
             self.assertEqual(type(obj), type(new_hooks))
+            self.assertEqual("No hook name", new_hooks.get_hook_name(None))
 
     def test_known_hooks_key_to_object(self):
         self.assertIs(branch.Branch.hooks,

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2009-08-19 16:33:39 +0000
+++ bzrlib/tests/test_http.py	2009-11-18 16:02:53 +0000
@@ -204,7 +204,7 @@
     It records the bytes sent to it, and replies with a 200.
     """
 
-    def __init__(self, expect_body_tail=None):
+    def __init__(self, expect_body_tail=None, scheme=''):
         """Constructor.
 
         :type expect_body_tail: str
@@ -215,6 +215,10 @@
         self.host = None
         self.port = None
         self.received_bytes = ''
+        self.scheme = scheme
+
+    def get_url(self):
+        return '%s://%s:%s/' % (self.scheme, self.host, self.port)
 
     def setUp(self):
         self._sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
@@ -304,7 +308,7 @@
 
         server = http_server.HttpServer(BogusRequestHandler)
         try:
-            self.assertRaises(httplib.UnknownProtocol,server.setUp)
+            self.assertRaises(httplib.UnknownProtocol, server.setUp)
         except:
             server.tearDown()
             self.fail('HTTP Server creation did not raise UnknownProtocol')
@@ -312,7 +316,7 @@
     def test_force_invalid_protocol(self):
         server = http_server.HttpServer(protocol_version='HTTP/0.1')
         try:
-            self.assertRaises(httplib.UnknownProtocol,server.setUp)
+            self.assertRaises(httplib.UnknownProtocol, server.setUp)
         except:
             server.tearDown()
             self.fail('HTTP Server creation did not raise UnknownProtocol')
@@ -320,8 +324,10 @@
     def test_server_start_and_stop(self):
         server = http_server.HttpServer()
         server.setUp()
-        self.assertTrue(server._http_running)
-        server.tearDown()
+        try:
+            self.assertTrue(server._http_running)
+        finally:
+            server.tearDown()
         self.assertFalse(server._http_running)
 
     def test_create_http_server_one_zero(self):
@@ -330,8 +336,7 @@
             protocol_version = 'HTTP/1.0'
 
         server = http_server.HttpServer(RequestHandlerOneZero)
-        server.setUp()
-        self.addCleanup(server.tearDown)
+        self.start_server(server)
         self.assertIsInstance(server._httpd, http_server.TestingHTTPServer)
 
     def test_create_http_server_one_one(self):
@@ -340,8 +345,7 @@
             protocol_version = 'HTTP/1.1'
 
         server = http_server.HttpServer(RequestHandlerOneOne)
-        server.setUp()
-        self.addCleanup(server.tearDown)
+        self.start_server(server)
         self.assertIsInstance(server._httpd,
                               http_server.TestingThreadingHTTPServer)
 
@@ -352,8 +356,7 @@
 
         server = http_server.HttpServer(RequestHandlerOneZero,
                                         protocol_version='HTTP/1.1')
-        server.setUp()
-        self.addCleanup(server.tearDown)
+        self.start_server(server)
         self.assertIsInstance(server._httpd,
                               http_server.TestingThreadingHTTPServer)
 
@@ -364,8 +367,7 @@
 
         server = http_server.HttpServer(RequestHandlerOneOne,
                                         protocol_version='HTTP/1.0')
-        server.setUp()
-        self.addCleanup(server.tearDown)
+        self.start_server(server)
         self.assertIsInstance(server._httpd,
                               http_server.TestingHTTPServer)
 
@@ -431,8 +433,8 @@
     def test_http_impl_urls(self):
         """There are servers which ask for particular clients to connect"""
         server = self._server()
+        server.setUp()
         try:
-            server.setUp()
             url = server.get_url()
             self.assertTrue(url.startswith('%s://' % self._qualified_prefix))
         finally:
@@ -543,11 +545,10 @@
 class TestPost(tests.TestCase):
 
     def test_post_body_is_received(self):
-        server = RecordingServer(expect_body_tail='end-of-body')
-        server.setUp()
-        self.addCleanup(server.tearDown)
-        scheme = self._qualified_prefix
-        url = '%s://%s:%s/' % (scheme, server.host, server.port)
+        server = RecordingServer(expect_body_tail='end-of-body',
+            scheme=self._qualified_prefix)
+        self.start_server(server)
+        url = server.get_url()
         http_transport = self._transport(url)
         code, response = http_transport._post('abc def end-of-body')
         self.assertTrue(
@@ -779,9 +780,8 @@
         self.assertEqual(None, server.port)
 
     def test_send_receive_bytes(self):
-        server = RecordingServer(expect_body_tail='c')
-        server.setUp()
-        self.addCleanup(server.tearDown)
+        server = RecordingServer(expect_body_tail='c', scheme='http')
+        self.start_server(server)
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         sock.connect((server.host, server.port))
         sock.sendall('abc')
@@ -1178,7 +1178,7 @@
         if self._testing_pycurl():
             # Oh my ! pycurl does not check for the port as part of
             # no_proxy :-( So we just test the host part
-            self.no_proxy_host = 'localhost'
+            self.no_proxy_host = self.server.host
         else:
             self.no_proxy_host = self.proxy_address
         # The secondary server is the proxy
@@ -1956,7 +1956,7 @@
         pass
 
 
-class TestActivity(tests.TestCase):
+class TestActivityMixin(object):
     """Test socket activity reporting.
 
     We use a special purpose server to control the bytes sent and received and
@@ -2100,3 +2100,57 @@
         code, f = t._post('abc def end-of-body\n')
         self.assertEqual('lalala whatever as long as itsssss\n', f.read())
         self.assertActivitiesMatch()
+
+
+class TestActivity(tests.TestCase, TestActivityMixin):
+
+    def setUp(self):
+        tests.TestCase.setUp(self)
+        self.server = self._activity_server(self._protocol_version)
+        self.server.setUp()
+        self.activities = {}
+        def report_activity(t, bytes, direction):
+            count = self.activities.get(direction, 0)
+            count += bytes
+            self.activities[direction] = count
+
+        # We override at class level because constructors may propagate the
+        # bound method and render instance overriding ineffective (an
+        # alternative would be to define a specific ui factory instead...)
+        self.orig_report_activity = self._transport._report_activity
+        self._transport._report_activity = report_activity
+
+    def tearDown(self):
+        self._transport._report_activity = self.orig_report_activity
+        self.server.tearDown()
+        tests.TestCase.tearDown(self)
+
+
+class TestNoReportActivity(tests.TestCase, TestActivityMixin):
+
+    def setUp(self):
+        tests.TestCase.setUp(self)
+        # Unlike TestActivity, we are really testing ReportingFileSocket and
+        # ReportingSocket, so we don't need all the parametrization. Since
+        # ReportingFileSocket and ReportingSocket are wrappers, it's easier to
+        # test them through their use by the transport than directly (that's a
+        # bit less clean but far more simpler and effective).
+        self.server = ActivityHTTPServer('HTTP/1.1')
+        self._transport=_urllib.HttpTransport_urllib
+
+        self.server.setUp()
+
+        # We override at class level because constructors may propagate the
+        # bound method and render instance overriding ineffective (an
+        # alternative would be to define a specific ui factory instead...)
+        self.orig_report_activity = self._transport._report_activity
+        self._transport._report_activity = None
+
+    def tearDown(self):
+        self._transport._report_activity = self.orig_report_activity
+        self.server.tearDown()
+        tests.TestCase.tearDown(self)
+
+    def assertActivitiesMatch(self):
+        # Nothing to check here
+        pass

=== modified file 'bzrlib/tests/test_index.py'
--- bzrlib/tests/test_index.py	2009-08-13 19:56:26 +0000
+++ bzrlib/tests/test_index.py	2009-11-07 01:58:11 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -173,6 +173,11 @@
             "key\x00\x00\t\x00data\n"
             "\n", contents)
 
+    def test_clear_cache(self):
+        builder = GraphIndexBuilder(reference_lists=2)
+        # This is a no-op, but the api should exist
+        builder.clear_cache()
+
     def test_node_references_are_byte_offsets(self):
         builder = GraphIndexBuilder(reference_lists=1)
         builder.add_node(('reference', ), 'data', ([], ))
@@ -230,7 +235,7 @@
         builder.add_node(('2-key', ), '', (references, ))
         stream = builder.finish()
         contents = stream.read()
-        self.assertEqual(
+        self.assertEqualDiff(
             "Bazaar Graph Index 1\nnode_ref_lists=1\nkey_elements=1\nlen=1\n"
             "0\x00a\x00\x00\n"
             "1\x00a\x00\x00\n"
@@ -383,6 +388,12 @@
         size = trans.put_file('index', stream)
         return GraphIndex(trans, 'index', size)
 
+    def test_clear_cache(self):
+        index = self.make_index()
+        # For now, we just want to make sure the api is available. As this is
+        # old code, we don't really worry if it *does* anything.
+        index.clear_cache()
+
     def test_open_bad_index_no_error(self):
         trans = self.get_transport()
         trans.put_bytes('name', "not an index\n")
@@ -1006,6 +1017,15 @@
         self.assertEqual(set(), missing_keys)
         self.assertEqual(set(), search_keys)
 
+    def test_supports_unlimited_cache(self):
+        builder = GraphIndexBuilder(0, key_elements=1)
+        stream = builder.finish()
+        trans = get_transport(self.get_url())
+        size = trans.put_file('index', stream)
+        # It doesn't matter what unlimited_cache does here, just that it can be
+        # passed
+        index = GraphIndex(trans, 'index', size, unlimited_cache=True)
+
 
 class TestCombinedGraphIndex(TestCaseWithMemoryTransport):
 
@@ -1062,6 +1082,30 @@
         index.insert_index(0, index1)
         self.assertEqual([(index1, ('key', ), '')], list(index.iter_all_entries()))
 
+    def test_clear_cache(self):
+        log = []
+
+        class ClearCacheProxy(object):
+
+            def __init__(self, index):
+                self._index = index
+
+            def __getattr__(self, name):
+                return getattr(self._index)
+
+            def clear_cache(self):
+                log.append(self._index)
+                return self._index.clear_cache()
+
+        index = CombinedGraphIndex([])
+        index1 = self.make_index('name', 0, nodes=[(('key', ), '', ())])
+        index.insert_index(0, ClearCacheProxy(index1))
+        index2 = self.make_index('name', 0, nodes=[(('key', ), '', ())])
+        index.insert_index(1, ClearCacheProxy(index2))
+        # CombinedGraphIndex should call 'clear_cache()' on all children
+        index.clear_cache()
+        self.assertEqual(sorted([index1, index2]), sorted(log))
+
     def test_iter_all_entries_empty(self):
         index = CombinedGraphIndex([])
         self.assertEqual([], list(index.iter_all_entries()))

=== modified file 'bzrlib/tests/test_inv.py'
--- bzrlib/tests/test_inv.py	2009-07-20 05:19:53 +0000
+++ bzrlib/tests/test_inv.py	2009-09-24 19:26:45 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,12 +17,14 @@
 
 from bzrlib import (
     chk_map,
+    groupcompress,
     bzrdir,
     errors,
     inventory,
     osutils,
     repository,
     revision,
+    tests,
     )
 from bzrlib.inventory import (CHKInventory, Inventory, ROOT_ID, InventoryFile,
     InventoryDirectory, InventoryEntry, TreeReference)
@@ -65,6 +67,14 @@
     return multiply_tests(to_adapt, scenarios, result)
 
 
+def create_texts_for_inv(repo, inv):
+    for path, ie in inv.iter_entries():
+        if ie.text_size:
+            lines = ['a' * ie.text_size]
+        else:
+            lines = []
+        repo.texts.add_lines((ie.file_id, ie.revision), [], lines)
+    
 def apply_inventory_Inventory(self, basis, delta):
     """Apply delta to basis and return the result.
     
@@ -137,6 +147,7 @@
             rev = revision.Revision('basis', timestamp=0, timezone=None,
                 message="", committer="foo@example.com")
             basis.revision_id = 'basis'
+            create_texts_for_inv(tree.branch.repository, basis)
             repo.add_revision('basis', rev, basis)
             # Add a revision for the result, with the basis content - 
             # update_basis_by_delta doesn't check that the delta results in
@@ -146,11 +157,10 @@
                 message="", committer="foo@example.com")
             basis.revision_id = 'result'
             repo.add_revision('result', rev, basis)
+            repo.commit_write_group()
         except:
             repo.abort_write_group()
             raise
-        else:
-            repo.commit_write_group()
         # Set the basis state as the trees current state
         tree._write_inventory(basis)
         # This reads basis from the repo and puts it into the tree's local
@@ -221,12 +231,12 @@
             rev = revision.Revision('basis', timestamp=0, timezone=None,
                 message="", committer="foo@example.com")
             basis.revision_id = 'basis'
+            create_texts_for_inv(repo, basis)
             repo.add_revision('basis', rev, basis)
+            repo.commit_write_group()
         except:
             repo.abort_write_group()
             raise
-        else:
-            repo.commit_write_group()
     finally:
         repo.unlock()
     repo.lock_write()
@@ -249,6 +259,76 @@
     return repo.get_inventory('result')
 
 
+class TestInventoryUpdates(TestCase):
+
+    def test_creation_from_root_id(self):
+        # iff a root id is passed to the constructor, a root directory is made
+        inv = inventory.Inventory(root_id='tree-root')
+        self.assertNotEqual(None, inv.root)
+        self.assertEqual('tree-root', inv.root.file_id)
+
+    def test_add_path_of_root(self):
+        # if no root id is given at creation time, there is no root directory
+        inv = inventory.Inventory(root_id=None)
+        self.assertIs(None, inv.root)
+        # add a root entry by adding its path
+        ie = inv.add_path("", "directory", "my-root")
+        ie.revision = 'test-rev'
+        self.assertEqual("my-root", ie.file_id)
+        self.assertIs(ie, inv.root)
+
+    def test_add_path(self):
+        inv = inventory.Inventory(root_id='tree_root')
+        ie = inv.add_path('hello', 'file', 'hello-id')
+        self.assertEqual('hello-id', ie.file_id)
+        self.assertEqual('file', ie.kind)
+
+    def test_copy(self):
+        """Make sure copy() works and creates a deep copy."""
+        inv = inventory.Inventory(root_id='some-tree-root')
+        ie = inv.add_path('hello', 'file', 'hello-id')
+        inv2 = inv.copy()
+        inv.root.file_id = 'some-new-root'
+        ie.name = 'file2'
+        self.assertEqual('some-tree-root', inv2.root.file_id)
+        self.assertEqual('hello', inv2['hello-id'].name)
+
+    def test_copy_empty(self):
+        """Make sure an empty inventory can be copied."""
+        inv = inventory.Inventory(root_id=None)
+        inv2 = inv.copy()
+        self.assertIs(None, inv2.root)
+
+    def test_copy_copies_root_revision(self):
+        """Make sure the revision of the root gets copied."""
+        inv = inventory.Inventory(root_id='someroot')
+        inv.root.revision = 'therev'
+        inv2 = inv.copy()
+        self.assertEquals('someroot', inv2.root.file_id)
+        self.assertEquals('therev', inv2.root.revision)
+
+    def test_create_tree_reference(self):
+        inv = inventory.Inventory('tree-root-123')
+        inv.add(TreeReference('nested-id', 'nested', parent_id='tree-root-123',
+                              revision='rev', reference_revision='rev2'))
+
+    def test_error_encoding(self):
+        inv = inventory.Inventory('tree-root')
+        inv.add(InventoryFile('a-id', u'\u1234', 'tree-root'))
+        e = self.assertRaises(errors.InconsistentDelta, inv.add,
+            InventoryFile('b-id', u'\u1234', 'tree-root'))
+        self.assertContainsRe(str(e), r'\\u1234')
+
+    def test_add_recursive(self):
+        parent = InventoryDirectory('src-id', 'src', 'tree-root')
+        child = InventoryFile('hello-id', 'hello.c', 'src-id')
+        parent.children[child.file_id] = child
+        inv = inventory.Inventory('tree-root')
+        inv.add(parent)
+        self.assertEqual('src/hello.c', inv.id2path('hello-id'))
+
+
+
 class TestDeltaApplication(TestCaseWithTransport):
  
     def get_empty_inventory(self, reference_inv=None):
@@ -495,6 +575,22 @@
             inv, delta)
 
 
+class TestInventory(TestCase):
+
+    def test_is_root(self):
+        """Ensure our root-checking code is accurate."""
+        inv = inventory.Inventory('TREE_ROOT')
+        self.assertTrue(inv.is_root('TREE_ROOT'))
+        self.assertFalse(inv.is_root('booga'))
+        inv.root.file_id = 'booga'
+        self.assertFalse(inv.is_root('TREE_ROOT'))
+        self.assertTrue(inv.is_root('booga'))
+        # works properly even if no root is set
+        inv.root = None
+        self.assertFalse(inv.is_root('TREE_ROOT'))
+        self.assertFalse(inv.is_root('booga'))
+
+
 class TestInventoryEntry(TestCase):
 
     def test_file_kind_character(self):
@@ -642,17 +738,12 @@
         self.assertEqual(expected_change, change)
 
 
-class TestCHKInventory(TestCaseWithTransport):
+class TestCHKInventory(tests.TestCaseWithMemoryTransport):
 
     def get_chk_bytes(self):
-        # The easiest way to get a CHK store is a development6 repository and
-        # then work with the chk_bytes attribute directly.
-        repo = self.make_repository(".", format="development6-rich-root")
-        repo.lock_write()
-        self.addCleanup(repo.unlock)
-        repo.start_write_group()
-        self.addCleanup(repo.abort_write_group)
-        return repo.chk_bytes
+        factory = groupcompress.make_pack_factory(True, True, 1)
+        trans = self.get_transport('')
+        return factory(trans)
 
     def read_bytes(self, chk_bytes, key):
         stream = chk_bytes.get_record_stream([key], 'unordered', True)
@@ -1123,3 +1214,135 @@
         self.assertIsInstance(ie2.name, unicode)
         self.assertEqual(('tree\xce\xa9name', 'tree-root-id', 'tree-rev-id'),
                          inv._bytes_to_utf8name_key(bytes))
+
+
+class TestCHKInventoryExpand(tests.TestCaseWithMemoryTransport):
+
+    def get_chk_bytes(self):
+        factory = groupcompress.make_pack_factory(True, True, 1)
+        trans = self.get_transport('')
+        return factory(trans)
+
+    def make_dir(self, inv, name, parent_id):
+        inv.add(inv.make_entry('directory', name, parent_id, name + '-id'))
+
+    def make_file(self, inv, name, parent_id, content='content\n'):
+        ie = inv.make_entry('file', name, parent_id, name + '-id')
+        ie.text_sha1 = osutils.sha_string(content)
+        ie.text_size = len(content)
+        inv.add(ie)
+
+    def make_simple_inventory(self):
+        inv = Inventory('TREE_ROOT')
+        inv.revision_id = "revid"
+        inv.root.revision = "rootrev"
+        # /                 TREE_ROOT
+        # dir1/             dir1-id
+        #   sub-file1       sub-file1-id
+        #   sub-file2       sub-file2-id
+        #   sub-dir1/       sub-dir1-id
+        #     subsub-file1  subsub-file1-id
+        # dir2/             dir2-id
+        #   sub2-file1      sub2-file1-id
+        # top               top-id
+        self.make_dir(inv, 'dir1', 'TREE_ROOT')
+        self.make_dir(inv, 'dir2', 'TREE_ROOT')
+        self.make_dir(inv, 'sub-dir1', 'dir1-id')
+        self.make_file(inv, 'top', 'TREE_ROOT')
+        self.make_file(inv, 'sub-file1', 'dir1-id')
+        self.make_file(inv, 'sub-file2', 'dir1-id')
+        self.make_file(inv, 'subsub-file1', 'sub-dir1-id')
+        self.make_file(inv, 'sub2-file1', 'dir2-id')
+        chk_bytes = self.get_chk_bytes()
+        #  use a small maximum_size to force internal paging structures
+        chk_inv = CHKInventory.from_inventory(chk_bytes, inv,
+                        maximum_size=100,
+                        search_key_name='hash-255-way')
+        bytes = ''.join(chk_inv.to_lines())
+        return CHKInventory.deserialise(chk_bytes, bytes, ("revid",))
+
+    def assert_Getitems(self, expected_fileids, inv, file_ids):
+        self.assertEqual(sorted(expected_fileids),
+                         sorted([ie.file_id for ie in inv._getitems(file_ids)]))
+
+    def assertExpand(self, all_ids, inv, file_ids):
+        (val_all_ids,
+         val_children) = inv._expand_fileids_to_parents_and_children(file_ids)
+        self.assertEqual(set(all_ids), val_all_ids)
+        entries = inv._getitems(val_all_ids)
+        expected_children = {}
+        for entry in entries:
+            s = expected_children.setdefault(entry.parent_id, [])
+            s.append(entry.file_id)
+        val_children = dict((k, sorted(v)) for k, v
+                            in val_children.iteritems())
+        expected_children = dict((k, sorted(v)) for k, v
+                            in expected_children.iteritems())
+        self.assertEqual(expected_children, val_children)
+
+    def test_make_simple_inventory(self):
+        inv = self.make_simple_inventory()
+        layout = []
+        for path, entry in inv.iter_entries_by_dir():
+            layout.append((path, entry.file_id))
+        self.assertEqual([
+            ('', 'TREE_ROOT'),
+            ('dir1', 'dir1-id'),
+            ('dir2', 'dir2-id'),
+            ('top', 'top-id'),
+            ('dir1/sub-dir1', 'sub-dir1-id'),
+            ('dir1/sub-file1', 'sub-file1-id'),
+            ('dir1/sub-file2', 'sub-file2-id'),
+            ('dir1/sub-dir1/subsub-file1', 'subsub-file1-id'),
+            ('dir2/sub2-file1', 'sub2-file1-id'),
+            ], layout)
+
+    def test__getitems(self):
+        inv = self.make_simple_inventory()
+        # Reading from disk
+        self.assert_Getitems(['dir1-id'], inv, ['dir1-id'])
+        self.assertTrue('dir1-id' in inv._fileid_to_entry_cache)
+        self.assertFalse('sub-file2-id' in inv._fileid_to_entry_cache)
+        # From cache
+        self.assert_Getitems(['dir1-id'], inv, ['dir1-id'])
+        # Mixed
+        self.assert_Getitems(['dir1-id', 'sub-file2-id'], inv,
+                             ['dir1-id', 'sub-file2-id'])
+        self.assertTrue('dir1-id' in inv._fileid_to_entry_cache)
+        self.assertTrue('sub-file2-id' in inv._fileid_to_entry_cache)
+
+    def test_single_file(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'top-id'], inv, ['top-id'])
+
+    def test_get_all_parents(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'dir1-id', 'sub-dir1-id',
+                           'subsub-file1-id',
+                          ], inv, ['subsub-file1-id'])
+
+    def test_get_children(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'dir1-id', 'sub-dir1-id',
+                           'sub-file1-id', 'sub-file2-id', 'subsub-file1-id',
+                          ], inv, ['dir1-id'])
+
+    def test_from_root(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'dir1-id', 'dir2-id', 'sub-dir1-id',
+                           'sub-file1-id', 'sub-file2-id', 'sub2-file1-id',
+                           'subsub-file1-id', 'top-id'], inv, ['TREE_ROOT'])
+
+    def test_top_level_file(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'top-id'], inv, ['top-id'])
+
+    def test_subsub_file(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'dir1-id', 'sub-dir1-id',
+                           'subsub-file1-id'], inv, ['subsub-file1-id'])
+
+    def test_sub_and_root(self):
+        inv = self.make_simple_inventory()
+        self.assertExpand(['TREE_ROOT', 'dir1-id', 'sub-dir1-id', 'top-id',
+                           'subsub-file1-id'], inv, ['top-id', 'subsub-file1-id'])

=== modified file 'bzrlib/tests/test_lsprof.py'
--- bzrlib/tests/test_lsprof.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_lsprof.py	2009-08-24 21:05:09 +0000
@@ -92,3 +92,22 @@
         self.stats.save(f)
         data1 = cPickle.load(open(f))
         self.assertEqual(type(data1), bzrlib.lsprof.Stats)
+
+
+class TestBzrProfiler(tests.TestCase):
+
+    _test_needs_features = [LSProfFeature]
+
+    def test_start_call_stuff_stop(self):
+        profiler = bzrlib.lsprof.BzrProfiler()
+        profiler.start()
+        try:
+            def a_function():
+                pass
+            a_function()
+        finally:
+            stats = profiler.stop()
+        stats.freeze()
+        lines = [str(data) for data in stats.data]
+        lines = [line for line in lines if 'a_function' in line]
+        self.assertLength(1, lines)

=== modified file 'bzrlib/tests/test_mail_client.py'
--- bzrlib/tests/test_mail_client.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/test_mail_client.py	2009-09-02 08:26:27 +0000
@@ -97,6 +97,8 @@
         # We won't be able to know the temporary file name at this stage
         # so we can't raise an assertion with assertEqual
         cmdline = eclient._get_compose_commandline(None, None, 'file%')
+        if eclient.elisp_tmp_file is not None:
+            self.addCleanup(osutils.delete_any, eclient.elisp_tmp_file)
         commandline = ' '.join(cmdline)
         self.assertContainsRe(commandline, '--eval')
         self.assertContainsRe(commandline, '(compose-mail nil nil)')
@@ -107,6 +109,8 @@
         eclient = mail_client.EmacsMail(None)
         commandline = eclient._get_compose_commandline(u'jrandom@example.org',
             u'Hi there!', u'file%')
+        if eclient.elisp_tmp_file is not None:
+            self.addCleanup(osutils.delete_any, eclient.elisp_tmp_file)
         for item in commandline:
             self.assertFalse(isinstance(item, unicode),
                 'Command-line item %r is unicode!' % item)

=== modified file 'bzrlib/tests/test_merge.py'
--- bzrlib/tests/test_merge.py	2009-08-26 03:20:32 +0000
+++ bzrlib/tests/test_merge.py	2009-09-19 00:32:14 +0000
@@ -36,7 +36,7 @@
 from bzrlib.osutils import pathjoin, file_kind
 from bzrlib.tests import TestCaseWithTransport, TestCaseWithMemoryTransport
 from bzrlib.workingtree import WorkingTree
-
+from bzrlib.transform import TreeTransform
 
 class TestMerge(TestCaseWithTransport):
     """Test appending more than one revision"""
@@ -1143,6 +1143,27 @@
                 'X\n'
                 'e\n', 'test/foo')
 
+    def get_limbodir_deletiondir(self, wt):
+        transform = TreeTransform(wt)
+        limbodir = transform._limbodir
+        deletiondir = transform._deletiondir
+        transform.finalize()
+        return (limbodir, deletiondir)
+    
+    def test_merge_with_existing_limbo(self):
+        wt = self.make_branch_and_tree('this')
+        (limbodir, deletiondir) =  self.get_limbodir_deletiondir(wt)
+        os.mkdir(limbodir)
+        self.assertRaises(errors.ExistingLimbo, self.do_merge, wt, wt)
+        self.assertRaises(errors.LockError, wt.unlock)
+
+    def test_merge_with_pending_deletion(self):
+        wt = self.make_branch_and_tree('this')
+        (limbodir, deletiondir) =  self.get_limbodir_deletiondir(wt)
+        os.mkdir(deletiondir)
+        self.assertRaises(errors.ExistingPendingDeletion, self.do_merge, wt, wt)
+        self.assertRaises(errors.LockError, wt.unlock)
+
 
 class TestMerge3Merge(TestCaseWithTransport, TestMergeImplementation):
 

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/test_msgeditor.py	2009-11-17 23:05:04 +0000
@@ -35,6 +35,7 @@
     edit_commit_message_encoded
 )
 from bzrlib.tests import (
+    TestCaseInTempDir,
     TestCaseWithTransport,
     TestNotApplicable,
     TestSkipped,
@@ -93,7 +94,7 @@
         tree3.commit('Feature Y, based on initial X work.',
                      timestamp=1233285960, timezone=0)
         tree.merge_from_branch(tree2.branch)
-        tree.merge_from_branch(tree3.branch)
+        tree.merge_from_branch(tree3.branch, force=True)
         return tree
 
     def test_commit_template_pending_merges(self):
@@ -290,7 +291,10 @@
         # Call _run_editor, capturing mutter.warning calls.
         warnings = []
         def warning(*args):
-            warnings.append(args[0] % args[1:])
+            if len(args) > 1:
+                warnings.append(args[0] % args[1:])
+            else:
+                warnings.append(args[0])
         _warning = trace.warning
         trace.warning = warning
         try:
@@ -364,3 +368,24 @@
         commit_obj = commit.Commit()
         self.assertEquals("save me some typing\n",
             msgeditor.generate_commit_message_template(commit_obj))
+
+
+# GZ 2009-11-17: This wants moving to osutils when the errno checking code is
+class TestPlatformErrnoWorkarounds(TestCaseInTempDir):
+    """Ensuring workarounds enshrined in code actually serve a purpose"""
+
+    def test_subprocess_call_bad_file(self):
+        if sys.platform != "win32":
+            raise TestNotApplicable("Workarounds for windows only")
+        import subprocess, errno
+        ERROR_BAD_EXE_FORMAT = 193
+        file("textfile.txt", "w").close()
+        e = self.assertRaises(WindowsError, subprocess.call, "textfile.txt")
+        # Python2.4 used the 'winerror' as the errno, which confuses a lot of
+        # our error trapping code. Make sure that we understand the mapping
+        # correctly.
+        if sys.version_info >= (2, 5):
+            self.assertEqual(e.errno, errno.ENOEXEC)
+            self.assertEqual(e.winerror, ERROR_BAD_EXE_FORMAT)
+        else:
+            self.assertEqual(e.errno, ERROR_BAD_EXE_FORMAT)

=== modified file 'bzrlib/tests/test_mutabletree.py'
--- bzrlib/tests/test_mutabletree.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_mutabletree.py	2009-10-06 16:34:48 +0000
@@ -19,22 +19,45 @@
 Most functionality of MutableTree is tested as part of WorkingTree.
 """
 
-from bzrlib.tests import TestCase
-from bzrlib.mutabletree import MutableTree, MutableTreeHooks
-
-class TestHooks(TestCase):
+from bzrlib import (
+    mutabletree,
+    tests,
+    )
+
+
+class TestHooks(tests.TestCase):
 
     def test_constructor(self):
         """Check that creating a MutableTreeHooks instance has the right
         defaults."""
-        hooks = MutableTreeHooks()
+        hooks = mutabletree.MutableTreeHooks()
         self.assertTrue("start_commit" in hooks,
                         "start_commit not in %s" % hooks)
+        self.assertTrue("post_commit" in hooks,
+                        "post_commit not in %s" % hooks)
 
     def test_installed_hooks_are_MutableTreeHooks(self):
         """The installed hooks object should be a MutableTreeHooks."""
         # the installed hooks are saved in self._preserved_hooks.
-        self.assertIsInstance(self._preserved_hooks[MutableTree][1],
-                              MutableTreeHooks)
-
-
+        self.assertIsInstance(self._preserved_hooks[mutabletree.MutableTree][1],
+                              mutabletree.MutableTreeHooks)
+
+
+class TestHasChanges(tests.TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestHasChanges, self).setUp()
+        self.tree = self.make_branch_and_tree('tree')
+
+    def test_with_uncommitted_changes(self):
+        self.build_tree(['tree/file'])
+        self.tree.add('file')
+        self.assertTrue(self.tree.has_changes())
+
+    def test_with_pending_merges(self):
+        other_tree = self.tree.bzrdir.sprout('other').open_workingtree()
+        self.build_tree(['other/file'])
+        other_tree.add('file')
+        other_tree.commit('added file')
+        self.tree.merge_from_branch(other_tree.branch)
+        self.assertTrue(self.tree.has_changes())

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2009-07-23 16:01:17 +0000
+++ bzrlib/tests/test_osutils.py	2009-12-02 07:56:16 +0000
@@ -29,6 +29,7 @@
     errors,
     osutils,
     tests,
+    trace,
     win32utils,
     )
 from bzrlib.tests import (
@@ -57,10 +58,6 @@
     return s
 
 
-def _fs_enc_to_unicode(s):
-    return s.decode(osutils._fs_enc)
-
-
 def _utf8_to_unicode(s):
     return s.decode('UTF-8')
 
@@ -86,12 +83,10 @@
     if test__walkdirs_win32.Win32ReadDirFeature.available():
         try:
             from bzrlib import _walkdirs_win32
-            # TODO: check on windows, it may be that we need to use/add
-            # safe_unicode instead of _fs_enc_to_unicode
             scenarios.append(
                 ('win32',
                  dict(_dir_reader_class=_walkdirs_win32.Win32ReadDir,
-                      _native_to_unicode=_fs_enc_to_unicode)))
+                      _native_to_unicode=_already_unicode)))
         except ImportError:
             pass
     return scenarios
@@ -125,33 +120,51 @@
 
 class TestRename(tests.TestCaseInTempDir):
 
+    def create_file(self, filename, content):
+        f = open(filename, 'wb')
+        try:
+            f.write(content)
+        finally:
+            f.close()
+
+    def _fancy_rename(self, a, b):
+        osutils.fancy_rename(a, b, rename_func=os.rename,
+                             unlink_func=os.unlink)
+
     def test_fancy_rename(self):
         # This should work everywhere
-        def rename(a, b):
-            osutils.fancy_rename(a, b,
-                    rename_func=os.rename,
-                    unlink_func=os.unlink)
-
-        open('a', 'wb').write('something in a\n')
-        rename('a', 'b')
+        self.create_file('a', 'something in a\n')
+        self._fancy_rename('a', 'b')
         self.failIfExists('a')
         self.failUnlessExists('b')
         self.check_file_contents('b', 'something in a\n')
 
-        open('a', 'wb').write('new something in a\n')
-        rename('b', 'a')
+        self.create_file('a', 'new something in a\n')
+        self._fancy_rename('b', 'a')
 
         self.check_file_contents('a', 'something in a\n')
 
+    def test_fancy_rename_fails_source_missing(self):
+        # An exception should be raised, and the target should be left in place
+        self.create_file('target', 'data in target\n')
+        self.assertRaises((IOError, OSError), self._fancy_rename,
+                          'missingsource', 'target')
+        self.failUnlessExists('target')
+        self.check_file_contents('target', 'data in target\n')
+
+    def test_fancy_rename_fails_if_source_and_target_missing(self):
+        self.assertRaises((IOError, OSError), self._fancy_rename,
+                          'missingsource', 'missingtarget')
+
     def test_rename(self):
         # Rename should be semi-atomic on all platforms
-        open('a', 'wb').write('something in a\n')
+        self.create_file('a', 'something in a\n')
         osutils.rename('a', 'b')
         self.failIfExists('a')
         self.failUnlessExists('b')
         self.check_file_contents('b', 'something in a\n')
 
-        open('a', 'wb').write('new something in a\n')
+        self.create_file('a', 'new something in a\n')
         osutils.rename('b', 'a')
 
         self.check_file_contents('a', 'something in a\n')
@@ -365,6 +378,14 @@
         # Instead blackbox.test_locale should check for localized
         # dates once they do occur in output strings.
 
+    def test_format_date_with_offset_in_original_timezone(self):
+        self.assertEqual("Thu 1970-01-01 00:00:00 +0000",
+            osutils.format_date_with_offset_in_original_timezone(0))
+        self.assertEqual("Fri 1970-01-02 03:46:40 +0000",
+            osutils.format_date_with_offset_in_original_timezone(100000))
+        self.assertEqual("Fri 1970-01-02 05:46:40 +0200",
+            osutils.format_date_with_offset_in_original_timezone(100000, 7200))
+
     def test_local_time_offset(self):
         """Test that local_time_offset() returns a sane value."""
         offset = osutils.local_time_offset()
@@ -446,20 +467,59 @@
     def test_canonical_relpath_simple(self):
         f = file('MixedCaseName', 'w')
         f.close()
-        # Watch out for tricky test dir (on OSX /tmp -> /private/tmp)
-        real_base_dir = osutils.realpath(self.test_base_dir)
-        actual = osutils.canonical_relpath(real_base_dir, 'mixedcasename')
+        actual = osutils.canonical_relpath(self.test_base_dir, 'mixedcasename')
         self.failUnlessEqual('work/MixedCaseName', actual)
 
     def test_canonical_relpath_missing_tail(self):
         os.mkdir('MixedCaseParent')
-        # Watch out for tricky test dir (on OSX /tmp -> /private/tmp)
-        real_base_dir = osutils.realpath(self.test_base_dir)
-        actual = osutils.canonical_relpath(real_base_dir,
+        actual = osutils.canonical_relpath(self.test_base_dir,
                                            'mixedcaseparent/nochild')
         self.failUnlessEqual('work/MixedCaseParent/nochild', actual)
 
 
+class Test_CICPCanonicalRelpath(tests.TestCaseWithTransport):
+
+    def assertRelpath(self, expected, base, path):
+        actual = osutils._cicp_canonical_relpath(base, path)
+        self.assertEqual(expected, actual)
+
+    def test_simple(self):
+        self.build_tree(['MixedCaseName'])
+        base = osutils.realpath(self.get_transport('.').local_abspath('.'))
+        self.assertRelpath('MixedCaseName', base, 'mixedcAsename')
+
+    def test_subdir_missing_tail(self):
+        self.build_tree(['MixedCaseParent/', 'MixedCaseParent/a_child'])
+        base = osutils.realpath(self.get_transport('.').local_abspath('.'))
+        self.assertRelpath('MixedCaseParent/a_child', base,
+                           'MixedCaseParent/a_child')
+        self.assertRelpath('MixedCaseParent/a_child', base,
+                           'MixedCaseParent/A_Child')
+        self.assertRelpath('MixedCaseParent/not_child', base,
+                           'MixedCaseParent/not_child')
+
+    def test_at_root_slash(self):
+        # We can't test this on Windows, because it has a 'MIN_ABS_PATHLENGTH'
+        # check...
+        if osutils.MIN_ABS_PATHLENGTH > 1:
+            raise tests.TestSkipped('relpath requires %d chars'
+                                    % osutils.MIN_ABS_PATHLENGTH)
+        self.assertRelpath('foo', '/', '/foo')
+
+    def test_at_root_drive(self):
+        if sys.platform != 'win32':
+            raise tests.TestNotApplicable('we can only test drive-letter relative'
+                                          ' paths on Windows where we have drive'
+                                          ' letters.')
+        # see bug #322807
+        # The specific issue is that when at the root of a drive, 'abspath'
+        # returns "C:/" or just "/". However, the code assumes that abspath
+        # always returns something like "C:/foo" or "/foo" (no trailing slash).
+        self.assertRelpath('foo', 'C:/', 'C:/foo')
+        self.assertRelpath('foo', 'X:/', 'X:/foo')
+        self.assertRelpath('foo', 'X:/', 'X://foo')
+
+
 class TestPumpFile(tests.TestCase):
     """Test pumpfile method."""
 
@@ -1573,7 +1633,7 @@
         text = 'test\r\nwith\nall\rpossible line endings\r\n'
         self.build_tree_contents([('foo', text)])
         expected_sha = osutils.sha_string(text)
-        f = open('foo')
+        f = open('foo', 'rb')
         self.addCleanup(f.close)
         size, sha = osutils.size_sha_file(f)
         self.assertEqual(38, size)
@@ -1795,6 +1855,70 @@
 
 class TestConcurrency(tests.TestCase):
 
+    def setUp(self):
+        super(TestConcurrency, self).setUp()
+        orig = osutils._cached_local_concurrency
+        def restore():
+            osutils._cached_local_concurrency = orig
+        self.addCleanup(restore)
+
     def test_local_concurrency(self):
         concurrency = osutils.local_concurrency()
         self.assertIsInstance(concurrency, int)
+
+    def test_local_concurrency_environment_variable(self):
+        os.environ['BZR_CONCURRENCY'] = '2'
+        self.assertEqual(2, osutils.local_concurrency(use_cache=False))
+        os.environ['BZR_CONCURRENCY'] = '3'
+        self.assertEqual(3, osutils.local_concurrency(use_cache=False))
+        os.environ['BZR_CONCURRENCY'] = 'foo'
+        self.assertEqual(1, osutils.local_concurrency(use_cache=False))
+
+    def test_option_concurrency(self):
+        os.environ['BZR_CONCURRENCY'] = '1'
+        self.run_bzr('rocks --concurrency 42')
+        # Command line overrides envrionment variable
+        self.assertEquals('42', os.environ['BZR_CONCURRENCY'])
+        self.assertEquals(42, osutils.local_concurrency(use_cache=False))
+
+
+class TestFailedToLoadExtension(tests.TestCase):
+
+    def _try_loading(self):
+        try:
+            import bzrlib._fictional_extension_py
+        except ImportError, e:
+            osutils.failed_to_load_extension(e)
+            return True
+
+    def setUp(self):
+        super(TestFailedToLoadExtension, self).setUp()
+        self.saved_failures = osutils._extension_load_failures[:]
+        del osutils._extension_load_failures[:]
+        self.addCleanup(self.restore_failures)
+
+    def restore_failures(self):
+        osutils._extension_load_failures = self.saved_failures
+
+    def test_failure_to_load(self):
+        self._try_loading()
+        self.assertLength(1, osutils._extension_load_failures)
+        self.assertEquals(osutils._extension_load_failures[0],
+            "No module named _fictional_extension_py")
+
+    def test_report_extension_load_failures_no_warning(self):
+        self.assertTrue(self._try_loading())
+        warnings, result = self.callCatchWarnings(osutils.report_extension_load_failures)
+        # it used to give a Python warning; it no longer does
+        self.assertLength(0, warnings)
+
+    def test_report_extension_load_failures_message(self):
+        log = StringIO()
+        trace.push_log_file(log)
+        self.assertTrue(self._try_loading())
+        osutils.report_extension_load_failures()
+        self.assertContainsRe(
+            log.getvalue(),
+            r"bzr: warning: some compiled extensions could not be loaded; "
+            "see <https://answers\.launchpad\.net/bzr/\+faq/703>\n"
+            )

=== modified file 'bzrlib/tests/test_patches.py'
--- bzrlib/tests/test_patches.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_patches.py	2009-11-03 15:45:56 +0000
@@ -24,6 +24,9 @@
 from bzrlib.patches import (MalformedLine,
                             MalformedHunkHeader,
                             MalformedPatchHeader,
+                            BinaryPatch,
+                            BinaryFiles,
+                            Patch,
                             ContextLine,
                             InsertLine,
                             RemoveLine,
@@ -45,6 +48,13 @@
                                  "test_patches_data", filename)
         return file(data_path, "rb")
 
+    def data_lines(self, filename):
+        datafile = self.datafile(filename)
+        try:
+            return datafile.readlines()
+        finally:
+            datafile.close()
+
     def testValidPatchHeader(self):
         """Parse a valid patch header"""
         lines = "--- orig/commands.py\n+++ mod/dommands.py\n".split('\n')
@@ -136,6 +146,30 @@
         patchtext = self.datafile("patchtext.patch").read()
         self.compare_parsed(patchtext)
 
+    def test_parse_binary(self):
+        """Test parsing a whole patch"""
+        patches = parse_patches(self.data_lines("binary.patch"))
+        self.assertIs(BinaryPatch, patches[0].__class__)
+        self.assertIs(Patch, patches[1].__class__)
+        self.assertContainsRe(patches[0].oldname, '^bar\t')
+        self.assertContainsRe(patches[0].newname, '^qux\t')
+        self.assertContainsRe(str(patches[0]),
+                                  'Binary files bar\t.* and qux\t.* differ\n')
+
+    def test_parse_binary_after_normal(self):
+        patches = parse_patches(self.data_lines("binary-after-normal.patch"))
+        self.assertIs(BinaryPatch, patches[1].__class__)
+        self.assertIs(Patch, patches[0].__class__)
+        self.assertContainsRe(patches[1].oldname, '^bar\t')
+        self.assertContainsRe(patches[1].newname, '^qux\t')
+        self.assertContainsRe(str(patches[1]),
+                                  'Binary files bar\t.* and qux\t.* differ\n')
+
+    def test_roundtrip_binary(self):
+        patchtext = ''.join(self.data_lines("binary.patch"))
+        patches = parse_patches(patchtext.splitlines(True))
+        self.assertEqual(patchtext, ''.join(str(p) for p in patches))
+
     def testInit(self):
         """Handle patches missing half the position, range tuple"""
         patchtext = \
@@ -194,6 +228,11 @@
                 count += 1
             self.assertEqual(count, len(mod_lines))
 
+    def test_iter_patched_binary(self):
+        binary_lines = self.data_lines('binary.patch')
+        e = self.assertRaises(BinaryFiles, iter_patched, [], binary_lines)
+
+
     def test_iter_patched_from_hunks(self):
         """Test a few patch files, and make sure they work."""
         files = [

=== added file 'bzrlib/tests/test_patches_data/binary-after-normal.patch'
--- bzrlib/tests/test_patches_data/binary-after-normal.patch	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_patches_data/binary-after-normal.patch	2009-11-03 15:45:56 +0000
@@ -0,0 +1,6 @@
+--- baz	2009-10-14 19:49:59 +0000
++++ quxx	2009-10-14 19:51:00 +0000
+@@ -1 +1 @@
+-hello
++goodbye
+Binary files bar	2009-10-14 19:49:59 +0000 and qux	2009-10-14 19:50:35 +0000 differ

=== added file 'bzrlib/tests/test_patches_data/binary.patch'
--- bzrlib/tests/test_patches_data/binary.patch	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_patches_data/binary.patch	2009-10-14 22:08:45 +0000
@@ -0,0 +1,6 @@
+Binary files bar	2009-10-14 19:49:59 +0000 and qux	2009-10-14 19:50:35 +0000 differ
+--- baz	2009-10-14 19:49:59 +0000
++++ quxx	2009-10-14 19:51:00 +0000
+@@ -1 +1 @@
+-hello
++goodbye

=== modified file 'bzrlib/tests/test_permissions.py'
--- bzrlib/tests/test_permissions.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_permissions.py	2009-09-07 08:46:00 +0000
@@ -140,10 +140,10 @@
     def test_new_files_group_sticky_bit(self):
         if sys.platform == 'win32':
             raise TestSkipped('chmod has no effect on win32')
-        elif sys.platform == 'darwin':
-            # OS X creates temp dirs with the 'wheel' group, which users are
-            # not likely to be in, and this prevents us from setting the sgid
-            # bit
+        elif sys.platform == 'darwin' or sys.platform.startswith('freebsd'):
+            # OS X (and FreeBSD) create temp dirs with the 'wheel' group, which
+            # users are not likely to be in, and this prevents us from setting
+            # the sgid bit
             os.chown(self.test_dir, os.getuid(), os.getgid())
 
         t = self.make_branch_and_tree('.')

=== modified file 'bzrlib/tests/test_plugins.py'
--- bzrlib/tests/test_plugins.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/test_plugins.py	2009-09-18 14:53:37 +0000
@@ -26,7 +26,11 @@
 import sys
 import zipfile
 
-from bzrlib import plugin, tests
+from bzrlib import (
+    osutils,
+    plugin,
+    tests,
+    )
 import bzrlib.plugin
 import bzrlib.plugins
 import bzrlib.commands
@@ -390,13 +394,18 @@
     def test_dev_fallback__version__with_version_info(self):
         self.setup_plugin("version_info = (1, 2, 3, 'dev', 4)")
         plugin = bzrlib.plugin.plugins()['plugin']
-        self.assertEqual("1.2.3.dev.4", plugin.__version__)
+        self.assertEqual("1.2.3dev4", plugin.__version__)
 
     def test_final__version__with_version_info(self):
         self.setup_plugin("version_info = (1, 2, 3, 'final', 0)")
         plugin = bzrlib.plugin.plugins()['plugin']
         self.assertEqual("1.2.3", plugin.__version__)
 
+    def test_final_fallback__version__with_version_info(self):
+        self.setup_plugin("version_info = (1, 2, 3, 'final', 2)")
+        plugin = bzrlib.plugin.plugins()['plugin']
+        self.assertEqual("1.2.3.final.2", plugin.__version__)
+
 
 class TestPluginHelp(TestCaseInTempDir):
 
@@ -454,41 +463,6 @@
                 delattr(bzrlib.plugins, 'myplug')
 
 
-class TestSetPluginsPath(TestCase):
-
-    def test_set_plugins_path(self):
-        """set_plugins_path should set the module __path__ correctly."""
-        old_path = bzrlib.plugins.__path__
-        try:
-            bzrlib.plugins.__path__ = []
-            expected_path = bzrlib.plugin.set_plugins_path()
-            self.assertEqual(expected_path, bzrlib.plugins.__path__)
-        finally:
-            bzrlib.plugins.__path__ = old_path
-
-    def test_set_plugins_path_with_trailing_slashes(self):
-        """set_plugins_path should set the module __path__ based on
-        BZR_PLUGIN_PATH after removing all trailing slashes."""
-        old_path = bzrlib.plugins.__path__
-        old_env = os.environ.get('BZR_PLUGIN_PATH')
-        try:
-            bzrlib.plugins.__path__ = []
-            os.environ['BZR_PLUGIN_PATH'] = "first\\//\\" + os.pathsep + \
-                "second/\\/\\/"
-            bzrlib.plugin.set_plugins_path()
-            # We expect our nominated paths to have all path-seps removed,
-            # and this is testing only that.
-            expected_path = ['first', 'second']
-            self.assertEqual(expected_path,
-                bzrlib.plugins.__path__[:len(expected_path)])
-        finally:
-            bzrlib.plugins.__path__ = old_path
-            if old_env is not None:
-                os.environ['BZR_PLUGIN_PATH'] = old_env
-            else:
-                del os.environ['BZR_PLUGIN_PATH']
-
-
 class TestHelpIndex(tests.TestCase):
     """Tests for the PluginsHelpIndex class."""
 
@@ -597,41 +571,42 @@
         self.assertEqual('foo_bar', topic.get_help_topic())
 
 
-def clear_plugins(test_case):
-    # Save the attributes that we're about to monkey-patch.
-    old_plugins_path = bzrlib.plugins.__path__
-    old_loaded = plugin._loaded
-    old_load_from_path = plugin.load_from_path
-    # Change bzrlib.plugin to think no plugins have been loaded yet.
-    bzrlib.plugins.__path__ = []
-    plugin._loaded = False
-    # Monkey-patch load_from_path to stop it from actually loading anything.
-    def load_from_path(dirs):
-        pass
-    plugin.load_from_path = load_from_path
-    def restore_plugins():
-        bzrlib.plugins.__path__ = old_plugins_path
-        plugin._loaded = old_loaded
-        plugin.load_from_path = old_load_from_path
-    test_case.addCleanup(restore_plugins)
-
-
-class TestPluginPaths(tests.TestCase):
+class TestLoadFromPath(tests.TestCaseInTempDir):
+
+    def setUp(self):
+        super(TestLoadFromPath, self).setUp()
+        # Save the attributes that we're about to monkey-patch.
+        old_plugins_path = bzrlib.plugins.__path__
+        old_loaded = plugin._loaded
+        old_load_from_path = plugin.load_from_path
+
+        def restore():
+            bzrlib.plugins.__path__ = old_plugins_path
+            plugin._loaded = old_loaded
+            plugin.load_from_path = old_load_from_path
+
+        self.addCleanup(restore)
+
+        # Change bzrlib.plugin to think no plugins have been loaded yet.
+        bzrlib.plugins.__path__ = []
+        plugin._loaded = False
+
+        # Monkey-patch load_from_path to stop it from actually loading anything.
+        def load_from_path(dirs):
+            pass
+        plugin.load_from_path = load_from_path
 
     def test_set_plugins_path_with_args(self):
-        clear_plugins(self)
         plugin.set_plugins_path(['a', 'b'])
         self.assertEqual(['a', 'b'], bzrlib.plugins.__path__)
 
     def test_set_plugins_path_defaults(self):
-        clear_plugins(self)
         plugin.set_plugins_path()
         self.assertEqual(plugin.get_standard_plugins_path(),
                          bzrlib.plugins.__path__)
 
     def test_get_standard_plugins_path(self):
         path = plugin.get_standard_plugins_path()
-        self.assertEqual(plugin.get_default_plugin_path(), path[0])
         for directory in path:
             self.assertNotContainsRe(directory, r'\\/$')
         try:
@@ -649,13 +624,11 @@
 
     def test_get_standard_plugins_path_env(self):
         os.environ['BZR_PLUGIN_PATH'] = 'foo/'
-        self.assertEqual('foo', plugin.get_standard_plugins_path()[0])
-
-
-class TestLoadPlugins(tests.TestCaseInTempDir):
+        path = plugin.get_standard_plugins_path()
+        for directory in path:
+            self.assertNotContainsRe(directory, r'\\/$')
 
     def test_load_plugins(self):
-        clear_plugins(self)
         plugin.load_plugins(['.'])
         self.assertEqual(bzrlib.plugins.__path__, ['.'])
         # subsequent loads are no-ops
@@ -663,7 +636,107 @@
         self.assertEqual(bzrlib.plugins.__path__, ['.'])
 
     def test_load_plugins_default(self):
-        clear_plugins(self)
         plugin.load_plugins()
         path = plugin.get_standard_plugins_path()
         self.assertEqual(path, bzrlib.plugins.__path__)
+
+
+class TestEnvPluginPath(tests.TestCaseInTempDir):
+
+    def setUp(self):
+        super(TestEnvPluginPath, self).setUp()
+        old_default = plugin.DEFAULT_PLUGIN_PATH
+
+        def restore():
+            plugin.DEFAULT_PLUGIN_PATH = old_default
+
+        self.addCleanup(restore)
+
+        plugin.DEFAULT_PLUGIN_PATH = None
+
+        self.user = plugin.get_user_plugin_path()
+        self.site = plugin.get_site_plugin_path()
+        self.core = plugin.get_core_plugin_path()
+
+    def _list2paths(self, *args):
+        paths = []
+        for p in args:
+            plugin._append_new_path(paths, p)
+        return paths
+
+    def _set_path(self, *args):
+        path = os.pathsep.join(self._list2paths(*args))
+        osutils.set_or_unset_env('BZR_PLUGIN_PATH', path)
+
+    def check_path(self, expected_dirs, setting_dirs):
+        if setting_dirs:
+            self._set_path(*setting_dirs)
+        actual = plugin.get_standard_plugins_path()
+        self.assertEquals(self._list2paths(*expected_dirs), actual)
+
+    def test_default(self):
+        self.check_path([self.user, self.core, self.site],
+                        None)
+
+    def test_adhoc_policy(self):
+        self.check_path([self.user, self.core, self.site],
+                        ['+user', '+core', '+site'])
+
+    def test_fallback_policy(self):
+        self.check_path([self.core, self.site, self.user],
+                        ['+core', '+site', '+user'])
+
+    def test_override_policy(self):
+        self.check_path([self.user, self.site, self.core],
+                        ['+user', '+site', '+core'])
+
+    def test_disable_user(self):
+        self.check_path([self.core, self.site], ['-user'])
+
+    def test_disable_user_twice(self):
+        # Ensures multiple removals don't left cruft
+        self.check_path([self.core, self.site], ['-user', '-user'])
+
+    def test_duplicates_are_removed(self):
+        self.check_path([self.user, self.core, self.site],
+                        ['+user', '+user'])
+        # And only the first reference is kept (since the later references will
+        # onnly produce <plugin> already loaded mutters)
+        self.check_path([self.user, self.core, self.site],
+                        ['+user', '+user', '+core',
+                         '+user', '+site', '+site',
+                         '+core'])
+
+    def test_disable_overrides_disable(self):
+        self.check_path([self.core, self.site], ['-user', '+user'])
+
+    def test_disable_core(self):
+        self.check_path([self.site], ['-core'])
+        self.check_path([self.user, self.site], ['+user', '-core'])
+
+    def test_disable_site(self):
+        self.check_path([self.core], ['-site'])
+        self.check_path([self.user, self.core], ['-site', '+user'])
+
+    def test_override_site(self):
+        self.check_path(['mysite', self.user, self.core],
+                        ['mysite', '-site', '+user'])
+        self.check_path(['mysite', self.core],
+                        ['mysite', '-site'])
+
+    def test_override_core(self):
+        self.check_path(['mycore', self.user, self.site],
+                        ['mycore', '-core', '+user', '+site'])
+        self.check_path(['mycore', self.site],
+                        ['mycore', '-core'])
+
+    def test_my_plugin_only(self):
+        self.check_path(['myplugin'], ['myplugin', '-user', '-core', '-site'])
+
+    def test_my_plugin_first(self):
+        self.check_path(['myplugin', self.core, self.site, self.user],
+                        ['myplugin', '+core', '+site', '+user'])
+
+    def test_bogus_references(self):
+        self.check_path(['+foo', '-bar', self.core, self.site],
+                        ['+foo', '-bar'])

=== modified file 'bzrlib/tests/test_reconfigure.py'
--- bzrlib/tests/test_reconfigure.py	2009-04-28 20:12:44 +0000
+++ bzrlib/tests/test_reconfigure.py	2009-10-06 14:40:37 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,6 +44,19 @@
         self.assertRaises(errors.NoWorkingTree, workingtree.WorkingTree.open,
                           'tree')
 
+    def test_tree_with_pending_merge_to_branch(self):
+        tree = self.make_branch_and_tree('tree')
+        other_tree = tree.bzrdir.sprout('other').open_workingtree()
+        self.build_tree(['other/file'])
+        other_tree.add('file')
+        other_tree.commit('file added')
+        tree.merge_from_branch(other_tree.branch)
+        reconfiguration = reconfigure.Reconfigure.to_branch(tree.bzrdir)
+        self.assertRaises(errors.UncommittedChanges, reconfiguration.apply)
+        reconfiguration.apply(force=True)
+        self.assertRaises(errors.NoWorkingTree, workingtree.WorkingTree.open,
+                          'tree')
+
     def test_branch_to_branch(self):
         branch = self.make_branch('branch')
         self.assertRaises(errors.AlreadyBranch,

=== modified file 'bzrlib/tests/test_registry.py'
--- bzrlib/tests/test_registry.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_registry.py	2009-09-16 10:37:29 +0000
@@ -21,13 +21,13 @@
 
 from bzrlib import (
     errors,
+    osutils,
     registry,
-    osutils,
+    tests,
     )
-from bzrlib.tests import TestCase, TestCaseInTempDir
-
-
-class TestRegistry(TestCase):
+
+
+class TestRegistry(tests.TestCase):
 
     def register_stuff(self, a_registry):
         a_registry.register('one', 1)
@@ -202,7 +202,64 @@
         self.assertIs(sftp_object, found_object)
 
 
-class TestRegistryWithDirs(TestCaseInTempDir):
+class TestRegistryIter(tests.TestCase):
+    """Test registry iteration behaviors.
+
+    There are dark corner cases here when the registered objects trigger
+    addition in the iterated registry.
+    """
+
+    def setUp(self):
+        super(TestRegistryIter, self).setUp()
+
+        # We create a registry with "official" objects and "hidden"
+        # objects. The later represent the side effects that led to bug #277048
+        # and #430510
+        self.registry =  registry.Registry()
+
+        def register_more():
+            self.registry.register('hidden', None)
+
+        self.registry.register('passive', None)
+        self.registry.register('active', register_more)
+        self.registry.register('passive-too', None)
+
+        class InvasiveGetter(registry._ObjectGetter):
+
+            def get_obj(inner_self):
+                # Surprise ! Getting a registered object (think lazy loaded
+                # module) register yet another object !
+                self.registry.register('more hidden', None)
+                return inner_self._obj
+
+        self.registry.register('hacky', None)
+        # We peek under the covers because the alternative is to use lazy
+        # registration and create a module that can reference our test registry
+        # it's too much work for such a corner case -- vila 090916
+        self.registry._dict['hacky'] = InvasiveGetter(None)
+
+    def _iter_them(self, iter_func_name):
+        iter_func = getattr(self.registry, iter_func_name, None)
+        self.assertIsNot(None, iter_func)
+        count = 0
+        for name, func in iter_func():
+            count += 1
+            self.assertFalse(name in ('hidden', 'more hidden'))
+            if func is not None:
+                # Using an object register another one as a side effect
+                func()
+        self.assertEqual(4, count)
+
+    def test_iteritems(self):
+        # the dict is modified during the iteration
+        self.assertRaises(RuntimeError, self._iter_them, 'iteritems')
+
+    def test_items(self):
+        # we should be able to iterate even if one item modify the dict
+        self._iter_them('items')
+
+
+class TestRegistryWithDirs(tests.TestCaseInTempDir):
     """Registry tests that require temporary dirs"""
 
     def create_plugin_file(self, contents):

=== modified file 'bzrlib/tests/test_remote.py'
--- bzrlib/tests/test_remote.py	2009-08-27 05:22:14 +0000
+++ bzrlib/tests/test_remote.py	2009-11-11 06:50:40 +0000
@@ -27,6 +27,7 @@
 from cStringIO import StringIO
 
 from bzrlib import (
+    branch,
     bzrdir,
     config,
     errors,
@@ -36,7 +37,6 @@
     pack,
     remote,
     repository,
-    smart,
     tests,
     treebuilder,
     urlutils,
@@ -61,9 +61,8 @@
     condition_isinstance,
     split_suite_by_condition,
     multiply_tests,
-    KnownFailure,
     )
-from bzrlib.transport import get_transport, http
+from bzrlib.transport import get_transport
 from bzrlib.transport.memory import MemoryTransport
 from bzrlib.transport.remote import (
     RemoteTransport,
@@ -280,6 +279,12 @@
         self.expecting_body = True
         return result[1], FakeProtocol(result[2], self)
 
+    def call_with_body_bytes(self, method, args, body):
+        self._check_call(method, args)
+        self._calls.append(('call_with_body_bytes', method, args, body))
+        result = self._get_next_response()
+        return result[1], FakeProtocol(result[2], self)
+
     def call_with_body_bytes_expecting_body(self, method, args, body):
         self._check_call(method, args)
         self._calls.append(('call_with_body_bytes_expecting_body', method,
@@ -468,6 +473,57 @@
         self.assertFinished(client)
 
 
+class TestBzrDirOpen(TestRemote):
+
+    def make_fake_client_and_transport(self, path='quack'):
+        transport = MemoryTransport()
+        transport.mkdir(path)
+        transport = transport.clone(path)
+        client = FakeClient(transport.base)
+        return client, transport
+
+    def test_absent(self):
+        client, transport = self.make_fake_client_and_transport()
+        client.add_expected_call(
+            'BzrDir.open_2.1', ('quack/',), 'success', ('no',))
+        self.assertRaises(errors.NotBranchError, RemoteBzrDir, transport,
+                remote.RemoteBzrDirFormat(), _client=client, _force_probe=True)
+        self.assertFinished(client)
+
+    def test_present_without_workingtree(self):
+        client, transport = self.make_fake_client_and_transport()
+        client.add_expected_call(
+            'BzrDir.open_2.1', ('quack/',), 'success', ('yes', 'no'))
+        bd = RemoteBzrDir(transport, remote.RemoteBzrDirFormat(),
+            _client=client, _force_probe=True)
+        self.assertIsInstance(bd, RemoteBzrDir)
+        self.assertFalse(bd.has_workingtree())
+        self.assertRaises(errors.NoWorkingTree, bd.open_workingtree)
+        self.assertFinished(client)
+
+    def test_present_with_workingtree(self):
+        client, transport = self.make_fake_client_and_transport()
+        client.add_expected_call(
+            'BzrDir.open_2.1', ('quack/',), 'success', ('yes', 'yes'))
+        bd = RemoteBzrDir(transport, remote.RemoteBzrDirFormat(),
+            _client=client, _force_probe=True)
+        self.assertIsInstance(bd, RemoteBzrDir)
+        self.assertTrue(bd.has_workingtree())
+        self.assertRaises(errors.NotLocalUrl, bd.open_workingtree)
+        self.assertFinished(client)
+
+    def test_backwards_compat(self):
+        client, transport = self.make_fake_client_and_transport()
+        client.add_expected_call(
+            'BzrDir.open_2.1', ('quack/',), 'unknown', ('BzrDir.open_2.1',))
+        client.add_expected_call(
+            'BzrDir.open', ('quack/',), 'success', ('yes',))
+        bd = RemoteBzrDir(transport, remote.RemoteBzrDirFormat(),
+            _client=client, _force_probe=True)
+        self.assertIsInstance(bd, RemoteBzrDir)
+        self.assertFinished(client)
+
+
 class TestBzrDirOpenBranch(TestRemote):
 
     def test_backwards_compat(self):
@@ -683,7 +739,9 @@
         # fallback all the way to the first version.
         reference_format = self.get_repo_format()
         network_name = reference_format.network_name()
-        client = FakeClient('bzr://example.com/')
+        server_url = 'bzr://example.com/'
+        self.permit_url(server_url)
+        client = FakeClient(server_url)
         client.add_unknown_method_response('BzrDir.find_repositoryV3')
         client.add_unknown_method_response('BzrDir.find_repositoryV2')
         client.add_success_response('ok', '', 'no', 'no')
@@ -695,7 +753,7 @@
             reference_format.get_format_string(), 'ok')
         # PackRepository wants to do a stat
         client.add_success_response('stat', '0', '65535')
-        remote_transport = RemoteTransport('bzr://example.com/quack/', medium=False,
+        remote_transport = RemoteTransport(server_url + 'quack/', medium=False,
             _client=client)
         bzrdir = RemoteBzrDir(remote_transport, remote.RemoteBzrDirFormat(),
             _client=client)
@@ -715,7 +773,9 @@
         # fallback to find_repositoryV2
         reference_format = self.get_repo_format()
         network_name = reference_format.network_name()
-        client = FakeClient('bzr://example.com/')
+        server_url = 'bzr://example.com/'
+        self.permit_url(server_url)
+        client = FakeClient(server_url)
         client.add_unknown_method_response('BzrDir.find_repositoryV3')
         client.add_success_response('ok', '', 'no', 'no', 'no')
         # A real repository instance will be created to determine the network
@@ -726,7 +786,7 @@
             reference_format.get_format_string(), 'ok')
         # PackRepository wants to do a stat
         client.add_success_response('stat', '0', '65535')
-        remote_transport = RemoteTransport('bzr://example.com/quack/', medium=False,
+        remote_transport = RemoteTransport(server_url + 'quack/', medium=False,
             _client=client)
         bzrdir = RemoteBzrDir(remote_transport, remote.RemoteBzrDirFormat(),
             _client=client)
@@ -851,6 +911,16 @@
 
 class RemoteBranchTestCase(RemoteBzrDirTestCase):
 
+    def lock_remote_branch(self, branch):
+        """Trick a RemoteBranch into thinking it is locked."""
+        branch._lock_mode = 'w'
+        branch._lock_count = 2
+        branch._lock_token = 'branch token'
+        branch._repo_lock_token = 'repo token'
+        branch.repository._lock_mode = 'w'
+        branch.repository._lock_count = 2
+        branch.repository._lock_token = 'repo token'
+
     def make_remote_branch(self, transport, client):
         """Make a RemoteBranch using 'client' as its _SmartClient.
 
@@ -995,6 +1065,54 @@
         self.assertEqual({}, result)
 
 
+class TestBranchSetTagsBytes(RemoteBranchTestCase):
+
+    def test_trivial(self):
+        transport = MemoryTransport()
+        client = FakeClient(transport.base)
+        client.add_expected_call(
+            'Branch.get_stacked_on_url', ('quack/',),
+            'error', ('NotStacked',))
+        client.add_expected_call(
+            'Branch.set_tags_bytes', ('quack/', 'branch token', 'repo token'),
+            'success', ('',))
+        transport.mkdir('quack')
+        transport = transport.clone('quack')
+        branch = self.make_remote_branch(transport, client)
+        self.lock_remote_branch(branch)
+        branch._set_tags_bytes('tags bytes')
+        self.assertFinished(client)
+        self.assertEqual('tags bytes', client._calls[-1][-1])
+
+    def test_backwards_compatible(self):
+        transport = MemoryTransport()
+        client = FakeClient(transport.base)
+        client.add_expected_call(
+            'Branch.get_stacked_on_url', ('quack/',),
+            'error', ('NotStacked',))
+        client.add_expected_call(
+            'Branch.set_tags_bytes', ('quack/', 'branch token', 'repo token'),
+            'unknown', ('Branch.set_tags_bytes',))
+        transport.mkdir('quack')
+        transport = transport.clone('quack')
+        branch = self.make_remote_branch(transport, client)
+        self.lock_remote_branch(branch)
+        class StubRealBranch(object):
+            def __init__(self):
+                self.calls = []
+            def _set_tags_bytes(self, bytes):
+                self.calls.append(('set_tags_bytes', bytes))
+        real_branch = StubRealBranch()
+        branch._real_branch = real_branch
+        branch._set_tags_bytes('tags bytes')
+        # Call a second time, to exercise the 'remote version already inferred'
+        # code path.
+        branch._set_tags_bytes('tags bytes')
+        self.assertFinished(client)
+        self.assertEqual(
+            [('set_tags_bytes', 'tags bytes')] * 2, real_branch.calls)
+
+
 class TestBranchLastRevisionInfo(RemoteBranchTestCase):
 
     def test_empty_branch(self):
@@ -1342,16 +1460,6 @@
             errors.NoSuchRevision, branch.set_last_revision_info, 123, 'revid')
         branch.unlock()
 
-    def lock_remote_branch(self, branch):
-        """Trick a RemoteBranch into thinking it is locked."""
-        branch._lock_mode = 'w'
-        branch._lock_count = 2
-        branch._lock_token = 'branch token'
-        branch._repo_lock_token = 'repo token'
-        branch.repository._lock_mode = 'w'
-        branch.repository._lock_count = 2
-        branch.repository._lock_token = 'repo token'
-
     def test_backwards_compatibility(self):
         """If the server does not support the Branch.set_last_revision_info
         verb (which is new in 1.4), then the client falls back to VFS methods.
@@ -1673,6 +1781,20 @@
         return repo, client
 
 
+def remoted_description(format):
+    return 'Remote: ' + format.get_format_description()
+
+
+class TestBranchFormat(tests.TestCase):
+
+    def test_get_format_description(self):
+        remote_format = RemoteBranchFormat()
+        real_format = branch.BranchFormat.get_default_format()
+        remote_format._network_name = real_format.network_name()
+        self.assertEqual(remoted_description(real_format),
+            remote_format.get_format_description())
+
+
 class TestRepositoryFormat(TestRemoteRepository):
 
     def test_fast_delta(self):
@@ -1685,6 +1807,13 @@
         false_format._network_name = false_name
         self.assertEqual(False, false_format.fast_deltas)
 
+    def test_get_format_description(self):
+        remote_repo_format = RemoteRepositoryFormat()
+        real_format = repository.RepositoryFormat.get_default_format()
+        remote_repo_format._network_name = real_format.network_name()
+        self.assertEqual(remoted_description(real_format),
+            remote_repo_format.get_format_description())
+
 
 class TestRepositoryGatherStats(TestRemoteRepository):
 
@@ -1945,8 +2074,7 @@
     def test_allows_new_revisions(self):
         """get_parent_map's results can be updated by commit."""
         smart_server = server.SmartTCPServer_for_testing()
-        smart_server.setUp()
-        self.addCleanup(smart_server.tearDown)
+        self.start_server(smart_server)
         self.make_branch('branch')
         branch = Branch.open(smart_server.get_url() + '/branch')
         tree = branch.create_checkout('tree', lightweight=True)
@@ -2093,6 +2221,26 @@
             repo.get_rev_id_for_revno, 5, (42, 'rev-foo'))
         self.assertFinished(client)
 
+    def test_branch_fallback_locking(self):
+        """RemoteBranch.get_rev_id takes a read lock, and tries to call the
+        get_rev_id_for_revno verb.  If the verb is unknown the VFS fallback
+        will be invoked, which will fail if the repo is unlocked.
+        """
+        self.setup_smart_server_with_call_log()
+        tree = self.make_branch_and_memory_tree('.')
+        tree.lock_write()
+        rev1 = tree.commit('First')
+        rev2 = tree.commit('Second')
+        tree.unlock()
+        branch = tree.branch
+        self.assertFalse(branch.is_locked())
+        self.reset_smart_call_log()
+        verb = 'Repository.get_rev_id_for_revno'
+        self.disable_verb(verb)
+        self.assertEqual(rev1, branch.get_rev_id(1))
+        self.assertLength(1, [call for call in self.hpss_calls if
+                              call.call.method == verb])
+
 
 class TestRepositoryIsShared(TestRemoteRepository):
 
@@ -2326,6 +2474,10 @@
         class FakeRealRepository:
             def _get_sink(self):
                 return fake_real_sink
+            def is_in_write_group(self):
+                return False
+            def refresh_data(self):
+                return True
         repo._real_repository = FakeRealRepository()
         sink = repo._get_sink()
         fmt = repository.RepositoryFormat.get_default_format()
@@ -2781,8 +2933,7 @@
         stacked_branch.set_stacked_on_url('../base')
         # start a server looking at this
         smart_server = server.SmartTCPServer_for_testing()
-        smart_server.setUp()
-        self.addCleanup(smart_server.tearDown)
+        self.start_server(smart_server)
         remote_bzrdir = BzrDir.open(smart_server.get_url() + '/stacked')
         # can get its branch and repository
         remote_branch = remote_bzrdir.open_branch()
@@ -2943,8 +3094,7 @@
         # Create a smart server that publishes whatever the backing VFS server
         # does.
         self.smart_server = server.SmartTCPServer_for_testing()
-        self.smart_server.setUp(self.get_server())
-        self.addCleanup(self.smart_server.tearDown)
+        self.start_server(self.smart_server, self.get_server())
         # Log all HPSS calls into self.hpss_calls.
         _SmartClient.hooks.install_named_hook(
             'call', self.capture_hpss_call, None)

=== modified file 'bzrlib/tests/test_repository.py'
--- bzrlib/tests/test_repository.py	2009-08-17 23:15:55 +0000
+++ bzrlib/tests/test_repository.py	2009-11-08 23:59:07 +0000
@@ -24,6 +24,7 @@
 
 from stat import S_ISDIR
 from StringIO import StringIO
+import sys
 
 import bzrlib
 from bzrlib.errors import (NotBranchError,
@@ -252,7 +253,14 @@
         tree = control.create_workingtree()
         tree.add(['foo'], ['Foo:Bar'], ['file'])
         tree.put_file_bytes_non_atomic('Foo:Bar', 'content\n')
-        tree.commit('first post', rev_id='first')
+        try:
+            tree.commit('first post', rev_id='first')
+        except errors.IllegalPath:
+            if sys.platform != 'win32':
+                raise
+            self.knownFailure('Foo:Bar cannot be used as a file-id on windows'
+                              ' in repo format 7')
+            return
         self.assertEqualDiff(
             '# bzr weave file v5\n'
             'i\n'
@@ -681,15 +689,84 @@
         self.assertFalse(repo._format.supports_external_lookups)
 
 
-class Test2a(TestCaseWithTransport):
+class Test2a(tests.TestCaseWithMemoryTransport):
+
+    def test_fetch_combines_groups(self):
+        builder = self.make_branch_builder('source', format='2a')
+        builder.start_series()
+        builder.build_snapshot('1', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        builder.build_snapshot('2', ['1'], [
+            ('modify', ('file-id', 'content-2\n'))])
+        builder.finish_series()
+        source = builder.get_branch()
+        target = self.make_repository('target', format='2a')
+        target.fetch(source.repository)
+        target.lock_read()
+        self.addCleanup(target.unlock)
+        details = target.texts._index.get_build_details(
+            [('file-id', '1',), ('file-id', '2',)])
+        file_1_details = details[('file-id', '1')]
+        file_2_details = details[('file-id', '2')]
+        # The index, and what to read off disk, should be the same for both
+        # versions of the file.
+        self.assertEqual(file_1_details[0][:3], file_2_details[0][:3])
+
+    def test_fetch_combines_groups(self):
+        builder = self.make_branch_builder('source', format='2a')
+        builder.start_series()
+        builder.build_snapshot('1', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        builder.build_snapshot('2', ['1'], [
+            ('modify', ('file-id', 'content-2\n'))])
+        builder.finish_series()
+        source = builder.get_branch()
+        target = self.make_repository('target', format='2a')
+        target.fetch(source.repository)
+        target.lock_read()
+        self.addCleanup(target.unlock)
+        details = target.texts._index.get_build_details(
+            [('file-id', '1',), ('file-id', '2',)])
+        file_1_details = details[('file-id', '1')]
+        file_2_details = details[('file-id', '2')]
+        # The index, and what to read off disk, should be the same for both
+        # versions of the file.
+        self.assertEqual(file_1_details[0][:3], file_2_details[0][:3])
+
+    def test_fetch_combines_groups(self):
+        builder = self.make_branch_builder('source', format='2a')
+        builder.start_series()
+        builder.build_snapshot('1', None, [
+            ('add', ('', 'root-id', 'directory', '')),
+            ('add', ('file', 'file-id', 'file', 'content\n'))])
+        builder.build_snapshot('2', ['1'], [
+            ('modify', ('file-id', 'content-2\n'))])
+        builder.finish_series()
+        source = builder.get_branch()
+        target = self.make_repository('target', format='2a')
+        target.fetch(source.repository)
+        target.lock_read()
+        self.addCleanup(target.unlock)
+        details = target.texts._index.get_build_details(
+            [('file-id', '1',), ('file-id', '2',)])
+        file_1_details = details[('file-id', '1')]
+        file_2_details = details[('file-id', '2')]
+        # The index, and what to read off disk, should be the same for both
+        # versions of the file.
+        self.assertEqual(file_1_details[0][:3], file_2_details[0][:3])
 
     def test_format_pack_compresses_True(self):
         repo = self.make_repository('repo', format='2a')
         self.assertTrue(repo._format.pack_compresses)
 
     def test_inventories_use_chk_map_with_parent_base_dict(self):
-        tree = self.make_branch_and_tree('repo', format="2a")
+        tree = self.make_branch_and_memory_tree('repo', format="2a")
+        tree.lock_write()
+        tree.add([''], ['TREE_ROOT'])
         revid = tree.commit("foo")
+        tree.unlock()
         tree.lock_read()
         self.addCleanup(tree.unlock)
         inv = tree.branch.repository.get_inventory(revid)
@@ -704,12 +781,19 @@
         # at 20 unchanged commits, chk pages are packed that are split into
         # two groups such that the new pack being made doesn't have all its
         # pages in the source packs (though they are in the repository).
-        tree = self.make_branch_and_tree('tree', format='2a')
+        # Use a memory backed repository, we don't need to hit disk for this
+        tree = self.make_branch_and_memory_tree('tree', format='2a')
+        tree.lock_write()
+        self.addCleanup(tree.unlock)
+        tree.add([''], ['TREE_ROOT'])
         for pos in range(20):
             tree.commit(str(pos))
 
     def test_pack_with_hint(self):
-        tree = self.make_branch_and_tree('tree', format='2a')
+        tree = self.make_branch_and_memory_tree('tree', format='2a')
+        tree.lock_write()
+        self.addCleanup(tree.unlock)
+        tree.add([''], ['TREE_ROOT'])
         # 1 commit to leave untouched
         tree.commit('1')
         to_keep = tree.branch.repository._pack_collection.names()
@@ -954,6 +1038,7 @@
             inv = inventory.Inventory(revision_id='rev1a')
             inv.root.revision = 'rev1a'
             self.add_file(repo, inv, 'file1', 'rev1a', [])
+            repo.texts.add_lines((inv.root.file_id, 'rev1a'), [], [])
             repo.add_inventory('rev1a', inv, [])
             revision = _mod_revision.Revision('rev1a',
                 committer='jrandom@example.com', timestamp=0,
@@ -994,6 +1079,7 @@
     def add_revision(self, repo, revision_id, inv, parent_ids):
         inv.revision_id = revision_id
         inv.root.revision = revision_id
+        repo.texts.add_lines((inv.root.file_id, revision_id), [], [])
         repo.add_inventory(revision_id, inv, parent_ids)
         revision = _mod_revision.Revision(revision_id,
             committer='jrandom@example.com', timestamp=0, inventory_sha1='',

=== modified file 'bzrlib/tests/test_revisionspec.py'
--- bzrlib/tests/test_revisionspec.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_revisionspec.py	2009-10-10 05:07:35 +0000
@@ -146,24 +146,49 @@
     def test_object(self):
         self.assertRaises(TypeError, RevisionSpec.from_string, object())
 
-    def test_unregistered_spec(self):
-        self.assertRaises(errors.NoSuchRevisionSpec,
-                          RevisionSpec.from_string, 'foo')
-        self.assertRaises(errors.NoSuchRevisionSpec,
-                          RevisionSpec.from_string, '123a')
-
-
-
-class TestRevnoFromString(TestCase):
-
-    def test_from_string_dotted_decimal(self):
-        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '-1.1')
-        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '.1')
-        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '1..1')
-        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '1.2..1')
-        self.assertRaises(errors.NoSuchRevisionSpec, RevisionSpec.from_string, '1.')
-        self.assertIsInstance(RevisionSpec.from_string('1.1'), RevisionSpec_revno)
-        self.assertIsInstance(RevisionSpec.from_string('1.1.3'), RevisionSpec_revno)
+
+class TestRevisionSpec_dwim(TestRevisionSpec):
+
+    # Don't need to test revno's explicitly since TRS_revno already
+    # covers that well for us
+    def test_dwim_spec_revno(self):
+        self.assertInHistoryIs(2, 'r2', '2')
+        self.assertAsRevisionId('alt_r2', '1.1.1')
+
+    def test_dwim_spec_revid(self):
+        self.assertInHistoryIs(2, 'r2', 'r2')
+
+    def test_dwim_spec_tag(self):
+        self.tree.branch.tags.set_tag('footag', 'r1')
+        self.assertAsRevisionId('r1', 'footag')
+        self.tree.branch.tags.delete_tag('footag')
+        self.assertRaises(errors.InvalidRevisionSpec,
+                          self.get_in_history, 'footag')
+
+    def test_dwim_spec_tag_that_looks_like_revno(self):
+        # Test that we slip past revno with things that look like revnos,
+        # but aren't.  Tags are convenient for testing this since we can
+        # make them look however we want.
+        self.tree.branch.tags.set_tag('3', 'r2')
+        self.assertAsRevisionId('r2', '3')
+        self.build_tree(['tree/b'])
+        self.tree.add(['b'])
+        self.tree.commit('b', rev_id='r3')
+        self.assertAsRevisionId('r3', '3')
+
+    def test_dwim_spec_date(self):
+        self.assertAsRevisionId('r1', 'today')
+
+    def test_dwim_spec_branch(self):
+        self.assertInHistoryIs(None, 'alt_r2', 'tree2')
+
+    def test_dwim_spec_nonexistent(self):
+        self.assertInvalid('somethingrandom', invalid_as_revision_id=False)
+        self.assertInvalid('-1.1', invalid_as_revision_id=False)
+        self.assertInvalid('.1', invalid_as_revision_id=False)
+        self.assertInvalid('1..1', invalid_as_revision_id=False)
+        self.assertInvalid('1.2..1', invalid_as_revision_id=False)
+        self.assertInvalid('1.', invalid_as_revision_id=False)
 
 
 class TestRevisionSpec_revno(TestRevisionSpec):

=== added file 'bzrlib/tests/test_script.py'
--- bzrlib/tests/test_script.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_script.py	2009-11-08 20:28:36 +0000
@@ -0,0 +1,409 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+
+from bzrlib import (
+    osutils,
+    tests,
+    )
+from bzrlib.tests import script
+
+
+class TestSyntax(tests.TestCase):
+
+    def test_comment_is_ignored(self):
+        self.assertEquals([], script._script_to_commands('#comment\n'))
+
+    def test_empty_line_is_ignored(self):
+        self.assertEquals([], script._script_to_commands('\n'))
+
+    def test_simple_command(self):
+        self.assertEquals([(['cd', 'trunk'], None, None, None)],
+                           script._script_to_commands('$ cd trunk'))
+
+    def test_command_with_single_quoted_param(self):
+        story = """$ bzr commit -m 'two words'"""
+        self.assertEquals([(['bzr', 'commit', '-m', "'two words'"],
+                            None, None, None)],
+                           script._script_to_commands(story))
+
+    def test_command_with_double_quoted_param(self):
+        story = """$ bzr commit -m "two words" """
+        self.assertEquals([(['bzr', 'commit', '-m', '"two words"'],
+                            None, None, None)],
+                           script._script_to_commands(story))
+
+    def test_command_with_input(self):
+        self.assertEquals(
+            [(['cat', '>file'], 'content\n', None, None)],
+            script._script_to_commands('$ cat >file\n<content\n'))
+
+    def test_command_with_output(self):
+        story = """
+$ bzr add
+adding file
+adding file2
+"""
+        self.assertEquals([(['bzr', 'add'], None,
+                            'adding file\nadding file2\n', None)],
+                          script._script_to_commands(story))
+
+    def test_command_with_error(self):
+        story = """
+$ bzr branch foo
+2>bzr: ERROR: Not a branch: "foo"
+"""
+        self.assertEquals([(['bzr', 'branch', 'foo'],
+                            None, None, 'bzr: ERROR: Not a branch: "foo"\n')],
+                          script._script_to_commands(story))
+
+    def test_input_without_command(self):
+        self.assertRaises(SyntaxError, script._script_to_commands, '<input')
+
+    def test_output_without_command(self):
+        self.assertRaises(SyntaxError, script._script_to_commands, '>input')
+
+    def test_command_with_backquotes(self):
+        story = """
+$ foo = `bzr file-id toto`
+"""
+        self.assertEquals([(['foo', '=', '`bzr file-id toto`'],
+                            None, None, None)],
+                          script._script_to_commands(story))
+
+
+class TestRedirections(tests.TestCase):
+
+    def _check(self, in_name, out_name, out_mode, remaining, args):
+        self.assertEqual(script._scan_redirection_options(args),
+                         (in_name, out_name, out_mode, remaining))
+
+    def test_no_redirection(self):
+        self._check(None, None, None, [], [])
+        self._check(None, None, None, ['foo', 'bar'], ['foo', 'bar'])
+
+    def test_input_redirection(self):
+        self._check('foo', None, None, [], ['<foo'])
+        self._check('foo', None, None, ['bar'], ['bar', '<foo'])
+        self._check('foo', None, None, ['bar'], ['bar', '<', 'foo'])
+        self._check('foo', None, None, ['bar'], ['<foo', 'bar'])
+        self._check('foo', None, None, ['bar', 'baz'], ['bar', '<foo', 'baz'])
+
+    def test_output_redirection(self):
+        self._check(None, 'foo', 'wb+', [], ['>foo'])
+        self._check(None, 'foo', 'wb+', ['bar'], ['bar', '>foo'])
+        self._check(None, 'foo', 'wb+', ['bar'], ['bar', '>', 'foo'])
+        self._check(None, 'foo', 'ab+', [], ['>>foo'])
+        self._check(None, 'foo', 'ab+', ['bar'], ['bar', '>>foo'])
+        self._check(None, 'foo', 'ab+', ['bar'], ['bar', '>>', 'foo'])
+
+    def test_redirection_syntax_errors(self):
+        self._check('', None, None, [], ['<'])
+        self._check(None, '', 'wb+', [], ['>'])
+        self._check(None, '', 'ab+', [], ['>>'])
+        self._check('>', '', 'ab+', [], ['<', '>', '>>'])
+
+
+
+class TestExecution(script.TestCaseWithTransportAndScript):
+
+    def test_unknown_command(self):
+        self.assertRaises(SyntaxError, self.run_script, 'foo')
+
+    def test_stops_on_unexpected_output(self):
+        story = """
+$ mkdir dir
+$ cd dir
+The cd command ouputs nothing
+"""
+        self.assertRaises(AssertionError, self.run_script, story)
+
+
+    def test_stops_on_unexpected_error(self):
+        story = """
+$ cat
+<Hello
+$ bzr not-a-command
+"""
+        self.assertRaises(AssertionError, self.run_script, story)
+
+    def test_continue_on_expected_error(self):
+        story = """
+$ bzr not-a-command
+2>..."not-a-command"
+"""
+        self.run_script(story)
+
+    def test_continue_on_error_output(self):
+        # The status matters, not the output
+        story = """
+$ bzr init
+$ cat >file
+<Hello
+$ bzr add file
+$ bzr commit -m 'adding file'
+"""
+        self.run_script(story)
+
+    def test_ellipsis_output(self):
+        story = """
+$ cat
+<first line
+<second line
+<last line
+first line
+...
+last line
+"""
+        self.run_script(story)
+        story = """
+$ bzr not-a-command
+2>..."not-a-command"
+"""
+        self.run_script(story)
+
+        story = """
+$ bzr branch not-a-branch
+2>bzr: ERROR: Not a branch...not-a-branch/".
+"""
+        self.run_script(story)
+
+
+class TestArgumentProcessing(script.TestCaseWithTransportAndScript):
+
+    def test_globing(self):
+        self.run_script("""
+$ echo cat >cat
+$ echo dog >dog
+$ cat *
+cat
+dog
+""")
+
+    def test_quoted_globbing(self):
+        self.run_script("""
+$ echo cat >cat
+$ cat '*'
+2>*: No such file or directory
+""")
+
+    def test_quotes_removal(self):
+        self.run_script("""
+$ echo 'cat' "dog" '"chicken"' "'dragon'"
+cat dog "chicken" 'dragon'
+""")
+
+
+class TestCat(script.TestCaseWithTransportAndScript):
+
+    def test_cat_usage(self):
+        self.assertRaises(SyntaxError, self.run_script, 'cat foo <bar')
+
+    def test_cat_input_to_output(self):
+        retcode, out, err = self.run_command(['cat'],
+                                             'content\n', 'content\n', None)
+        self.assertEquals('content\n', out)
+        self.assertEquals(None, err)
+
+    def test_cat_file_to_output(self):
+        self.build_tree_contents([('file', 'content\n')])
+        retcode, out, err = self.run_command(['cat', 'file'],
+                                             None, 'content\n', None)
+        self.assertEquals('content\n', out)
+        self.assertEquals(None, err)
+
+    def test_cat_input_to_file(self):
+        retcode, out, err = self.run_command(['cat', '>file'],
+                                             'content\n', None, None)
+        self.assertFileEqual('content\n', 'file')
+        self.assertEquals(None, out)
+        self.assertEquals(None, err)
+        retcode, out, err = self.run_command(['cat', '>>file'],
+                                             'more\n', None, None)
+        self.assertFileEqual('content\nmore\n', 'file')
+        self.assertEquals(None, out)
+        self.assertEquals(None, err)
+
+    def test_cat_file_to_file(self):
+        self.build_tree_contents([('file', 'content\n')])
+        retcode, out, err = self.run_command(['cat', 'file', '>file2'],
+                                             None, None, None)
+        self.assertFileEqual('content\n', 'file2')
+
+    def test_cat_files_to_file(self):
+        self.build_tree_contents([('cat', 'cat\n')])
+        self.build_tree_contents([('dog', 'dog\n')])
+        retcode, out, err = self.run_command(['cat', 'cat', 'dog', '>file'],
+                                             None, None, None)
+        self.assertFileEqual('cat\ndog\n', 'file')
+
+    def test_cat_bogus_input_file(self):
+        self.run_script("""
+$ cat <file
+2>file: No such file or directory
+""")
+
+    def test_cat_bogus_output_file(self):
+        self.run_script("""
+$ cat >
+2>: No such file or directory
+""")
+
+    def test_echo_bogus_output_file(self):
+        # We need a backing file sysytem for that test so it can't be in
+        # TestEcho
+        self.run_script("""
+$ echo >
+2>: No such file or directory
+""")
+
+
+class TestMkdir(script.TestCaseWithTransportAndScript):
+
+    def test_mkdir_usage(self):
+        self.assertRaises(SyntaxError, self.run_script, '$ mkdir')
+        self.assertRaises(SyntaxError, self.run_script, '$ mkdir foo bar')
+
+    def test_mkdir_jailed(self):
+        self.assertRaises(ValueError, self.run_script, '$ mkdir /out-of-jail')
+        self.assertRaises(ValueError, self.run_script, '$ mkdir ../out-of-jail')
+
+    def test_mkdir_in_jail(self):
+        self.run_script("""
+$ mkdir dir
+$ cd dir
+$ mkdir ../dir2
+$ cd ..
+""")
+        self.failUnlessExists('dir')
+        self.failUnlessExists('dir2')
+
+
+class TestCd(script.TestCaseWithTransportAndScript):
+
+    def test_cd_usage(self):
+        self.assertRaises(SyntaxError, self.run_script, '$ cd foo bar')
+
+    def test_cd_out_of_jail(self):
+        self.assertRaises(ValueError, self.run_script, '$ cd /out-of-jail')
+        self.assertRaises(ValueError, self.run_script, '$ cd ..')
+
+    def test_cd_dir_and_back_home(self):
+        self.assertEquals(self.test_dir, osutils.getcwd())
+        self.run_script("""
+$ mkdir dir
+$ cd dir
+""")
+        self.assertEquals(osutils.pathjoin(self.test_dir, 'dir'),
+                          osutils.getcwd())
+
+        self.run_script('$ cd')
+        self.assertEquals(self.test_dir, osutils.getcwd())
+
+
+class TestBzr(script.TestCaseWithTransportAndScript):
+
+    def test_bzr_smoke(self):
+        self.run_script('$ bzr init branch')
+        self.failUnlessExists('branch')
+
+
+class TestEcho(script.TestCaseWithMemoryTransportAndScript):
+
+    def test_echo_usage(self):
+        story = """
+$ echo foo
+<bar
+"""
+        self.assertRaises(SyntaxError, self.run_script, story)
+
+    def test_echo_input(self):
+        self.assertRaises(SyntaxError, self.run_script, """
+            $ echo <foo
+            """)
+
+    def test_echo_to_output(self):
+        retcode, out, err = self.run_command(['echo'], None, '\n', None)
+        self.assertEquals('\n', out)
+        self.assertEquals(None, err)
+
+    def test_echo_some_to_output(self):
+        retcode, out, err = self.run_command(['echo', 'hello'],
+                                             None, 'hello\n', None)
+        self.assertEquals('hello\n', out)
+        self.assertEquals(None, err)
+
+    def test_echo_more_output(self):
+        retcode, out, err = self.run_command(
+            ['echo', 'hello', 'happy', 'world'],
+            None, 'hello happy world\n', None)
+        self.assertEquals('hello happy world\n', out)
+        self.assertEquals(None, err)
+
+    def test_echo_appended(self):
+        retcode, out, err = self.run_command(['echo', 'hello', '>file'],
+                                             None, None, None)
+        self.assertEquals(None, out)
+        self.assertEquals(None, err)
+        self.assertFileEqual('hello\n', 'file')
+        retcode, out, err = self.run_command(['echo', 'happy', '>>file'],
+                                             None, None, None)
+        self.assertEquals(None, out)
+        self.assertEquals(None, err)
+        self.assertFileEqual('hello\nhappy\n', 'file')
+
+
+class TestRm(script.TestCaseWithTransportAndScript):
+
+    def test_rm_usage(self):
+        self.assertRaises(SyntaxError, self.run_script, '$ rm')
+        self.assertRaises(SyntaxError, self.run_script, '$ rm -ff foo')
+
+    def test_rm_file(self):
+        self.run_script('$ echo content >file')
+        self.failUnlessExists('file')
+        self.run_script('$ rm file')
+        self.failIfExists('file')
+
+    def test_rm_file_force(self):
+        self.failIfExists('file')
+        self.run_script('$ rm -f file')
+        self.failIfExists('file')
+
+    def test_rm_files(self):
+        self.run_script("""
+$ echo content >file
+$ echo content >file2
+""")
+        self.failUnlessExists('file2')
+        self.run_script('$ rm file file2')
+        self.failIfExists('file2')
+
+    def test_rm_dir(self):
+        self.run_script('$ mkdir dir')
+        self.failUnlessExists('dir')
+        self.run_script("""
+$ rm dir
+2>rm: cannot remove 'dir': Is a directory
+""")
+        self.failUnlessExists('dir')
+
+    def test_rm_dir_recursive(self):
+        self.run_script("""
+$ mkdir dir
+$ rm -r dir
+""")
+        self.failIfExists('dir')

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2009-08-24 05:35:28 +0000
+++ bzrlib/tests/test_selftest.py	2009-11-24 02:25:23 +0000
@@ -38,6 +38,7 @@
     repository,
     symbol_versioning,
     tests,
+    transport,
     workingtree,
     )
 from bzrlib.repofmt import (
@@ -489,9 +490,9 @@
         self.assertEqualStat(real, fake)
 
     def test_assertEqualStat_notequal(self):
-        self.build_tree(["foo", "bar"])
+        self.build_tree(["foo", "longname"])
         self.assertRaises(AssertionError, self.assertEqualStat,
-            os.lstat("foo"), os.lstat("bar"))
+            os.lstat("foo"), os.lstat("longname"))
 
 
 class TestTestCaseWithMemoryTransport(tests.TestCaseWithMemoryTransport):
@@ -515,6 +516,14 @@
         cwd = osutils.getcwd()
         self.assertIsSameRealPath(self.test_dir, cwd)
 
+    def test_BZR_HOME_and_HOME_are_bytestrings(self):
+        """The $BZR_HOME and $HOME environment variables should not be unicode.
+
+        See https://bugs.launchpad.net/bzr/+bug/464174
+        """
+        self.assertIsInstance(os.environ['BZR_HOME'], str)
+        self.assertIsInstance(os.environ['HOME'], str)
+
     def test_make_branch_and_memory_tree(self):
         """In TestCaseWithMemoryTransport we should not make the branch on disk.
 
@@ -576,19 +585,6 @@
                          self.get_transport().get_bytes(
                             'dir/.bzr/repository/format'))
 
-    def test_safety_net(self):
-        """No test should modify the safety .bzr directory.
-
-        We just test that the _check_safety_net private method raises
-        AssertionError, it's easier than building a test suite with the same
-        test.
-        """
-        # Oops, a commit in the current directory (i.e. without local .bzr
-        # directory) will crawl up the hierarchy to find a .bzr directory.
-        self.run_bzr(['commit', '-mfoo', '--unchanged'])
-        # But we have a safety net in place.
-        self.assertRaises(AssertionError, self._check_safety_net)
-
     def test_dangling_locks_cause_failures(self):
         class TestDanglingLock(tests.TestCaseWithMemoryTransport):
             def test_function(self):
@@ -687,6 +683,26 @@
         self.assertEqual(url, t.clone('..').base)
 
 
+class TestProfileResult(tests.TestCase):
+
+    def test_profiles_tests(self):
+        self.requireFeature(test_lsprof.LSProfFeature)
+        terminal = unittest.TestResult()
+        result = tests.ProfileResult(terminal)
+        class Sample(tests.TestCase):
+            def a(self):
+                self.sample_function()
+            def sample_function(self):
+                pass
+        test = Sample("a")
+        test.attrs_to_keep = test.attrs_to_keep + ('_benchcalls',)
+        test.run(result)
+        self.assertLength(1, test._benchcalls)
+        # We must be able to unpack it as the test reporting code wants
+        (_, _, _), stats = test._benchcalls[0]
+        self.assertTrue(callable(stats.pprint))
+
+
 class TestTestResult(tests.TestCase):
 
     def check_timing(self, test_case, expected_re):
@@ -719,7 +735,19 @@
         self.check_timing(ShortDelayTestCase('test_short_delay'),
                           r"^ +[0-9]+ms$")
 
+    def _patch_get_bzr_source_tree(self):
+        # Reading from the actual source tree breaks isolation, but we don't
+        # want to assume that thats *all* that would happen.
+        def _get_bzr_source_tree():
+            return None
+        orig_get_bzr_source_tree = bzrlib.version._get_bzr_source_tree
+        bzrlib.version._get_bzr_source_tree = _get_bzr_source_tree
+        def restore():
+            bzrlib.version._get_bzr_source_tree = orig_get_bzr_source_tree
+        self.addCleanup(restore)
+
     def test_assigned_benchmark_file_stores_date(self):
+        self._patch_get_bzr_source_tree()
         output = StringIO()
         result = bzrlib.tests.TextTestResult(self._log_file,
                                         descriptions=0,
@@ -733,6 +761,7 @@
         self.assertContainsRe(output_string, "--date [0-9.]+")
 
     def test_benchhistory_records_test_times(self):
+        self._patch_get_bzr_source_tree()
         result_stream = StringIO()
         result = bzrlib.tests.TextTestResult(
             self._log_file,
@@ -800,15 +829,16 @@
     def test_known_failure(self):
         """A KnownFailure being raised should trigger several result actions."""
         class InstrumentedTestResult(tests.ExtendedTestResult):
-            def done(self): pass
+            def stopTestRun(self): pass
             def startTests(self): pass
             def report_test_start(self, test): pass
             def report_known_failure(self, test, err):
                 self._call = test, err
         result = InstrumentedTestResult(None, None, None, None)
-        def test_function():
-            raise tests.KnownFailure('failed!')
-        test = unittest.FunctionTestCase(test_function)
+        class Test(tests.TestCase):
+            def test_function(self):
+                raise tests.KnownFailure('failed!')
+        test = Test("test_function")
         test.run(result)
         # it should invoke 'report_known_failure'.
         self.assertEqual(2, len(result._call))
@@ -854,7 +884,7 @@
     def test_add_not_supported(self):
         """Test the behaviour of invoking addNotSupported."""
         class InstrumentedTestResult(tests.ExtendedTestResult):
-            def done(self): pass
+            def stopTestRun(self): pass
             def startTests(self): pass
             def report_test_start(self, test): pass
             def report_unsupported(self, test, feature):
@@ -898,16 +928,17 @@
     def test_unavailable_exception(self):
         """An UnavailableFeature being raised should invoke addNotSupported."""
         class InstrumentedTestResult(tests.ExtendedTestResult):
-            def done(self): pass
+            def stopTestRun(self): pass
             def startTests(self): pass
             def report_test_start(self, test): pass
             def addNotSupported(self, test, feature):
                 self._call = test, feature
         result = InstrumentedTestResult(None, None, None, None)
         feature = tests.Feature()
-        def test_function():
-            raise tests.UnavailableFeature(feature)
-        test = unittest.FunctionTestCase(test_function)
+        class Test(tests.TestCase):
+            def test_function(self):
+                raise tests.UnavailableFeature(feature)
+        test = Test("test_function")
         test.run(result)
         # it should invoke 'addNotSupported'.
         self.assertEqual(2, len(result._call))
@@ -930,7 +961,7 @@
                                              verbosity=1)
         test = self.get_passing_test()
         err = (tests.KnownFailure, tests.KnownFailure('foo'), None)
-        result._addKnownFailure(test, err)
+        result.addExpectedFailure(test, err)
         self.assertFalse(result.wasStrictlySuccessful())
         self.assertEqual(None, result._extractBenchmarkTime(test))
 
@@ -981,19 +1012,23 @@
         because of our use of global state.
         """
         old_root = tests.TestCaseInTempDir.TEST_ROOT
+        old_leak = tests.TestCase._first_thread_leaker_id
         try:
             tests.TestCaseInTempDir.TEST_ROOT = None
+            tests.TestCase._first_thread_leaker_id = None
             return testrunner.run(test)
         finally:
             tests.TestCaseInTempDir.TEST_ROOT = old_root
+            tests.TestCase._first_thread_leaker_id = old_leak
 
     def test_known_failure_failed_run(self):
         # run a test that generates a known failure which should be printed in
         # the final output when real failures occur.
-        def known_failure_test():
-            raise tests.KnownFailure('failed')
+        class Test(tests.TestCase):
+            def known_failure_test(self):
+                raise tests.KnownFailure('failed')
         test = unittest.TestSuite()
-        test.addTest(unittest.FunctionTestCase(known_failure_test))
+        test.addTest(Test("known_failure_test"))
         def failing_test():
             raise AssertionError('foo')
         test.addTest(unittest.FunctionTestCase(failing_test))
@@ -1017,10 +1052,12 @@
             )
 
     def test_known_failure_ok_run(self):
-        # run a test that generates a known failure which should be printed in the final output.
-        def known_failure_test():
-            raise tests.KnownFailure('failed')
-        test = unittest.FunctionTestCase(known_failure_test)
+        # run a test that generates a known failure which should be printed in
+        # the final output.
+        class Test(tests.TestCase):
+            def known_failure_test(self):
+                raise tests.KnownFailure('failed')
+        test = Test("known_failure_test")
         stream = StringIO()
         runner = tests.TextTestRunner(stream=stream)
         result = self.run_test_runner(runner, test)
@@ -1031,6 +1068,20 @@
             '\n'
             'OK \\(known_failures=1\\)\n')
 
+    def test_result_decorator(self):
+        # decorate results
+        calls = []
+        class LoggingDecorator(tests.ForwardingResult):
+            def startTest(self, test):
+                tests.ForwardingResult.startTest(self, test)
+                calls.append('start')
+        test = unittest.FunctionTestCase(lambda:None)
+        stream = StringIO()
+        runner = tests.TextTestRunner(stream=stream,
+            result_decorators=[LoggingDecorator])
+        result = self.run_test_runner(runner, test)
+        self.assertLength(1, calls)
+
     def test_skipped_test(self):
         # run a test that is skipped, and check the suite as a whole still
         # succeeds.
@@ -1089,11 +1140,12 @@
 
     def test_not_applicable(self):
         # run a test that is skipped because it's not applicable
-        def not_applicable_test():
-            raise tests.TestNotApplicable('this test never runs')
+        class Test(tests.TestCase):
+            def not_applicable_test(self):
+                raise tests.TestNotApplicable('this test never runs')
         out = StringIO()
         runner = tests.TextTestRunner(stream=out, verbosity=2)
-        test = unittest.FunctionTestCase(not_applicable_test)
+        test = Test("not_applicable_test")
         result = self.run_test_runner(runner, test)
         self._log_file.write(out.getvalue())
         self.assertTrue(result.wasSuccessful())
@@ -1103,10 +1155,6 @@
         self.assertContainsRe(out.getvalue(),
                 r'(?m)^    this test never runs')
 
-    def test_not_applicable_demo(self):
-        # just so you can see it in the test output
-        raise tests.TestNotApplicable('this test is just a demonstation')
-
     def test_unsupported_features_listed(self):
         """When unsupported features are encountered they are detailed."""
         class Feature1(tests.Feature):
@@ -1132,11 +1180,24 @@
             ],
             lines[-3:])
 
+    def _patch_get_bzr_source_tree(self):
+        # Reading from the actual source tree breaks isolation, but we don't
+        # want to assume that thats *all* that would happen.
+        self._get_source_tree_calls = []
+        def _get_bzr_source_tree():
+            self._get_source_tree_calls.append("called")
+            return None
+        orig_get_bzr_source_tree = bzrlib.version._get_bzr_source_tree
+        bzrlib.version._get_bzr_source_tree = _get_bzr_source_tree
+        def restore():
+            bzrlib.version._get_bzr_source_tree = orig_get_bzr_source_tree
+        self.addCleanup(restore)
+
     def test_bench_history(self):
-        # tests that the running the benchmark produces a history file
-        # containing a timestamp and the revision id of the bzrlib source which
-        # was tested.
-        workingtree = _get_bzr_source_tree()
+        # tests that the running the benchmark passes bench_history into
+        # the test result object. We can tell that happens if
+        # _get_bzr_source_tree is called.
+        self._patch_get_bzr_source_tree()
         test = TestRunner('dummy_test')
         output = StringIO()
         runner = tests.TextTestRunner(stream=self._log_file,
@@ -1144,9 +1205,7 @@
         result = self.run_test_runner(runner, test)
         output_string = output.getvalue()
         self.assertContainsRe(output_string, "--date [0-9.]+")
-        if workingtree is not None:
-            revision_id = workingtree.get_parent_ids()[0]
-            self.assertEndsWith(output_string.rstrip(), revision_id)
+        self.assertLength(1, self._get_source_tree_calls)
 
     def assertLogDeleted(self, test):
         log = test._get_log()
@@ -1261,6 +1320,34 @@
         self.assertContainsRe(log, 'this will be kept')
         self.assertEqual(log, test._log_contents)
 
+    def test_startTestRun(self):
+        """run should call result.startTestRun()"""
+        calls = []
+        class LoggingDecorator(tests.ForwardingResult):
+            def startTestRun(self):
+                tests.ForwardingResult.startTestRun(self)
+                calls.append('startTestRun')
+        test = unittest.FunctionTestCase(lambda:None)
+        stream = StringIO()
+        runner = tests.TextTestRunner(stream=stream,
+            result_decorators=[LoggingDecorator])
+        result = self.run_test_runner(runner, test)
+        self.assertLength(1, calls)
+
+    def test_stopTestRun(self):
+        """run should call result.stopTestRun()"""
+        calls = []
+        class LoggingDecorator(tests.ForwardingResult):
+            def stopTestRun(self):
+                tests.ForwardingResult.stopTestRun(self)
+                calls.append('stopTestRun')
+        test = unittest.FunctionTestCase(lambda:None)
+        stream = StringIO()
+        runner = tests.TextTestRunner(stream=stream,
+            result_decorators=[LoggingDecorator])
+        result = self.run_test_runner(runner, test)
+        self.assertLength(1, calls)
+
 
 class SampleTestCase(tests.TestCase):
 
@@ -1432,6 +1519,7 @@
         outer_test = TestTestCase("outer_child")
         result = self.make_test_result()
         outer_test.run(result)
+        self.addCleanup(osutils.delete_any, outer_test._log_file_name)
         self.assertEqual(original_trace, bzrlib.trace._trace_file)
 
     def method_that_times_a_bit_twice(self):
@@ -1480,11 +1568,29 @@
         self.assertEqual((time.sleep, (0.003,), {}), self._benchcalls[1][0])
         self.assertIsInstance(self._benchcalls[0][1], bzrlib.lsprof.Stats)
         self.assertIsInstance(self._benchcalls[1][1], bzrlib.lsprof.Stats)
+        del self._benchcalls[:]
 
     def test_knownFailure(self):
         """Self.knownFailure() should raise a KnownFailure exception."""
         self.assertRaises(tests.KnownFailure, self.knownFailure, "A Failure")
 
+    def test_open_bzrdir_safe_roots(self):
+        # even a memory transport should fail to open when its url isn't 
+        # permitted.
+        # Manually set one up (TestCase doesn't and shouldn't provide magic
+        # machinery)
+        transport_server = MemoryServer()
+        transport_server.setUp()
+        self.addCleanup(transport_server.tearDown)
+        t = transport.get_transport(transport_server.get_url())
+        bzrdir.BzrDir.create(t.base)
+        self.assertRaises(errors.BzrError,
+            bzrdir.BzrDir.open_from_transport, t)
+        # But if we declare this as safe, we can open the bzrdir.
+        self.permit_url(t.base)
+        self._bzr_selftest_roots.append(t.base)
+        bzrdir.BzrDir.open_from_transport(t)
+
     def test_requireFeature_available(self):
         """self.requireFeature(available) is a no-op."""
         class Available(tests.Feature):
@@ -1557,6 +1663,14 @@
             ],
             result.calls)
 
+    def test_start_server_registers_url(self):
+        transport_server = MemoryServer()
+        # A little strict, but unlikely to be changed soon.
+        self.assertEqual([], self._bzr_selftest_roots)
+        self.start_server(transport_server)
+        self.assertSubset([transport_server.get_url()],
+            self._bzr_selftest_roots)
+
     def test_assert_list_raises_on_generator(self):
         def generator_which_will_raise():
             # This will not raise until after the first yield
@@ -1660,6 +1774,21 @@
         self.assertEndsWith('foo', 'oo')
         self.assertRaises(AssertionError, self.assertEndsWith, 'o', 'oo')
 
+    def test_assertEqualDiff(self):
+        e = self.assertRaises(AssertionError,
+                              self.assertEqualDiff, '', '\n')
+        self.assertEquals(str(e),
+                          # Don't blink ! The '+' applies to the second string
+                          'first string is missing a final newline.\n+ \n')
+        e = self.assertRaises(AssertionError,
+                              self.assertEqualDiff, '\n', '')
+        self.assertEquals(str(e),
+                          # Don't blink ! The '-' applies to the second string
+                          'second string is missing a final newline.\n- \n')
+
+
+class TestDeprecations(tests.TestCase):
+
     def test_applyDeprecated_not_deprecated(self):
         sample_object = ApplyDeprecatedHelper()
         # calling an undeprecated callable raises an assertion
@@ -1742,16 +1871,16 @@
         tree = self.make_branch_and_memory_tree('a')
         self.assertIsInstance(tree, bzrlib.memorytree.MemoryTree)
 
-
-class TestSFTPMakeBranchAndTree(test_sftp_transport.TestCaseWithSFTPServer):
-
-    def test_make_tree_for_sftp_branch(self):
-        """Transports backed by local directories create local trees."""
-        # NB: This is arguably a bug in the definition of make_branch_and_tree.
+    def test_make_tree_for_local_vfs_backed_transport(self):
+        # make_branch_and_tree has to use local branch and repositories
+        # when the vfs transport and local disk are colocated, even if
+        # a different transport is in use for url generation.
+        from bzrlib.transport.fakevfat import FakeVFATServer
+        self.transport_server = FakeVFATServer
+        self.assertFalse(self.get_url('t1').startswith('file://'))
         tree = self.make_branch_and_tree('t1')
         base = tree.bzrdir.root_transport.base
-        self.failIf(base.startswith('sftp'),
-                'base %r is on sftp but should be local' % base)
+        self.assertStartsWith(base, 'file://')
         self.assertEquals(tree.bzrdir.root_transport,
                 tree.branch.bzrdir.root_transport)
         self.assertEquals(tree.bzrdir.root_transport,
@@ -1817,6 +1946,20 @@
         self.assertNotContainsRe("Test.b", output.getvalue())
         self.assertLength(2, output.readlines())
 
+    def test_lsprof_tests(self):
+        self.requireFeature(test_lsprof.LSProfFeature)
+        calls = []
+        class Test(object):
+            def __call__(test, result):
+                test.run(result)
+            def run(test, result):
+                self.assertIsInstance(result, tests.ForwardingResult)
+                calls.append("called")
+            def countTestCases(self):
+                return 1
+        self.run_selftest(test_suite_factory=Test, lsprof_tests=True)
+        self.assertLength(1, calls)
+
     def test_random(self):
         # test randomising by listing a number of tests.
         output_123 = self.run_selftest(test_suite_factory=self.factory,
@@ -1877,8 +2020,8 @@
     def test_transport_sftp(self):
         try:
             import bzrlib.transport.sftp
-        except ParamikoNotPresent:
-            raise TestSkipped("Paramiko not present")
+        except errors.ParamikoNotPresent:
+            raise tests.TestSkipped("Paramiko not present")
         self.check_transport_set(bzrlib.transport.sftp.SFTPAbsoluteServer)
 
     def test_transport_memory(self):
@@ -1914,30 +2057,32 @@
 
         Attempts to run bzr from inside this class don't actually run it.
 
-        We test how run_bzr actually invokes bzr in another location.
-        Here we only need to test that it is run_bzr passes the right
-        parameters to run_bzr.
+        We test how run_bzr actually invokes bzr in another location.  Here we
+        only need to test that it passes the right parameters to run_bzr.
         """
         self.argv = list(argv)
         self.retcode = retcode
         self.encoding = encoding
         self.stdin = stdin
         self.working_dir = working_dir
-        return self.out, self.err
+        return self.retcode, self.out, self.err
 
     def test_run_bzr_error(self):
         self.out = "It sure does!\n"
         out, err = self.run_bzr_error(['^$'], ['rocks'], retcode=34)
         self.assertEqual(['rocks'], self.argv)
         self.assertEqual(34, self.retcode)
-        self.assertEqual(out, 'It sure does!\n')
+        self.assertEqual('It sure does!\n', out)
+        self.assertEquals(out, self.out)
+        self.assertEqual('', err)
+        self.assertEquals(err, self.err)
 
     def test_run_bzr_error_regexes(self):
         self.out = ''
         self.err = "bzr: ERROR: foobarbaz is not versioned"
         out, err = self.run_bzr_error(
-                ["bzr: ERROR: foobarbaz is not versioned"],
-                ['file-id', 'foobarbaz'])
+            ["bzr: ERROR: foobarbaz is not versioned"],
+            ['file-id', 'foobarbaz'])
 
     def test_encoding(self):
         """Test that run_bzr passes encoding to _run_bzr_core"""
@@ -2072,7 +2217,8 @@
         return self.out, self.err
 
 
-class TestRunBzrSubprocess(tests.TestCaseWithTransport):
+class TestWithFakedStartBzrSubprocess(tests.TestCaseWithTransport):
+    """Base class for tests testing how we might run bzr."""
 
     def setUp(self):
         tests.TestCaseWithTransport.setUp(self)
@@ -2089,6 +2235,9 @@
             'working_dir':working_dir, 'allow_plugins':allow_plugins})
         return self.next_subprocess
 
+
+class TestRunBzrSubprocess(TestWithFakedStartBzrSubprocess):
+
     def assertRunBzrSubprocess(self, expected_args, process, *args, **kwargs):
         """Run run_bzr_subprocess with args and kwargs using a stubbed process.
 
@@ -2157,6 +2306,32 @@
             StubProcess(), '', allow_plugins=True)
 
 
+class TestFinishBzrSubprocess(TestWithFakedStartBzrSubprocess):
+
+    def test_finish_bzr_subprocess_with_error(self):
+        """finish_bzr_subprocess allows specification of the desired exit code.
+        """
+        process = StubProcess(err="unknown command", retcode=3)
+        result = self.finish_bzr_subprocess(process, retcode=3)
+        self.assertEqual('', result[0])
+        self.assertContainsRe(result[1], 'unknown command')
+
+    def test_finish_bzr_subprocess_ignoring_retcode(self):
+        """finish_bzr_subprocess allows the exit code to be ignored."""
+        process = StubProcess(err="unknown command", retcode=3)
+        result = self.finish_bzr_subprocess(process, retcode=None)
+        self.assertEqual('', result[0])
+        self.assertContainsRe(result[1], 'unknown command')
+
+    def test_finish_subprocess_with_unexpected_retcode(self):
+        """finish_bzr_subprocess raises self.failureException if the retcode is
+        not the expected one.
+        """
+        process = StubProcess(err="unknown command", retcode=3)
+        self.assertRaises(self.failureException, self.finish_bzr_subprocess,
+                          process)
+
+
 class _DontSpawnProcess(Exception):
     """A simple exception which just allows us to skip unnecessary steps"""
 
@@ -2240,44 +2415,14 @@
         self.assertEqual(['foo', 'current'], chdirs)
 
 
-class TestBzrSubprocess(tests.TestCaseWithTransport):
-
-    def test_start_and_stop_bzr_subprocess(self):
-        """We can start and perform other test actions while that process is
-        still alive.
-        """
-        process = self.start_bzr_subprocess(['--version'])
-        result = self.finish_bzr_subprocess(process)
-        self.assertContainsRe(result[0], 'is free software')
-        self.assertEqual('', result[1])
-
-    def test_start_and_stop_bzr_subprocess_with_error(self):
-        """finish_bzr_subprocess allows specification of the desired exit code.
-        """
-        process = self.start_bzr_subprocess(['--versionn'])
-        result = self.finish_bzr_subprocess(process, retcode=3)
-        self.assertEqual('', result[0])
-        self.assertContainsRe(result[1], 'unknown command')
-
-    def test_start_and_stop_bzr_subprocess_ignoring_retcode(self):
-        """finish_bzr_subprocess allows the exit code to be ignored."""
-        process = self.start_bzr_subprocess(['--versionn'])
-        result = self.finish_bzr_subprocess(process, retcode=None)
-        self.assertEqual('', result[0])
-        self.assertContainsRe(result[1], 'unknown command')
-
-    def test_start_and_stop_bzr_subprocess_with_unexpected_retcode(self):
-        """finish_bzr_subprocess raises self.failureException if the retcode is
-        not the expected one.
-        """
-        process = self.start_bzr_subprocess(['--versionn'])
-        self.assertRaises(self.failureException, self.finish_bzr_subprocess,
-                          process)
+class TestActuallyStartBzrSubprocess(tests.TestCaseWithTransport):
+    """Tests that really need to do things with an external bzr."""
 
     def test_start_and_stop_bzr_subprocess_send_signal(self):
         """finish_bzr_subprocess raises self.failureException if the retcode is
         not the expected one.
         """
+        self.disable_missing_extensions_warning()
         process = self.start_bzr_subprocess(['wait-until-signalled'],
                                             skip_if_plan_to_signal=True)
         self.assertEqual('running\n', process.stdout.readline())
@@ -2286,14 +2431,6 @@
         self.assertEqual('', result[0])
         self.assertEqual('bzr: interrupted\n', result[1])
 
-    def test_start_and_stop_working_dir(self):
-        cwd = osutils.getcwd()
-        self.make_branch_and_tree('one')
-        process = self.start_bzr_subprocess(['root'], working_dir='one')
-        result = self.finish_bzr_subprocess(process, universal_newlines=True)
-        self.assertEndsWith(result[0], 'one\n')
-        self.assertEqual('', result[1])
-
 
 class TestKnownFailure(tests.TestCase):
 
@@ -2549,7 +2686,12 @@
         # Running bzr in blackbox mode, normal/expected/user errors should be
         # caught in the regular way and turned into an error message plus exit
         # code.
-        out, err = self.run_bzr(["log", "/nonexistantpath"], retcode=3)
+        transport_server = MemoryServer()
+        transport_server.setUp()
+        self.addCleanup(transport_server.tearDown)
+        url = transport_server.get_url()
+        self.permit_url(url)
+        out, err = self.run_bzr(["log", "%s/nonexistantpath" % url], retcode=3)
         self.assertEqual(out, '')
         self.assertContainsRe(err,
             'bzr: ERROR: Not a branch: ".*nonexistantpath/".\n')
@@ -2681,27 +2823,72 @@
 
 class TestTestSuite(tests.TestCase):
 
+    def test__test_suite_testmod_names(self):
+        # Test that a plausible list of test module names are returned
+        # by _test_suite_testmod_names.
+        test_list = tests._test_suite_testmod_names()
+        self.assertSubset([
+            'bzrlib.tests.blackbox',
+            'bzrlib.tests.per_transport',
+            'bzrlib.tests.test_selftest',
+            ],
+            test_list)
+
+    def test__test_suite_modules_to_doctest(self):
+        # Test that a plausible list of modules to doctest is returned
+        # by _test_suite_modules_to_doctest.
+        test_list = tests._test_suite_modules_to_doctest()
+        self.assertSubset([
+            'bzrlib.timestamp',
+            ],
+            test_list)
+
     def test_test_suite(self):
-        # This test is slow - it loads the entire test suite to operate, so we
-        # do a single test with one test in each category
-        test_list = [
+        # test_suite() loads the entire test suite to operate. To avoid this
+        # overhead, and yet still be confident that things are happening,
+        # we temporarily replace two functions used by test_suite with 
+        # test doubles that supply a few sample tests to load, and check they
+        # are loaded.
+        calls = []
+        def _test_suite_testmod_names():
+            calls.append("testmod_names")
+            return [
+                'bzrlib.tests.blackbox.test_branch',
+                'bzrlib.tests.per_transport',
+                'bzrlib.tests.test_selftest',
+                ]
+        original_testmod_names = tests._test_suite_testmod_names
+        def _test_suite_modules_to_doctest():
+            calls.append("modules_to_doctest")
+            return ['bzrlib.timestamp']
+        orig_modules_to_doctest = tests._test_suite_modules_to_doctest
+        def restore_names():
+            tests._test_suite_testmod_names = original_testmod_names
+            tests._test_suite_modules_to_doctest = orig_modules_to_doctest
+        self.addCleanup(restore_names)
+        tests._test_suite_testmod_names = _test_suite_testmod_names
+        tests._test_suite_modules_to_doctest = _test_suite_modules_to_doctest
+        expected_test_list = [
             # testmod_names
             'bzrlib.tests.blackbox.test_branch.TestBranch.test_branch',
             ('bzrlib.tests.per_transport.TransportTests'
-             '.test_abspath(LocalURLServer)'),
+             '.test_abspath(LocalTransport,LocalURLServer)'),
             'bzrlib.tests.test_selftest.TestTestSuite.test_test_suite',
             # modules_to_doctest
             'bzrlib.timestamp.format_highres_date',
             # plugins can't be tested that way since selftest may be run with
             # --no-plugins
             ]
-        suite = tests.test_suite(test_list)
-        self.assertEquals(test_list, _test_ids(suite))
+        suite = tests.test_suite()
+        self.assertEqual(set(["testmod_names", "modules_to_doctest"]),
+            set(calls))
+        self.assertSubset(expected_test_list, _test_ids(suite))
 
     def test_test_suite_list_and_start(self):
         # We cannot test this at the same time as the main load, because we want
-        # to know that starting_with == None works. So a second full load is
-        # incurred.
+        # to know that starting_with == None works. So a second load is
+        # incurred - note that the starting_with parameter causes a partial load
+        # rather than a full load so this test should be pretty quick.
         test_list = ['bzrlib.tests.test_selftest.TestTestSuite.test_test_suite']
         suite = tests.test_suite(test_list,
                                  ['bzrlib.tests.test_selftest.TestTestSuite'])
@@ -2853,19 +3040,3 @@
                                                 self.verbosity)
         tests.run_suite(suite, runner_class=MyRunner, stream=StringIO())
         self.assertLength(1, calls)
-
-    def test_done(self):
-        """run_suite should call result.done()"""
-        self.calls = 0
-        def one_more_call(): self.calls += 1
-        def test_function():
-            pass
-        test = unittest.FunctionTestCase(test_function)
-        class InstrumentedTestResult(tests.ExtendedTestResult):
-            def done(self): one_more_call()
-        class MyRunner(tests.TextTestRunner):
-            def run(self, test):
-                return InstrumentedTestResult(self.stream, self.descriptions,
-                                              self.verbosity)
-        tests.run_suite(test, runner_class=MyRunner, stream=StringIO())
-        self.assertEquals(1, self.calls)

=== modified file 'bzrlib/tests/test_shelf.py'
--- bzrlib/tests/test_shelf.py	2009-08-26 07:40:38 +0000
+++ bzrlib/tests/test_shelf.py	2009-09-11 07:55:48 +0000
@@ -476,6 +476,8 @@
     def test_shelve_skips_added_root(self):
         """Skip adds of the root when iterating through shelvable changes."""
         tree = self.make_branch_and_tree('tree')
+        tree.lock_tree_write()
+        self.addCleanup(tree.unlock)
         creator = shelf.ShelfCreator(tree, tree.basis_tree())
         self.addCleanup(creator.finalize)
         self.assertEqual([], list(creator.iter_shelvable()))
@@ -501,6 +503,7 @@
             shelf_file.seek(0)
             unshelver = shelf.Unshelver.from_tree_and_shelf(tree, shelf_file)
             unshelver.make_merger().do_merge()
+            self.addCleanup(unshelver.finalize)
             self.assertFileEqual('bar', 'tree/foo')
         finally:
             shelf_file.close()
@@ -524,6 +527,7 @@
         self.build_tree_contents([('tree/foo', 'z\na\nb\nc\n')])
         shelf_file.seek(0)
         unshelver = shelf.Unshelver.from_tree_and_shelf(tree, shelf_file)
+        self.addCleanup(unshelver.finalize)
         unshelver.make_merger().do_merge()
         self.assertFileEqual('z\na\nb\nd\n', 'tree/foo')
 
@@ -552,6 +556,7 @@
         self.assertFileEqual('baz', 'tree/foo/bar')
         shelf_file.seek(0)
         unshelver = shelf.Unshelver.from_tree_and_shelf(tree, shelf_file)
+        self.addCleanup(unshelver.finalize)
         unshelver.make_merger().do_merge()
         self.assertFalse('foo-id' in tree)
         self.assertFalse('bar-id' in tree)
@@ -697,6 +702,7 @@
         shelf_id = shelf_manager.shelve_changes(creator)
         self.failIfExists('tree/foo')
         unshelver = shelf_manager.get_unshelver(shelf_id)
+        self.addCleanup(unshelver.finalize)
         unshelver.make_merger().do_merge()
         self.assertFileEqual('bar', 'tree/foo')
 

=== modified file 'bzrlib/tests/test_shelf_ui.py'
--- bzrlib/tests/test_shelf_ui.py	2009-08-26 07:40:38 +0000
+++ bzrlib/tests/test_shelf_ui.py	2009-10-23 03:35:32 +0000
@@ -76,6 +76,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         e = self.assertRaises(AssertionError, shelver.run)
         self.assertEqual('Unexpected prompt: Shelve? [yNfq?]', str(e))
 
@@ -84,6 +85,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('foo', 'y')
         e = self.assertRaises(AssertionError, shelver.run)
         self.assertEqual('Wrong prompt: Shelve? [yNfq?]', str(e))
@@ -93,6 +95,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', 'n')
         shelver.expect('Shelve? [yNfq?]', 'n')
         # No final shelving prompt because no changes were selected
@@ -104,6 +107,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', 'y')
         shelver.expect('Shelve? [yNfq?]', 'y')
         shelver.expect('Shelve 2 change(s)? [yNfq?]', 'n')
@@ -115,6 +119,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', 'y')
         shelver.expect('Shelve? [yNfq?]', 'y')
         shelver.expect('Shelve 2 change(s)? [yNfq?]', 'y')
@@ -126,6 +131,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', 'y')
         shelver.expect('Shelve? [yNfq?]', 'n')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
@@ -138,6 +144,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve binary changes? [yNfq?]', 'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -149,6 +156,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve renaming "foo" => "bar"? [yNfq?]', 'y')
         shelver.expect('Shelve? [yNfq?]', 'y')
         shelver.expect('Shelve? [yNfq?]', 'y')
@@ -162,6 +170,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve removing file "foo"? [yNfq?]', 'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -175,6 +184,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve adding file "foo"? [yNfq?]', 'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -187,6 +197,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve changing "foo" from file to directory? [yNfq?]',
                        'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
@@ -202,6 +213,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve changing target of "baz" from "bar" to '
                 '"vax"? [yNfq?]', 'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
@@ -213,6 +225,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', 'f')
         shelver.expect('Shelve 2 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -223,6 +236,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', 'q')
         self.assertRaises(errors.UserAbort, shelver.run)
         self.assertFileEqual(LINES_ZY, 'tree/foo')
@@ -234,7 +248,7 @@
         try:
             shelver.run()
         finally:
-            shelver.work_tree.unlock()
+            shelver.finalize()
         self.assertFileEqual(LINES_AJ, 'tree/foo')
 
     def test_shelve_filename(self):
@@ -244,6 +258,7 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(), file_list=['bar'])
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve adding file "bar"? [yNfq?]', 'y')
         shelver.expect('Shelve 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -253,19 +268,18 @@
         tree.lock_tree_write()
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Shelve? [yNfq?]', '?')
         shelver.expect('Shelve? [(y)es, (N)o, (f)inish, or (q)uit]', 'f')
         shelver.expect('Shelve 2 change(s)? [yNfq?]', 'y')
         shelver.run()
 
-    def test_shelve_distroy(self):
+    def test_shelve_destroy(self):
         tree = self.create_shelvable_tree()
         shelver = shelf_ui.Shelver.from_args(sys.stdout, all=True,
                                              directory='tree', destroy=True)
-        try:
-            shelver.run()
-        finally:
-            shelver.work_tree.unlock()
+        self.addCleanup(shelver.finalize)
+        shelver.run()
         self.assertIs(None, tree.get_shelf_manager().last_shelf())
         self.assertFileEqual(LINES_AJ, 'tree/foo')
 
@@ -276,7 +290,10 @@
             target = tree.branch.repository.revision_tree(target_revision_id)
             shelver = shelf_ui.Shelver(tree, target, auto=True,
                                        auto_apply=True)
-            shelver.run()
+            try:
+                shelver.run()
+            finally:
+                shelver.finalize()
         finally:
             tree.unlock()
 
@@ -316,6 +333,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Apply change? [yNfq?]', 'n')
         shelver.expect('Apply change? [yNfq?]', 'n')
         # No final shelving prompt because no changes were selected
@@ -328,6 +346,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Apply change? [yNfq?]', 'y')
         shelver.expect('Apply change? [yNfq?]', 'y')
         shelver.expect('Apply 2 change(s)? [yNfq?]', 'n')
@@ -340,6 +359,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Apply change? [yNfq?]', 'y')
         shelver.expect('Apply change? [yNfq?]', 'y')
         shelver.expect('Apply 2 change(s)? [yNfq?]', 'y')
@@ -353,6 +373,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Apply binary changes? [yNfq?]', 'y')
         shelver.expect('Apply 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -365,6 +386,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Rename "bar" => "foo"? [yNfq?]', 'y')
         shelver.expect('Apply change? [yNfq?]', 'y')
         shelver.expect('Apply change? [yNfq?]', 'y')
@@ -379,6 +401,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Add file "foo"? [yNfq?]', 'y')
         shelver.expect('Apply 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -393,6 +416,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Delete file "foo"? [yNfq?]', 'y')
         shelver.expect('Apply 1 change(s)? [yNfq?]', 'y')
         shelver.run()
@@ -406,6 +430,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Change "foo" from directory to a file? [yNfq?]', 'y')
         shelver.expect('Apply 1 change(s)? [yNfq?]', 'y')
 
@@ -421,6 +446,7 @@
         self.addCleanup(tree.unlock)
         shelver = ExpectShelver(tree, tree.basis_tree(),
                                 reporter=shelf_ui.ApplyReporter())
+        self.addCleanup(shelver.finalize)
         shelver.expect('Change target of "baz" from "vax" to "bar"? [yNfq?]',
                        'y')
         shelver.expect('Apply 1 change(s)? [yNfq?]', 'y')
@@ -438,8 +464,12 @@
             tree.add('foo', 'foo-id')
             tree.commit('added foo')
             self.build_tree_contents([('tree/foo', LINES_ZY)])
-            shelf_ui.Shelver(tree, tree.basis_tree(), auto_apply=True,
-                             auto=True).run()
+            shelver = shelf_ui.Shelver(tree, tree.basis_tree(),
+                                       auto_apply=True, auto=True)
+            try:
+                shelver.run()
+            finally:
+                shelver.finalize()
         finally:
             tree.unlock()
         return tree

=== modified file 'bzrlib/tests/test_smart.py'
--- bzrlib/tests/test_smart.py	2009-08-17 23:15:55 +0000
+++ bzrlib/tests/test_smart.py	2009-10-29 00:16:50 +0000
@@ -36,12 +36,14 @@
     smart,
     tests,
     urlutils,
+    versionedfile,
     )
 from bzrlib.branch import Branch, BranchReferenceFormat
 import bzrlib.smart.branch
 import bzrlib.smart.bzrdir, bzrlib.smart.bzrdir as smart_dir
 import bzrlib.smart.packrepository
 import bzrlib.smart.repository
+import bzrlib.smart.vfs
 from bzrlib.smart.request import (
     FailedSmartServerResponse,
     SmartServerRequest,
@@ -51,7 +53,7 @@
 from bzrlib.tests import (
     split_suite_by_re,
     )
-from bzrlib.transport import chroot, get_transport
+from bzrlib.transport import chroot, get_transport, local, memory
 
 
 def load_tests(standard_tests, module, loader):
@@ -80,6 +82,7 @@
 class TestCaseWithChrootedTransport(tests.TestCaseWithTransport):
 
     def setUp(self):
+        self.vfs_transport_factory = memory.MemoryServer
         tests.TestCaseWithTransport.setUp(self)
         self._chroot_server = None
 
@@ -87,15 +90,14 @@
         if self._chroot_server is None:
             backing_transport = tests.TestCaseWithTransport.get_transport(self)
             self._chroot_server = chroot.ChrootServer(backing_transport)
-            self._chroot_server.setUp()
-            self.addCleanup(self._chroot_server.tearDown)
+            self.start_server(self._chroot_server)
         t = get_transport(self._chroot_server.get_url())
         if relpath is not None:
             t = t.clone(relpath)
         return t
 
 
-class TestCaseWithSmartMedium(tests.TestCaseWithTransport):
+class TestCaseWithSmartMedium(tests.TestCaseWithMemoryTransport):
 
     def setUp(self):
         super(TestCaseWithSmartMedium, self).setUp()
@@ -113,6 +115,25 @@
         return self.get_transport().get_smart_medium()
 
 
+class TestByteStreamToStream(tests.TestCase):
+
+    def test_repeated_substreams_same_kind_are_one_stream(self):
+        # Make a stream - an iterable of bytestrings.
+        stream = [('text', [versionedfile.FulltextContentFactory(('k1',), None,
+            None, 'foo')]),('text', [
+            versionedfile.FulltextContentFactory(('k2',), None, None, 'bar')])]
+        fmt = bzrdir.format_registry.get('pack-0.92')().repository_format
+        bytes = smart.repository._stream_to_byte_stream(stream, fmt)
+        streams = []
+        # Iterate the resulting iterable; checking that we get only one stream
+        # out.
+        fmt, stream = smart.repository._byte_stream_to_stream(bytes)
+        for kind, substream in stream:
+            streams.append((kind, list(substream)))
+        self.assertLength(1, streams)
+        self.assertLength(2, streams[0][1])
+
+
 class TestSmartServerResponse(tests.TestCase):
 
     def test__eq__(self):
@@ -150,6 +171,18 @@
         self.assertRaises(
             errors.PathNotChild, request.translate_client_path, 'bar/')
         self.assertEqual('./baz', request.translate_client_path('foo/baz'))
+        e_acute = u'\N{LATIN SMALL LETTER E WITH ACUTE}'.encode('utf-8')
+        self.assertEqual('./' + urlutils.escape(e_acute),
+                         request.translate_client_path('foo/' + e_acute))
+
+    def test_translate_client_path_vfs(self):
+        """VfsRequests receive escaped paths rather than raw UTF-8."""
+        transport = self.get_transport()
+        request = smart.vfs.VfsRequest(transport, 'foo/')
+        e_acute = u'\N{LATIN SMALL LETTER E WITH ACUTE}'.encode('utf-8')
+        escaped = urlutils.escape('foo/' + e_acute)
+        self.assertEqual('./' + urlutils.escape(e_acute),
+                         request.translate_client_path(escaped))
 
     def test_transport_from_client_path(self):
         transport = self.get_transport()
@@ -394,6 +427,73 @@
             'False', 'False', 'False', '', '', '', '', 'False')
 
 
+class TestSmartServerRequestOpenBzrDir(tests.TestCaseWithMemoryTransport):
+    
+    def test_no_directory(self):
+        backing = self.get_transport()
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir(backing)
+        self.assertEqual(SmartServerResponse(('no', )),
+            request.execute('does-not-exist'))
+
+    def test_empty_directory(self):
+        backing = self.get_transport()
+        backing.mkdir('empty')
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir(backing)
+        self.assertEqual(SmartServerResponse(('no', )),
+            request.execute('empty'))
+
+    def test_outside_root_client_path(self):
+        backing = self.get_transport()
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir(backing,
+            root_client_path='root')
+        self.assertEqual(SmartServerResponse(('no', )),
+            request.execute('not-root'))
+
+    
+class TestSmartServerRequestOpenBzrDir_2_1(tests.TestCaseWithMemoryTransport):
+    
+    def test_no_directory(self):
+        backing = self.get_transport()
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
+        self.assertEqual(SmartServerResponse(('no', )),
+            request.execute('does-not-exist'))
+
+    def test_empty_directory(self):
+        backing = self.get_transport()
+        backing.mkdir('empty')
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
+        self.assertEqual(SmartServerResponse(('no', )),
+            request.execute('empty'))
+
+    def test_present_without_workingtree(self):
+        backing = self.get_transport()
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
+        self.make_bzrdir('.')
+        self.assertEqual(SmartServerResponse(('yes', 'no')),
+            request.execute(''))
+
+    def test_outside_root_client_path(self):
+        backing = self.get_transport()
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing,
+            root_client_path='root')
+        self.assertEqual(SmartServerResponse(('no',)),
+            request.execute('not-root'))
+
+    
+class TestSmartServerRequestOpenBzrDir_2_1_disk(TestCaseWithChrootedTransport):
+
+    def test_present_with_workingtree(self):
+        self.vfs_transport_factory = local.LocalURLServer
+        backing = self.get_transport()
+        request = smart.bzrdir.SmartServerRequestOpenBzrDir_2_1(backing)
+        bd = self.make_bzrdir('.')
+        bd.create_repository()
+        bd.create_branch()
+        bd.create_workingtree()
+        self.assertEqual(SmartServerResponse(('yes', 'yes')),
+            request.execute(''))
+
+
 class TestSmartServerRequestOpenBranch(TestCaseWithChrootedTransport):
 
     def test_no_branch(self):
@@ -414,6 +514,7 @@
 
     def test_branch_reference(self):
         """When there is a branch reference, the reference URL is returned."""
+        self.vfs_transport_factory = local.LocalURLServer
         backing = self.get_transport()
         request = smart.bzrdir.SmartServerRequestOpenBranch(backing)
         branch = self.make_branch('branch')
@@ -444,6 +545,7 @@
 
     def test_branch_reference(self):
         """When there is a branch reference, the reference URL is returned."""
+        self.vfs_transport_factory = local.LocalURLServer
         backing = self.get_transport()
         request = smart.bzrdir.SmartServerRequestOpenBranchV2(backing)
         branch = self.make_branch('branch')
@@ -1601,6 +1703,19 @@
         self.assertEqual(SmartServerResponse(('ok',)), response)
 
 
+class TestSmartServerVfsGet(tests.TestCaseWithMemoryTransport):
+
+    def test_unicode_path(self):
+        """VFS requests expect unicode paths to be escaped."""
+        filename = u'foo\N{INTERROBANG}'
+        filename_escaped = urlutils.escape(filename)
+        backing = self.get_transport()
+        request = smart.vfs.GetRequest(backing)
+        backing.put_bytes_non_atomic(filename_escaped, 'contents')
+        self.assertEqual(SmartServerResponse(('ok', ), 'contents'),
+            request.execute(filename_escaped))
+
+
 class TestHandlers(tests.TestCase):
     """Tests for the request.request_handlers object."""
 

=== modified file 'bzrlib/tests/test_smart_transport.py'
--- bzrlib/tests/test_smart_transport.py	2009-07-08 07:03:38 +0000
+++ bzrlib/tests/test_smart_transport.py	2009-10-27 06:30:37 +0000
@@ -657,8 +657,10 @@
         # wire-to-wire, using the whole stack, with a UTF-8 filename.
         transport = memory.MemoryTransport('memory:///')
         utf8_filename = u'testfile\N{INTERROBANG}'.encode('utf-8')
+        # VFS requests use filenames, not raw UTF-8.
+        hpss_path = urlutils.escape(utf8_filename)
         transport.put_bytes(utf8_filename, 'contents\nof\nfile\n')
-        to_server = StringIO('get\001' + utf8_filename + '\n')
+        to_server = StringIO('get\001' + hpss_path + '\n')
         from_server = StringIO()
         server = medium.SmartServerPipeStreamMedium(
             to_server, from_server, transport)
@@ -732,7 +734,7 @@
         client_sock.sendall(rest_of_request_bytes)
         server._serve_one_request(server_protocol)
         server_sock.close()
-        self.assertEqual(expected_response, client_sock.recv(50),
+        self.assertEqual(expected_response, osutils.recv_all(client_sock, 50),
                          "Not a version 2 response to 'hello' request.")
         self.assertEqual('', client_sock.recv(1))
 
@@ -993,8 +995,15 @@
 
         :param readonly: Create a readonly server.
         """
+        # NB: Tests using this fall into two categories: tests of the server,
+        # tests wanting a server. The latter should be updated to use
+        # self.vfs_transport_factory etc.
         if not backing_transport:
-            self.backing_transport = memory.MemoryTransport()
+            mem_server = memory.MemoryServer()
+            mem_server.setUp()
+            self.addCleanup(mem_server.tearDown)
+            self.permit_url(mem_server.get_url())
+            self.backing_transport = get_transport(mem_server.get_url())
         else:
             self.backing_transport = backing_transport
         if readonly:
@@ -1004,6 +1013,7 @@
         self.server.start_background_thread('-' + self.id())
         self.transport = remote.RemoteTCPTransport(self.server.get_url())
         self.addCleanup(self.tearDownServer)
+        self.permit_url(self.server.get_url())
 
     def tearDownServer(self):
         if getattr(self, 'transport', None):
@@ -1248,7 +1258,7 @@
 
     def test_hello(self):
         handler = self.build_handler(None)
-        handler.dispatch_command('hello', ())
+        handler.args_received(('hello',))
         self.assertEqual(('ok', '2'), handler.response.args)
         self.assertEqual(None, handler.response.body)
 
@@ -1268,7 +1278,7 @@
         """The response for a read-only error is ('ReadOnlyError')."""
         handler = self.build_handler(self.get_readonly_transport())
         # send a mkdir for foo, with no explicit mode - should fail.
-        handler.dispatch_command('mkdir', ('foo', ''))
+        handler.args_received(('mkdir', 'foo', ''))
         # and the failure should be an explicit ReadOnlyError
         self.assertEqual(("ReadOnlyError", ), handler.response.args)
         # XXX: TODO: test that other TransportNotPossible errors are
@@ -1279,14 +1289,14 @@
     def test_hello_has_finished_body_on_dispatch(self):
         """The 'hello' command should set finished_reading."""
         handler = self.build_handler(None)
-        handler.dispatch_command('hello', ())
+        handler.args_received(('hello',))
         self.assertTrue(handler.finished_reading)
         self.assertNotEqual(None, handler.response)
 
     def test_put_bytes_non_atomic(self):
         """'put_...' should set finished_reading after reading the bytes."""
         handler = self.build_handler(self.get_transport())
-        handler.dispatch_command('put_non_atomic', ('a-file', '', 'F', ''))
+        handler.args_received(('put_non_atomic', 'a-file', '', 'F', ''))
         self.assertFalse(handler.finished_reading)
         handler.accept_body('1234')
         self.assertFalse(handler.finished_reading)
@@ -1300,7 +1310,7 @@
         """'readv' should set finished_reading after reading offsets."""
         self.build_tree(['a-file'])
         handler = self.build_handler(self.get_readonly_transport())
-        handler.dispatch_command('readv', ('a-file', ))
+        handler.args_received(('readv', 'a-file'))
         self.assertFalse(handler.finished_reading)
         handler.accept_body('2,')
         self.assertFalse(handler.finished_reading)
@@ -1315,7 +1325,7 @@
         """'readv' when a short read occurs sets the response appropriately."""
         self.build_tree(['a-file'])
         handler = self.build_handler(self.get_readonly_transport())
-        handler.dispatch_command('readv', ('a-file', ))
+        handler.args_received(('readv', 'a-file'))
         # read beyond the end of the file.
         handler.accept_body('100,1')
         handler.end_of_body()
@@ -2542,8 +2552,8 @@
         self.calls.append(('end_received',))
         self.finished_reading = True
 
-    def dispatch_command(self, cmd, args):
-        self.calls.append(('dispatch_command', cmd, args))
+    def args_received(self, args):
+        self.calls.append(('args_received', args))
 
     def accept_body(self, bytes):
         self.calls.append(('accept_body', bytes))

=== modified file 'bzrlib/tests/test_source.py'
--- bzrlib/tests/test_source.py	2009-06-10 03:56:49 +0000
+++ bzrlib/tests/test_source.py	2009-09-17 19:16:58 +0000
@@ -1,6 +1,4 @@
-# Copyright (C) 2005, 2006, 2008 Canonical Ltd
-#   Authors: Robert Collins <robert.collins@canonical.com>
-#            and others
+# Copyright (C) 2005, 2006, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,12 +40,16 @@
 
 # Files which are listed here will be skipped when testing for Copyright (or
 # GPL) statements.
-COPYRIGHT_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py']
+COPYRIGHT_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py',
+    'bzrlib/doc_generate/sphinx_conf.py']
 
-LICENSE_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py']
+LICENSE_EXCEPTIONS = ['bzrlib/lsprof.py', 'bzrlib/_bencode_py.py',
+    'bzrlib/doc_generate/sphinx_conf.py']
 # Technically, 'bzrlib/lsprof.py' should be 'bzrlib/util/lsprof.py',
 # (we do not check bzrlib/util/, since that is code bundled from elsewhere)
 # but for compatibility with previous releases, we don't want to move it.
+#
+# sphinx_conf is semi-autogenerated.
 
 
 class TestSourceHelper(TestCase):
@@ -357,10 +359,13 @@
                     return True
             return False
         badfiles = []
+        assert_re = re.compile(r'\bassert\b')
         for fname, text in self.get_source_file_contents():
             if not self.is_our_code(fname):
                 continue
-            ast = parser.ast2tuple(parser.suite(''.join(text)))
+            if not assert_re.search(text):
+                continue
+            ast = parser.ast2tuple(parser.suite(text))
             if search(ast):
                 badfiles.append(fname)
         if badfiles:

=== modified file 'bzrlib/tests/test_ssh_transport.py'
--- bzrlib/tests/test_ssh_transport.py	2009-08-22 05:01:55 +0000
+++ bzrlib/tests/test_ssh_transport.py	2009-11-07 08:02:13 +0000
@@ -132,6 +132,25 @@
         # Last cached value always checked first
         self.assertIs(manager.get_vendor({}), vendor)
 
+    def test_get_vendor_from_path_win32_plink(self):
+        manager = TestSSHVendorManager()
+        manager.set_ssh_version_string("plink: Release 0.60")
+        plink_path = "C:/Program Files/PuTTY/plink.exe"
+        vendor = manager.get_vendor({"BZR_SSH": plink_path})
+        self.assertIsInstance(vendor, PLinkSubprocessVendor)
+        args = vendor._get_vendor_specific_argv("user", "host", 22, ["bzr"])
+        self.assertEqual(args[0], plink_path)
+
+    def test_get_vendor_from_path_nix_openssh(self):
+        manager = TestSSHVendorManager()
+        manager.set_ssh_version_string(
+            "OpenSSH_5.1p1 Debian-5, OpenSSL, 0.9.8g 19 Oct 2007")
+        openssh_path = "/usr/bin/ssh"
+        vendor = manager.get_vendor({"BZR_SSH": openssh_path})
+        self.assertIsInstance(vendor, OpenSSHSubprocessVendor)
+        args = vendor._get_vendor_specific_argv("user", "host", 22, ["bzr"])
+        self.assertEqual(args[0], openssh_path)
+
 
 class SubprocessVendorsTests(TestCase):
 

=== modified file 'bzrlib/tests/test_status.py'
--- bzrlib/tests/test_status.py	2009-08-20 04:09:58 +0000
+++ bzrlib/tests/test_status.py	2009-10-06 14:40:37 +0000
@@ -53,7 +53,7 @@
         tree2.commit('commit 3b', timestamp=1196796819, timezone=0)
         tree3.commit('commit 3c', timestamp=1196796819, timezone=0)
         tree.merge_from_branch(tree2.branch)
-        tree.merge_from_branch(tree3.branch)
+        tree.merge_from_branch(tree3.branch, force=True)
         return tree
 
     def test_multiple_pending(self):

=== modified file 'bzrlib/tests/test_symbol_versioning.py'
--- bzrlib/tests/test_symbol_versioning.py	2009-03-24 01:53:42 +0000
+++ bzrlib/tests/test_symbol_versioning.py	2009-09-15 01:43:42 +0000
@@ -76,11 +76,11 @@
         expected_warning = (
             "bzrlib.tests.test_symbol_versioning."
             "deprecated_static "
-            "was deprecated in version 0.7.", DeprecationWarning, 2)
+            "was deprecated in version 0.7.0.", DeprecationWarning, 2)
         expected_docstring = (
             'Deprecated static.\n'
             '\n'
-            'This function was deprecated in version 0.7.\n'
+            'This function was deprecated in version 0.7.0.\n'
             )
         self.check_deprecated_callable(
             expected_warning, expected_docstring,
@@ -92,13 +92,14 @@
         expected_warning = (
             "bzrlib.tests.test_symbol_versioning."
             "TestDeprecationWarnings.deprecated_method "
-            "was deprecated in version 0.7.", DeprecationWarning, 2)
-        expected_docstring = ('Deprecated method docstring.\n'
-                              '\n'
-                              '        This might explain stuff.\n'
-                              '        \n'
-                              '        This method was deprecated in version 0.7.\n'
-                              '        ')
+            "was deprecated in version 0.7.0.", DeprecationWarning, 2)
+        expected_docstring = (
+            'Deprecated method docstring.\n'
+            '\n'
+            '        This might explain stuff.\n'
+            '        \n'
+            '        This method was deprecated in version 0.7.0.\n'
+            '        ')
         self.check_deprecated_callable(expected_warning, expected_docstring,
                                        "deprecated_method",
                                        "bzrlib.tests.test_symbol_versioning",
@@ -107,10 +108,10 @@
     def test_deprecated_function(self):
         expected_warning = (
             "bzrlib.tests.test_symbol_versioning.sample_deprecated_function "
-            "was deprecated in version 0.7.", DeprecationWarning, 2)
+            "was deprecated in version 0.7.0.", DeprecationWarning, 2)
         expected_docstring = ('Deprecated function docstring.\n'
                               '\n'
-                              'This function was deprecated in version 0.7.\n'
+                              'This function was deprecated in version 0.7.0.\n'
                               )
         self.check_deprecated_callable(expected_warning, expected_docstring,
                                        "sample_deprecated_function",
@@ -119,7 +120,7 @@
 
     def test_deprecated_list(self):
         expected_warning = (
-            "Modifying a_deprecated_list was deprecated in version 0.9."
+            "Modifying a_deprecated_list was deprecated in version 0.9.0."
             " Don't use me", DeprecationWarning, 3)
         old_warning_method = symbol_versioning.warn
         try:
@@ -157,7 +158,7 @@
 
     def test_deprecated_dict(self):
         expected_warning = (
-            "access to a_deprecated_dict was deprecated in version 0.14."
+            "access to a_deprecated_dict was deprecated in version 0.14.0."
             " Pull the other one!", DeprecationWarning, 2)
         old_warning_method = symbol_versioning.warn
         try:
@@ -205,12 +206,12 @@
         """We can get a deprecation string for a method or function."""
         self.assertEqual('bzrlib.tests.test_symbol_versioning.'
             'TestDeprecationWarnings.test_deprecation_string was deprecated in '
-            'version 0.11.',
+            'version 0.11.0.',
             symbol_versioning.deprecation_string(
             self.test_deprecation_string,
             deprecated_in((0, 11, 0))))
         self.assertEqual('bzrlib.symbol_versioning.deprecated_function was '
-            'deprecated in version 0.11.',
+            'deprecated in version 0.11.0.',
             symbol_versioning.deprecation_string(
                 symbol_versioning.deprecated_function,
                 deprecated_in((0, 11, 0))))

=== modified file 'bzrlib/tests/test_trace.py'
--- bzrlib/tests/test_trace.py	2009-08-20 04:30:16 +0000
+++ bzrlib/tests/test_trace.py	2009-11-08 19:07:00 +0000
@@ -72,14 +72,24 @@
         self.assertTrue(len(msg) > 0)
         self.assertEqualDiff(msg, 'bzr: interrupted\n')
 
+    def test_format_memory_error(self):
+        try:
+            raise MemoryError()
+        except MemoryError:
+            pass
+        msg = _format_exception()
+        self.assertEquals(msg,
+            "bzr: out of memory\n")
+
     def test_format_os_error(self):
         try:
             os.rmdir('nosuchfile22222')
-        except OSError:
-            pass
+        except OSError, e:
+            e_str = str(e)
         msg = _format_exception()
-        self.assertContainsRe(msg,
-            r'^bzr: ERROR: \[Errno .*\] No such file.*nosuchfile22222')
+        # Linux seems to give "No such file" but Windows gives "The system
+        # cannot find the file specified".
+        self.assertEqual('bzr: ERROR: %s\n' % (e_str,), msg)
 
     def test_format_io_error(self):
         try:
@@ -87,7 +97,10 @@
         except IOError:
             pass
         msg = _format_exception()
-        self.assertContainsRe(msg, r'^bzr: ERROR: \[Errno .*\] No such file.*nosuchfile')
+        # Even though Windows and Linux differ for 'os.rmdir', they both give
+        # 'No such file' for open()
+        self.assertContainsRe(msg,
+            r'^bzr: ERROR: \[Errno .*\] No such file.*nosuchfile')
 
     def test_format_unicode_error(self):
         try:
@@ -259,7 +272,7 @@
     def test_log_rollover(self):
         temp_log_name = 'test-log'
         trace_file = open(temp_log_name, 'at')
-        trace_file.write('test_log_rollover padding\n' * 1000000)
+        trace_file.writelines(['test_log_rollover padding\n'] * 200000)
         trace_file.close()
         _rollover_trace_maybe(temp_log_name)
         # should have been rolled over

=== modified file 'bzrlib/tests/test_transform.py'
--- bzrlib/tests/test_transform.py	2009-08-13 01:33:15 +0000
+++ bzrlib/tests/test_transform.py	2009-11-18 16:10:18 +0000
@@ -369,6 +369,18 @@
         self.assertContainsRe(transform._limbo_name(first), 'new-1/file')
         self.assertNotContainsRe(transform._limbo_name(second), 'new-1/FiLe')
 
+    def test_adjust_path_updates_child_limbo_names(self):
+        tree = self.make_branch_and_tree('tree')
+        transform = TreeTransform(tree)
+        self.addCleanup(transform.finalize)
+        foo_id = transform.new_directory('foo', transform.root)
+        bar_id = transform.new_directory('bar', foo_id)
+        baz_id = transform.new_directory('baz', bar_id)
+        qux_id = transform.new_directory('qux', baz_id)
+        transform.adjust_path('quxx', foo_id, bar_id)
+        self.assertStartsWith(transform._limbo_name(qux_id),
+                              transform._limbo_name(bar_id))
+
     def test_add_del(self):
         start, root = self.get_transform()
         start.new_directory('a', root, 'a')
@@ -1916,6 +1928,7 @@
         branch.lock_write()
         self.addCleanup(branch.unlock)
         tt = TransformPreview(branch.basis_tree())
+        self.addCleanup(tt.finalize)
         tt.new_directory('', ROOT_PARENT, 'TREE_ROOT')
         rev = tt.commit(branch, 'my message')
         self.assertEqual([], branch.basis_tree().get_parent_ids())
@@ -1927,6 +1940,7 @@
         branch.lock_write()
         self.addCleanup(branch.unlock)
         tt = TransformPreview(branch.basis_tree())
+        self.addCleanup(tt.finalize)
         e = self.assertRaises(ValueError, tt.commit, branch,
                           'my message', ['rev1b-id'])
         self.assertEqual('Cannot supply merge parents for first commit.',
@@ -1937,14 +1951,16 @@
         branch, tt = self.get_branch_and_transform()
         tt.new_file('file', tt.root, 'contents', 'file-id')
         trans_id = tt.new_directory('dir', tt.root, 'dir-id')
-        tt.new_symlink('symlink', trans_id, 'target', 'symlink-id')
+        if SymlinkFeature.available():
+            tt.new_symlink('symlink', trans_id, 'target', 'symlink-id')
         rev = tt.commit(branch, 'message')
         tree = branch.basis_tree()
         self.assertEqual('file', tree.id2path('file-id'))
         self.assertEqual('contents', tree.get_file_text('file-id'))
         self.assertEqual('dir', tree.id2path('dir-id'))
-        self.assertEqual('dir/symlink', tree.id2path('symlink-id'))
-        self.assertEqual('target', tree.get_symlink_target('symlink-id'))
+        if SymlinkFeature.available():
+            self.assertEqual('dir/symlink', tree.id2path('symlink-id'))
+            self.assertEqual('target', tree.get_symlink_target('symlink-id'))
 
     def test_add_unversioned(self):
         branch, tt = self.get_branch_and_transform()
@@ -1957,6 +1973,7 @@
         tt.new_file('file', tt.root, 'contents', 'file-id')
         tt.commit(branch, 'message', strict=True)
         tt = TransformPreview(branch.basis_tree())
+        self.addCleanup(tt.finalize)
         trans_id = tt.trans_id_file_id('file-id')
         tt.delete_contents(trans_id)
         tt.create_file('contents', trans_id)
@@ -2274,6 +2291,18 @@
         self.assertEqual(os.stat(limbo_path).st_mtime,
                          preview_tree.get_file_mtime('file-id'))
 
+    def test_get_file_mtime_renamed(self):
+        work_tree = self.make_branch_and_tree('tree')
+        self.build_tree(['tree/file'])
+        work_tree.add('file', 'file-id')
+        preview = TransformPreview(work_tree)
+        self.addCleanup(preview.finalize)
+        file_trans_id = preview.trans_id_tree_file_id('file-id')
+        preview.adjust_path('renamed', preview.root, file_trans_id)
+        preview_tree = preview.get_preview_tree()
+        preview_mtime = preview_tree.get_file_mtime('file-id', 'renamed')
+        work_mtime = work_tree.get_file_mtime('file-id', 'file')
+
     def test_get_file(self):
         preview = self.get_empty_preview()
         preview.new_file('file', preview.root, 'contents', 'file-id')
@@ -2427,8 +2456,6 @@
         self.assertEqual(('missing', None, None, None), summary)
 
     def test_file_content_summary_executable(self):
-        if not osutils.supports_executable():
-            raise TestNotApplicable()
         preview = self.get_empty_preview()
         path_id = preview.new_file('path', preview.root, 'contents', 'path-id')
         preview.set_executability(True, path_id)
@@ -2443,8 +2470,6 @@
         self.assertIs(None, summary[3])
 
     def test_change_executability(self):
-        if not osutils.supports_executable():
-            raise TestNotApplicable()
         tree = self.make_branch_and_tree('tree')
         self.build_tree(['tree/path'])
         tree.add('path')
@@ -2464,10 +2489,7 @@
         # size must be known
         self.assertEqual(len('contents'), summary[1])
         # not executable
-        if osutils.supports_executable():
-            self.assertEqual(False, summary[2])
-        else:
-            self.assertEqual(None, summary[2])
+        self.assertEqual(False, summary[2])
         # will not have hash (not cheap to determine)
         self.assertIs(None, summary[3])
 
@@ -2614,7 +2636,9 @@
 
     def test_walkdirs(self):
         preview = self.get_empty_preview()
-        preview.version_file('tree-root', preview.root)
+        root = preview.new_directory('', ROOT_PARENT, 'tree-root')
+        # FIXME: new_directory should mark root.
+        preview.adjust_path('', ROOT_PARENT, root)
         preview_tree = preview.get_preview_tree()
         file_trans_id = preview.new_file('a', preview.root, 'contents',
                                          'a-id')
@@ -2651,11 +2675,11 @@
         self.addCleanup(work_tree.unlock)
         preview = TransformPreview(work_tree)
         self.addCleanup(preview.finalize)
-        preview_tree = preview.get_preview_tree()
         file_trans_id = preview.trans_id_file_id('file-id')
         preview.delete_contents(file_trans_id)
         preview.create_file('a\nb\n', file_trans_id)
         pb = progress.DummyProgress()
+        preview_tree = preview.get_preview_tree()
         merger = Merger.from_revision_ids(pb, preview_tree,
                                           child_tree.branch.last_revision(),
                                           other_branch=child_tree.branch,
@@ -2725,6 +2749,17 @@
         rev2_tree = tree.branch.repository.revision_tree(rev2_id)
         self.assertEqual('contents', rev2_tree.get_file_text('file_id'))
 
+    def test_ascii_limbo_paths(self):
+        self.requireFeature(tests.UnicodeFilenameFeature)
+        branch = self.make_branch('any')
+        tree = branch.repository.revision_tree(_mod_revision.NULL_REVISION)
+        tt = TransformPreview(tree)
+        self.addCleanup(tt.finalize)
+        foo_id = tt.new_directory('', ROOT_PARENT)
+        bar_id = tt.new_file(u'\u1234bar', foo_id, 'contents')
+        limbo_path = tt._limbo_name(bar_id)
+        self.assertEqual(limbo_path.encode('ascii', 'replace'), limbo_path)
+
 
 class FakeSerializer(object):
     """Serializer implementation that simply returns the input.

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_transport.py	2009-09-22 04:25:05 +0000
@@ -16,11 +16,16 @@
 
 
 from cStringIO import StringIO
+import os
+import subprocess
+import sys
+import threading
 
 import bzrlib
 from bzrlib import (
     errors,
     osutils,
+    tests,
     urlutils,
     )
 from bzrlib.errors import (DependencyNotPresent,
@@ -31,7 +36,7 @@
                            ReadError,
                            UnsupportedProtocol,
                            )
-from bzrlib.tests import TestCase, TestCaseInTempDir
+from bzrlib.tests import ParamikoFeature, TestCase, TestCaseInTempDir
 from bzrlib.transport import (_clear_protocol_handlers,
                               _CoalescedOffset,
                               ConnectedTransport,
@@ -48,6 +53,7 @@
 from bzrlib.transport.memory import MemoryTransport
 from bzrlib.transport.local import (LocalTransport,
                                     EmulatedWin32LocalTransport)
+from bzrlib.transport.pathfilter import PathFilteringServer
 
 
 # TODO: Should possibly split transport-specific tests into their own files.
@@ -80,7 +86,8 @@
             register_lazy_transport('bar', 'bzrlib.tests.test_transport',
                                     'TestTransport.SampleHandler')
             self.assertEqual([SampleHandler.__module__,
-                              'bzrlib.transport.chroot'],
+                              'bzrlib.transport.chroot',
+                              'bzrlib.transport.pathfilter'],
                              _get_transport_modules())
         finally:
             _set_protocol_handlers(handlers)
@@ -363,24 +370,22 @@
     def test_abspath(self):
         # The abspath is always relative to the chroot_url.
         server = ChrootServer(get_transport('memory:///foo/bar/'))
-        server.setUp()
+        self.start_server(server)
         transport = get_transport(server.get_url())
         self.assertEqual(server.get_url(), transport.abspath('/'))
 
         subdir_transport = transport.clone('subdir')
         self.assertEqual(server.get_url(), subdir_transport.abspath('/'))
-        server.tearDown()
 
     def test_clone(self):
         server = ChrootServer(get_transport('memory:///foo/bar/'))
-        server.setUp()
+        self.start_server(server)
         transport = get_transport(server.get_url())
         # relpath from root and root path are the same
         relpath_cloned = transport.clone('foo')
         abspath_cloned = transport.clone('/foo')
         self.assertEqual(server, relpath_cloned.server)
         self.assertEqual(server, abspath_cloned.server)
-        server.tearDown()
 
     def test_chroot_url_preserves_chroot(self):
         """Calling get_transport on a chroot transport's base should produce a
@@ -393,12 +398,11 @@
             new_transport = get_transport(parent_url)
         """
         server = ChrootServer(get_transport('memory:///path/subpath'))
-        server.setUp()
+        self.start_server(server)
         transport = get_transport(server.get_url())
         new_transport = get_transport(transport.base)
         self.assertEqual(transport.server, new_transport.server)
         self.assertEqual(transport.base, new_transport.base)
-        server.tearDown()
 
     def test_urljoin_preserves_chroot(self):
         """Using urlutils.join(url, '..') on a chroot URL should not produce a
@@ -410,11 +414,10 @@
             new_transport = get_transport(parent_url)
         """
         server = ChrootServer(get_transport('memory:///path/'))
-        server.setUp()
+        self.start_server(server)
         transport = get_transport(server.get_url())
         self.assertRaises(
             InvalidURLJoin, urlutils.join, transport.base, '..')
-        server.tearDown()
 
 
 class ChrootServerTest(TestCase):
@@ -428,7 +431,10 @@
         backing_transport = MemoryTransport()
         server = ChrootServer(backing_transport)
         server.setUp()
-        self.assertTrue(server.scheme in _get_protocol_handlers().keys())
+        try:
+            self.assertTrue(server.scheme in _get_protocol_handlers().keys())
+        finally:
+            server.tearDown()
 
     def test_tearDown(self):
         backing_transport = MemoryTransport()
@@ -441,9 +447,95 @@
         backing_transport = MemoryTransport()
         server = ChrootServer(backing_transport)
         server.setUp()
-        self.assertEqual('chroot-%d:///' % id(server), server.get_url())
+        try:
+            self.assertEqual('chroot-%d:///' % id(server), server.get_url())
+        finally:
+            server.tearDown()
+
+
+class PathFilteringDecoratorTransportTest(TestCase):
+    """Pathfilter decoration specific tests."""
+
+    def test_abspath(self):
+        # The abspath is always relative to the base of the backing transport.
+        server = PathFilteringServer(get_transport('memory:///foo/bar/'),
+            lambda x: x)
+        server.setUp()
+        transport = get_transport(server.get_url())
+        self.assertEqual(server.get_url(), transport.abspath('/'))
+
+        subdir_transport = transport.clone('subdir')
+        self.assertEqual(server.get_url(), subdir_transport.abspath('/'))
         server.tearDown()
 
+    def make_pf_transport(self, filter_func=None):
+        """Make a PathFilteringTransport backed by a MemoryTransport.
+        
+        :param filter_func: by default this will be a no-op function.  Use this
+            parameter to override it."""
+        if filter_func is None:
+            filter_func = lambda x: x
+        server = PathFilteringServer(
+            get_transport('memory:///foo/bar/'), filter_func)
+        server.setUp()
+        self.addCleanup(server.tearDown)
+        return get_transport(server.get_url())
+
+    def test__filter(self):
+        # _filter (with an identity func as filter_func) always returns
+        # paths relative to the base of the backing transport.
+        transport = self.make_pf_transport()
+        self.assertEqual('foo', transport._filter('foo'))
+        self.assertEqual('foo/bar', transport._filter('foo/bar'))
+        self.assertEqual('', transport._filter('..'))
+        self.assertEqual('', transport._filter('/'))
+        # The base of the pathfiltering transport is taken into account too.
+        transport = transport.clone('subdir1/subdir2')
+        self.assertEqual('subdir1/subdir2/foo', transport._filter('foo'))
+        self.assertEqual(
+            'subdir1/subdir2/foo/bar', transport._filter('foo/bar'))
+        self.assertEqual('subdir1', transport._filter('..'))
+        self.assertEqual('', transport._filter('/'))
+
+    def test_filter_invocation(self):
+        filter_log = []
+        def filter(path):
+            filter_log.append(path)
+            return path
+        transport = self.make_pf_transport(filter)
+        transport.has('abc')
+        self.assertEqual(['abc'], filter_log)
+        del filter_log[:]
+        transport.clone('abc').has('xyz')
+        self.assertEqual(['abc/xyz'], filter_log)
+        del filter_log[:]
+        transport.has('/abc')
+        self.assertEqual(['abc'], filter_log)
+
+    def test_clone(self):
+        transport = self.make_pf_transport()
+        # relpath from root and root path are the same
+        relpath_cloned = transport.clone('foo')
+        abspath_cloned = transport.clone('/foo')
+        self.assertEqual(transport.server, relpath_cloned.server)
+        self.assertEqual(transport.server, abspath_cloned.server)
+
+    def test_url_preserves_pathfiltering(self):
+        """Calling get_transport on a pathfiltered transport's base should
+        produce a transport with exactly the same behaviour as the original
+        pathfiltered transport.
+
+        This is so that it is not possible to escape (accidentally or
+        otherwise) the filtering by doing::
+            url = filtered_transport.base
+            parent_url = urlutils.join(url, '..')
+            new_transport = get_transport(parent_url)
+        """
+        transport = self.make_pf_transport()
+        new_transport = get_transport(transport.base)
+        self.assertEqual(transport.server, new_transport.server)
+        self.assertEqual(transport.base, new_transport.base)
+
 
 class ReadonlyDecoratorTransportTest(TestCase):
     """Readonly decoration specific tests."""
@@ -460,15 +552,12 @@
         import bzrlib.transport.readonly as readonly
         # connect to '.' via http which is not listable
         server = HttpServer()
-        server.setUp()
-        try:
-            transport = get_transport('readonly+' + server.get_url())
-            self.failUnless(isinstance(transport,
-                                       readonly.ReadonlyTransportDecorator))
-            self.assertEqual(False, transport.listable())
-            self.assertEqual(True, transport.is_readonly())
-        finally:
-            server.tearDown()
+        self.start_server(server)
+        transport = get_transport('readonly+' + server.get_url())
+        self.failUnless(isinstance(transport,
+                                   readonly.ReadonlyTransportDecorator))
+        self.assertEqual(False, transport.listable())
+        self.assertEqual(True, transport.is_readonly())
 
 
 class FakeNFSDecoratorTests(TestCaseInTempDir):
@@ -492,31 +581,24 @@
         from bzrlib.tests.http_server import HttpServer
         # connect to '.' via http which is not listable
         server = HttpServer()
-        server.setUp()
-        try:
-            transport = self.get_nfs_transport(server.get_url())
-            self.assertIsInstance(
-                transport, bzrlib.transport.fakenfs.FakeNFSTransportDecorator)
-            self.assertEqual(False, transport.listable())
-            self.assertEqual(True, transport.is_readonly())
-        finally:
-            server.tearDown()
+        self.start_server(server)
+        transport = self.get_nfs_transport(server.get_url())
+        self.assertIsInstance(
+            transport, bzrlib.transport.fakenfs.FakeNFSTransportDecorator)
+        self.assertEqual(False, transport.listable())
+        self.assertEqual(True, transport.is_readonly())
 
     def test_fakenfs_server_default(self):
         # a FakeNFSServer() should bring up a local relpath server for itself
         import bzrlib.transport.fakenfs as fakenfs
         server = fakenfs.FakeNFSServer()
-        server.setUp()
-        try:
-            # the url should be decorated appropriately
-            self.assertStartsWith(server.get_url(), 'fakenfs+')
-            # and we should be able to get a transport for it
-            transport = get_transport(server.get_url())
-            # which must be a FakeNFSTransportDecorator instance.
-            self.assertIsInstance(
-                transport, fakenfs.FakeNFSTransportDecorator)
-        finally:
-            server.tearDown()
+        self.start_server(server)
+        # the url should be decorated appropriately
+        self.assertStartsWith(server.get_url(), 'fakenfs+')
+        # and we should be able to get a transport for it
+        transport = get_transport(server.get_url())
+        # which must be a FakeNFSTransportDecorator instance.
+        self.assertIsInstance(transport, fakenfs.FakeNFSTransportDecorator)
 
     def test_fakenfs_rename_semantics(self):
         # a FakeNFS transport must mangle the way rename errors occur to
@@ -587,8 +669,7 @@
     def setUp(self):
         super(TestTransportImplementation, self).setUp()
         self._server = self.transport_server()
-        self._server.setUp()
-        self.addCleanup(self._server.tearDown)
+        self.start_server(self._server)
 
     def get_transport(self, relpath=None):
         """Return a connected transport to the local directory.
@@ -800,3 +881,89 @@
         # readv records the supplied offset request
         expected_result.append(('readv', 'foo', [(0, 1), (3, 2)], True, 6))
         self.assertEqual(expected_result, transport._activity)
+
+
+class TestSSHConnections(tests.TestCaseWithTransport):
+
+    def test_bzr_connect_to_bzr_ssh(self):
+        """User acceptance that get_transport of a bzr+ssh:// behaves correctly.
+
+        bzr+ssh:// should cause bzr to run a remote bzr smart server over SSH.
+        """
+        # This test actually causes a bzr instance to be invoked, which is very
+        # expensive: it should be the only such test in the test suite.
+        # A reasonable evolution for this would be to simply check inside
+        # check_channel_exec_request that the command is appropriate, and then
+        # satisfy requests in-process.
+        self.requireFeature(ParamikoFeature)
+        # SFTPFullAbsoluteServer has a get_url method, and doesn't
+        # override the interface (doesn't change self._vendor).
+        # Note that this does encryption, so can be slow.
+        from bzrlib.transport.sftp import SFTPFullAbsoluteServer
+        from bzrlib.tests.stub_sftp import StubServer
+
+        # Start an SSH server
+        self.command_executed = []
+        # XXX: This is horrible -- we define a really dumb SSH server that
+        # executes commands, and manage the hooking up of stdin/out/err to the
+        # SSH channel ourselves.  Surely this has already been implemented
+        # elsewhere?
+        class StubSSHServer(StubServer):
+
+            test = self
+
+            def check_channel_exec_request(self, channel, command):
+                self.test.command_executed.append(command)
+                proc = subprocess.Popen(
+                    command, shell=True, stdin=subprocess.PIPE,
+                    stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+
+                # XXX: horribly inefficient, not to mention ugly.
+                # Start a thread for each of stdin/out/err, and relay bytes from
+                # the subprocess to channel and vice versa.
+                def ferry_bytes(read, write, close):
+                    while True:
+                        bytes = read(1)
+                        if bytes == '':
+                            close()
+                            break
+                        write(bytes)
+
+                file_functions = [
+                    (channel.recv, proc.stdin.write, proc.stdin.close),
+                    (proc.stdout.read, channel.sendall, channel.close),
+                    (proc.stderr.read, channel.sendall_stderr, channel.close)]
+                for read, write, close in file_functions:
+                    t = threading.Thread(
+                        target=ferry_bytes, args=(read, write, close))
+                    t.start()
+
+                return True
+
+        ssh_server = SFTPFullAbsoluteServer(StubSSHServer)
+        # We *don't* want to override the default SSH vendor: the detected one
+        # is the one to use.
+        self.start_server(ssh_server)
+        port = ssh_server._listener.port
+
+        if sys.platform == 'win32':
+            bzr_remote_path = sys.executable + ' ' + self.get_bzr_path()
+        else:
+            bzr_remote_path = self.get_bzr_path()
+        os.environ['BZR_REMOTE_PATH'] = bzr_remote_path
+
+        # Access the branch via a bzr+ssh URL.  The BZR_REMOTE_PATH environment
+        # variable is used to tell bzr what command to run on the remote end.
+        path_to_branch = osutils.abspath('.')
+        if sys.platform == 'win32':
+            # On Windows, we export all drives as '/C:/, etc. So we need to
+            # prefix a '/' to get the right path.
+            path_to_branch = '/' + path_to_branch
+        url = 'bzr+ssh://fred:secret@localhost:%d%s' % (port, path_to_branch)
+        t = get_transport(url)
+        self.permit_url(t.base)
+        t.mkdir('foo')
+
+        self.assertEqual(
+            ['%s serve --inet --directory=/ --allow-writes' % bzr_remote_path],
+            self.command_executed)

=== modified file 'bzrlib/tests/test_ui.py'
--- bzrlib/tests/test_ui.py	2009-08-03 05:54:52 +0000
+++ bzrlib/tests/test_ui.py	2009-10-15 20:04:37 +0000
@@ -42,7 +42,6 @@
     )
 from bzrlib.ui import (
     CannedInputUIFactory,
-    CLIUIFactory,
     SilentUIFactory,
     UIFactory,
     make_ui_for_terminal,
@@ -54,7 +53,7 @@
     )
 
 
-class UITests(tests.TestCase):
+class TestTextUIFactory(tests.TestCase):
 
     def test_text_factory_ascii_password(self):
         ui = tests.TestUIFactory(stdin='secret\n',
@@ -100,56 +99,6 @@
         finally:
             pb.finished()
 
-    def test_progress_construction(self):
-        """TextUIFactory constructs the right progress view.
-        """
-        for (file_class, term, pb, expected_pb_class) in (
-            # on an xterm, either use them or not as the user requests,
-            # otherwise default on
-            (_TTYStringIO, 'xterm', 'none', NullProgressView),
-            (_TTYStringIO, 'xterm', 'text', TextProgressView),
-            (_TTYStringIO, 'xterm', None, TextProgressView),
-            # on a dumb terminal, again if there's explicit configuration do
-            # it, otherwise default off
-            (_TTYStringIO, 'dumb', 'none', NullProgressView),
-            (_TTYStringIO, 'dumb', 'text', TextProgressView),
-            (_TTYStringIO, 'dumb', None, NullProgressView),
-            # on a non-tty terminal, it's null regardless of $TERM
-            (StringIO, 'xterm', None, NullProgressView),
-            (StringIO, 'dumb', None, NullProgressView),
-            # however, it can still be forced on
-            (StringIO, 'dumb', 'text', TextProgressView),
-            ):
-            os.environ['TERM'] = term
-            if pb is None:
-                if 'BZR_PROGRESS_BAR' in os.environ:
-                    del os.environ['BZR_PROGRESS_BAR']
-            else:
-                os.environ['BZR_PROGRESS_BAR'] = pb
-            stdin = file_class('')
-            stderr = file_class()
-            stdout = file_class()
-            uif = make_ui_for_terminal(stdin, stdout, stderr)
-            self.assertIsInstance(uif, TextUIFactory,
-                "TERM=%s BZR_PROGRESS_BAR=%s uif=%r" % (term, pb, uif,))
-            self.assertIsInstance(uif.make_progress_view(),
-                expected_pb_class,
-                "TERM=%s BZR_PROGRESS_BAR=%s uif=%r" % (term, pb, uif,))
-
-    def test_text_ui_non_terminal(self):
-        """Even on non-ttys, make_ui_for_terminal gives a text ui."""
-        stdin = _NonTTYStringIO('')
-        stderr = _NonTTYStringIO()
-        stdout = _NonTTYStringIO()
-        for term_type in ['dumb', None, 'xterm']:
-            if term_type is None:
-                del os.environ['TERM']
-            else:
-                os.environ['TERM'] = term_type
-            uif = make_ui_for_terminal(stdin, stdout, stderr)
-            self.assertIsInstance(uif, TextUIFactory,
-                'TERM=%r' % (term_type,))
-
     def test_progress_note(self):
         stderr = StringIO()
         stdout = StringIO()
@@ -158,7 +107,9 @@
             stdout=stdout)
         pb = ui_factory.nested_progress_bar()
         try:
-            result = pb.note('t')
+            result = self.applyDeprecated(deprecated_in((2, 1, 0)),
+                pb.note,
+                't')
             self.assertEqual(None, result)
             self.assertEqual("t\n", stdout.getvalue())
             # Since there was no update() call, there should be no clear() call
@@ -182,7 +133,8 @@
         try:
             # Create a progress update that isn't throttled
             pb.update('x', 1, 1)
-            result = pb.note('t')
+            result = self.applyDeprecated(deprecated_in((2, 1, 0)),
+                pb.note, 't')
             self.assertEqual(None, result)
             self.assertEqual("t\n", stdout.getvalue())
             # the exact contents will depend on the terminal width and we don't
@@ -301,13 +253,57 @@
             pb.finished()
 
 
-class CLIUITests(TestCase):
-
-    def test_cli_factory_deprecated(self):
-        uif = self.applyDeprecated(deprecated_in((1, 18, 0)),
-            CLIUIFactory,
-            StringIO(), StringIO(), StringIO())
-        self.assertIsInstance(uif, UIFactory)
+class UITests(tests.TestCase):
+
+    def test_progress_construction(self):
+        """TextUIFactory constructs the right progress view.
+        """
+        for (file_class, term, pb, expected_pb_class) in (
+            # on an xterm, either use them or not as the user requests,
+            # otherwise default on
+            (_TTYStringIO, 'xterm', 'none', NullProgressView),
+            (_TTYStringIO, 'xterm', 'text', TextProgressView),
+            (_TTYStringIO, 'xterm', None, TextProgressView),
+            # on a dumb terminal, again if there's explicit configuration do
+            # it, otherwise default off
+            (_TTYStringIO, 'dumb', 'none', NullProgressView),
+            (_TTYStringIO, 'dumb', 'text', TextProgressView),
+            (_TTYStringIO, 'dumb', None, NullProgressView),
+            # on a non-tty terminal, it's null regardless of $TERM
+            (StringIO, 'xterm', None, NullProgressView),
+            (StringIO, 'dumb', None, NullProgressView),
+            # however, it can still be forced on
+            (StringIO, 'dumb', 'text', TextProgressView),
+            ):
+            os.environ['TERM'] = term
+            if pb is None:
+                if 'BZR_PROGRESS_BAR' in os.environ:
+                    del os.environ['BZR_PROGRESS_BAR']
+            else:
+                os.environ['BZR_PROGRESS_BAR'] = pb
+            stdin = file_class('')
+            stderr = file_class()
+            stdout = file_class()
+            uif = make_ui_for_terminal(stdin, stdout, stderr)
+            self.assertIsInstance(uif, TextUIFactory,
+                "TERM=%s BZR_PROGRESS_BAR=%s uif=%r" % (term, pb, uif,))
+            self.assertIsInstance(uif.make_progress_view(),
+                expected_pb_class,
+                "TERM=%s BZR_PROGRESS_BAR=%s uif=%r" % (term, pb, uif,))
+
+    def test_text_ui_non_terminal(self):
+        """Even on non-ttys, make_ui_for_terminal gives a text ui."""
+        stdin = _NonTTYStringIO('')
+        stderr = _NonTTYStringIO()
+        stdout = _NonTTYStringIO()
+        for term_type in ['dumb', None, 'xterm']:
+            if term_type is None:
+                del os.environ['TERM']
+            else:
+                os.environ['TERM'] = term_type
+            uif = make_ui_for_terminal(stdin, stdout, stderr)
+            self.assertIsInstance(uif, TextUIFactory,
+                'TERM=%r' % (term_type,))
 
 
 class SilentUITests(TestCase):

=== modified file 'bzrlib/tests/test_urlutils.py'
--- bzrlib/tests/test_urlutils.py	2009-04-04 01:45:09 +0000
+++ bzrlib/tests/test_urlutils.py	2009-11-26 04:01:58 +0000
@@ -17,7 +17,6 @@
 """Tests for the urlutils wrapper."""
 
 import os
-import re
 import sys
 
 from bzrlib import osutils, urlutils, win32utils
@@ -300,8 +299,13 @@
             from_url('file:///path/to/r%C3%A4ksm%C3%B6rg%C3%A5s'))
         self.assertEqual(u'/path/to/r\xe4ksm\xf6rg\xe5s',
             from_url('file:///path/to/r%c3%a4ksm%c3%b6rg%c3%a5s'))
+        self.assertEqual(u'/path/to/r\xe4ksm\xf6rg\xe5s',
+            from_url('file://localhost/path/to/r%c3%a4ksm%c3%b6rg%c3%a5s'))
 
         self.assertRaises(InvalidURL, from_url, '/path/to/foo')
+        self.assertRaises(
+            InvalidURL, from_url,
+            'file://remotehost/path/to/r%c3%a4ksm%c3%b6rg%c3%a5s')
 
     def test_win32_local_path_to_url(self):
         to_url = urlutils._win32_local_path_to_url

=== modified file 'bzrlib/tests/test_version.py'
--- bzrlib/tests/test_version.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_version.py	2009-09-17 11:54:41 +0000
@@ -24,6 +24,7 @@
 
     def test_get_bzr_source_tree(self):
         """Get tree for bzr source, if any."""
+        self.permit_source_tree_branch_repo()
         # We don't know if these tests are being run from a checkout or branch
         # of bzr, from an installed copy, or from source unpacked from a
         # tarball.  We don't construct a branch just for testing this, so we

=== modified file 'bzrlib/tests/test_win32utils.py'
--- bzrlib/tests/test_win32utils.py	2009-07-03 14:26:34 +0000
+++ bzrlib/tests/test_win32utils.py	2009-11-20 16:42:28 +0000
@@ -17,7 +17,11 @@
 import os
 import sys
 
-from bzrlib import osutils
+from bzrlib import (
+    osutils,
+    tests,
+    win32utils,
+    )
 from bzrlib.tests import (
     Feature,
     TestCase,
@@ -26,21 +30,22 @@
     UnicodeFilenameFeature,
     )
 from bzrlib.win32utils import glob_expand, get_app_path
-from bzrlib import win32utils
-
-
-# Features
-# --------
-
-class _NeedsGlobExpansionFeature(Feature):
+
+
+class _BackslashDirSeparatorFeature(tests.Feature):
 
     def _probe(self):
-        return sys.platform == 'win32'
+        try:
+            os.lstat(os.getcwd() + '\\')
+        except OSError:
+            return False
+        else:
+            return True
 
     def feature_name(self):
-        return 'Internally performed glob expansion'
+        return "Filesystem treats '\\' as a directory separator."
 
-NeedsGlobExpansionFeature = _NeedsGlobExpansionFeature()
+BackslashDirSeparatorFeature = _BackslashDirSeparatorFeature()
 
 
 class _RequiredModuleFeature(Feature):
@@ -67,19 +72,9 @@
 # Tests
 # -----
 
-class TestNeedsGlobExpansionFeature(TestCase):
-
-    def test_available(self):
-        self.assertEqual(sys.platform == 'win32',
-                         NeedsGlobExpansionFeature.available())
-
-    def test_str(self):
-        self.assertTrue("performed" in str(NeedsGlobExpansionFeature))
-
-
 class TestWin32UtilsGlobExpand(TestCaseInTempDir):
 
-    _test_needs_features = [NeedsGlobExpansionFeature]
+    _test_needs_features = []
 
     def test_empty_tree(self):
         self.build_tree([])
@@ -89,22 +84,28 @@
             [['*'], ['*']],
             [['a', 'a'], ['a', 'a']]])
 
-    def test_tree_ascii(self):
-        """Checks the glob expansion and path separation char
-        normalization"""
+    def build_ascii_tree(self):
         self.build_tree(['a', 'a1', 'a2', 'a11', 'a.1',
                          'b', 'b1', 'b2', 'b3',
                          'c/', 'c/c1', 'c/c2',
                          'd/', 'd/d1', 'd/d2', 'd/e/', 'd/e/e1'])
+
+    def build_unicode_tree(self):
+        self.requireFeature(UnicodeFilenameFeature)
+        self.build_tree([u'\u1234', u'\u1234\u1234', u'\u1235/',
+                         u'\u1235/\u1235'])
+
+    def test_tree_ascii(self):
+        """Checks the glob expansion and path separation char
+        normalization"""
+        self.build_ascii_tree()
         self._run_testset([
             # no wildcards
             [[u'a'], [u'a']],
             [[u'a', u'a' ], [u'a', u'a']],
-            [[u'A'], [u'A']],
 
             [[u'd'], [u'd']],
             [[u'd/'], [u'd/']],
-            [[u'd\\'], [u'd/']],
 
             # wildcards
             [[u'a*'], [u'a', u'a1', u'a2', u'a11', u'a.1']],
@@ -112,18 +113,35 @@
             [[u'a?'], [u'a1', u'a2']],
             [[u'a??'], [u'a11', u'a.1']],
             [[u'b[1-2]'], [u'b1', u'b2']],
-            [[u'A?'], [u'a1', u'a2']],
 
             [[u'd/*'], [u'd/d1', u'd/d2', u'd/e']],
+            [[u'?/*'], [u'c/c1', u'c/c2', u'd/d1', u'd/d2', u'd/e']],
+            [[u'*/*'], [u'c/c1', u'c/c2', u'd/d1', u'd/d2', u'd/e']],
+            [[u'*/'], [u'c/', u'd/']],
+            ])
+
+    def test_backslash_globbing(self):
+        self.requireFeature(BackslashDirSeparatorFeature)
+        self.build_ascii_tree()
+        self._run_testset([
+            [[u'd\\'], [u'd/']],
             [[u'd\\*'], [u'd/d1', u'd/d2', u'd/e']],
             [[u'?\\*'], [u'c/c1', u'c/c2', u'd/d1', u'd/d2', u'd/e']],
             [[u'*\\*'], [u'c/c1', u'c/c2', u'd/d1', u'd/d2', u'd/e']],
-            [[u'*/'], [u'c/', u'd/']],
-            [[u'*\\'], [u'c/', u'd/']]])
+            [[u'*\\'], [u'c/', u'd/']],
+            ])
+
+    def test_case_insensitive_globbing(self):
+        self.requireFeature(tests.CaseInsCasePresFilenameFeature)
+        self.build_ascii_tree()
+        self._run_testset([
+            [[u'A'], [u'A']],
+            [[u'A?'], [u'a1', u'a2']],
+            ])
 
     def test_tree_unicode(self):
         """Checks behaviour with non-ascii filenames"""
-        self.build_tree([u'\u1234', u'\u1234\u1234', u'\u1235/', u'\u1235/\u1235'])
+        self.build_unicode_tree()
         self._run_testset([
             # no wildcards
             [[u'\u1234'], [u'\u1234']],
@@ -139,16 +157,26 @@
 
             [[u'\u1235/?'], [u'\u1235/\u1235']],
             [[u'\u1235/*'], [u'\u1235/\u1235']],
+            [[u'?/'], [u'\u1235/']],
+            [[u'*/'], [u'\u1235/']],
+            [[u'?/?'], [u'\u1235/\u1235']],
+            [[u'*/*'], [u'\u1235/\u1235']],
+            ])
+
+    def test_unicode_backslashes(self):
+        self.requireFeature(BackslashDirSeparatorFeature)
+        self.build_unicode_tree()
+        self._run_testset([
+            # no wildcards
+            [[u'\u1235\\'], [u'\u1235/']],
+            [[u'\u1235\\\u1235'], [u'\u1235/\u1235']],
             [[u'\u1235\\?'], [u'\u1235/\u1235']],
             [[u'\u1235\\*'], [u'\u1235/\u1235']],
-            [[u'?/'], [u'\u1235/']],
-            [[u'*/'], [u'\u1235/']],
             [[u'?\\'], [u'\u1235/']],
             [[u'*\\'], [u'\u1235/']],
-            [[u'?/?'], [u'\u1235/\u1235']],
-            [[u'*/*'], [u'\u1235/\u1235']],
             [[u'?\\?'], [u'\u1235/\u1235']],
-            [[u'*\\*'], [u'\u1235/\u1235']]])
+            [[u'*\\*'], [u'\u1235/\u1235']],
+            ])
 
     def _run_testset(self, testset):
         for pattern, expected in testset:
@@ -261,3 +289,108 @@
         os.makedirs(u'\u1234\\.bzr')
         path = osutils.abspath(u'\u1234\\.bzr')
         win32utils.set_file_attr_hidden(path)
+
+
+
+class TestUnicodeShlex(tests.TestCase):
+
+    def assertAsTokens(self, expected, line):
+        s = win32utils.UnicodeShlex(line)
+        self.assertEqual(expected, list(s))
+
+    def test_simple(self):
+        self.assertAsTokens([(False, u'foo'), (False, u'bar'), (False, u'baz')],
+                            u'foo bar baz')
+
+    def test_ignore_multiple_spaces(self):
+        self.assertAsTokens([(False, u'foo'), (False, u'bar')], u'foo  bar')
+
+    def test_ignore_leading_space(self):
+        self.assertAsTokens([(False, u'foo'), (False, u'bar')], u'  foo bar')
+
+    def test_ignore_trailing_space(self):
+        self.assertAsTokens([(False, u'foo'), (False, u'bar')], u'foo bar  ')
+
+    def test_posix_quotations(self):
+        self.assertAsTokens([(True, u'foo bar')], u'"foo bar"')
+        self.assertAsTokens([(False, u"'fo''o"), (False, u"b''ar'")],
+            u"'fo''o b''ar'")
+        self.assertAsTokens([(True, u'foo bar')], u'"fo""o b""ar"')
+        self.assertAsTokens([(True, u"fo'o"), (True, u"b'ar")],
+            u'"fo"\'o b\'"ar"')
+
+    def test_nested_quotations(self):
+        self.assertAsTokens([(True, u'foo"" bar')], u"\"foo\\\"\\\" bar\"")
+        self.assertAsTokens([(True, u'foo\'\' bar')], u"\"foo'' bar\"")
+
+    def test_empty_result(self):
+        self.assertAsTokens([], u'')
+        self.assertAsTokens([], u'    ')
+
+    def test_quoted_empty(self):
+        self.assertAsTokens([(True, '')], u'""')
+        self.assertAsTokens([(False, u"''")], u"''")
+
+    def test_unicode_chars(self):
+        self.assertAsTokens([(False, u'f\xb5\xee'), (False, u'\u1234\u3456')],
+                             u'f\xb5\xee \u1234\u3456')
+
+    def test_newline_in_quoted_section(self):
+        self.assertAsTokens([(True, u'foo\nbar\nbaz\n')], u'"foo\nbar\nbaz\n"')
+
+    def test_escape_chars(self):
+        self.assertAsTokens([(False, u'foo\\bar')], u'foo\\bar')
+
+    def test_escape_quote(self):
+        self.assertAsTokens([(True, u'foo"bar')], u'"foo\\"bar"')
+
+    def test_double_escape(self):
+        self.assertAsTokens([(True, u'foo\\bar')], u'"foo\\\\bar"')
+        self.assertAsTokens([(False, u'foo\\\\bar')], u"foo\\\\bar")
+
+
+class Test_CommandLineToArgv(tests.TestCaseInTempDir):
+
+    def assertCommandLine(self, expected, line):
+        # Strictly speaking we should respect parameter order versus glob
+        # expansions, but it's not really worth the effort here
+        self.assertEqual(expected,
+                         sorted(win32utils._command_line_to_argv(line)))
+
+    def test_glob_paths(self):
+        self.build_tree(['a/', 'a/b.c', 'a/c.c', 'a/c.h'])
+        self.assertCommandLine([u'a/b.c', u'a/c.c'], 'a/*.c')
+        self.build_tree(['b/', 'b/b.c', 'b/d.c', 'b/d.h'])
+        self.assertCommandLine([u'a/b.c', u'b/b.c'], '*/b.c')
+        self.assertCommandLine([u'a/b.c', u'a/c.c', u'b/b.c', u'b/d.c'],
+                               '*/*.c')
+        # Bash style, just pass through the argument if nothing matches
+        self.assertCommandLine([u'*/*.qqq'], '*/*.qqq')
+
+    def test_quoted_globs(self):
+        self.build_tree(['a/', 'a/b.c', 'a/c.c', 'a/c.h'])
+        self.assertCommandLine([u'a/*.c'], '"a/*.c"')
+        self.assertCommandLine([u"'a/*.c'"], "'a/*.c'")
+
+    def test_slashes_changed(self):
+        # Quoting doesn't change the supplied args
+        self.assertCommandLine([u'a\\*.c'], '"a\\*.c"')
+        # Expands the glob, but nothing matches, swaps slashes
+        self.assertCommandLine([u'a/*.c'], 'a\\*.c')
+        self.assertCommandLine([u'a/?.c'], 'a\\?.c')
+        # No glob, doesn't touch slashes
+        self.assertCommandLine([u'a\\foo.c'], 'a\\foo.c')
+
+    def test_no_single_quote_supported(self):
+        self.assertCommandLine(["add", "let's-do-it.txt"],
+            "add let's-do-it.txt")
+
+    def test_case_insensitive_globs(self):
+        self.requireFeature(tests.CaseInsCasePresFilenameFeature)
+        self.build_tree(['a/', 'a/b.c', 'a/c.c', 'a/c.h'])
+        self.assertCommandLine([u'A/b.c'], 'A/B*')
+
+    def test_backslashes(self):
+        self.requireFeature(BackslashDirSeparatorFeature)
+        self.build_tree(['a/', 'a/b.c', 'a/c.c', 'a/c.h'])
+        self.assertCommandLine([u'a/b.c'], 'a\\b*')

=== modified file 'bzrlib/tests/test_wsgi.py'
--- bzrlib/tests/test_wsgi.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/test_wsgi.py	2009-10-21 11:13:40 +0000
@@ -19,17 +19,12 @@
 from cStringIO import StringIO
 
 from bzrlib import tests
-from bzrlib.smart import protocol
+from bzrlib.smart import medium, message, protocol
 from bzrlib.transport.http import wsgi
 from bzrlib.transport import chroot, memory
 
 
-class TestWSGI(tests.TestCase):
-
-    def setUp(self):
-        tests.TestCase.setUp(self)
-        self.status = None
-        self.headers = None
+class WSGITestMixin(object):
 
     def build_environ(self, updates=None):
         """Builds an environ dict with all fields required by PEP 333.
@@ -69,6 +64,14 @@
         self.status = status
         self.headers = headers
 
+
+class TestWSGI(tests.TestCase, WSGITestMixin):
+
+    def setUp(self):
+        tests.TestCase.setUp(self)
+        self.status = None
+        self.headers = None
+
     def test_construct(self):
         app = wsgi.SmartWSGIApp(FakeTransport())
         self.assertIsInstance(
@@ -242,6 +245,51 @@
             protocol.RESPONSE_VERSION_TWO + 'success\nok\x012\n', response)
 
 
+class TestWSGIJail(tests.TestCaseWithMemoryTransport, WSGITestMixin):
+
+    def make_hpss_wsgi_request(self, wsgi_relpath, *args):
+        write_buf = StringIO()
+        request_medium = medium.SmartSimplePipesClientMedium(
+            None, write_buf, 'fake:' + wsgi_relpath)
+        request_encoder = protocol.ProtocolThreeRequester(
+            request_medium.get_request())
+        request_encoder.call(*args)
+        write_buf.seek(0)
+        environ = self.build_environ({
+            'REQUEST_METHOD': 'POST',
+            'CONTENT_LENGTH': len(write_buf.getvalue()),
+            'wsgi.input': write_buf,
+            'bzrlib.relpath': wsgi_relpath,
+        })
+        return environ
+
+    def test_jail_root(self):
+        """The WSGI HPSS glue allows access to the whole WSGI backing
+        transport, regardless of which HTTP path the request was delivered
+        to.
+        """
+        # make a branch in a shared repo
+        self.make_repository('repo', shared=True)
+        branch = self.make_bzrdir('repo/branch').create_branch()
+        # serve the repo via bzr+http WSGI
+        wsgi_app = wsgi.SmartWSGIApp(self.get_transport())
+        # send a request to /repo/branch that will have to access /repo.
+        environ = self.make_hpss_wsgi_request(
+            '/repo/branch', 'BzrDir.open_branchV2', '.')
+        iterable = wsgi_app(environ, self.start_response)
+        response_bytes = self.read_response(iterable)
+        self.assertEqual('200 OK', self.status)
+        # expect a successful response, rather than a jail break error
+        from bzrlib.tests.test_smart_transport import LoggingMessageHandler
+        message_handler = LoggingMessageHandler()
+        decoder = protocol.ProtocolThreeDecoder(
+            message_handler, expect_version_marker=True)
+        decoder.accept_bytes(response_bytes)
+        self.assertTrue(
+            ('structure', ('branch', branch._format.network_name()))
+            in message_handler.event_log)
+
+
 class FakeRequest(object):
 
     def __init__(self, transport, write_func):

=== modified file 'bzrlib/tests/transport_util.py'
--- bzrlib/tests/transport_util.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/transport_util.py	2009-09-17 11:54:41 +0000
@@ -33,6 +33,7 @@
 
 from bzrlib.transport import (
     ConnectedTransport,
+    get_transport,
     register_transport,
     register_urlparse_netloc_protocol,
     unregister_transport,
@@ -106,6 +107,16 @@
         self.addCleanup(unregister)
         super(TestCaseWithConnectionHookedTransport, self).setUp()
         self.reset_connections()
+        # Add the 'hooked' url to the permitted url list.
+        # XXX: See TestCase.start_server. This whole module shouldn't need to
+        # exist - a bug has been filed on that. once its cleanedup/removed, the
+        # standard test support code will work and permit the server url
+        # correctly.
+        url = self.get_url()
+        t = get_transport(url)
+        if t.base.endswith('work/'):
+            t = t.clone('../..')
+        self.permit_url(t.base)
 
     def get_url(self, relpath=None):
         super_self = super(TestCaseWithConnectionHookedTransport, self)

=== removed file 'bzrlib/textui.py'
--- bzrlib/textui.py	2009-03-23 14:59:43 +0000
+++ bzrlib/textui.py	1970-01-01 00:00:00 +0000
@@ -1,40 +0,0 @@
-# Bazaar -- distributed version control
-#
-# Copyright (C) 2005, 2006 Canonical Ltd
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
-
-import sys
-
-
-def show_status(state, kind, name, to_file=None):
-    if kind == 'directory':
-        # use this even on windows?
-        kind_ch = '/'
-    elif kind == 'symlink':
-        kind_ch = '->'
-    elif kind == 'file':
-        kind_ch = ''
-    else:
-        raise ValueError(kind)
-
-    if len(state) != 1:
-        raise ValueError(state)
-
-    if to_file is None:
-        to_file = sys.stdout
-
-    to_file.write(state + '       ' + name + kind_ch + '\n')
-

=== modified file 'bzrlib/trace.py'
--- bzrlib/trace.py	2009-08-20 05:02:45 +0000
+++ bzrlib/trace.py	2009-12-01 05:35:52 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007, 2008 Canonical Ltd
+# Copyright (C) 2005, 2006, 2007, 2008, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,6 @@
 import logging
 import os
 import sys
-import re
 import time
 
 from bzrlib.lazy_import import lazy_import
@@ -72,6 +71,11 @@
 
 import bzrlib
 
+from bzrlib.symbol_versioning import (
+    deprecated_function,
+    deprecated_in,
+    )
+
 lazy_import(globals(), """
 from bzrlib import (
     debug,
@@ -123,20 +127,37 @@
     _bzr_logger.warning(*args, **kwargs)
 
 
-# configure convenient aliases for output routines
-#
-# TODO: deprecate them, have one name for each.
-info = note
-log_error = _bzr_logger.error
-error =     _bzr_logger.error
-
-
-_last_mutter_flush_time = None
+@deprecated_function(deprecated_in((2, 1, 0)))
+def info(*args, **kwargs):
+    """Deprecated: use trace.note instead."""
+    note(*args, **kwargs)
+
+
+@deprecated_function(deprecated_in((2, 1, 0)))
+def log_error(*args, **kwargs):
+    """Deprecated: use bzrlib.trace.show_error instead"""
+    _bzr_logger.error(*args, **kwargs)
+
+
+@deprecated_function(deprecated_in((2, 1, 0)))
+def error(*args, **kwargs):
+    """Deprecated: use bzrlib.trace.show_error instead"""
+    _bzr_logger.error(*args, **kwargs)
+
+
+def show_error(msg):
+    """Show an error message to the user.
+
+    Don't use this for exceptions, use report_exception instead.
+    """
+    _bzr_logger.error(*args, **kwargs)
+
 
 def mutter(fmt, *args):
-    global _last_mutter_flush_time
     if _trace_file is None:
         return
+    # XXX: Don't check this every time; instead anyone who closes the file
+    # ought to deregister it.  We can tolerate None.
     if (getattr(_trace_file, 'closed', None) is not None) and _trace_file.closed:
         return
 
@@ -159,15 +180,7 @@
     timestamp = '%0.3f  ' % (now - _bzr_log_start_time,)
     out = timestamp + out + '\n'
     _trace_file.write(out)
-    # We flush if we haven't flushed for a few seconds. We don't want to flush
-    # on every mutter, but when a command takes a while, it can be nice to see
-    # updates in the debug log.
-    if (_last_mutter_flush_time is None
-        or (now - _last_mutter_flush_time) > 2.0):
-        flush = getattr(_trace_file, 'flush', None)
-        if flush is not None:
-            flush()
-        _last_mutter_flush_time = now
+    # there's no explicit flushing; the file is typically line buffered.
 
 
 def mutter_callsite(stacklevel, fmt, *args):
@@ -228,7 +241,7 @@
     _bzr_log_filename = _get_bzr_log_filename()
     _rollover_trace_maybe(_bzr_log_filename)
     try:
-        bzr_log_file = open(_bzr_log_filename, 'at', 1) # line buffered
+        bzr_log_file = open(_bzr_log_filename, 'at', buffering=0) # unbuffered
         # bzr_log_file.tell() on windows always return 0 until some writing done
         bzr_log_file.write('\n')
         if bzr_log_file.tell() <= 2:
@@ -422,9 +435,12 @@
 
     :return: The appropriate exit code for this error.
     """
-    exc_type, exc_object, exc_tb = exc_info
     # Log the full traceback to ~/.bzr.log
     log_exception_quietly()
+    if 'error' in debug.debug_flags:
+        print_exception(exc_info, err_file)
+        return errors.EXIT_ERROR
+    exc_type, exc_object, exc_tb = exc_info
     if (isinstance(exc_object, IOError)
         and getattr(exc_object, 'errno', None) == errno.EPIPE):
         err_file.write("bzr: broken pipe\n")
@@ -432,6 +448,9 @@
     elif isinstance(exc_object, KeyboardInterrupt):
         err_file.write("bzr: interrupted\n")
         return errors.EXIT_ERROR
+    elif isinstance(exc_object, MemoryError):
+        err_file.write("bzr: out of memory\n")
+        return errors.EXIT_ERROR
     elif isinstance(exc_object, ImportError) \
         and str(exc_object).startswith("No module named "):
         report_user_error(exc_info, err_file,
@@ -468,9 +487,6 @@
     :param advice: Extra advice to the user to be printed following the
         exception.
     """
-    if 'error' in debug.debug_flags:
-        print_exception(exc_info, err_file)
-        return
     err_file.write("bzr: ERROR: %s\n" % (exc_info[1],))
     if advice:
         err_file.write("%s\n" % (advice,))

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2009-09-01 01:25:37 +0000
+++ bzrlib/transform.py	2009-12-03 02:24:54 +0000
@@ -859,8 +859,8 @@
     def get_preview_tree(self):
         """Return a tree representing the result of the transform.
 
-        This tree only supports the subset of Tree functionality required
-        by show_diff_trees.  It must only be compared to tt._tree.
+        The tree is a snapshot, and altering the TreeTransform will invalidate
+        it.
         """
         return _PreviewTree(self)
 
@@ -1054,47 +1054,20 @@
     def _limbo_name(self, trans_id):
         """Generate the limbo name of a file"""
         limbo_name = self._limbo_files.get(trans_id)
-        if limbo_name is not None:
-            return limbo_name
-        parent = self._new_parent.get(trans_id)
-        # if the parent directory is already in limbo (e.g. when building a
-        # tree), choose a limbo name inside the parent, to reduce further
-        # renames.
-        use_direct_path = False
-        if self._new_contents.get(parent) == 'directory':
-            filename = self._new_name.get(trans_id)
-            if filename is not None:
-                if parent not in self._limbo_children:
-                    self._limbo_children[parent] = set()
-                    self._limbo_children_names[parent] = {}
-                    use_direct_path = True
-                # the direct path can only be used if no other file has
-                # already taken this pathname, i.e. if the name is unused, or
-                # if it is already associated with this trans_id.
-                elif self._case_sensitive_target:
-                    if (self._limbo_children_names[parent].get(filename)
-                        in (trans_id, None)):
-                        use_direct_path = True
-                else:
-                    for l_filename, l_trans_id in\
-                        self._limbo_children_names[parent].iteritems():
-                        if l_trans_id == trans_id:
-                            continue
-                        if l_filename.lower() == filename.lower():
-                            break
-                    else:
-                        use_direct_path = True
-
-        if use_direct_path:
-            limbo_name = pathjoin(self._limbo_files[parent], filename)
-            self._limbo_children[parent].add(trans_id)
-            self._limbo_children_names[parent][filename] = trans_id
-        else:
-            limbo_name = pathjoin(self._limbodir, trans_id)
-            self._needs_rename.add(trans_id)
-        self._limbo_files[trans_id] = limbo_name
+        if limbo_name is None:
+            limbo_name = self._generate_limbo_path(trans_id)
+            self._limbo_files[trans_id] = limbo_name
         return limbo_name
 
+    def _generate_limbo_path(self, trans_id):
+        """Generate a limbo path using the trans_id as the relative path.
+
+        This is suitable as a fallback, and when the transform should not be
+        sensitive to the path encoding of the limbo directory.
+        """
+        self._needs_rename.add(trans_id)
+        return pathjoin(self._limbodir, trans_id)
+
     def adjust_path(self, name, parent, trans_id):
         previous_parent = self._new_parent.get(trans_id)
         previous_name = self._new_name.get(trans_id)
@@ -1122,6 +1095,17 @@
                 continue
             new_path = self._limbo_name(trans_id)
             os.rename(old_path, new_path)
+            for descendant in self._limbo_descendants(trans_id):
+                desc_path = self._limbo_files[descendant]
+                desc_path = new_path + desc_path[len(old_path):]
+                self._limbo_files[descendant] = desc_path
+
+    def _limbo_descendants(self, trans_id):
+        """Return the set of trans_ids whose limbo paths descend from this."""
+        descendants = set(self._limbo_children.get(trans_id, []))
+        for descendant in list(descendants):
+            descendants.update(self._limbo_descendants(descendant))
+        return descendants
 
     def create_file(self, contents, trans_id, mode_id=None):
         """Schedule creation of a new file.
@@ -1396,6 +1380,54 @@
                 continue
             yield self.trans_id_tree_path(childpath)
 
+    def _generate_limbo_path(self, trans_id):
+        """Generate a limbo path using the final path if possible.
+
+        This optimizes the performance of applying the tree transform by
+        avoiding renames.  These renames can be avoided only when the parent
+        directory is already scheduled for creation.
+
+        If the final path cannot be used, falls back to using the trans_id as
+        the relpath.
+        """
+        parent = self._new_parent.get(trans_id)
+        # if the parent directory is already in limbo (e.g. when building a
+        # tree), choose a limbo name inside the parent, to reduce further
+        # renames.
+        use_direct_path = False
+        if self._new_contents.get(parent) == 'directory':
+            filename = self._new_name.get(trans_id)
+            if filename is not None:
+                if parent not in self._limbo_children:
+                    self._limbo_children[parent] = set()
+                    self._limbo_children_names[parent] = {}
+                    use_direct_path = True
+                # the direct path can only be used if no other file has
+                # already taken this pathname, i.e. if the name is unused, or
+                # if it is already associated with this trans_id.
+                elif self._case_sensitive_target:
+                    if (self._limbo_children_names[parent].get(filename)
+                        in (trans_id, None)):
+                        use_direct_path = True
+                else:
+                    for l_filename, l_trans_id in\
+                        self._limbo_children_names[parent].iteritems():
+                        if l_trans_id == trans_id:
+                            continue
+                        if l_filename.lower() == filename.lower():
+                            break
+                    else:
+                        use_direct_path = True
+
+        if not use_direct_path:
+            return DiskTreeTransform._generate_limbo_path(self, trans_id)
+
+        limbo_name = pathjoin(self._limbo_files[parent], filename)
+        self._limbo_children[parent].add(trans_id)
+        self._limbo_children_names[parent][filename] = trans_id
+        return limbo_name
+
+
     def apply(self, no_conflicts=False, precomputed_delta=None, _mover=None):
         """Apply all changes to the inventory and filesystem.
 
@@ -1635,15 +1667,12 @@
         self._all_children_cache = {}
         self._path2trans_id_cache = {}
         self._final_name_cache = {}
-
-    def _changes(self, file_id):
-        for changes in self._transform.iter_changes():
-            if changes[0] == file_id:
-                return changes
+        self._iter_changes_cache = dict((c[0], c) for c in
+                                        self._transform.iter_changes())
 
     def _content_change(self, file_id):
         """Return True if the content of this file changed"""
-        changes = self._changes(file_id)
+        changes = self._iter_changes_cache.get(file_id)
         # changes[2] is true if the file content changed.  See
         # InterTree.iter_changes.
         return (changes is not None and changes[2])
@@ -1884,7 +1913,7 @@
     def get_file_mtime(self, file_id, path=None):
         """See Tree.get_file_mtime"""
         if not self._content_change(file_id):
-            return self._transform._tree.get_file_mtime(file_id, path)
+            return self._transform._tree.get_file_mtime(file_id)
         return self._stat_limbo_file(file_id).st_mtime
 
     def _file_size(self, entry, stat_value):
@@ -1944,7 +1973,7 @@
                 statval = os.lstat(limbo_name)
                 size = statval.st_size
                 if not supports_executable():
-                    executable = None
+                    executable = False
                 else:
                     executable = statval.st_mode & S_IEXEC
             else:
@@ -1952,8 +1981,7 @@
                 executable = None
             if kind == 'symlink':
                 link_or_sha1 = os.readlink(limbo_name).decode(osutils._fs_enc)
-        if supports_executable():
-            executable = tt._new_executability.get(trans_id, executable)
+        executable = tt._new_executability.get(trans_id, executable)
         return kind, size, executable, link_or_sha1
 
     def iter_changes(self, from_tree, include_unchanged=False,
@@ -1990,7 +2018,7 @@
 
     def annotate_iter(self, file_id,
                       default_revision=_mod_revision.CURRENT_REVISION):
-        changes = self._changes(file_id)
+        changes = self._iter_changes_cache.get(file_id)
         if changes is None:
             get_old = True
         else:
@@ -2621,9 +2649,22 @@
                 tt.adjust_path(name[1], parent_trans, trans_id)
             if executable[0] != executable[1] and kind[1] == "file":
                 tt.set_executability(executable[1], trans_id)
-        for (trans_id, mode_id), bytes in target_tree.iter_files_bytes(
-            deferred_files):
-            tt.create_file(bytes, trans_id, mode_id)
+        if working_tree.supports_content_filtering():
+            for index, ((trans_id, mode_id), bytes) in enumerate(
+                target_tree.iter_files_bytes(deferred_files)):
+                file_id = deferred_files[index][0]
+                # We're reverting a tree to the target tree so using the
+                # target tree to find the file path seems the best choice
+                # here IMO - Ian C 27/Oct/2009
+                filter_tree_path = target_tree.id2path(file_id)
+                filters = working_tree._content_filter_stack(filter_tree_path)
+                bytes = filtered_output_bytes(bytes, filters,
+                    ContentFilterContext(filter_tree_path, working_tree))
+                tt.create_file(bytes, trans_id, mode_id)
+        else:
+            for (trans_id, mode_id), bytes in target_tree.iter_files_bytes(
+                deferred_files):
+                tt.create_file(bytes, trans_id, mode_id)
     finally:
         if basis_tree is not None:
             basis_tree.unlock()

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2009-08-04 11:40:59 +0000
+++ bzrlib/transport/__init__.py	2009-10-22 13:55:55 +0000
@@ -90,8 +90,10 @@
                 modules.add(factory._module_name)
             else:
                 modules.add(factory._obj.__module__)
-    # Add chroot directly, because there is no handler registered for it.
+    # Add chroot and pathfilter directly, because there is no handler
+    # registered for it.
     modules.add('bzrlib.transport.chroot')
+    modules.add('bzrlib.transport.pathfilter')
     result = list(modules)
     result.sort()
     return result
@@ -106,7 +108,7 @@
     register_transport_provider( ) ( and the "lazy" variant )
 
     This is needed because:
-    a) a single provider can support multple protcol ( like the ftp
+    a) a single provider can support multiple protocols ( like the ftp
     provider which supports both the ftp:// and the aftp:// protocols )
     b) a single protocol can have multiple providers ( like the http://
     protocol which is supported by both the urllib and pycurl provider )

=== modified file 'bzrlib/transport/chroot.py'
--- bzrlib/transport/chroot.py	2009-03-23 14:59:43 +0000
+++ bzrlib/transport/chroot.py	2009-09-16 04:37:33 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006 Canonical Ltd
+# Copyright (C) 2006-2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,21 +17,18 @@
 """Implementation of Transport that prevents access to locations above a set
 root.
 """
-from urlparse import urlparse
 
-from bzrlib import errors, urlutils
 from bzrlib.transport import (
     get_transport,
+    pathfilter,
     register_transport,
     Server,
     Transport,
     unregister_transport,
     )
-from bzrlib.transport.decorator import TransportDecorator, DecoratorServer
-from bzrlib.transport.memory import MemoryTransport
-
-
-class ChrootServer(Server):
+
+
+class ChrootServer(pathfilter.PathFilteringServer):
     """User space 'chroot' facility.
 
     The server's get_url returns the url for a chroot transport mapped to the
@@ -39,126 +36,40 @@
     directories of the backing transport are not visible. The chroot url will
     not allow '..' sequences to result in requests to the chroot affecting
     directories outside the backing transport.
+
+    PathFilteringServer does all the path sanitation needed to enforce a
+    chroot, so this is a simple subclass of PathFilteringServer that ignores
+    filter_func.
     """
 
     def __init__(self, backing_transport):
-        self.backing_transport = backing_transport
+        pathfilter.PathFilteringServer.__init__(self, backing_transport, None)
 
     def _factory(self, url):
         return ChrootTransport(self, url)
 
-    def get_url(self):
-        return self.scheme
-
     def setUp(self):
         self.scheme = 'chroot-%d:///' % id(self)
         register_transport(self.scheme, self._factory)
 
-    def tearDown(self):
-        unregister_transport(self.scheme, self._factory)
-
-
-class ChrootTransport(Transport):
+
+class ChrootTransport(pathfilter.PathFilteringTransport):
     """A ChrootTransport.
 
     Please see ChrootServer for details.
     """
 
-    def __init__(self, server, base):
-        self.server = server
-        if not base.endswith('/'):
-            base += '/'
-        Transport.__init__(self, base)
-        self.base_path = self.base[len(self.server.scheme)-1:]
-        self.scheme = self.server.scheme
-
-    def _call(self, methodname, relpath, *args):
-        method = getattr(self.server.backing_transport, methodname)
-        return method(self._safe_relpath(relpath), *args)
-
-    def _safe_relpath(self, relpath):
-        safe_relpath = self._combine_paths(self.base_path, relpath)
-        if not safe_relpath.startswith('/'):
-            raise ValueError(safe_relpath)
-        return safe_relpath[1:]
-
-    # Transport methods
-    def abspath(self, relpath):
-        return self.scheme + self._safe_relpath(relpath)
-
-    def append_file(self, relpath, f, mode=None):
-        return self._call('append_file', relpath, f, mode)
-
-    def _can_roundtrip_unix_modebits(self):
-        return self.server.backing_transport._can_roundtrip_unix_modebits()
-
-    def clone(self, relpath):
-        return ChrootTransport(self.server, self.abspath(relpath))
-
-    def delete(self, relpath):
-        return self._call('delete', relpath)
-
-    def delete_tree(self, relpath):
-        return self._call('delete_tree', relpath)
-
-    def external_url(self):
-        """See bzrlib.transport.Transport.external_url."""
-        # Chroots, like MemoryTransport depend on in-process
-        # state and thus the base cannot simply be handed out.
-        # See the base class docstring for more details and
-        # possible directions. For now we return the chrooted
-        # url.
-        return self.server.backing_transport.external_url()
-
-    def get(self, relpath):
-        return self._call('get', relpath)
-
-    def has(self, relpath):
-        return self._call('has', relpath)
-
-    def is_readonly(self):
-        return self.server.backing_transport.is_readonly()
-
-    def iter_files_recursive(self):
-        backing_transport = self.server.backing_transport.clone(
-            self._safe_relpath('.'))
-        return backing_transport.iter_files_recursive()
-
-    def listable(self):
-        return self.server.backing_transport.listable()
-
-    def list_dir(self, relpath):
-        return self._call('list_dir', relpath)
-
-    def lock_read(self, relpath):
-        return self._call('lock_read', relpath)
-
-    def lock_write(self, relpath):
-        return self._call('lock_write', relpath)
-
-    def mkdir(self, relpath, mode=None):
-        return self._call('mkdir', relpath, mode)
-
-    def open_write_stream(self, relpath, mode=None):
-        return self._call('open_write_stream', relpath, mode)
-
-    def put_file(self, relpath, f, mode=None):
-        return self._call('put_file', relpath, f, mode)
-
-    def rename(self, rel_from, rel_to):
-        return self._call('rename', rel_from, self._safe_relpath(rel_to))
-
-    def rmdir(self, relpath):
-        return self._call('rmdir', relpath)
-
-    def stat(self, relpath):
-        return self._call('stat', relpath)
+    def _filter(self, relpath):
+        # A simplified version of PathFilteringTransport's _filter that omits
+        # the call to self.server.filter_func.
+        return self._relpath_from_server_root(relpath)
 
 
 class TestingChrootServer(ChrootServer):
 
     def __init__(self):
         """TestingChrootServer is not usable until setUp is called."""
+        ChrootServer.__init__(self, None)
 
     def setUp(self, backing_server=None):
         """Setup the Chroot on backing_server."""
@@ -171,5 +82,4 @@
 
 def get_test_permutations():
     """Return the permutations to be used in testing."""
-    return [(ChrootTransport, TestingChrootServer),
-            ]
+    return [(ChrootTransport, TestingChrootServer)]

=== modified file 'bzrlib/transport/ftp/__init__.py'
--- bzrlib/transport/ftp/__init__.py	2009-07-22 06:51:13 +0000
+++ bzrlib/transport/ftp/__init__.py	2009-10-06 08:24:14 +0000
@@ -25,17 +25,13 @@
 """
 
 from cStringIO import StringIO
-import errno
 import ftplib
 import getpass
 import os
-import os.path
-import urlparse
 import random
 import socket
 import stat
 import time
-from warnings import warn
 
 from bzrlib import (
     config,
@@ -51,8 +47,6 @@
     register_urlparse_netloc_protocol,
     Server,
     )
-from bzrlib.transport.local import LocalURLServer
-import bzrlib.ui
 
 
 register_urlparse_netloc_protocol('aftp')
@@ -99,8 +93,9 @@
             self.is_active = True
         else:
             self.is_active = False
-        
-        # Most modern FTP servers support the APPE command. If ours doesn't, we (re)set this flag accordingly later.
+
+        # Most modern FTP servers support the APPE command. If ours doesn't, we
+        # (re)set this flag accordingly later.
         self._has_append = True
 
     def _get_FTP(self):
@@ -113,6 +108,8 @@
             self._set_connection(connection, credentials)
         return connection
 
+    connection_class = ftplib.FTP
+
     def _create_connection(self, credentials=None):
         """Create a new connection with the provided credentials.
 
@@ -138,13 +135,9 @@
                ((self._host, self._port, user, '********',
                 self.is_active),))
         try:
-            connection = ftplib.FTP()
+            connection = self.connection_class()
             connection.connect(host=self._host, port=self._port)
-            if user and user != 'anonymous' and \
-                    password is None: # '' is a valid password
-                password = auth.get_password('ftp', self._host, user,
-                                             port=self._port)
-            connection.login(user=user, passwd=password)
+            self._login(connection, auth, user, password)
             connection.set_pasv(not self.is_active)
             # binary mode is the default
             connection.voidcmd('TYPE I')
@@ -157,6 +150,13 @@
                                         " %s" % str(e), orig_error=e)
         return connection, (user, password)
 
+    def _login(self, connection, auth, user, password):
+        # '' is a valid password
+        if user and user != 'anonymous' and password is None:
+            password = auth.get_password('ftp', self._host,
+                                         user, port=self._port)
+        connection.login(user=user, passwd=password)
+
     def _reconnect(self):
         """Create a new connection with the previously used credentials"""
         credentials = self._get_credentials()
@@ -391,7 +391,6 @@
         location.
         """
         text = f.read()
-        
         abspath = self._remote_path(relpath)
         if self.has(relpath):
             ftp = self._get_FTP()
@@ -426,18 +425,18 @@
         except ftplib.error_perm, e:
             # Check whether the command is not supported (reply code 502)
             if str(e).startswith('502 '):
-                warning("FTP server does not support file appending natively. " \
-                    "Performance may be severely degraded! (%s)", e)
+                warning("FTP server does not support file appending natively. "
+                        "Performance may be severely degraded! (%s)", e)
                 self._has_append = False
                 self._fallback_append(relpath, text, mode)
             else:
                 self._translate_perm_error(e, abspath, extra='error appending',
                     unknown_exc=errors.NoSuchFile)
-            
         except ftplib.error_temp, e:
             if retries > _number_of_retries:
-                raise errors.TransportError("FTP temporary error during APPEND %s." \
-                        "Aborting." % abspath, orig_error=e)
+                raise errors.TransportError(
+                    "FTP temporary error during APPEND %s. Aborting."
+                    % abspath, orig_error=e)
             else:
                 warning("FTP temporary error: %s. Retrying.", str(e))
                 self._reconnect()
@@ -445,9 +444,9 @@
 
     def _fallback_append(self, relpath, text, mode = None):
         remote = self.get(relpath)
-        remote.seek(0, 2)
+        remote.seek(0, os.SEEK_END)
         remote.write(text)
-        remote.seek(0, 0)
+        remote.seek(0)
         return self.put_file(relpath, remote, mode)
 
     def _setmode(self, relpath, mode):

=== modified file 'bzrlib/transport/ftp/_gssapi.py'
--- bzrlib/transport/ftp/_gssapi.py	2009-04-27 16:10:10 +0000
+++ bzrlib/transport/ftp/_gssapi.py	2009-10-06 08:24:14 +0000
@@ -25,7 +25,7 @@
     config,
     errors,
     )
-from bzrlib.trace import info, mutter
+from bzrlib.trace import mutter
 from bzrlib.transport.ftp import FtpTransport
 from bzrlib.transport import register_transport_proto, register_transport
 
@@ -81,7 +81,7 @@
                         if not ((resp.startswith('235 ') and rc == 1) or
                                 (resp.startswith('335 ') and rc == 0)):
                             raise ftplib.error_reply, resp
-            info("Authenticated as %s" % kerberos.authGSSClientUserName(
+            trace.note("Authenticated as %s" % kerberos.authGSSClientUserName(
                     self.vc))
 
             # Monkey patch ftplib
@@ -97,52 +97,22 @@
 
     """
 
-    def _create_connection(self, credentials=None):
-        """Create a new connection with the provided credentials.
-
-        :param credentials: The credentials needed to establish the connection.
-
-        :return: The created connection and its associated credentials.
-
-        The credentials are a tuple with the username and password. The
-        password is used if GSSAPI Authentication is not available.
+    connection_class = GSSAPIFtp
+
+    def _login(self, connection, auth, user, password):
+        """Login with GSSAPI Authentication.
+
+        The password is used if GSSAPI Authentication is not available.
 
         The username and password can both be None, in which case the
         credentials specified in the URL or provided by the
         AuthenticationConfig() are used.
         """
-        if credentials is None:
-            user, password = self._user, self._password
-        else:
-            user, password = credentials
-
-        auth = config.AuthenticationConfig()
-        if user is None:
-            user = auth.get_user('ftp', self._host, port=self._port,
-                                 default=getpass.getuser())
-        mutter("Constructing FTP instance against %r" %
-               ((self._host, self._port, user, '********',
-                self.is_active),))
         try:
-            connection = GSSAPIFtp()
-            connection.connect(host=self._host, port=self._port)
-            try:
-                connection.gssapi_login(user=user)
-            except ftplib.error_perm, e:
-                if user and user != 'anonymous' and \
-                        password is None: # '' is a valid password
-                    password = auth.get_password('ftp', self._host, user,
-                                                 port=self._port)
-                connection.login(user=user, passwd=password)
-            connection.set_pasv(not self.is_active)
-        except socket.error, e:
-            raise errors.SocketConnectionError(self._host, self._port,
-                                               msg='Unable to connect to',
-                                               orig_error= e)
+            connection.gssapi_login(user=user)
         except ftplib.error_perm, e:
-            raise errors.TransportError(msg="Error setting up connection:"
-                                        " %s" % str(e), orig_error=e)
-        return connection, (user, password)
+            super(GSSAPIFtpTransport, self)._login(connection, auth,
+                                                   user, password)
 
 
 def get_test_permutations():

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2009-08-19 16:33:39 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2009-11-03 13:46:16 +0000
@@ -80,10 +80,13 @@
         self.filesock = filesock
         self._report_activity = report_activity
 
+    def report_activity(self, size, direction):
+        if self._report_activity:
+            self._report_activity(size, direction)
 
     def read(self, size=1):
         s = self.filesock.read(size)
-        self._report_activity(len(s), 'read')
+        self.report_activity(len(s), 'read')
         return s
 
     def readline(self):
@@ -93,7 +96,7 @@
         #  don't *need* the size parameter we'll stay with readline(self)
         #  --  vila 20090209
         s = self.filesock.readline()
-        self._report_activity(len(s), 'read')
+        self.report_activity(len(s), 'read')
         return s
 
     def __getattr__(self, name):
@@ -106,13 +109,17 @@
         self.sock = sock
         self._report_activity = report_activity
 
+    def report_activity(self, size, direction):
+        if self._report_activity:
+            self._report_activity(size, direction)
+
     def sendall(self, s, *args):
         self.sock.sendall(s, *args)
-        self._report_activity(len(s), 'write')
+        self.report_activity(len(s), 'write')
 
     def recv(self, *args):
         s = self.sock.recv(*args)
-        self._report_activity(len(s), 'read')
+        self.report_activity(len(s), 'read')
         return s
 
     def makefile(self, mode='r', bufsize=-1):
@@ -219,8 +226,7 @@
     # we want to warn. But not below a given thresold.
     _range_warning_thresold = 1024 * 1024
 
-    def __init__(self,
-                 report_activity=None):
+    def __init__(self, report_activity=None):
         self._response = None
         self._report_activity = report_activity
         self._ranges_received_whole_file = None
@@ -360,7 +366,16 @@
 
     def set_proxy(self, proxy, type):
         """Set the proxy and remember the proxied host."""
-        self.proxied_host = self.get_host()
+        host, port = urllib.splitport(self.get_host())
+        if port is None:
+            # We need to set the default port ourselves way before it gets set
+            # in the HTTP[S]Connection object at build time.
+            if self.type == 'https':
+                conn_class = HTTPSConnection
+            else:
+                conn_class = HTTPConnection
+            port = conn_class.default_port
+        self.proxied_host = '%s:%s' % (host, port)
         urllib2.Request.set_proxy(self, proxy, type)
 
 

=== modified file 'bzrlib/transport/http/wsgi.py'
--- bzrlib/transport/http/wsgi.py	2009-03-23 14:59:43 +0000
+++ bzrlib/transport/http/wsgi.py	2009-10-21 06:05:49 +0000
@@ -176,6 +176,7 @@
     def make_request(self, transport, write_func, request_bytes, rcp):
         protocol_factory, unused_bytes = medium._get_protocol_factory_for_bytes(
             request_bytes)
-        server_protocol = protocol_factory(transport, write_func, rcp)
+        server_protocol = protocol_factory(
+            transport, write_func, rcp, self.backing_transport)
         server_protocol.accept_bytes(unused_bytes)
         return server_protocol

=== added file 'bzrlib/transport/pathfilter.py'
--- bzrlib/transport/pathfilter.py	1970-01-01 00:00:00 +0000
+++ bzrlib/transport/pathfilter.py	2009-09-16 05:00:54 +0000
@@ -0,0 +1,195 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+"""A transport decorator that filters all paths that are passed to it."""
+
+
+from bzrlib.transport import (
+    get_transport,
+    register_transport,
+    Server,
+    Transport,
+    unregister_transport,
+    )
+
+
+class PathFilteringServer(Server):
+    """Transport server for PathFilteringTransport.
+
+    It holds the backing_transport and filter_func for PathFilteringTransports.
+    All paths will be passed through filter_func before calling into the
+    backing_transport.
+
+    Note that paths returned from the backing transport are *not* altered in
+    anyway.  So, depending on the filter_func, PathFilteringTransports might
+    not conform to the usual expectations of Transport behaviour; e.g. 'name'
+    in t.list_dir('dir') might not imply t.has('dir/name') is True!  A filter
+    that merely prefixes a constant path segment will be essentially
+    transparent, whereas a filter that does rot13 to paths will break
+    expectations and probably cause confusing errors.  So choose your
+    filter_func with care.
+    """
+
+    def __init__(self, backing_transport, filter_func):
+        """Constructor.
+
+        :param backing_transport: a transport
+        :param filter_func: a callable that takes paths, and translates them
+            into paths for use with the backing transport.
+        """
+        self.backing_transport = backing_transport
+        self.filter_func = filter_func
+
+    def _factory(self, url):
+        return PathFilteringTransport(self, url)
+
+    def get_url(self):
+        return self.scheme
+
+    def setUp(self):
+        self.scheme = 'filtered-%d:///' % id(self)
+        register_transport(self.scheme, self._factory)
+
+    def tearDown(self):
+        unregister_transport(self.scheme, self._factory)
+
+
+class PathFilteringTransport(Transport):
+    """A PathFilteringTransport.
+
+    Please see PathFilteringServer for details.
+    """
+
+    def __init__(self, server, base):
+        self.server = server
+        if not base.endswith('/'):
+            base += '/'
+        Transport.__init__(self, base)
+        self.base_path = self.base[len(self.server.scheme)-1:]
+        self.scheme = self.server.scheme
+
+    def _relpath_from_server_root(self, relpath):
+        unfiltered_path = self._combine_paths(self.base_path, relpath)
+        if not unfiltered_path.startswith('/'):
+            raise ValueError(unfiltered_path)
+        return unfiltered_path[1:]
+
+    def _filter(self, relpath):
+        return self.server.filter_func(self._relpath_from_server_root(relpath))
+
+    def _call(self, methodname, relpath, *args):
+        """Helper for Transport methods of the form:
+            operation(path, [other args ...])
+        """
+        backing_method = getattr(self.server.backing_transport, methodname)
+        return backing_method(self._filter(relpath), *args)
+
+    # Transport methods
+    def abspath(self, relpath):
+        # We do *not* want to filter at this point; e.g if the filter is
+        # homedir expansion, self.base == 'this:///' and relpath == '~/foo',
+        # then the abspath should be this:///~/foo (not this:///home/user/foo).
+        # Instead filtering should happen when self's base is passed to the
+        # backing.
+        return self.scheme + self._relpath_from_server_root(relpath)
+
+    def append_file(self, relpath, f, mode=None):
+        return self._call('append_file', relpath, f, mode)
+
+    def _can_roundtrip_unix_modebits(self):
+        return self.server.backing_transport._can_roundtrip_unix_modebits()
+
+    def clone(self, relpath):
+        return self.__class__(self.server, self.abspath(relpath))
+
+    def delete(self, relpath):
+        return self._call('delete', relpath)
+
+    def delete_tree(self, relpath):
+        return self._call('delete_tree', relpath)
+
+    def external_url(self):
+        """See bzrlib.transport.Transport.external_url."""
+        # PathFilteringTransports, like MemoryTransport, depend on in-process
+        # state and thus the base cannot simply be handed out.  See the base
+        # class docstring for more details and possible directions. For now we
+        # return the path-filtered URL.
+        return self.server.backing_transport.external_url()
+
+    def get(self, relpath):
+        return self._call('get', relpath)
+
+    def has(self, relpath):
+        return self._call('has', relpath)
+
+    def is_readonly(self):
+        return self.server.backing_transport.is_readonly()
+
+    def iter_files_recursive(self):
+        backing_transport = self.server.backing_transport.clone(
+            self._filter('.'))
+        return backing_transport.iter_files_recursive()
+
+    def listable(self):
+        return self.server.backing_transport.listable()
+
+    def list_dir(self, relpath):
+        return self._call('list_dir', relpath)
+
+    def lock_read(self, relpath):
+        return self._call('lock_read', relpath)
+
+    def lock_write(self, relpath):
+        return self._call('lock_write', relpath)
+
+    def mkdir(self, relpath, mode=None):
+        return self._call('mkdir', relpath, mode)
+
+    def open_write_stream(self, relpath, mode=None):
+        return self._call('open_write_stream', relpath, mode)
+
+    def put_file(self, relpath, f, mode=None):
+        return self._call('put_file', relpath, f, mode)
+
+    def rename(self, rel_from, rel_to):
+        return self._call('rename', rel_from, self._filter(rel_to))
+
+    def rmdir(self, relpath):
+        return self._call('rmdir', relpath)
+
+    def stat(self, relpath):
+        return self._call('stat', relpath)
+
+
+class TestingPathFilteringServer(PathFilteringServer):
+
+    def __init__(self):
+        """TestingChrootServer is not usable until setUp is called."""
+
+    def setUp(self, backing_server=None):
+        """Setup the Chroot on backing_server."""
+        if backing_server is not None:
+            self.backing_transport = get_transport(backing_server.get_url())
+        else:
+            self.backing_transport = get_transport('.')
+        self.backing_transport.clone('added-by-filter').ensure_base()
+        self.filter_func = lambda x: 'added-by-filter/' + x
+        PathFilteringServer.setUp(self)
+
+
+def get_test_permutations():
+    """Return the permutations to be used in testing."""
+    return [(PathFilteringTransport, TestingPathFilteringServer)]

=== modified file 'bzrlib/transport/sftp.py'
--- bzrlib/transport/sftp.py	2009-06-10 03:56:49 +0000
+++ bzrlib/transport/sftp.py	2009-11-11 07:35:08 +0000
@@ -917,7 +917,7 @@
         self._socket.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         self._socket.bind(('localhost', 0))
         self._socket.listen(1)
-        self.port = self._socket.getsockname()[1]
+        self.host, self.port = self._socket.getsockname()[:2]
         self._stop_event = threading.Event()
 
     def stop(self):
@@ -1045,7 +1045,8 @@
 
     def _get_sftp_url(self, path):
         """Calculate an sftp url to this server for path."""
-        return 'sftp://foo:bar@localhost:%d/%s' % (self._listener.port, path)
+        return 'sftp://foo:bar@%s:%d/%s' % (self._listener.host,
+                                            self._listener.port, path)
 
     def log(self, message):
         """StubServer uses this to log when a new server is created."""

=== modified file 'bzrlib/transport/ssh.py'
--- bzrlib/transport/ssh.py	2009-08-22 05:01:55 +0000
+++ bzrlib/transport/ssh.py	2009-11-25 07:27:43 +0000
@@ -94,7 +94,10 @@
             try:
                 vendor = self._ssh_vendors[vendor_name]
             except KeyError:
-                raise errors.UnknownSSH(vendor_name)
+                vendor = self._get_vendor_from_path(vendor_name)
+                if vendor is None:
+                    raise errors.UnknownSSH(vendor_name)
+                vendor.executable_path = vendor_name
             return vendor
         return None
 
@@ -110,7 +113,7 @@
             stdout = stderr = ''
         return stdout + stderr
 
-    def _get_vendor_by_version_string(self, version, args):
+    def _get_vendor_by_version_string(self, version, progname):
         """Return the vendor or None based on output from the subprocess.
 
         :param version: The output of 'ssh -V' like command.
@@ -123,25 +126,27 @@
         elif 'SSH Secure Shell' in version:
             trace.mutter('ssh implementation is SSH Corp.')
             vendor = SSHCorpSubprocessVendor()
-        # Auto-detect of plink vendor disabled, on Windows recommended
-        # default ssh-client is paramiko
-        # see https://bugs.launchpad.net/bugs/414743
-        #~elif 'plink' in version and args[0] == 'plink':
-        #~    # Checking if "plink" was the executed argument as Windows
-        #~    # sometimes reports 'ssh -V' incorrectly with 'plink' in it's
-        #~    # version.  See https://bugs.launchpad.net/bzr/+bug/107155
-        #~    trace.mutter("ssh implementation is Putty's plink.")
-        #~    vendor = PLinkSubprocessVendor()
+        # As plink user prompts are not handled currently, don't auto-detect
+        # it by inspection below, but keep this vendor detection for if a path
+        # is given in BZR_SSH. See https://bugs.launchpad.net/bugs/414743
+        elif 'plink' in version and progname == 'plink':
+            # Checking if "plink" was the executed argument as Windows
+            # sometimes reports 'ssh -V' incorrectly with 'plink' in it's
+            # version.  See https://bugs.launchpad.net/bzr/+bug/107155
+            trace.mutter("ssh implementation is Putty's plink.")
+            vendor = PLinkSubprocessVendor()
         return vendor
 
     def _get_vendor_by_inspection(self):
         """Return the vendor or None by checking for known SSH implementations."""
-        for args in (['ssh', '-V'], ['plink', '-V']):
-            version = self._get_ssh_version_string(args)
-            vendor = self._get_vendor_by_version_string(version, args)
-            if vendor is not None:
-                return vendor
-        return None
+        version = self._get_ssh_version_string(['ssh', '-V'])
+        return self._get_vendor_by_version_string(version, "ssh")
+
+    def _get_vendor_from_path(self, path):
+        """Return the vendor or None using the program at the given path"""
+        version = self._get_ssh_version_string([path, '-V'])
+        return self._get_vendor_by_version_string(version, 
+            os.path.splitext(os.path.basename(path))[0])
 
     def get_vendor(self, environment=None):
         """Find out what version of SSH is on the system.
@@ -404,9 +409,11 @@
 class OpenSSHSubprocessVendor(SubprocessVendor):
     """SSH vendor that uses the 'ssh' executable from OpenSSH."""
 
+    executable_path = 'ssh'
+
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):
-        args = ['ssh',
+        args = [self.executable_path,
                 '-oForwardX11=no', '-oForwardAgent=no',
                 '-oClearAllForwardings=yes', '-oProtocol=2',
                 '-oNoHostAuthenticationForLocalhost=yes']
@@ -426,9 +433,11 @@
 class SSHCorpSubprocessVendor(SubprocessVendor):
     """SSH vendor that uses the 'ssh' executable from SSH Corporation."""
 
+    executable_path = 'ssh'
+
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):
-        args = ['ssh', '-x']
+        args = [self.executable_path, '-x']
         if port is not None:
             args.extend(['-p', str(port)])
         if username is not None:
@@ -439,15 +448,17 @@
             args.extend([host] + command)
         return args
 
-register_ssh_vendor('ssh', SSHCorpSubprocessVendor())
+register_ssh_vendor('sshcorp', SSHCorpSubprocessVendor())
 
 
 class PLinkSubprocessVendor(SubprocessVendor):
     """SSH vendor that uses the 'plink' executable from Putty."""
 
+    executable_path = 'plink'
+
     def _get_vendor_specific_argv(self, username, host, port, subsystem=None,
                                   command=None):
-        args = ['plink', '-x', '-a', '-ssh', '-2', '-batch']
+        args = [self.executable_path, '-x', '-a', '-ssh', '-2', '-batch']
         if port is not None:
             args.extend(['-P', str(port)])
         if username is not None:
@@ -504,7 +515,16 @@
     except paramiko.SSHException, e:
         # Don't know what happened, but just ignore it
         pass
-    if 'password' not in supported_auth_types:
+    # We treat 'keyboard-interactive' and 'password' auth methods identically,
+    # because Paramiko's auth_password method will automatically try
+    # 'keyboard-interactive' auth (using the password as the response) if
+    # 'password' auth is not available.  Apparently some Debian and Gentoo
+    # OpenSSH servers require this.
+    # XXX: It's possible for a server to require keyboard-interactive auth that
+    # requires something other than a single password, but we currently don't
+    # support that.
+    if ('password' not in supported_auth_types and
+        'keyboard-interactive' not in supported_auth_types):
         raise errors.ConnectionError('Unable to authenticate to SSH host as'
             '\n  %s@%s\nsupported auth types: %s'
             % (username, host, supported_auth_types))
@@ -618,12 +638,28 @@
                 'close_fds': True,
                 }
 
+import weakref
+_subproc_weakrefs = set()
+
+def _close_ssh_proc(proc):
+    for func in [proc.stdin.close, proc.stdout.close, proc.wait]:
+        try:
+            func()
+        except OSError:
+            pass
+
 
 class SSHSubprocess(object):
     """A socket-like object that talks to an ssh subprocess via pipes."""
 
     def __init__(self, proc):
         self.proc = proc
+        # Add a weakref to proc that will attempt to do the same as self.close
+        # to avoid leaving processes lingering indefinitely.
+        def terminate(ref):
+            _subproc_weakrefs.remove(ref)
+            _close_ssh_proc(proc)
+        _subproc_weakrefs.add(weakref.ref(self, terminate))
 
     def send(self, data):
         return os.write(self.proc.stdin.fileno(), data)
@@ -632,9 +668,7 @@
         return os.read(self.proc.stdout.fileno(), count)
 
     def close(self):
-        self.proc.stdin.close()
-        self.proc.stdout.close()
-        self.proc.wait()
+        _close_ssh_proc(self.proc)
 
     def get_filelike_channels(self):
         return (self.proc.stdout, self.proc.stdin)

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2009-08-26 05:38:16 +0000
+++ bzrlib/tree.py	2009-11-27 23:21:36 +0000
@@ -697,7 +697,6 @@
                 for path in path_names:
                     yield searcher.get_items(path)
 
-    @needs_read_lock
     def _get_rules_searcher(self, default_searcher):
         """Get the RulesSearcher for this tree given the default one."""
         searcher = default_searcher
@@ -852,6 +851,12 @@
     will pass through to InterTree as appropriate.
     """
 
+    # Formats that will be used to test this InterTree. If both are
+    # None, this InterTree will not be tested (e.g. because a complex
+    # setup is required)
+    _matching_from_tree_format = None
+    _matching_to_tree_format = None
+
     _optimisers = []
 
     def _changes_from_entries(self, source_entry, target_entry,
@@ -954,8 +959,6 @@
             a PathsNotVersionedError will be thrown.
         :param want_unversioned: Scan for unversioned paths.
         """
-        # NB: show_status depends on being able to pass in non-versioned files
-        # and report them as unknown
         trees = (self.source,)
         if extra_trees is not None:
             trees = trees + tuple(extra_trees)

=== modified file 'bzrlib/ui/__init__.py'
--- bzrlib/ui/__init__.py	2009-07-22 07:34:08 +0000
+++ bzrlib/ui/__init__.py	2009-10-15 20:04:37 +0000
@@ -22,18 +22,18 @@
 Several levels are supported, and you can also register new factories such as
 for a GUI.
 
-UIFactory
+bzrlib.ui.UIFactory
     Semi-abstract base class
 
-SilentUIFactory
+bzrlib.ui.SilentUIFactory
     Produces no output and cannot take any input; useful for programs using
     bzrlib in batch mode or for programs such as loggerhead.
 
-CannedInputUIFactory
+bzrlib.ui.CannedInputUIFactory
     For use in testing; the input values to be returned are provided 
     at construction.
 
-TextUIFactory
+bzrlib.ui.text.TextUIFactory
     Standard text command-line interface, with stdin, stdout, stderr.
     May make more or less advanced use of them, eg in drawing progress bars,
     depending on the detected capabilities of the terminal.
@@ -208,95 +208,22 @@
         """
         pass
 
-
-
-class CLIUIFactory(UIFactory):
-    """Deprecated in favor of TextUIFactory."""
-
-    @deprecated_method(deprecated_in((1, 18, 0)))
-    def __init__(self, stdin=None, stdout=None, stderr=None):
-        UIFactory.__init__(self)
-        self.stdin = stdin or sys.stdin
-        self.stdout = stdout or sys.stdout
-        self.stderr = stderr or sys.stderr
-
-    _accepted_boolean_strings = dict(y=True, n=False, yes=True, no=False)
-
-    def get_boolean(self, prompt):
-        while True:
-            self.prompt(prompt + "? [y/n]: ")
-            line = self.stdin.readline()
-            line = line.rstrip('\n')
-            val = bool_from_string(line, self._accepted_boolean_strings)
-            if val is not None:
-                return val
-
-    def get_non_echoed_password(self):
-        isatty = getattr(self.stdin, 'isatty', None)
-        if isatty is not None and isatty():
-            # getpass() ensure the password is not echoed and other
-            # cross-platform niceties
-            password = getpass.getpass('')
-        else:
-            # echo doesn't make sense without a terminal
-            password = self.stdin.readline()
-            if not password:
-                password = None
-            elif password[-1] == '\n':
-                password = password[:-1]
-        return password
-
-    def get_password(self, prompt='', **kwargs):
-        """Prompt the user for a password.
-
-        :param prompt: The prompt to present the user
-        :param kwargs: Arguments which will be expanded into the prompt.
-                       This lets front ends display different things if
-                       they so choose.
-        :return: The password string, return None if the user
-                 canceled the request.
-        """
-        prompt += ': '
-        self.prompt(prompt, **kwargs)
-        # There's currently no way to say 'i decline to enter a password'
-        # as opposed to 'my password is empty' -- does it matter?
-        return self.get_non_echoed_password()
-
-    def get_username(self, prompt, **kwargs):
-        """Prompt the user for a username.
-
-        :param prompt: The prompt to present the user
-        :param kwargs: Arguments which will be expanded into the prompt.
-                       This lets front ends display different things if
-                       they so choose.
-        :return: The username string, return None if the user
-                 canceled the request.
-        """
-        prompt += ': '
-        self.prompt(prompt, **kwargs)
-        username = self.stdin.readline()
-        if not username:
-            username = None
-        elif username[-1] == '\n':
-            username = username[:-1]
-        return username
-
-    def prompt(self, prompt, **kwargs):
-        """Emit prompt on the CLI.
+    def show_error(self, msg):
+        """Show an error message (not an exception) to the user.
         
-        :param kwargs: Dictionary of arguments to insert into the prompt,
-            to allow UIs to reformat the prompt.
+        The message should not have an error prefix or trailing newline.  That
+        will be added by the factory if appropriate. 
         """
-        if kwargs:
-            # See <https://launchpad.net/bugs/365891>
-            prompt = prompt % kwargs
-        prompt = prompt.encode(osutils.get_terminal_encoding(), 'replace')
-        self.clear_term()
-        self.stderr.write(prompt)
-
-    def note(self, msg):
-        """Write an already-formatted message."""
-        self.stdout.write(msg + '\n')
+        raise NotImplementedError(self.show_error)
+
+    def show_message(self, msg):
+        """Show a message to the user."""
+        raise NotImplementedError(self.show_message)
+
+    def show_warning(self, msg):
+        """Show a warning to the user."""
+        raise NotImplementedError(self.show_warning)
+
 
 
 class SilentUIFactory(UIFactory):
@@ -318,6 +245,15 @@
     def get_username(self, prompt, **kwargs):
         return None
 
+    def show_error(self, msg):
+        pass
+
+    def show_message(self, msg):
+        pass
+
+    def show_warning(self, msg):
+        pass
+
 
 class CannedInputUIFactory(SilentUIFactory):
     """A silent UI that return canned input."""
@@ -343,13 +279,6 @@
                 % (self,))
 
 
-@deprecated_function(deprecated_in((1, 18, 0)))
-def clear_decorator(func, *args, **kwargs):
-    """Decorator that clears the term"""
-    ui_factory.clear_term()
-    func(*args, **kwargs)
-
-
 ui_factory = SilentUIFactory()
 # IMPORTANT: never import this symbol directly. ONLY ever access it as
 # ui.ui_factory, so that you refer to the current value.

=== modified file 'bzrlib/ui/text.py'
--- bzrlib/ui/text.py	2009-08-06 02:23:37 +0000
+++ bzrlib/ui/text.py	2009-09-23 06:29:46 +0000
@@ -49,9 +49,6 @@
                  stdout=None,
                  stderr=None):
         """Create a TextUIFactory.
-
-        :param bar_type: The type of progress bar to create.  Deprecated
-            and ignored; a TextProgressView is always used.
         """
         super(TextUIFactory, self).__init__()
         # TODO: there's no good reason not to pass all three streams, maybe we
@@ -176,6 +173,17 @@
         self._progress_view.show_transport_activity(transport,
             direction, byte_count)
 
+    def show_error(self, msg):
+        self.clear_term()
+        self.stderr.write("bzr: error: %s\n" % msg)
+
+    def show_message(self, msg):
+        self.note(msg)
+
+    def show_warning(self, msg):
+        self.clear_term()
+        self.stderr.write("bzr: warning: %s\n" % msg)
+
     def _progress_updated(self, task):
         """A task has been updated and wants to be displayed.
         """

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2009-05-07 05:08:46 +0000
+++ bzrlib/upgrade.py	2009-06-23 09:17:21 +0000
@@ -46,8 +46,8 @@
             branch = self.bzrdir.open_branch()
             if branch.bzrdir.root_transport.base != \
                 self.bzrdir.root_transport.base:
-                self.pb.note("This is a checkout. The branch (%s) needs to be "
-                             "upgraded separately.",
+                ui.ui_factory.note("This is a checkout. The branch (%s) needs to be "
+                             "upgraded separately." %
                              branch.bzrdir.root_transport.base)
             del branch
         except (errors.NotBranchError, errors.IncompatibleRepositories):
@@ -72,12 +72,13 @@
             raise errors.BzrError("cannot upgrade from bzrdir format %s" %
                            self.bzrdir._format)
         self.bzrdir.check_conversion_target(format)
-        self.pb.note('starting upgrade of %s', self.transport.base)
+        ui.ui_factory.note('starting upgrade of %s' % self.transport.base)
+
         self.bzrdir.backup_bzrdir()
         while self.bzrdir.needs_format_conversion(format):
             converter = self.bzrdir._format.get_converter(format)
             self.bzrdir = converter.convert(self.bzrdir, self.pb)
-        self.pb.note("finished")
+        ui.ui_factory.note("finished")
 
 
 def upgrade(url, format=None):

=== modified file 'bzrlib/urlutils.py'
--- bzrlib/urlutils.py	2009-07-16 07:10:45 +0000
+++ bzrlib/urlutils.py	2009-11-26 04:01:58 +0000
@@ -217,10 +217,16 @@
 # jam 20060502 Sorted to 'l' because the final target is 'local_path_from_url'
 def _posix_local_path_from_url(url):
     """Convert a url like file:///path/to/foo into /path/to/foo"""
-    if not url.startswith('file:///'):
-        raise errors.InvalidURL(url, 'local urls must start with file:///')
+    file_localhost_prefix = 'file://localhost/'
+    if url.startswith(file_localhost_prefix):
+        path = url[len(file_localhost_prefix) - 1:]
+    elif not url.startswith('file:///'):
+        raise errors.InvalidURL(
+            url, 'local urls must start with file:/// or file://localhost/')
+    else:
+        path = url[len('file://'):]
     # We only strip off 2 slashes
-    return unescape(url[len('file://'):])
+    return unescape(path)
 
 
 def _posix_local_path_to_url(path):

=== modified file 'bzrlib/util/_bencode_py.py'
--- bzrlib/util/_bencode_py.py	2009-06-10 03:56:49 +0000
+++ bzrlib/util/_bencode_py.py	2009-12-01 19:44:12 +0000
@@ -154,6 +154,15 @@
         encode_int(int(x), r)
     encode_func[BooleanType] = encode_bool
 
+from bzrlib._static_tuple_py import StaticTuple
+encode_func[StaticTuple] = encode_list
+try:
+    from bzrlib._static_tuple_c import StaticTuple
+except ImportError:
+    pass
+else:
+    encode_func[StaticTuple] = encode_list
+
 
 def bencode(x):
     r = []

=== modified file 'bzrlib/version.py'
--- bzrlib/version.py	2009-08-14 12:08:08 +0000
+++ bzrlib/version.py	2009-11-30 04:41:36 +0000
@@ -50,8 +50,9 @@
     # show path to python interpreter
     # (bzr.exe use python interpreter from pythonXY.dll
     # but sys.executable point to bzr.exe itself)
-    if not hasattr(sys, 'frozen'):  # check for bzr.exe
-        # python executable
+    # however, sys.frozen exists if running from bzr.exe
+    # see http://www.py2exe.org/index.cgi/Py2exeEnvironment
+    if getattr(sys, 'frozen', None) is None: # if not bzr.exe
         to_file.write(sys.executable + ' ')
     else:
         # pythonXY.dll

=== modified file 'bzrlib/version_info_formats/format_rio.py'
--- bzrlib/version_info_formats/format_rio.py	2009-04-06 02:54:48 +0000
+++ bzrlib/version_info_formats/format_rio.py	2009-11-03 09:32:17 +0000
@@ -84,6 +84,7 @@
     """Hooks for rio-formatted version-info output."""
 
     def __init__(self):
+        super(RioVersionInfoBuilderHooks, self).__init__()
         self.create_hook(hooks.HookPoint('revision',
             "Invoked when adding information about a revision to the"
             " RIO stanza that is printed. revision is called with a"

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2009-08-17 22:08:21 +0000
+++ bzrlib/versionedfile.py	2009-10-19 15:06:58 +0000
@@ -930,6 +930,13 @@
     def check_not_reserved_id(version_id):
         revision.check_not_reserved_id(version_id)
 
+    def clear_cache(self):
+        """Clear whatever caches this VersionedFile holds.
+
+        This is generally called after an operation has been performed, when we
+        don't expect to be using this versioned file again soon.
+        """
+
     def _check_lines_not_unicode(self, lines):
         """Check that lines being added to a versioned file are not unicode."""
         for line in lines:

=== modified file 'bzrlib/win32utils.py'
--- bzrlib/win32utils.py	2009-07-08 14:37:25 +0000
+++ bzrlib/win32utils.py	2009-11-20 16:42:28 +0000
@@ -19,8 +19,12 @@
 Only one dependency: ctypes should be installed.
 """
 
+import glob
 import os
+import re
+import shlex
 import struct
+import StringIO
 import sys
 
 
@@ -422,6 +426,26 @@
 
 
 
+def glob_one(possible_glob):
+    """Same as glob.glob().
+
+    work around bugs in glob.glob()
+    - Python bug #1001604 ("glob doesn't return unicode with ...")
+    - failing expansion for */* with non-iso-8859-* chars
+    """
+    corrected_glob, corrected = _ensure_with_dir(possible_glob)
+    glob_files = glob.glob(corrected_glob)
+
+    if not glob_files:
+        # special case to let the normal code path handle
+        # files that do not exist, etc.
+        glob_files = [possible_glob]
+    elif corrected:
+        glob_files = [_undo_ensure_with_dir(elem, corrected)
+                      for elem in glob_files]
+    return [elem.replace(u'\\', u'/') for elem in glob_files]
+
+
 def glob_expand(file_list):
     """Replacement for glob expansion by the shell.
 
@@ -435,25 +459,10 @@
     """
     if not file_list:
         return []
-    import glob
     expanded_file_list = []
     for possible_glob in file_list:
-        # work around bugs in glob.glob()
-        # - Python bug #1001604 ("glob doesn't return unicode with ...")
-        # - failing expansion for */* with non-iso-8859-* chars
-        possible_glob, corrected = _ensure_with_dir(possible_glob)
-        glob_files = glob.glob(possible_glob)
-
-        if glob_files == []:
-            # special case to let the normal code path handle
-            # files that do not exists
-            expanded_file_list.append(
-                _undo_ensure_with_dir(possible_glob, corrected))
-        else:
-            glob_files = [_undo_ensure_with_dir(elem, corrected) for elem in glob_files]
-            expanded_file_list += glob_files
-
-    return [elem.replace(u'\\', u'/') for elem in expanded_file_list]
+        expanded_file_list.extend(glob_one(possible_glob))
+    return expanded_file_list
 
 
 def get_app_path(appname):
@@ -511,6 +520,123 @@
             trace.mutter('Unable to set hidden attribute on %r: %s', path, e)
 
 
+
+class UnicodeShlex(object):
+    """This is a very simplified version of shlex.shlex.
+
+    The main change is that it supports non-ascii input streams. The internal
+    structure is quite simplified relative to shlex.shlex, since we aren't
+    trying to handle multiple input streams, etc. In fact, we don't use a
+    file-like api either.
+    """
+
+    def __init__(self, uni_string):
+        self._input = uni_string
+        self._input_iter = iter(self._input)
+        self._whitespace_match = re.compile(u'\s').match
+        self._word_match = re.compile(u'\S').match
+        self._quote_chars = u'"'
+        # self._quote_match = re.compile(u'[\'"]').match
+        self._escape_match = lambda x: None # Never matches
+        self._escape = '\\'
+        # State can be
+        #   ' ' - after whitespace, starting a new token
+        #   'a' - after text, currently working on a token
+        #   '"' - after ", currently in a "-delimited quoted section
+        #   "\" - after '\', checking the next char
+        self._state = ' '
+        self._token = [] # Current token being parsed
+
+    def _get_token(self):
+        # Were there quote chars as part of this token?
+        quoted = False
+        quoted_state = None
+        for nextchar in self._input_iter:
+            if self._state == ' ':
+                if self._whitespace_match(nextchar):
+                    # if self._token: return token
+                    continue
+                elif nextchar in self._quote_chars:
+                    self._state = nextchar # quoted state
+                elif self._word_match(nextchar):
+                    self._token.append(nextchar)
+                    self._state = 'a'
+                else:
+                    raise AssertionError('wtttf?')
+            elif self._state in self._quote_chars:
+                quoted = True
+                if nextchar == self._state: # End of quote
+                    self._state = 'a' # posix allows 'foo'bar to translate to
+                                      # foobar
+                elif self._state == '"' and nextchar == self._escape:
+                    quoted_state = self._state
+                    self._state = nextchar
+                else:
+                    self._token.append(nextchar)
+            elif self._state == self._escape:
+                if nextchar == '\\':
+                    self._token.append('\\')
+                elif nextchar == '"':
+                    self._token.append(nextchar)
+                else:
+                    self._token.append('\\' + nextchar)
+                self._state = quoted_state
+            elif self._state == 'a':
+                if self._whitespace_match(nextchar):
+                    if self._token:
+                        break # emit this token
+                    else:
+                        continue # no token to emit
+                elif nextchar in self._quote_chars:
+                    # Start a new quoted section
+                    self._state = nextchar
+                # escape?
+                elif (self._word_match(nextchar)
+                      or nextchar in self._quote_chars
+                      # or whitespace_split?
+                      ):
+                    self._token.append(nextchar)
+                else:
+                    raise AssertionError('state == "a", char: %r'
+                                         % (nextchar,))
+            else:
+                raise AssertionError('unknown state: %r' % (self._state,))
+        result = ''.join(self._token)
+        self._token = []
+        if not quoted and result == '':
+            result = None
+        return quoted, result
+
+    def __iter__(self):
+        return self
+
+    def next(self):
+        quoted, token = self._get_token()
+        if token is None:
+            raise StopIteration
+        return quoted, token
+
+
+def _command_line_to_argv(command_line):
+    """Convert a Unicode command line into a set of argv arguments.
+
+    This does wildcard expansion, etc. It is intended to make wildcards act
+    closer to how they work in posix shells, versus how they work by default on
+    Windows.
+    """
+    s = UnicodeShlex(command_line)
+    # Now that we've split the content, expand globs
+    # TODO: Use 'globbing' instead of 'glob.glob', this gives us stuff like
+    #       '**/' style globs
+    args = []
+    for is_quoted, arg in s:
+        if is_quoted or not glob.has_magic(arg):
+            args.append(arg)
+        else:
+            args.extend(glob_one(arg))
+    return args
+
+
 if has_ctypes and winver != 'Windows 98':
     def get_unicode_argv():
         LPCWSTR = ctypes.c_wchar_p
@@ -520,21 +646,19 @@
         GetCommandLine = prototype(("GetCommandLineW",
                                     ctypes.windll.kernel32))
         prototype = ctypes.WINFUNCTYPE(POINTER(LPCWSTR), LPCWSTR, POINTER(INT))
-        CommandLineToArgv = prototype(("CommandLineToArgvW",
-                                       ctypes.windll.shell32))
-        c = INT(0)
-        pargv = CommandLineToArgv(GetCommandLine(), ctypes.byref(c))
+        command_line = GetCommandLine()
         # Skip the first argument, since we only care about parameters
-        argv = [pargv[i] for i in range(1, c.value)]
+        argv = _command_line_to_argv(GetCommandLine())[1:]
         if getattr(sys, 'frozen', None) is None:
             # Invoked via 'python.exe' which takes the form:
             #   python.exe [PYTHON_OPTIONS] C:\Path\bzr [BZR_OPTIONS]
             # we need to get only BZR_OPTIONS part,
-            # so let's using sys.argv[1:] as reference to get the tail
-            # of unicode argv
-            tail_len = len(sys.argv[1:])
-            ix = len(argv) - tail_len
-            argv = argv[ix:]
+            # We already removed 'python.exe' so we remove everything up to and
+            # including the first non-option ('-') argument.
+            for idx in xrange(len(argv)):
+                if argv[idx][:1] != '-':
+                    break
+            argv = argv[idx+1:]
         return argv
 else:
     get_unicode_argv = None

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2009-08-26 05:38:16 +0000
+++ bzrlib/workingtree.py	2009-12-02 18:15:55 +0000
@@ -65,7 +65,6 @@
     merge,
     revision as _mod_revision,
     revisiontree,
-    textui,
     trace,
     transform,
     ui,
@@ -544,11 +543,11 @@
         else:
             parents = [last_rev]
         try:
-            merges_file = self._transport.get('pending-merges')
+            merges_bytes = self._transport.get_bytes('pending-merges')
         except errors.NoSuchFile:
             pass
         else:
-            for l in merges_file.readlines():
+            for l in osutils.split_lines(merges_bytes):
                 revision_id = l.rstrip('\n')
                 parents.append(revision_id)
         return parents
@@ -636,6 +635,10 @@
 
     def _is_executable_from_path_and_stat_from_basis(self, path, stat_result):
         file_id = self.path2id(path)
+        if file_id is None:
+            # For unversioned files on win32, we just assume they are not
+            # executable
+            return False
         return self._inventory[file_id].executable
 
     def _is_executable_from_path_and_stat_from_stat(self, path, stat_result):
@@ -896,7 +899,7 @@
 
     @needs_write_lock # because merge pulls data into the branch.
     def merge_from_branch(self, branch, to_revision=None, from_revision=None,
-        merge_type=None):
+                          merge_type=None, force=False):
         """Merge from a branch into this working tree.
 
         :param branch: The branch to merge from.
@@ -911,9 +914,9 @@
             merger = Merger(self.branch, this_tree=self, pb=pb)
             merger.pp = ProgressPhase("Merge phase", 5, pb)
             merger.pp.next_phase()
-            # check that there are no
-            # local alterations
-            merger.check_basis(check_clean=True, require_commits=False)
+            # check that there are no local alterations
+            if not force and self.has_changes():
+                raise errors.UncommittedChanges(self)
             if to_revision is None:
                 to_revision = _mod_revision.ensure_null(branch.last_revision())
             merger.other_rev_id = to_revision
@@ -1841,7 +1844,11 @@
     def _reset_data(self):
         """Reset transient data that cannot be revalidated."""
         self._inventory_is_modified = False
-        result = self._deserialize(self._transport.get('inventory'))
+        f = self._transport.get('inventory')
+        try:
+            result = self._deserialize(f)
+        finally:
+            f.close()
         self._set_inventory(result, dirty=False)
 
     @needs_tree_write_lock
@@ -1923,7 +1930,11 @@
         # binary.
         if self._inventory_is_modified:
             raise errors.InventoryModified(self)
-        result = self._deserialize(self._transport.get('inventory'))
+        f = self._transport.get('inventory')
+        try:
+            result = self._deserialize(f)
+        finally:
+            f.close()
         self._set_inventory(result, dirty=False)
         return result
 
@@ -1944,6 +1955,8 @@
 
         new_files=set()
         unknown_nested_files=set()
+        if to_file is None:
+            to_file = sys.stdout
 
         def recurse_directory_to_add_files(directory):
             # Recurse directory and add all files
@@ -2019,8 +2032,9 @@
                         new_status = 'I'
                     else:
                         new_status = '?'
-                    textui.show_status(new_status, self.kind(fid), f,
-                                       to_file=to_file)
+                    # XXX: Really should be a more abstract reporter interface
+                    kind_ch = osutils.kind_marker(self.kind(fid))
+                    to_file.write(new_status + '       ' + f + kind_ch + '\n')
                 # Unversion file
                 inv_delta.append((f, None, fid, None))
                 message = "removed %s" % (f,)
@@ -2580,7 +2594,6 @@
         """
         return
 
-    @needs_read_lock
     def _get_rules_searcher(self, default_searcher):
         """See Tree._get_rules_searcher."""
         if self._rules_searcher is None:
@@ -2765,7 +2778,7 @@
         """Return the format for the working tree object in a_bzrdir."""
         try:
             transport = a_bzrdir.get_workingtree_transport(None)
-            format_string = transport.get("format").read()
+            format_string = transport.get_bytes("format")
             return klass._formats[format_string]
         except errors.NoSuchFile:
             raise errors.NoWorkingTree(base=transport.base)

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2009-08-25 04:43:21 +0000
+++ bzrlib/workingtree_4.py	2009-11-14 11:06:51 +0000
@@ -1267,9 +1267,17 @@
         if self._dirty:
             raise AssertionError("attempting to write an inventory when the "
                 "dirstate is dirty will lose pending changes")
-        self.current_dirstate().set_state_from_inventory(inv)
-        self._make_dirty(reset_inventory=False)
-        if self._inventory is not None:
+        had_inventory = self._inventory is not None
+        # Setting self._inventory = None forces the dirstate to regenerate the
+        # working inventory. We do this because self.inventory may be inv, or
+        # may have been modified, and either case would prevent a clean delta
+        # being created.
+        self._inventory = None
+        # generate a delta,
+        delta = inv._make_delta(self.inventory)
+        # and apply it.
+        self.apply_inventory_delta(delta)
+        if had_inventory:
             self._inventory = inv
         self.flush()
 
@@ -2019,8 +2027,6 @@
             output. An unversioned file is defined as one with (False, False)
             for the versioned pair.
         """
-        # NB: show_status depends on being able to pass in non-versioned files
-        # and report them as unknown
         # TODO: handle extra trees in the dirstate.
         if (extra_trees or specific_files == []):
             # we can't fast-path these cases (yet)

=== removed file 'doc/BUILD-NOTES'
--- doc/BUILD-NOTES	2009-07-26 15:58:33 +0000
+++ doc/BUILD-NOTES	1970-01-01 00:00:00 +0000
@@ -1,35 +0,0 @@
-To build Bazaar's documentation using Sphinx, follow the
-steps below.
-
-0. Install Sphinx. You'll need Sphinx 0.6 or later. If that
-   version isn't available in your package manager repositories
-   yet, install python-easyinstall and use it to install Sphinx.
-   See http://sphinx.pocoo.org/ for details.
-
-1. Build the Bazaar docs normally, i.e. in the project root, run:
-
-   make docs
-
-2. Tweak the User Guide index page used:
-
-   cd doc/en/user-guide
-   bzr mv index.txt index-for-1x.txt
-   bzr mv index-for-2x.txt index.txt
-
-3. Tweak the Release Notes TOC depth:
-
-   cd ../release-notes
-   vi NEWS.txt  (change depth to 2)
-
-4. Change to the docs directory and build the site:
-
-   cd ../..
-   make html
-
-The generated output site can be found in _build/html.
-
-Note: All of the above will Just Work soon. For now, we don't
-want to break the existing doc generation until a few issues
-with the Sphinx-generated site are ironed out, e.g. links from
-the User Reference to ../user-guide/index.html#foo no longer
-work when the User Guide is nicely split into topic pages.

=== added file 'doc/Bazaar-Logo-For-Manuals.png'
Binary files doc/Bazaar-Logo-For-Manuals.png and doc/Bazaar-Logo-For-Manuals.png differ
=== removed directory 'doc/_static/en/quick-reference'
=== removed file 'doc/bazaar-vcs.org.kid'
--- doc/bazaar-vcs.org.kid	2007-08-14 03:59:22 +0000
+++ doc/bazaar-vcs.org.kid	1970-01-01 00:00:00 +0000
@@ -1,482 +0,0 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<?python
-   def update_attrib(attrib, **kwargs):
-      attrib = dict(attrib)
-      attrib.update(kwargs)
-      return attrib
-?>
-<html xmlns="http://www.w3.org/1999/xhtml" xmlns:py="http://purl.org/kid/ns#">
-<head>
-<script type="text/javascript" src=
-"/htdocs/bazaarNew/js/opacity.js">
-</script>
-<link rel="shortcut icon" href=
-"http://bazaar-vcs.org/Welcome?action=AttachFile&amp;do=get&amp;target=favicon.ico"
-type="image/x-icon" />
-<meta http-equiv="Content-Type" content=
-"text/html; charset=us-ascii" />
-<meta name="robots" content="index,follow" />
-<title>Welcome - Bazaar Version Control</title>
-
-<script type="text/javascript" src="http://bazaar-vcs.org/htdocs/common/js/common.js">
-</script>
-<script type="text/javascript">
-//<![CDATA[
-<!--// common functions
-
-// We keep here the state of the search box
-searchIsDisabled = false;
-
-function searchChange(e) {
-    // Update search buttons status according to search box content.
-    // Ignore empty or whitespace search term.
-    var value = e.value.replace(/\s+/, '');
-    if (value == '' || searchIsDisabled) { 
-        searchSetDisabled(true);
-    } else {
-        searchSetDisabled(false);
-    }
-}
-
-function searchSetDisabled(flag) {
-    // Enable or disable search
-    document.getElementById('fullsearch').disabled = flag;
-    document.getElementById('titlesearch').disabled = flag;
-}
-
-function searchFocus(e) {
-    // Update search input content on focus
-    if (e.value == 'Search') {
-        e.value = '';
-        e.className = '';
-        searchIsDisabled = false;
-    }
-}
-
-function searchBlur(e) {
-    // Update search input content on blur
-    if (e.value == '') {
-        e.value = 'Search';
-        e.className = 'disabled';
-        searchIsDisabled = true;
-    }
-}
-
-function actionsMenuInit(title) {
-    // Initialize action menu
-    for (i = 0; i < document.forms.length; i++) {
-        var form = document.forms[i];
-        if (form.className == 'actionsmenu') {
-            // Check if this form needs update
-            var div = form.getElementsByTagName('div')[0];
-            var label = div.getElementsByTagName('label')[0];
-            if (label) {
-                // This is the first time: remove label and do buton.
-                div.removeChild(label);
-                var dobutton = div.getElementsByTagName('input')[0];
-                div.removeChild(dobutton);
-                // and add menu title
-                var select = div.getElementsByTagName('select')[0];
-                var item = document.createElement('option');
-                item.appendChild(document.createTextNode(title));
-                item.value = 'show';
-                select.insertBefore(item, select.options[0]);
-                select.selectedIndex = 0;
-            }
-        }
-    }
-}
-//-->
-//]]>
-</script>
-<link rel="stylesheet" type="text/css" charset="utf-8" media="all"
-href="http://bazaar-vcs.org/htdocs/bazaarNew/css/common.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/screen.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"print" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/print.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"projection" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/projection.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/v4.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/screen2.css" />
-<link rel="stylesheet" type="text/css" charset="utf-8" media=
-"screen" href="http://bazaar-vcs.org/htdocs/bazaarNew/css/twoColumnsRight.css" />
-<style type="text/css">
-a.toc-backref
-{
-    color: black;
-    text-decoration: none;
-}
-</style>
-<link rel="alternate" title="Bazaar Version Control Recent Changes"
-href="http://bazaar-vcs.org/RecentChanges?action=rss_rc&amp;ddiffs=1&amp;unique=1" type=
-"application/rss+xml" />
-<link rel="Start" href="http://bazaar-vcs.org/Welcome" />
-<link rel="Alternate" title="Wiki Markup" href=
-"http://bazaar-vcs.org/Welcome?action=raw" />
-<link rel="Alternate" media="print" title="Print View" href=
-"http://bazaar-vcs.org/Welcome?action=print" />
-<link rel="Appendix" title="favicon.ico" href=
-"http://bazaar-vcs.org/Welcome?action=AttachFile&amp;do=view&amp;target=favicon.ico" />
-<link rel="Search" href="http://bazaar-vcs.org/FindPage" />
-<link rel="Index" href="http://bazaar-vcs.org/TitleIndex" />
-<link rel="Glossary" href="http://bazaar-vcs.org/WordIndex" />
-<link rel="Help" href="http://bazaar-vcs.org/HelpOnFormatting" />
-</head>
-<body lang="en" dir="ltr" xml:lang="en">
-<div id="page_header1_div"><script type="text/javascript">
-//<![CDATA[
-gui_editor_link_text = gui_editor_link_href = null;
-//]]>
-</script></div>
-<div id="pageWrapper">
-<hr class="hide" />
-<div id="masthead" class="inside">
-<div id="logoimage"><a href="http://bazaar-vcs.org/"><img src=
-"http://bazaar-vcs.org/htdocs/bazaarNew/css/logo.png" width="144" height="149" alt=
-"Bazaar" /></a></div>
-<h1><a href="http://bazaar-vcs.org/">Bazaar</a></h1>
-<p>GPL Distributed Version Control Software</p>
-</div>
-<hr class="hide" />
-<div class="hnav">
-<ul>
-<li class="hide"><a class="hide" href="#skipToContent"><em>Skip
-Navigation</em></a> <span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/Documentation" id="hnav_learn" name=
-"hnav_learn">Learn</a> <span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/Download" id="hnav_get" name="hnav_get">Get</a>
-<span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/BzrSupport" id="hnav_community" name=
-"hnav_community">Community</a> <span class="divider">:</span></li>
-<li><a href="http://bazaar-vcs.org/BzrPlugins" id="hnav_plugins" name=
-"hnav_plugins">Plugins</a></li>
-</ul>
-</div>
-<div id="outerColumnContainer">
-<div id="innerColumnContainer">
-<hr class="hide" />
-<div id="leftColumn">
-<div class="inside"></div>
-</div>
-<hr class="hide" />
-<div id="rightColumn">
-<div class="inside">
-<div id="searchbox">
-<form name="search" method="get" action="http://bazaar-vcs.org/" id="search">
-<div><input type="hidden" name="action" value="fullsearch" id=
-"fullsearch" /> <input type="hidden" name="context" value="180" />
-<input type="hidden" name="fullsearch" value="Text" /> <label for=
-"search_q" py:content="'Search Wiki'">Search Bazaar</label> <input type="text" name="value"
-id="search_q" value="" onfocus="searchFocus(this)" onblur=
-"searchBlur(this)" onkeyup="searchChange(this)" onchange=
-"searchChange(this)" alt="Search" /> <input type="submit" value=
-"go" name="go" id="search_go" /></div>
-</form>
-</div>
-<div id="searchform"></div>
-<div id="username" class="vnav">
-<h4>Website Links</h4>
-<ul>
-<li><a href="http://doc.bazaar-vcs.org">Documentation</a></li>
-<li><a href="http://bazaar-vcs.org">Wiki</a></li>
-</ul>
-</div>
-</div>
-</div>
-<div id="contentColumn" class="page_Welcome">
-<hr class="hide" />
-<div id="msg" class="vnav"></div>
-<a name="skipToContent" id="skipToContent"></a>
-<div class="inside" >
-<!--<img id="navProtection" width="1" height="1" border="0" src="/htdocs/bazaarNew/css/spacer.gif" alt="" style="height: 1px"/>-->
-<a py:match="item.tag == 'a' and 'href' not in item.attrib" py:content="item.text" py:attrs="update_attrib(item.attrib, style='color: black')"/>
-<div dir="ltr" id="content" lang="en" xml:lang="en" py:content="body[:]"><span
-class="anchor" id="top"></span> <span class="anchor" id="line-8"></span>
-<h1 id="head-31592baed255c2a5cdfdaafb9521b837ea61021f">Performance
-Drive Under Way</h1>
-<span class="anchor" id="line-9"></span>
-<p class="line879">There was substantial progress on performance
-since 0.8. See <a href="/Performance/0.9">Performance/0.9</a>,
-<a href="/Performance/0.10">Performance/0.10</a> and <a href=
-"/Performance/0.11">Performance/0.11</a>. Thanks to everyone who
-has contributed patches and ideas! The focus from here to 1.0 will
-continue to be performance and documentation. Already there is work
-in progress to: <span class="anchor" id="line-10"></span></p>
-<span class="anchor" id="line-11"></span>
-<ul>
-<li>
-<p class="line879">write a <a href="/SmartServer">SmartServer</a>
-for high speed network operations (first look in 0.11).
-<span class="anchor" id="line-12"></span></p>
-</li>
-<li>
-<p class="line886">optimise file system access (tune our code and
-data structures to minimise probable disk io and disk seeking)
-<span class="anchor" id="line-13"></span></p>
-</li>
-<li>
-<p class="line886">optimise file formats for performance without
-sacrificing proven correctness and completeness <span class=
-"anchor" id="line-14"></span></p>
-</li>
-<li>
-<p class="line886">tune the codepaths that are most heavily used
-<span class="anchor" id="line-15"></span></p>
-</li>
-<li>
-<p class="line886">ensure that large imports are only done when
-needed, and use lightweight imports where possible <span class=
-"anchor" id="line-16"></span></p>
-<span class="anchor" id="line-17"></span></li>
-</ul>
-<h1 id="head-ceb9b8e0146b0ce087048f495b2ff2964c5d57ec">News</h1>
-<span class="anchor" id="line-18"></span>
-<h2 id="head-39a1524e97c9a6ba89ecee7856cb1a2e68134373">27th
-September 2006 - 0.11rc2 released</h2>
-<span class="anchor" id="line-19"></span>
-<p class="line879">bzr 0.11rc2 has been released. This release
-candidate corrects two regressions that occured from 0.10. Windows
-developers and users with very large source trees should upgrade
-immediately. Release <a class="https" href=
-"https://lists.canonical.com/archives/bazaar-ng/2006q3/017581.html">
-announcement</a> or <a class="http" href=
-"http://bazaar-vcs.org/releases/src/bzr-0.11rc2.tar.gz">download
-now</a>. For details of the original 0.11 release candidate, see
-the <a class="https" href=
-"https://lists.canonical.com/archives/bazaar-ng/2006q3/017502.html">
-announcement</a>. <span class="anchor" id="line-20"></span></p>
-<span class="anchor" id="line-21"></span>
-<h2 id="head-9940b3014f81c7b8ca65aa3235341588859d09dd">4th
-September 2006 - 0.10 released</h2>
-<span class="anchor" id="line-22"></span>
-<p class="line879">bzr 0.10 has been released after a smooth beta
-period. <a class="http" href=
-"http://bazaar-vcs.org/releases/src/bzr-0.10.tar.gz">download it
-now</a>! <span class="anchor" id="line-23"></span></p>
-<span class="anchor" id="line-24"></span>
-<h1 id="head-c2a87bc7d0bc411d33e18585154e534201115501">What is
-Bazaar?</h1>
-<span class="anchor" id="line-25"></span>
-<p class="line879">Bazaar is a decentralized revision control
-system designed to be easy for developers and end users alike.
-Decentralized revision control systems give people the ability to
-work over the internet using the <a class="http" href=
-"http://en.wikipedia.org/wiki/The_Cathedral_and_the_Bazaar">bazaar
-development model</a>. When you use Bazaar, you can commit to your
-own branches of your favorite free software projects without
-needing special permission. For more information, see: <span class=
-"anchor" id="line-26"></span></p>
-<span class="anchor" id="line-27"></span>
-<ul>
-<li>
-<p class="line903"><a href="/Bzr">What Is Bazaar?</a> <span class=
-"anchor" id="line-28"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/WhoUsesBzr">Who Uses Bazaar?</a>
-<span class="anchor" id="line-29"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrFeatures">Bazaar Features</a>
-<span class="anchor" id="line-30"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/FAQ">FAQ</a> (Frequently Asked
-Questions) <span class="anchor" id="line-31"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrGlossary">Bazaar Glossary</a>
-<span class="anchor" id="line-32"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/ReleaseRoadmap">What's Coming</a> (the
-release roadmap) <span class="anchor" id="line-33"></span></p>
-<span class="anchor" id="line-34"></span></li>
-</ul>
-<h1 id="head-54a84f21f8314a452aecfb4e2da59fcb246fee7b">Where do I
-get it?</h1>
-<span class="anchor" id="line-35"></span>
-<p class="line886">The easiest place to get Bazaar is with your
-distribution. Do not despair if your distribution does not have
-Bazaar, as plain installation is still easy. <span class="anchor"
-id="line-36"></span></p>
-<span class="anchor" id="line-37"></span>
-<ul>
-<li>
-<p class="line903"><a href="/DistroDownloads">Packages</a> -
-Downloads for various distributions <span class="anchor" id=
-"line-38"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/OfficialDownloads">Source</a> - Source
-downloads <span class="anchor" id="line-39"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/WindowsDownloads">Windows</a> -
-Downloads for windows <span class="anchor" id="line-40"></span></p>
-<span class="anchor" id="line-41"></span></li>
-</ul>
-<h1 id="head-400b61668c5f3ab729ffbfeed0f9fc93e853044e">How do I
-install it?</h1>
-<span class="anchor" id="line-42"></span>
-<p class="line879">Installation for Bazaar is a snap. Supported
-operating systems include Linux, FreeBSD, Windows (Native &amp;
-Cygwin) and Solaris. If you can run Python 2.4, then you can run
-Bazaar. <span class="anchor" id="line-43"></span></p>
-<span class="anchor" id="line-44"></span>
-<ul>
-<li>
-<p class="line903"><a href="/DistroDownloads">Packages</a> -
-Downloads for various distributions <span class="anchor" id=
-"line-45"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/Installation">Generic</a> - Generic
-Installation Instructions. <span class="anchor" id=
-"line-46"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrOnPureWindows">Native Windows</a> -
-Installation of Bazaar on Native windows. <span class="anchor" id=
-"line-47"></span></p>
-<span class="anchor" id="line-48"></span></li>
-</ul>
-<h1 id="head-6350ee8bfd03b56b430e775595af1eb29ac7bdb4">How do I use
-it?</h1>
-<span class="anchor" id="line-49"></span>
-<p class="line886">Included are the pearls of wisdom from people
-that have already branched off into a new world of development.
-<span class="anchor" id="line-50"></span></p>
-<span class="anchor" id="line-51"></span>
-<ul>
-<li>
-<p class="line903"><a href="/Documentation">Documents</a> - The
-main documentation page for Bazaar. <span class="anchor" id=
-"line-52"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/IntroductionToBzr">Introduction</a> -
-Introduction to Bazaar gives a walkthough of the simpler commands.
-<span class="anchor" id="line-53"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/QuickHackingWithBzr">Mini Tutorial</a>
-- The five minutes Bazaar Tutorial. <span class="anchor" id=
-"line-54"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrRevisionSpec">Revision Specs</a> -
-Arguments for -r that can be given with "bzr log", "bzr merge" and
-such. <span class="anchor" id="line-55"></span></p>
-<span class="anchor" id="line-56"></span></li>
-</ul>
-<h1 id="head-148c5debbd034308b67411c490e69555ee5a03a3">How does it
-compare?</h1>
-<span class="anchor" id="line-57"></span>
-<p class="line886">If you're familiar with other version control
-systems, you might like to see a quick comparison to them, or read
-guidelines to help you understand how to use bzr most effectively
-given your current experience. <span class="anchor" id=
-"line-58"></span></p>
-<span class="anchor" id="line-59"></span>
-<ul>
-<li>
-<p class="line903"><a href="/BzrForCVSUsers">BzrForCVSUsers</a> -
-Learning Bazaar for CVS users. <span class="anchor" id=
-"line-60"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/BzrForGITUsers">BzrForGITUsers</a> -
-(In progress) Learning Bazaar for GIT users <span class="anchor"
-id="line-61"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/RcsComparisons">RcsComparisons</a> -
-Comparison table of functionality and performance with Bazaar, GIT,
-Mercurial, SVN and other VCS systems. <span class="anchor" id=
-"line-62"></span></p>
-<span class="anchor" id="line-63"></span></li>
-</ul>
-<h1 id="head-e966f9f6520262482dc713218b2a916600636f14">How can I
-get Help?</h1>
-<span class="anchor" id="line-64"></span>
-<p class="line879">Our primary page for getting help is the
-<a href="/BzrSupport">BzrSupport</a> page. <span class="anchor" id=
-"line-65"></span></p>
-<span class="anchor" id="line-66"></span>
-<ul>
-<li>
-<p class="line903"><a class="https" href=
-"https://launchpad.net/products/bzr/+bugs">Bug Tracker</a> - You
-can check here to see if someone else is experiencing the same
-problem that you are. <span class="anchor" id="line-67"></span></p>
-</li>
-<li>
-<p class="line903"><a class="http" href=
-"http://lists.canonical.com/mailman/listinfo/bazaar-ng">Mailing
-List</a> - A high volume list focused upon Bazaar development and
-support. <span class="anchor" id="line-68"></span></p>
-</li>
-<li>
-<p class="line886">IRC - #bzr on irc.freenode.net <span class=
-"anchor" id="line-69"></span></p>
-<span class="anchor" id="line-70"></span></li>
-</ul>
-<h1 id="head-45d36005ff61e184525081c9c40ed26ded3c8f02">How can I
-contribute?</h1>
-<span class="anchor" id="line-71"></span>
-<p class="line879">Our primary development doc page is <a href=
-"/BzrDevelopment">BzrDevelopment</a>. <span class="anchor" id=
-"line-72"></span></p>
-<span class="anchor" id="line-73"></span>
-<ul>
-<li>
-<p class="line903"><a href="/BzrDevelopment">Development
-Instructions</a> - We keep our main development instructions here.
-<span class="anchor" id="line-74"></span></p>
-</li>
-<li>
-<p class="line903"><a href="/OfficialDownloads">Source Code</a> -
-Source code to get hacking with. <span class="anchor" id=
-"line-75"></span></p>
-</li>
-<li>
-<p class="line903"><a class="https" href=
-"https://launchpad.net/products/bzr/+specs">Specifications</a> -
-Specifications list which things are being worked on today and are
-likely to be worked on next. <span class="anchor" id=
-"line-76"></span></p>
-</li>
-<li>
-<p class="line903"><a class="https" href=
-"https://launchpad.net/products/bzr/+bugs">BugTracker</a> - Open
-bugs that you can work on. <span class="anchor" id=
-"line-77"></span></p>
-<span class="anchor" id="line-78"></span></li>
-</ul>
-<p class="line879">You are also welcome to improve this wiki site.
-To edit pages, please <a href="/UserPreferences">register</a>.
-Anonymous editing is disabled to prevent spammer attacks.
-<span class="anchor" id="line-79"></span></p>
-<span class="anchor" id="bottom"></span></div>
-</div>
-<div class="clear mozclear"></div>
-</div>
-</div>
-<div class="hide" id="nsFooterClear"><!-- for NS4's sake --></div>
-<hr class="hide" />
-<div id="footer" class="inside">
-<p style="margin:0;">&copy; 2006 - <a href=
-"http://canonical.com/">Canonical Ltd.</a></p>
-<div id="endofpage"></div>
-<div id="footer_custom_html"></div>
-<div id="footer_links"></div>
-</div>
-<hr class="hide" /></div>
-</div>
-</body>
-</html>

=== modified file 'doc/default.css'
--- doc/default.css	2008-02-07 07:05:13 +0000
+++ doc/default.css	2009-12-02 20:34:07 +0000
@@ -51,7 +51,7 @@
   }
 
 h1 {
-  color: #b52b2b; 
+  color: #b52b2b;
   /* DKREDcolor: #966b72; */
   /* GREY color: #444444; */
   font-size: 1.5em;
@@ -60,7 +60,7 @@
 h1 a:link {
   color: inherit;
   }
-  
+
 h1 a:hover {
   color: inherit;
   }
@@ -89,7 +89,7 @@
   }
 
 h3 {
-  color: #966b72; 
+  color: #966b72;
   /* color: #966b72; */
   }
 
@@ -114,7 +114,7 @@
   padding: 1ex;
   background: #7777FF;
         }
-dt:hover 
+dt:hover
   {
   background-color: black;
   }

=== renamed file 'doc/en/developer-guide/HACKING.txt' => 'doc/developers/HACKING.txt'
--- doc/en/developer-guide/HACKING.txt	2009-08-13 17:16:31 +0000
+++ doc/developers/HACKING.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 Bazaar Developer Guide
 ======================
 
-This document describes the Bazaar internals and the development process.  
+This document describes the Bazaar internals and the development process.
 It's meant for people interested in developing Bazaar, and some parts will
 also be useful to people developing Bazaar plugins.
 
@@ -11,14 +11,8 @@
 the Bazaar mailing list.  To propose a correction or addition to this
 document, send a merge request or new text to the mailing list.
 
-The current version of this document is available in the file 
-``doc/en/developer-guide/HACKING.txt`` in the source tree, or at
-http://doc.bazaar-vcs.org/bzr.dev/en/developer-guide/HACKING.html
-
-See also:
-`Bazaar Developer Documentation Catalog <../../developers/index.html>`_.
-
-.. contents::
+The latest developer documentation can be found online at
+http://doc.bazaar-vcs.org/developers/.
 
 
 Getting Started
@@ -70,7 +64,7 @@
 
 * you get to build on the wisdom on others, saving time
 
-* if others can direct you to similar code, it minimises the work to be done 
+* if others can direct you to similar code, it minimises the work to be done
 
 * it assists everyone in coordinating direction, priorities and effort.
 
@@ -93,7 +87,7 @@
 -----------------
 
 First, get a local copy of the development mainline (See `Why make a local
-copy of bzr.dev?`_.) 
+copy of bzr.dev?`_.)
 ::
 
  $ bzr init-repo ~/bzr
@@ -106,7 +100,7 @@
 
 This will give you a branch called "123456-my-bugfix" that you can work on
 and commit in. Here, you can study the code, make a fix or a new feature.
-Feel free to commit early and often (after all, it's your branch!). 
+Feel free to commit early and often (after all, it's your branch!).
 
 Documentation improvements are an easy place to get started giving back to the
 Bazaar project.  The documentation is in the `doc/` subdirectory of the Bazaar
@@ -139,14 +133,14 @@
 Making a local mirror of bzr.dev is not strictly necessary, but it means
 
 - You can use that copy of bzr.dev as your main bzr executable, and keep it
-  up-to-date using ``bzr pull``.  
+  up-to-date using ``bzr pull``.
 - Certain operations are faster, and can be done when offline.  For example:
 
   - ``bzr bundle``
   - ``bzr diff -r ancestor:...``
   - ``bzr merge``
 
-- When it's time to create your next branch, it's more convenient.  When you 
+- When it's time to create your next branch, it's more convenient.  When you
   have further contributions to make, you should do them in their own branch::
 
     $ cd ~/bzr
@@ -199,9 +193,9 @@
 
 * create a local copy of the main development branch (bzr.dev) by using
   this command::
-  
+
     bzr branch http://bazaar-vcs.org/bzr/bzr.dev/ bzr.dev
-   
+
 * keep your copy of bzr.dev pristine (by not developing in it) and keep
   it up to date (by using bzr pull)
 
@@ -228,10 +222,10 @@
 
 README
     This file covers a brief introduction to Bazaar and lists some of its
-    key features. 
+    key features.
 
 NEWS
-    Summary of changes in each Bazaar release that can affect users or 
+    Summary of changes in each Bazaar release that can affect users or
     plugin developers.
 
 setup.py
@@ -243,7 +237,7 @@
     with this but don't be confused by it. The build process puts a copy
     of the main code base into this build directory, along with some other
     files. You don't need to go in here for anything discussed in this
-    guide. 
+    guide.
 
 bzrlib
     Possibly the most exciting folder of all, bzrlib holds the main code
@@ -254,19 +248,20 @@
     Holds documentation on a whole range of things on Bazaar from the
     origination of ideas within the project to information on Bazaar
     features and use cases.  Within this directory there is a subdirectory
-    for each translation into a human language.  All the documentation 
+    for each translation into a human language.  All the documentation
     is in the ReStructuredText markup language.
 
-doc/developers 
+doc/developers
     Documentation specifically targeted at Bazaar and plugin developers.
     (Including this document.)
-    
-        
-
-Automatically-generated API reference information is available at 
-<http://starship.python.net/crew/mwh/bzrlibapi/>.  
-
-See also the `Bazaar Architectural Overview  <../../developers/overview.html>`_.
+
+
+
+Automatically-generated API reference information is available at
+<http://starship.python.net/crew/mwh/bzrlibapi/>.
+
+See also the `Bazaar Architectural Overview
+<http://doc.bazaar-vcs.org/developers/overview.html>`_.
 
 
 The Code Review Process
@@ -296,7 +291,7 @@
 
 * **how** this change achieves this purpose
 
-* anything else you may have fixed in passing 
+* anything else you may have fixed in passing
 
 * anything significant that you thought of doing, such as a more
   extensive fix or a different approach, but didn't or couldn't do now
@@ -341,7 +336,7 @@
 welcome that only cleanup the code without changing the external
 behaviour.  The core developers take care to keep the code quality high
 and understandable while recognising that perfect is sometimes the enemy
-of good. 
+of good.
 
 It is easy for reviews to make people notice other things which should be
 fixed but those things should not hold up the original fix being accepted.
@@ -383,7 +378,7 @@
 ====================
 
 From May 2009 on, we prefer people to propose code reviews through
-Launchpad.  
+Launchpad.
 
  * <https://launchpad.net/+tour/code-review>
 
@@ -408,7 +403,7 @@
 Then go to the branch's web page, which in this case would be
 <https://code.launchpad.net/~mbp/bzr/doc>.  You can simplify this step by just
 running ::
- 
+
   bzr lp-open
 
 You can then click "Propose for merging into another branch", and enter your
@@ -430,7 +425,7 @@
 You can generate a merge request like this::
 
   bzr send -o bug-1234.diff
-  
+
 ``bzr send`` can also send mail directly if you prefer; see the help.
 
 Reviewing changes
@@ -462,7 +457,7 @@
 You can generate a merge request like this::
 
   bzr send -o bug-1234.patch
-  
+
 A ``.patch`` extension is recommended instead of .bundle as many mail clients
 will send the latter as a binary file.
 
@@ -517,7 +512,7 @@
 Code layout
 ===========
 
-Please write PEP-8__ compliant code.  
+Please write PEP-8__ compliant code.
 
 __ http://www.python.org/peps/pep-0008.html
 
@@ -535,7 +530,7 @@
 Each file must have a newline at the end of it.
 
 Lines should be no more than 79 characters if at all possible.
-Lines that continue a long statement may be indented in either of 
+Lines that continue a long statement may be indented in either of
 two ways:
 
 within the parenthesis or other character that opens the block, e.g.::
@@ -625,12 +620,10 @@
 Naming
 ======
 
-Functions, methods or members that are "private" to bzrlib are given
+Functions, methods or members that are relatively private are given
 a leading underscore prefix.  Names without a leading underscore are
 public not just across modules but to programmers using bzrlib as an
-API. As a consequence, a leading underscore is appropriate for names
-exposed across modules but that are not to be exposed to bzrlib API
-programmers.
+API.
 
 We prefer class names to be concatenated capital words (``TestCase``)
 and variables, methods and functions to be lowercase words joined by
@@ -678,6 +671,19 @@
     may not catch every case but it's still useful sometimes.
 
 
+Cleanup methods
+===============
+
+Often when something has failed later code, including cleanups invoked
+from ``finally`` blocks, will fail too.  These secondary failures are
+generally uninteresting compared to the original exception.  So use the
+``only_raises`` decorator (from ``bzrlib.decorators``) for methods that
+are typically called in ``finally`` blocks, such as ``unlock`` methods.
+For example, ``@only_raises(LockNotHeld, LockBroken)``.  All errors that
+are unlikely to be a knock-on failure from an previous failure should be
+allowed.
+
+
 Factories
 =========
 
@@ -696,8 +702,8 @@
 Registries
 ==========
 
-Several places in Bazaar use (or will use) a registry, which is a 
-mapping from names to objects or classes.  The registry allows for 
+Several places in Bazaar use (or will use) a registry, which is a
+mapping from names to objects or classes.  The registry allows for
 loading in registered code only when it's needed, and keeping
 associated information such as a help string or description.
 
@@ -707,13 +713,13 @@
 
 The ``InterObject`` provides for two-way `multiple dispatch`__: matching
 up for example a source and destination repository to find the right way
-to transfer data between them. 
+to transfer data between them.
 
 .. __: http://en.wikipedia.org/wiki/Multiple_dispatch
 
 There is a subclass ``InterObject`` classes for each type of object that is
 dispatched this way, e.g. ``InterRepository``.  Calling ``.get()`` on this
-class will return an ``InterObject`` instance providing the best match for 
+class will return an ``InterObject`` instance providing the best match for
 those parameters, and this instance then has methods for operations
 between the objects.
 
@@ -800,7 +806,7 @@
 
 If you add a new class you should generally add a ``__repr__`` method
 unless there is an adequate method in a parent class.  There should be a
-test for the repr.  
+test for the repr.
 
 Representations should typically look like Python constructor syntax, but
 they don't need to include every value in the object and they don't need
@@ -841,8 +847,9 @@
 Test coverage
 =============
 
-All code should be exercised by the test suite.  See `Guide to Testing
-Bazaar <../../developers/testing.html>`_ for detailed information about writing tests.
+All code should be exercised by the test suite.  See the `Bazaar Testing
+Guide <http://doc.bazaar-vcs.org/developers/testing.html>`_ for detailed
+information about writing tests.
 
 
 Core Topics
@@ -851,8 +858,8 @@
 Evolving Interfaces
 ===================
 
-We have a commitment to 6 months API stability - any supported symbol in a
-release of bzr MUST NOT be altered in any way that would result in
+We don't change APIs in stable branches: any supported symbol in a stable
+release of bzr must not be altered in any way that would result in
 breaking existing code that uses it. That means that method names,
 parameter ordering, parameter names, variable and attribute names etc must
 not be changed without leaving a 'deprecated forwarder' behind. This even
@@ -862,7 +869,10 @@
 way, you need to change its name as well. For instance, if I add an optional keyword
 parameter to branch.commit - that's fine. On the other hand, if I add a
 keyword parameter to branch.commit which is a *required* transaction
-object, I should rename the API - i.e. to 'branch.commit_transaction'. 
+object, I should rename the API - i.e. to 'branch.commit_transaction'.
+
+  (Actually, that may break code that provides a new implementation of
+  ``commit`` and doesn't expect to receive the parameter.)
 
 When renaming such supported API's, be sure to leave a deprecated_method (or
 _function or ...) behind which forwards to the new API. See the
@@ -1029,8 +1039,8 @@
 
     0. OK.
     1. Conflicts in merge-like operations, or changes are present in
-       diff-like operations. 
-    2. Unrepresentable diff changes (i.e. binary files that we cannot show 
+       diff-like operations.
+    2. Unrepresentable diff changes (i.e. binary files that we cannot show
        a diff of).
     3. An error or exception has occurred.
     4. An internal error occurred (one that shows a traceback.)
@@ -1067,13 +1077,13 @@
 format string.
 
 #. If it is something that a caller can recover from, a custom exception
-   is reasonable. 
+   is reasonable.
 
 #. If it is a data consistency issue, using a builtin like
-   ``ValueError``/``TypeError`` is reasonable. 
+   ``ValueError``/``TypeError`` is reasonable.
 
 #. If it is a programmer error (using an api incorrectly)
-   ``AssertionError`` is reasonable. 
+   ``AssertionError`` is reasonable.
 
 #. Otherwise, use ``BzrError`` or ``InternalBzrError``.
 
@@ -1132,7 +1142,7 @@
 Within each release, entries in the news file should have the most
 user-visible changes first.  So the order should be approximately:
 
- * changes to existing behaviour - the highest priority because the 
+ * changes to existing behaviour - the highest priority because the
    user's existing knowledge is incorrect
  * new features - should be brought to their attention
  * bug fixes - may be of interest if the bug was affecting them, and
@@ -1157,7 +1167,7 @@
 -----------------
 
 Functions, methods, classes and modules should have docstrings
-describing how they are used. 
+describing how they are used.
 
 The first line of the docstring should be a self-contained sentence.
 
@@ -1188,13 +1198,13 @@
     We had the problem that lots of our files were "Copyright Canonical
     Development Ltd" which is not a real company, and some other variations
     on this theme. Also, some files were missing the GPL statements.
-    
+
     I want to be clear about the intent of this patch, since copyright can
     be a little controversial.
-    
+
     1) The big motivation for this is not to shut out the community, but
     just to clean up all of the invalid copyright statements.
-    
+
     2) It has been the general policy for bzr that we want a single
     copyright holder for all of the core code. This is following the model
     set by the FSF, which makes it easier to update the code to a new
@@ -1207,15 +1217,15 @@
     I'm sure Canonical would do the same).
     As such, Canonical has requested copyright assignments from all of the
     major contributers.
-    
+
     3) If someone wants to add code and not attribute it to Canonical, there
     is a specific list of files that are excluded from this check. And the
     test failure indicates where that is, and how to update it.
-    
+
     4) If anyone feels that I changed a copyright statement incorrectly, just
     let me know, and I'll be happy to correct it. Whenever you have large
     mechanical changes like this, it is possible to make some mistakes.
-    
+
     Just to reiterate, this is a community project, and it is meant to stay
     that way. Core bzr code is copyright Canonical for legal reasons, and
     the tests are just there to help us maintain that.
@@ -1232,7 +1242,7 @@
 
 .. _pdb: http://docs.python.org/lib/debugger-commands.html
 
-If the ``BZR_PDB`` environment variable is set 
+If the ``BZR_PDB`` environment variable is set
 then bzr will go into pdb post-mortem mode when an unhandled exception
 occurs.
 
@@ -1300,7 +1310,7 @@
     for automated processing.
     For example: ``bzr log`` should not fail if one of the entries has text
     that cannot be displayed.
-  
+
   strict
     Attempting to print an unprintable character will cause a UnicodeError.
     This is for commands that are intended more as scripting support, rather
@@ -1310,7 +1320,7 @@
     printed a filename with a '?', the wrong file could be deleted. (At the
     very least, the correct file would not be deleted). An error is used to
     indicate that the requested action could not be performed.
-  
+
   exact
     Do not attempt to automatically convert Unicode strings. This is used
     for commands that must handle conversion themselves.
@@ -1364,16 +1374,16 @@
 
 To create an extension, add rules to setup.py for building it with pyrex,
 and with distutils. Now start with an empty .pyx file. At the top add
-"include 'yourmodule.py'". This will import the contents of foo.py into this 
+"include 'yourmodule.py'". This will import the contents of foo.py into this
 file at build time - remember that only one module will be loaded at
 runtime. Now you can subclass classes, or replace functions, and only your
 changes need to be present in the .pyx file.
 
 Note that pyrex does not support all 2.4 programming idioms, so some
-syntax changes may be required. I.e. 
+syntax changes may be required. I.e.
 
- - 'from foo import (bar, gam)' needs to change to not use the brackets. 
- - 'import foo.bar as bar' needs to be 'import foo.bar; bar = foo.bar' 
+ - 'from foo import (bar, gam)' needs to change to not use the brackets.
+ - 'import foo.bar as bar' needs to be 'import foo.bar; bar = foo.bar'
 
 If the changes are too dramatic, consider
 maintaining the python code twice - once in the .pyx, and once in the .py,
@@ -1403,7 +1413,7 @@
 * reviewing changes
 * reviewing blueprints
 * planning releases
-* managing releases (see the `Releasing Bazaar <../../developers/releasing.html>`_)
+* managing releases (see `Releasing Bazaar <http://doc.bazaar-vcs.org/developers/releasing.html>`_)
 
 .. note::
   Removing barriers to community participation is a key reason for adopting
@@ -1656,7 +1666,7 @@
 .. note::
   As well as prioritizing bugs and nominating them against a
   target milestone, Launchpad lets core developers offer to mentor others in
-  fixing them. 
+  fixing them.
 
 
 ..

=== added directory 'doc/developers/_static'
=== added file 'doc/developers/_static/bzr icon 16.png'
Binary files doc/developers/_static/bzr icon 16.png and doc/developers/_static/bzr icon 16.png differ
=== added file 'doc/developers/_static/bzr-doc.css'
--- doc/developers/_static/bzr-doc.css	1970-01-01 00:00:00 +0000
+++ doc/developers/_static/bzr-doc.css	2009-11-18 02:08:40 +0000
@@ -0,0 +1,4 @@
+
+ol.loweralpha {
+  list-style-type: lower-alpha;
+}

=== added file 'doc/developers/_static/bzr.ico'
Binary files doc/developers/_static/bzr.ico and doc/developers/_static/bzr.ico differ
=== added directory 'doc/developers/_templates'
=== added file 'doc/developers/_templates/layout.html'
--- doc/developers/_templates/layout.html	1970-01-01 00:00:00 +0000
+++ doc/developers/_templates/layout.html	2009-11-18 02:08:40 +0000
@@ -0,0 +1,32 @@
+{% extends "!layout.html" %}
+
+{% block linktags %}
+{{ super() }}
+<link rel="stylesheet" href="_static/bzr-doc.css" type="text/css" />
+{% endblock %}
+
+{% block rootrellink %}
+<li><a href="http://bazaar-vcs.org/">
+    <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Home</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/en/">Documentation</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}
+
+{% block document %}
+ <script type="text/javascript">
+  var gaJsHost = (("https:" == document.location.protocol) ?  "https://ssl." : "http://www.");
+  document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
+  </script>
+  <script type="text/javascript">
+  try{
+  var pageTracker = _gat._getTracker("UA-1018242-1");
+  pageTracker._trackPageview();
+  } catch(err) {}
+  try {
+    /* bazaar team tracker */
+    var pageTracker = _gat._getTracker("UA-11329411-2");
+    pageTracker._trackPageview();
+  } catch(err) {}
+</script>
+{{ super() }}
+{% endblock %}

=== modified file 'doc/developers/add.txt'
--- doc/developers/add.txt	2007-06-05 08:02:04 +0000
+++ doc/developers/add.txt	2009-12-02 20:34:07 +0000
@@ -28,7 +28,7 @@
 ------------------
 
 #. If the path is versioned, and it is a directory, push onto the recurse stack.
-#. If the path is supplied by the user or is not ignored, version it, and if a 
+#. If the path is supplied by the user or is not ignored, version it, and if a
    directory, push onto the recurse stack. Versioning the path may require
    versioning the paths parents.
 #. Output or otherwise record the ignored rule as per the user interface selected.

=== modified file 'doc/developers/api-versioning.txt'
--- doc/developers/api-versioning.txt	2009-01-23 18:44:10 +0000
+++ doc/developers/api-versioning.txt	2009-12-02 20:34:07 +0000
@@ -86,8 +86,8 @@
 with ``(0, 18, 0)``.
 
 +------------+---------------+
-| API        | Covers        | 
-+============+===============+ 
+| API        | Covers        |
++============+===============+
 | bzrlib     | All of bzrlib |
 +------------+---------------+
 

=== modified file 'doc/developers/apport.txt'
--- doc/developers/apport.txt	2009-08-13 14:31:20 +0000
+++ doc/developers/apport.txt	2009-12-02 20:34:07 +0000
@@ -37,7 +37,7 @@
 report to file later.  At the moment we just show them the filename and
 let them take it from there.
 
-The process is 
+The process is
 
 #. An exception reaches the top-level handler.
 
@@ -83,5 +83,5 @@
 
   Possibly these bugs are better reported in the next time bzr runs.
 
-.. 
+..
     vim: ft=rst

=== modified file 'doc/developers/authentication-ring.txt'
--- doc/developers/authentication-ring.txt	2009-01-08 16:57:10 +0000
+++ doc/developers/authentication-ring.txt	2009-12-02 20:34:07 +0000
@@ -88,7 +88,7 @@
 really needed is (``user``, ``password``, ``host``, ``path``). The ``realm``
 can be ignored [#ignored_realm]_ as long as it is still presented to the user
 when prompting for the password (unless someone found a way to declare two
-different realms for the same path). 
+different realms for the same path).
 
 ``HTTP proxy`` can be handled as ``HTTP`` (or ``HTTPS``) by explicitly
 specifying the appropriate port.
@@ -260,7 +260,7 @@
         host=r.hobby.net
         user=jim
         password=obvious1234
-        
+
         # Home server
         [home]
         scheme=https
@@ -269,11 +269,11 @@
         password='c2VjcmV0LXBhc3M='
         password_encoding=base64
         verify_certificates=no # Still searching a free certificate provider
-        
+
         [DEFAULT]
         # Our local user is barbaz, on all remote sites we're known as foobar
         user=foobar
-        
+
   * an HTTP server and a proxy::
 
         # development branches on dev server
@@ -283,7 +283,7 @@
         path=/dev
         user=user1
         password=pass1
-        
+
         # toy branches
         [localhost]
         scheme=http
@@ -291,7 +291,7 @@
         path=/
         user=user2
         password=pass2
-        
+
         # proxy
         [proxy]
         scheme=http

=== modified file 'doc/developers/bug-handling.txt'
--- doc/developers/bug-handling.txt	2009-08-24 00:29:31 +0000
+++ doc/developers/bug-handling.txt	2009-12-02 20:34:07 +0000
@@ -51,7 +51,7 @@
 report, but they generally care more about getting bugs fixed.
 
 The aim of investigating bugs before starting concentrated work on them is
-therefore only to: 
+therefore only to:
 
 * determine if they are critical or high priority (and
   should displace existing work)
@@ -76,7 +76,7 @@
  | One of the things you should not do often is to start asking
  | questions/for more debug info and then forget about the bug. It's just
  | a waste of the reporter's and your time, and will create frustration
- | on the reporter side. 
+ | on the reporter side.
 
 
 Priorities
@@ -85,7 +85,7 @@
 The suggested priorities for bug work are:
 
 1. Fix critical bugs.
-   
+
 2. Get existing fixes through review and landed.
 
 3. Fix bugs that are already in progress.
@@ -137,17 +137,13 @@
 Incomplete
     The bug requires more information from the reporter to make progress.
 Confirmed
-    The bug report has been seen by a developer and we agree it's a bug.  
+    The bug report has been seen by a developer and we agree it's a bug.
     You don't have to reproduce the bug to mark it confirmed.  (Generally
     it's not a good idea for a developer to spend time reproducing the bug
     until they're going to work on it.)
 Triaged
-    This is an odd state - one we consider a bug in launchpad, as it really
-    means "Importance has been set". We use this to mean the same thing
-    as confirmed, and set no preference on whether Confirmed or Triaged are
-    used. Please do not change a "Confirmed" bug to "Triaged" or vice verca -
-    any reports we create or use will always search for both "Confirmed" and
-    "Triaged" or neither "Confirmed" nor "Triaged".
+    We don't use this status.  If it is set, it means the same as
+    Confirmed.
 In Progress
     Someone has started working on this.
 Won't Fix
@@ -161,10 +157,17 @@
     A fix for this bug exists in a branch somewhere.  Ideally the bug will
     be linked to the branch.
 Fix Released
-    The fix for this bug is now in the bzr trunk.  It's not necessarily
-    true that it's released yet, but it will be in the next release.  The
-    bug target milestone should be set to the release it went into, but
-    don't spend too much time updating this if you don't immediately know.
+    The fix for this bug is now in the bzr branch that this task is for.
+    The branch for the default task on a bug is bzr.dev.  We use this value
+    even though the fix may not have been been included in a release yet
+    because all the developer activity around it is complete and we want to
+    both avoid bug spam when releases happen, and keep the list of bugs that
+    developers see when they look at the bug tracker trimmed to those that
+    require action. When setting a bug task to fix released, the bug target
+    milestone should be set to the release the fix will be included in (or
+    was included in, if you are updating an old bug). Don't spend too much time
+    updating this if you don't immediately know: its not critical that it be
+    set.
 
 
 Bug Importance
@@ -208,16 +211,14 @@
 ***************
 
 It's possible to target a bug to a milestone, eg
-<https://bugs.edge.launchpad.net/bzr/+milestone/1.16>.  We use this mostly
-to help the release manager know what **must** be merged to make the
-release.
+<https://bugs.edge.launchpad.net/bzr/+milestone/1.16>.  We use this to help the
+release manager know what **must** be merged to make the release.
 
 Therefore, we don't target bugs that we'd like to have fixed or that could
 be fixed in a particular release, we only target bugs that must be fixed
-and that will or might cause us to decide to slip the release if they're
-not fixed.  At any time, very few if any of the bugs targetted to a
-release should be still open.  By definition, these bugs should normally
-be Critical priority.
+and that will cause us to slip the release if they're not fixed.  At any time,
+very few if any of the bugs targeted to a release should be still open.  By
+definition, these bugs should normally be Critical priority.
 
 
 Backports
@@ -228,8 +229,10 @@
 represent this, create a new bug task (ie link in the status table on the
 bug page) by clicking the `poorly-named
 <https://bugs.launchpad.net/bugs/132733>`_ "Target to Release" link.
-Target it to the appropriate series (ie 1.15) and then to the milestone
-within that release.  
+Target it to the appropriate series (ie 1.15). If the bug should also
+prevent any point releases of that series then you should also target the
+new task to the appropriate milestone within that release. (See Targeting Bugs
+above)
 
 This bug task then has a separate status and importance to indicate the
 separate work to get it into that release.
@@ -253,53 +256,53 @@
 authentication
     authenticating to servers
 
-backport 
+backport
     candidate for backporting to an update of the previous release
 
-dirstate 
+dirstate
     WorkingTree4
 
-easy 
+easy
     should be possible to finish in an hour or two
 
-hpss 
+hpss
     bugs about the High-Performance Smart Server, i.e. bzr+ssh://, etc.
 
-hpssvfs 
+hpssvfs
     bugs for causes of VFS methods of the smart server
 
-launchpad 
+launchpad
     bugs about interactions with launchpad (typically this means bzrlib.plugins.launchpad).
 
-locale 
+locale
     problems using locales other than English
 
-memory 
+memory
     problems where we use too much memory for some reason
 
-newformat 
+newformat
     fixing this would need a new disk format
 
-performance 
+performance
     bugs about performance problems.
 
-test 
+test
     needs changes to the test framework
 
-transport 
+transport
     virtual filesystem for http, sftp, etc
 
-trivial 
+trivial
     should be very easy to fix (10-20 minutes) and easily landed: typically just spelling errors and the like
 
-ui 
+ui
     bugs relating to the bzr user interface, e.g. confusing error messages.
 
-win32 
-    bugs that mainly affects Windows. Also there is cygwin and win98 tags for marking specific bugs. 
+win32
+    bugs that mainly affects Windows. Also there is cygwin and win98 tags for marking specific bugs.
 
 You can see the full list of tags in use at
 <https://bugs.edge.launchpad.net/bzr/+bugs>.  As of September 2008 the
-list is on the right. 
+list is on the right.
 
 .. vim: ft=rst

=== modified file 'doc/developers/bundles.txt'
--- doc/developers/bundles.txt	2007-12-05 19:55:07 +0000
+++ doc/developers/bundles.txt	2009-12-02 20:34:07 +0000
@@ -1,5 +1,5 @@
 =======
-Bundles 
+Bundles
 =======
 
 Status

=== modified file 'doc/developers/case-insensitive-file-systems.txt'
--- doc/developers/case-insensitive-file-systems.txt	2008-12-23 04:20:49 +0000
+++ doc/developers/case-insensitive-file-systems.txt	2009-12-02 20:34:07 +0000
@@ -27,7 +27,7 @@
 * Case-insensitive: This is the file-system used by very old Windows versions
   and is rarely encountered "in the wild".  Two files that differ only by
   case is not allowed and the case used to create a file is not preserved.
-  
+
 As can be implied by the above descriptions, only the first two are considered
 relevant to a modern Bazaar.
 

=== modified file 'doc/developers/colocated-branches.txt'
--- doc/developers/colocated-branches.txt	2009-02-10 04:10:44 +0000
+++ doc/developers/colocated-branches.txt	2009-12-02 20:34:07 +0000
@@ -17,7 +17,7 @@
 Allowing multiple branches to live under the same directory in the file
 system means that it is possible to very easily share the same working
 tree and repository between those branches, without having a lot of fs
-infrastructure. 
+infrastructure.
 
 Git and Mercurial (can) store multiple branches under a single directory
 in the file system - per repository, so to speak. In order for this to
@@ -47,20 +47,20 @@
 ~~~~~~~~~~
 
 Bazaar URLs need to have some way to specify a colocated branch other
-than the current HEAD. Several options have been discussed, each with 
+than the current HEAD. Several options have been discussed, each with
 its own advantages and disadvantages: This was discussed on the mailing
 list, most notably the use of a ";branch=NAME" suffix as well as a special
-separation character (+, =, etc), but no final conclusion was reached. 
+separation character (+, =, etc), but no final conclusion was reached.
 
 https://lists.ubuntu.com/archives/bazaar/2008q4/050105.html
 
 Code Changes
 ~~~~~~~~~~~~
 
-BzrDir should support a BzrDir.supports_colocated_branches() call as well as 
+BzrDir should support a BzrDir.supports_colocated_branches() call as well as
 BzrDir.colocated_branches property that contains a colocated branch container,
-that can be used to add / remove colocated branches as well as change the 
-currently active colocated branch. 
+that can be used to add / remove colocated branches as well as change the
+currently active colocated branch.
 
 ::
 
@@ -87,11 +87,11 @@
 	   def destroy_branch(self, name):
 		 """Destroy the specified branch.
 			
-		This will remove the branch from disk.""" 
+		This will remove the branch from disk."""
 
 If the particular BzrDir implementation doesn't support colocated
 branches, it can just return a dummy container that just contains a
-HEAD branch. 
+HEAD branch.
 
 Looms can of course return a container with all their threads.
 
@@ -106,7 +106,7 @@
 feature in its own file formats.
 
 Eventually, Bazaar could easily support colocated branches by just
-creating a new branch transport for each colocated branch and have a 
+creating a new branch transport for each colocated branch and have a
 "regular" branch live there. This would require something like
 BzrDirMeta2 though.
 

=== modified file 'doc/developers/commit.txt'
--- doc/developers/commit.txt	2007-06-28 02:43:50 +0000
+++ doc/developers/commit.txt	2009-12-02 20:34:07 +0000
@@ -174,7 +174,7 @@
      happened several commits back. There are several edge cases to be
      handled here, like if both branches modified the same file, or if
      just one branch modified it.
-     
+
   b) The trickier case is when a file appears unmodified since last
      commit, but it was modified versus one of the merged branches. I
      believe there are a few ways this can happen, like if a merged
@@ -291,7 +291,7 @@
 It is desirable to avoid roundtrips to the Repository during commit,
 particularly because it may be remote.  If the WorkingTree can determine
 by itself that a text was in the parent and therefore should be in the
-Repository that avoids one roundtrip per file.  
+Repository that avoids one roundtrip per file.
 
 There is a possibility here that the parent revision is not stored, or not
 correctly stored, in the repository the tree is being committed into, and
@@ -311,9 +311,9 @@
 This creates a CommitBuilder object matched to the Branch, Repository and
 Tree.  It can vary depending on model differences or by knowledge of what
 is efficient with the Repository and Tree.  Model differences might
-include whether no-text-change merges need to be reported, and whether the 
+include whether no-text-change merges need to be reported, and whether the
 
-The basic CommitBuilder.commit structure can be 
+The basic CommitBuilder.commit structure can be
 
 1. Ask the branch if it is ready to commit (up to date with master if
    any.)
@@ -358,10 +358,10 @@
 
 * the working tree basis is up to date with the branch tip
 
-* the local branch is up to date with the master branch, if there 
+* the local branch is up to date with the master branch, if there
   is one and --local is not specified
 
-* an empty commit message is given, 
+* an empty commit message is given,
 
 * a hook flags an error
 
@@ -396,7 +396,7 @@
 * if there are tree references and recursing into them is enabled, then
   do so
 
-Commit needs to protect against duplicated file ids 
+Commit needs to protect against duplicated file ids
 
 
 Updates that need to be made in the working tree, either on conclusion
@@ -429,13 +429,13 @@
 * or an indication that it should be read interactively from the ui object;
 * a list of files to commit
 * an option for a dry-run commit
-* verbose option, or callback to indicate 
+* verbose option, or callback to indicate
 * timestamp, timezone, committer, chosen revision id
 * config (for what?)
 * option for local-only commit on a bound branch
 * option for strict commits (fail if there are unknown or missing files)
 * option to allow "pointless" commits (with no tree changes)
- 
+
 (This is rather a lot of options to pass individually and just for code tidyness maybe some of them should be combine into objects.)
 
 >>> Branch.commit(from_tree, message, files_to_commit, ...)
@@ -466,10 +466,10 @@
 This needs to collect a list of added/changed/removed files, each of which
 must have its text stored (if any) and containing directory updated.  This
 can be done by calling Tree._iter_changes on the source tree, asking for
-changes 
+changes
 
 In the 0.17 model the commit operation needs to know the per-file parents
-and per-file last-changed revision.  
+and per-file last-changed revision.
 
 (In this and other operations we must avoid having multiple layers walk
 over the tree separately.  For example, it is no good to have the Command
@@ -530,8 +530,8 @@
 The main things the tree needs to tell the Branch about are:
 
 * A file is modified from its parent revision (in text, permissions,
-  other), and so its text may need to be stored.  
-  
+  other), and so its text may need to be stored.
+
   Files should also be reported if they have more than one unique parent
   revision, for repositories that store per-file graphs or last-change
   revisions.  Perhaps this behaviour should be optional.
@@ -540,11 +540,11 @@
 
 * The complete contents of a modified directory, so that its inventory
   text may be stored.  This should be done after all the contained files
-  and directories have been reported.  If there are unmodified files, 
-  or unselected files carried through from 
+  and directories have been reported.  If there are unmodified files,
+  or unselected files carried through from
 
-  XXX: Actually perhaps not grouped by directory, but rather grouped 
-  appropriately for the shape of inventory storage in the repository. 
+  XXX: Actually perhaps not grouped by directory, but rather grouped
+  appropriately for the shape of inventory storage in the repository.
 
   In a zoomed-in checkout the workingtree may not have all the shape data
   for the entire tree.
@@ -577,7 +577,7 @@
 This might be construed as an enhanced version of ``set_parent_trees``.
 We can avoid a stat on each file by using the value that was observed when
 it was first read.
- 
+
 
 
 Selective commit
@@ -591,7 +591,7 @@
 However, the tree walking code does probably need to know about selected
 paths to avoid examining unselected files or directories.
 
-We never refuse selective file commits (except of merges).  
+We never refuse selective file commits (except of merges).
 
 
 

=== added file 'doc/developers/conf.py'
--- doc/developers/conf.py	1970-01-01 00:00:00 +0000
+++ doc/developers/conf.py	2009-09-09 15:51:18 +0000
@@ -0,0 +1,71 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'en'
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = u"Developer Document Catalog (%s)" % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-developers'
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  ('HACKING', 'bzr-en-developer-guide.tex', u'Bazaar Developer Guide',
+   u'Bazaar Developers', 'manual'),
+  ('testing', 'bzr-en-testing-guide.tex', u'Bazaar Testing Guide',
+   u'Bazaar Developers', 'manual'),
+  ('overview', 'bzr-en-architecture-overview.tex', u'Bazaar Architecture Overview',
+   u'Bazaar Developers', 'howto'),
+  ('integration', 'bzr-en-integration-guide.tex', u'Bazaar Integration Guide',
+   u'Bazaar Developers', 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+# Note: Maybe some of them *ought* to be linked in somewhere?
+unused_docs = [
+  'add',
+  'annotate',
+  'bundle-creation',
+  'bundle-format4',
+  'check',
+  'commit',
+  'diff',
+  'directory-fingerprints',
+  'gc',
+  'index-plain',
+  'incremental-push-pull',
+  'initial-push-pull',
+  'merge-scaling',
+  'missing',
+  'performance-roadmap-rationale',
+  'performance-use-case-analysis',
+  'planned-change-integration',
+  'planned-performance-changes',
+  'revert',
+  'status',
+  'uncommit',
+]

=== modified file 'doc/developers/container-format.txt'
--- doc/developers/container-format.txt	2009-02-22 16:54:02 +0000
+++ doc/developers/container-format.txt	2009-12-02 20:34:07 +0000
@@ -136,7 +136,7 @@
 
 Some proposed object names:
 
-  * to name a revision: "``revision:``\ *revision-id*".  e.g., 
+  * to name a revision: "``revision:``\ *revision-id*".  e.g.,
     `revision:pqm@pqm.ubuntu.com-20070531210833-8ptk86ocu822hjd5`.
   * to name an inventory delta: "``inventory.delta:``\ *revision-id*".  e.g.,
     `inventory.delta:pqm@pqm.ubuntu.com-20070531210833-8ptk86ocu822hjd5`.
@@ -155,7 +155,7 @@
 
   * a record's content could be self-describing in the context of a
     particular container, or
-  * a record could be accessed via an index based on SHA-1, or 
+  * a record could be accessed via an index based on SHA-1, or
   * when streaming, the first record could be treated specially.
 
 Reasonably cheap for small records
@@ -203,12 +203,12 @@
 A **Bytes** record:
 
   * has a kind marker of "``B``",
-  * followed by a mandatory **content length** [1]_: 
+  * followed by a mandatory **content length** [1]_:
     "*number*\ ``\n``", where *number* is in decimal, e.g::
 
       1234
 
-  * followed by zero or more optional **names**: 
+  * followed by zero or more optional **names**:
     "*name*\ ``\n``", e.g.::
 
       revision:pqm@pqm.ubuntu.com-20070531210833-8ptk86ocu822hjd5

=== modified file 'doc/developers/content-filtering.txt'
--- doc/developers/content-filtering.txt	2009-08-26 03:20:32 +0000
+++ doc/developers/content-filtering.txt	2009-12-02 20:34:07 +0000
@@ -106,7 +106,7 @@
 
 * In a future workingtree format, it might be better not to separately
   store the working-copy hash and size, but rather just a stat fingerprint
-  at which point it was known to have the same canonical form as the 
+  at which point it was known to have the same canonical form as the
   basis tree.
 
 * It may be worthwhile to have a virtual Tree-like object that does

=== added file 'doc/developers/contribution-quickstart.txt'
--- doc/developers/contribution-quickstart.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/contribution-quickstart.txt	2009-11-19 02:03:12 +0000
@@ -0,0 +1,59 @@
+Bazaar Contribution in Five Minutes
+===================================
+
+Contributing to Bazaar requires attention to quality.  To ensure
+high-quality commits, the "Bazaar process" involves you in our
+code review and improvement activities.
+
+In brief, a contribution should include:
+
+1.  A brief rationale, including expected audience and use cases,
+    for inclusion in Bazaar.
+
+2.  A branch registered as a branch on Launchpad, and submitted as
+    a merge proposal.
+
+3.  The branch should include:
+
+    a.  implementation of the feature,
+
+    b.  user documentation (if the feature is visible in the user
+        interface) and/or developer documentation (if new or
+        changed APIs are provided), and
+
+    c.  tests to ensure the specification is correctly
+        implemented.
+
+For more information, see the `Bazaar Developer Guide <HACKING.html>`_.
+
+If you are not an experienced Bazaar contributor, why not ask for
+mentoring?  When you submit your merge proposal on Launchpad, simply say
+"I'd like to be mentored, please" in your submission.  Or ask for help
+with your contribution on the IRC channel, mailing list, or on Launchpad
+(https://answers.launchpad.net/bzr).
+
+
+Current Bazaar Mentors
+----------------------
+
+See the roster at http://bazaar-vcs.org/PatchPilot, although other
+developers may help too!
+
+
+Bazaar Mentors FAQ
+------------------
+
+1.  Why is this "Bazaar process" in HACKING.txt so complicated?
+
+    Answer: If we knew *that*, we'd simplify it!  We are working
+    on streamlining many aspects, but quality comes first.
+
+1.  What sort of things can a mentor help with?
+
+    Anything that's getting in your way, time permitting.  This includes
+    guiding you through the ``bzrlib`` API, explaining how to use our test
+    infrastructure, discussing possible designs for your bug fix or
+    feature, and so on.
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/cycle.txt'
--- doc/developers/cycle.txt	2009-08-12 06:43:36 +0000
+++ doc/developers/cycle.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 Bazaar Release Cycles
 *********************
 
-:status: Current policy, as of 2009-08. 
+:status: Current policy, as of 2009-08.
 :blueprint: <https://blueprints.launchpad.net/bzr/+spec/6m-cycle>
 
 
@@ -18,14 +18,14 @@
 
 * `Bazaar Developer Document Catalog <index.html>`_
 
-* `Releasing Bazaar <releasing.html>`_ -- the process for actually making 
+* `Releasing Bazaar <releasing.html>`_ -- the process for actually making
   a release or release candidate.
 
 The Problem Situation
 *********************
 
 Bazaar makes a release every month, preceded by a one-week
-release-candidate test.  
+release-candidate test.
 
 In any release we may fix bugs, add formats, change the default format,
 improve performance, add new commands or change command line behaviour,
@@ -97,15 +97,15 @@
 
 ::
 
- 2.0 --- 2.0.1 -- 2.0.2 -- ...
+ 2.0.0 --- 2.0.1 -- 2.0.2 -- ...
   \
-   +--2.1beta1 -- 2.1beta2 -- ... -- 2.1rc1 -- 2.1 -- 2.1.1 -- ...
-                                                \
-                                                 \
-                                                  +-- 3.0beta1 ...
-
-
-Starting from the date of a major release: 
+   +--2.1.0beta1 -- 2.1.0beta2 -- ... -- 2.1.0rc1 -- 2.1.0 -- 2.1.1 -- ...
+                                                      \
+                                                       \
+                                                        +-- 3.0.0beta1 ...
+
+
+Starting from the date of a major release:
 
 At four-week intervals we make a new beta release.  There will be no
 separate release candidate, but if a serious problem is discovered we may
@@ -121,7 +121,7 @@
 We will then make a release candidate for the next major release, and at
 this point create a release branch for it.  We will iterate release
 candidates at approximately weekly intervals until there are no bugs
-blocking the final major release. 
+blocking the final major release.
 
 Compared to the current process this has approximately the same amount of
 release-related work, because the extra releases from the stable branch
@@ -144,26 +144,32 @@
 ---------
 
 The number for a six-month cycle is chosen at the start, with an increment
-to either the first field (3.0) or second field (3.1) depending on what we
-expect to be the user impact of the release.  We expect releases that
-culminate in a new disk format or that require changes in how people use
-the tool will get a new major number.  We can change (forward only) if it
-turns out that we land larger changes than were expected.
+to either the first field (3.0.0) or second field (3.1.0) depending on
+what we expect to be the user impact of the release.  We expect releases
+that culminate in a new disk format or that require changes in how people
+use the tool will get a new major number.  We can change (forward only) if
+it turns out that we land larger changes than were expected.
+
+We will always use the 3-digit form (major.minor.micro) even when
+referring to the initial major release. This should help clarify where a
+patch is intended to land. (eg, "I propose this for 2.0.0" is clear, while
+"I propose this for 2.0" could mean you want to make the 2.0.0 release, or
+that you just want to land on the 2.0.x stable release series.)
 
 
 Terminology
 -----------
 
-Major releases (2.0 or 2.1)
+Major releases (2.0.0 or 2.1.0)
     The big ones, every six months, intended to ship in distributions and
     to be used by stability-oriented users.
 
-Release candidate (2.0rc1)
+Release candidate (2.0.0rc1)
     A preview of a major release, made one or a few weeks beforehand at
     the time the release branch is created.  There should be few if any
     changes from the rc to the stable release.  We should avoid the
-    confusing phrasing "release candidate 2.0rc1 is released"; instead use
-    "available."
+    confusing phrasing "release candidate 2.0.0rc1 is released"; instead
+    use "available."
 
 Bugfix releases (2.0.1)
     Based on the previous major release or bugfix; contains only bugfixes
@@ -175,7 +181,7 @@
 Stable release
     Either a major release or a bugfix release.
 
-Beta release (3.0beta1)
+Beta release (3.0.0beta1)
     Made from trunk every month, except for the month there's a major
     release.  Stable and suitable for users who want the latest code and
     can live with some changes from month to month.
@@ -186,7 +192,7 @@
 Bug Work
 --------
 
-Bug fixes should normally be done first against the stable branch, 
+Bug fixes should normally be done first against the stable branch,
 reviewed against that branch, and then merged forward to trunk.
 
 It may not always be easy to do this, if fixing the bug requires large
@@ -234,7 +240,7 @@
 of bzrlib, which is an elusive target in Python.
 
 This may mean that in cases where today a plugin would keep running but
-give warnings, it will now fail altogether with an error.   
+give warnings, it will now fail altogether with an error.
 
 In return we expect more freedom to change and cleanup bzrlib code without
 needing to keep old code around, or write extra compatibility shims, or
@@ -246,7 +252,7 @@
 but that aren't technically plugins.  The same approach, though the
 technical considerations are different, should apply to other extensions
 such as programs that use bzr through the shell interface.
-  
+
 
 
 Data and Network Formats
@@ -260,7 +266,7 @@
 Each major release will have one recommended data format which will be the
 default.  The name of the format will indicate which release series (not
 specific release) it comes from: '2a' is the first supported format for
-the 2.0 series, '2b' the second, etc.  We don't mention the particular
+the 2.0.x series, '2b' the second, etc.  We don't mention the particular
 release that introduced it so as to avoid problems predicting precisely
 when it will land.
 
@@ -290,7 +296,7 @@
 This can be handled in various ways either at the OS packaging or the
 Python level.  We don't propose to directly address it in the upstream
 source.  (For example, we will not change the bzrlib library name from one
-release to the next.)  
+release to the next.)
 
 The issue already exists with people who may want to use for example the
 previous bzr release and the trunk.  There is a related issue that plugins
@@ -321,9 +327,10 @@
 only the stable releases.  This is probably better than having them only
 intermittently or slowly ship the monthly releases.
 
-Binary installers should use a version number like '2.0-1' or '2.0beta1-1'
-so that the last component just reflects the packaging version, and can be
-incremented if a new installer is made with no upstream source changes.
+Binary installers should use a version number like '2.0.0-1' or
+'2.0.0beta1-1' so that the last component just reflects the packaging
+version, and can be incremented if a new installer is made with no
+upstream source changes.
 
 
 Code Freeze vs Announcement
@@ -343,7 +350,7 @@
 
 * Early communication about changing dependencies or defaults
 
-* Reminder re lifecycle and where we're up to right now, in particular the 
+* Reminder re lifecycle and where we're up to right now, in particular the
   dates for the next release and/or candidate.
 
 * Summary of recent successes and pending work.
@@ -357,11 +364,11 @@
 Questions
 *********
 
-Do users actually want this?  
+Do users actually want this?
     Apparently yes, because it's often requested and often raised as a
     problem.
 
-Would this confuse users?  
+Would this confuse users?
     It shouldn't, because it's a fairly standard scheme.
 
 Won't it take more time to fix bugs in multiple places?
@@ -381,7 +388,7 @@
     really rather not test them, forcing them is not helpful.
 
 Isn't this a step backwards to a slower, less-agile process?
-    No, our trunk stays releasable, and we ship every month.  We're just 
+    No, our trunk stays releasable, and we ship every month.  We're just
     cutting out things that hold us back (continuous rather than episodic
     API stability; RCs every month) and giving users what they demand.
 
@@ -399,7 +406,7 @@
   and stable releases, indicating that each has value.
 
 * API changes are easier or safer to make during beta periods, without
-  being held back by fears of compatibility or 
+  being held back by fears of compatibility or
 
 * The stable releases are actually stable and don't introduce regressions
   or break plugins.

=== modified file 'doc/developers/development-repo.txt'
--- doc/developers/development-repo.txt	2009-04-09 20:23:07 +0000
+++ doc/developers/development-repo.txt	2009-12-02 20:34:07 +0000
@@ -28,7 +28,7 @@
 
 When a release of bzr is done, all the older numbered development
 formats will be removed from 'bzr.dev', so we will not be carrying the
-code for them around indefinately. 
+code for them around indefinately.
 
 Support for upgrade and migration
 ---------------------------------
@@ -40,7 +40,7 @@
  - users of a given development format can always get back onto regular
    formats by switching to the next bzr released version which is
    guaranteed to be able to upgrade from that development format.
- - users that routinely use bzr.dev should upgrade to the most recent 
+ - users that routinely use bzr.dev should upgrade to the most recent
    development version available before pulling in bzr.dev changes
    around release time, as that is when old format cleanups will occur.
 

=== modified file 'doc/developers/diff.txt'
--- doc/developers/diff.txt	2007-07-17 00:27:16 +0000
+++ doc/developers/diff.txt	2009-12-02 20:34:07 +0000
@@ -61,7 +61,7 @@
 that only certain files should be compared.
 
 Performance can be further improved by caching comparisons to avoid repeating
-them.  Caching could potentially be performed by ``diff`` and perhaps by 
+them.  Caching could potentially be performed by ``diff`` and perhaps by
 ``merge``.  Merge is aware of the relationship of a text merge's result to
 the THIS value, and the THIS value is generally the basis value.  So the
 comparison is latent, but present.  The only issue is extracting it.

=== modified file 'doc/developers/directory-fingerprints.txt'
--- doc/developers/directory-fingerprints.txt	2007-07-31 03:38:18 +0000
+++ doc/developers/directory-fingerprints.txt	2009-12-02 20:34:07 +0000
@@ -8,7 +8,7 @@
 
 The basic idea is that for a directory in a tree (committed or otherwise), we
 will have a single scalar value.  If these values are the same, the contents of
-the subtree under that directory are necessarily the same.  
+the subtree under that directory are necessarily the same.
 
 This is intended to help with these use cases, by allowing them to quickly skip
 over directories with no relevant changes, and to detect when a directory has
@@ -26,7 +26,7 @@
 
 Most of this will be hidden behind the Tree interface.  This should cover
 ``log -v``, ``diff``, ``status``, ``merge`` (and implicit merge during
-push, pull, update):: 
+push, pull, update)::
 
   tree.iter_changes(other_tree)
   tree.get_file_lines(file_id)   # and get_file, get_file_text
@@ -38,7 +38,7 @@
 compare to all the trees.  Commit currently needs to compare the working
 tree to all the parent trees, which is needed to update the last_modified
 field and would be unnecessary if we removed that field (for both files
-and directories) and did not store per-file graphs.  
+and directories) and did not store per-file graphs.
 This would potentially speed up commit after merge.
 
 Verbose commit also displays the merged files, which does
@@ -49,7 +49,7 @@
 ~~~~~~~
 
 Log is interested in two operations: finding the revisions that touched
-anything inside a directory, and getting the differences between 
+anything inside a directory, and getting the differences between
 consecutive revisions (possibly filtered to a directory)::
 
   find_touching_revisions(branch, file_id) # should be on Branch?
@@ -90,9 +90,9 @@
   Hashes converge: if you modify and then modify back, you get the same
   hash.  This is a pro because you can detect that there were ultimately
   no significant changes.  And also a con: you cannot use these hashes to form a graph
-  because they get cycles.  
-
-  
+  because they get cycles.
+
+
 * Are the values unique across the whole tree, or only when comparing
   different versions of the same object?
 
@@ -107,7 +107,7 @@
 
 
 * Is it reasonable to assume hashes won't collide?
-  
+
   The odds of SHA-1 hashes colliding "accidentally" are vanishingly small.
 
   It is possible that a `preimage attack`_ against SHA-1 may be discovered
@@ -132,7 +132,7 @@
 
   It is desirable that we have a hash that covers all data, to guard
   against bugs, transmission errors, or users trying to hand-hack files.
-  Since we need one hash of everything in the tree, perhaps we should also 
+  Since we need one hash of everything in the tree, perhaps we should also
   use it for the fingerprint.
 
   Testaments explicitly separate the form used for hashing/signing from
@@ -143,7 +143,7 @@
   stored data which is not protected by the signature: this data is less
   important, but corruption of it would still cause problems.
   We have encountered some specific problems with disagreement between
-  inventories as to the last-change of files, which is currently unsigned. 
+  inventories as to the last-change of files, which is currently unsigned.
   These problems can be introduced by ghosts.
 
   If we hash the representation, there is still a way to support old
@@ -156,16 +156,16 @@
 * Is hashing substantially slower than other possible approaches?
 
   We already hash all the plain files.  Except in unusual cases, the
-  directory metadata will be substantially smaller: perhaps 200:1 as a 
+  directory metadata will be substantially smaller: perhaps 200:1 as a
   rule of thumb.
 
   When building a bzr tree, we spend on the order of 100ms hashing all the
   source lines to validate them (about 13MB of source).
 
 
-* Can you calculate one from a directory in the working tree?  Without a basis?  
+* Can you calculate one from a directory in the working tree?  Without a basis?
 
-  This seems possible with either hashes or revision ids.  
+  This seems possible with either hashes or revision ids.
 
   Using last_changed means that calculating the fingerprint from a working
   tree necessarily requires reading the inventory for the basis
@@ -199,30 +199,30 @@
   This does rule out for example using ``last_modified=None`` or
   ``='current:'`` to mean "changed in the working tree."  Even if this is
   not supported there seems some risk that we would get the same
-  fingerprint for trees that are actually different.  
-  
-  We could assign a 
+  fingerprint for trees that are actually different.
+
+  We could assign a
   hypothetical revision id to the tree for uncommitted files.  In that
   case there is some risk that the not-yet-committed id would become
   visible or committed.
 
-  
+
 * Can we use an "approximate basis"?
 
   When using radix trees, you may need context beyond the specific
-  directory being compared.  
-
-
-* Can you get the fingerprint of parents directories with only selected file ids 
+  directory being compared.
+
+
+* Can you get the fingerprint of parents directories with only selected file ids
   taken from the working tree?
 
   With hashes, we'd want to carry through the unselected files and
-  directories from the values they had in the parent revision.  
-
-
-* Are unbalanced trees a significant problem?  Trees can be unbalanced by having 
-  many directories (deep or wide), or many files per directory.  
-  
+  directories from the values they had in the parent revision.
+
+
+* Are unbalanced trees a significant problem?  Trees can be unbalanced by having
+  many directories (deep or wide), or many files per directory.
+
   For small trees like bzr, 744 of 874 are in the bzrlib subtree.  In
   general, larger trees are more balanced, because humans, editors and
   other tools have trouble managing very unbalanced trees.  But there are
@@ -230,7 +230,7 @@
   entries in one directory.
 
 
-* Should we use a radix tree approach where fingerprints are calculated on a synthetic 
+* Should we use a radix tree approach where fingerprints are calculated on a synthetic
   tree that is by definition balanced, even when the actual tree is unbalanced?
 
 
@@ -268,10 +268,10 @@
      This has some consequences for how we can upgrade it in future: all
      the changed directories need to be rewritten up to the revision level.
 
-  1. If we address directories by hash we need hash-addressed 
+  1. If we address directories by hash we need hash-addressed
      storage.
 
-  1. If we address directories by hash then for consistency we'd probably 
+  1. If we address directories by hash then for consistency we'd probably
      (not necessarily) want to address file texts by hash.
 
   1. The per-file graph can't be indexed by hash because they can converge, so we
@@ -316,8 +316,8 @@
   If the version of a file or directory is identified by a hash, we can't
   use that to point into a per-file graph.  We can have a graph indexed by
   ``(file_id, hash, revision_id)``.  The last-modified could be stored as
-  part of this graph.  
-  
+  part of this graph.
+
   The graph would no longer be core data; it could be always present but
   might be rebuilt.  Treating it as non-core data may make some changes
   like shallow branches easier?
@@ -354,6 +354,6 @@
 -----------
 
 
-..  
+..
   vim: filetype=rst textwidth=78 expandtab spelllang=en spell
 

=== modified file 'doc/developers/dirstate.txt'
--- doc/developers/dirstate.txt	2007-06-18 02:04:20 +0000
+++ doc/developers/dirstate.txt	2009-09-09 15:51:18 +0000
@@ -1,3 +1,6 @@
+Dirstate
+========
+
 Don't really need the hashes of the current versions - just knowing
 whether they've changed or not will generally be enough - and just the
 mtime and ctime of a point in time may be enough?

=== modified file 'doc/developers/ec2.txt'
--- doc/developers/ec2.txt	2009-03-23 00:25:27 +0000
+++ doc/developers/ec2.txt	2009-12-02 20:34:07 +0000
@@ -8,7 +8,7 @@
 but we aim to use it for the production Windows installer build of 1.13 in
 March.
 
-See also: 
+See also:
 
 * `Bazaar Developer Documentation Catalog <index.html>`_.
 
@@ -20,8 +20,8 @@
 =====
 
 * The instance is only running (and incurring charges) when it's needed
-  for testing or packaging.  
-  
+  for testing or packaging.
+
 * It can be started or stopped by anyone on the team using a
   straightforward script.
 
@@ -41,7 +41,7 @@
 ========
 
 The working disk and the AMI images are stored in one person's account for
-billing purposes.  
+billing purposes.
 
 Ideally we want to give other people access to run this machine without
 giving full access to the account.  I'm not sure if that's feasible.  If
@@ -76,7 +76,7 @@
 This is distinct from the account identifier - likely due to the different
 toolchains in use (the keypairs are used for unix ssh keys, and I (Robert)
 suspect a rather unix friendly core at Amazon).
-Once a custom image is made with a saved password, you can skip using 
+Once a custom image is made with a saved password, you can skip using
 ``ec2-get-password`` (which is only needed for Windows anyway).
 
 It would be nice if rdesktop could use private key authentication but
@@ -125,9 +125,9 @@
 * Install the rdesktop client, to actually access the machine.
 
 * Possibly read some of the `EC2 documentation`_ for background.
-   
-.. _`bug 330930`: https://bugs.edge.launchpad.net/ubuntu/+bug/330930 
-.. _`Amazon EC2 API tools`: 
+
+.. _`bug 330930`: https://bugs.edge.launchpad.net/ubuntu/+bug/330930
+.. _`Amazon EC2 API tools`:
      http://developer.amazonwebservices.com/connect/entry.jspa?externalID=368&categoryID=88
 .. _`EC2 documentation`: http://aws.amazon.com/
 .. _`ami-bdfe19d4`:
@@ -138,7 +138,7 @@
     ec2-add-group desolation-group -d 'bzr win32 build machine'
     ec2-authorize desolation-group -p 3389 -s 1.2.3.4/32
     ec2-authorize desolation-group -t -1:-1 -P icmp
-  
+
   Add your public IP there.  You can repeat that command to allow others
   in.
 
@@ -149,11 +149,11 @@
 1. Get the right AMI image ID from another developer.
 
 1. Start the instance::
-   
+
      ec2-run-instances $image_id -g desolation-group
 
    This will print out some information including the image id, something
-   like ``i-31a74258``.  
+   like ``i-31a74258``.
 
 1. Actually starting the machine will take a few minutes.  Once it's in
    the *running* state, get the machine's public IP with ::
@@ -171,18 +171,18 @@
 To save a system snapshot as an image
 -------------------------------------
 
-1. Bundle the current state.  *Doing this will reboot the machine.* 
+1. Bundle the current state.  *Doing this will reboot the machine.*
    You need to choose a unique s3 bucket name,
-   typically based on a domain or email address, which can contain 
+   typically based on a domain or email address, which can contain
    any number of images.  You also need a name unique within the bucket
-   for this image, like ``desolation-vs2008-20090219``.  And finally 
+   for this image, like ``desolation-vs2008-20090219``.  And finally
    it needs your AWS S3 access key and secret key, which should be set in
    ``~/.aws``::
-    
+
       ec2-bundle-instance -b ec2.sourcefrog.net \
           -p desolation-vs2008-2009021 \
           -o "$AWS_ACCESS_KEY_ID" \
-          -w "$AWS_SECRET_ACCESS_KEY" 
+          -w "$AWS_SECRET_ACCESS_KEY"
 
 1.  This will take several minutes:  You can check progress with ::
 

=== added file 'doc/developers/implementation-notes.txt'
--- doc/developers/implementation-notes.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/implementation-notes.txt	2009-09-07 07:44:36 +0000
@@ -0,0 +1,28 @@
+Implementation notes
+====================
+
+.. toctree::
+   :hidden:
+
+   btree_index_prefetch
+   last-modified
+   content-filtering
+   lca_tree_merging
+
+
+* `BTree Index Prefetch <btree_index_prefetch.html>`_ |--| How bzr decides
+  to pre-read extra nodes in the btree index.
+
+* `Computing last_modified values <last-modified.html>`_ for inventory
+  entries
+
+* `Content filtering <content-filtering.html>`_
+
+* `LCA Tree Merging <lca_tree_merging.html>`_ |--| Merging tree-shape when
+  there is not a single unique ancestor (criss-cross merge).
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/improved_chk_index.txt'
--- doc/developers/improved_chk_index.txt	2009-03-24 16:35:22 +0000
+++ doc/developers/improved_chk_index.txt	2009-12-02 20:34:07 +0000
@@ -16,7 +16,7 @@
 per key, which is the same size as the binary representation of the hash. This
 means we could write an index format that gets approximately the same on-disk
 size, without having the overhead of ``zlib.decompress``. Some thought would
-still need to be put into how to efficiently access these records from remote. 
+still need to be put into how to efficiently access these records from remote.
 
 
 Required information
@@ -99,7 +99,7 @@
    offset + endpoint as a header in the group itself.)
 
 5. So for 1M keys, an ideal chk+group index would be:
-    
+
     a. 6-byte hash prefix
 
     b. 2-byte group number
@@ -149,13 +149,13 @@
       information to read the entire group block. For local ops, you could
       only read enough to get the header, and then only read enough to
       decompress just the content you want to get at.
-      
+
       Using an offset, you also don't need to decode the entire group header.
       If we assume that things are stored in fixed-size records, you can jump
       to exactly the entry that you care about, and read its 8-byte
       (start,length in uncompressed) info.  If we wanted more redundancy we
       could store the 20-byte hash, but the content can verify itself.
-      
+
    f. If the size of these mini headers becomes critical (8 bytes per record
       is 8% overhead for 100 byte records), we could also compress this mini
       header. Changing the number of bytes per entry is unlikely to be
@@ -172,7 +172,7 @@
       would also have the advantage that fixed width would be highly
       compressible itself. (Most nodes are going to have a length that fits
       1-2 bytes.)
-      
+
       An alternative form would be to use the base-128 encoding.  (If the MSB
       is set, then the next byte needs to be added to the current value
       shifted by 7*n bits.) This encodes 4GiB in 5 bytes, but stores 127B in 1
@@ -470,5 +470,5 @@
 group pointer, we can refer to 16.7M groups. It does add complexity, but it is
 likely necessary to allow for arbitrary cases.
 
-.. 
+..
   vim: ft=rst tw=78 ai

=== modified file 'doc/developers/incremental-push-pull.txt'
--- doc/developers/incremental-push-pull.txt	2009-02-22 16:54:02 +0000
+++ doc/developers/incremental-push-pull.txt	2009-12-02 20:34:07 +0000
@@ -94,8 +94,8 @@
       found to be a subset of the other, or a complete list of revisions to be
       transmitted is created.
 
- * Uncommon cases: 
-   
+ * Uncommon cases:
+
    1. Repositories with many projects or branches which are very old may
       require reading a lot of unrelated graph data.
 
@@ -109,7 +109,7 @@
  2. Determine one sided graph difference. To avoid obtaining a full graph over
     the wire this needs to be done without reference to the full graph, and
     with some logarthmic scaling algorithm. There are several already available
-    for this. 
+    for this.
 
 With ghost and new-signature detection:
 
@@ -219,7 +219,7 @@
 Data grouping:
 
 * File per full identifier (fileid:revisionid:meta|content): 104000
-* Delta-chain per object: object id count * constant overhead per object id 
+* Delta-chain per object: object id count * constant overhead per object id
   (26 -> 80006)
 * Collation/pack file: 1
 
@@ -251,7 +251,7 @@
 
  #. setup
 
-   look at graph of revisions for ~N comits to deretmine eligibility for 
+   look at graph of revisions for ~N comits to deretmine eligibility for
    if preserve mainline is on, check LH only
 
     identify objects to send that are not on the client repo

=== added file 'doc/developers/index-plain.txt'
--- doc/developers/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,146 @@
+=================================
+Bazaar Developer Document Catalog
+=================================
+
+
+Overall developer documentation
+===============================
+
+* `Developer Guide <HACKING.html>`_
+
+* `Architectural Overview <overview.html>`_ |--| describes some of the
+  most important classes and concepts.
+
+* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_
+  (external link)
+  |--| automatically generated API reference information
+
+* `Integrating with Bazaar <http://bazaar-vcs.org/Integrating_with_Bazaar>`_
+  (wiki) |--| a guide for writing Python programs that work with Bazaar.
+
+* `Revision Properties <revision-properties.html>`_ |--| An application
+  can set arbitrary per-revision key/value pairs to store app-specific
+  data.
+
+* `Testing <testing.html>`_ |--| Guide to writing tests for Bazaar.
+
+* `Writing plugins <http://bazaar-vcs.org/WritingPlugins>`_ (wiki)
+  |--| specific advice on writing Bazaar plugins.
+
+Process
+=======
+
+* `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
+  development cycle and how to run it.
+
+* `Releasing Bazaar <releasing.html>`_ |--|
+  Checklist to make a release of Bazaar.
+
+* `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
+
+* `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
+  your changes to Bazaar integrated into a release.
+
+* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile
+  bzr code and visualize the results.
+
+* `EC2 resources <ec2.html>`_ |--| A team resource for
+  Windows packaging and testing, and Ubuntu testing.
+
+* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug
+  tracker.
+
+Plans
+=====
+
+* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap
+  for fixing performance in bzr over the next few releases.
+
+* `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
+  for storing multiple branches in one file-system directory.
+
+* `Bazaar Windows Shell Extension Options <tortoise-strategy.html>`_ |--|
+  Implmentation strategy for Bazaar Windows Shell Extensions, aka
+  TortoiseBzr.
+
+* `CHK Optimized index <improved_chk_index.html>`_
+
+Specifications
+==============
+
+* `API versioning <api-versioning.html>`_ |--| bzrlib API versioning.
+
+* `Apport error reporting <apport.html>`_ |--| Capture data to report
+  bugs.
+
+* `Authentication ring <authentication-ring.html>`_ |--| Configuring
+  authentication.
+
+* `Bundles <bundles.html>`_ |--| All about bzr bundles.
+
+* `Container format <container-format.html>`_ |--| Notes on a container format
+  for streaming and storing Bazaar data.
+
+* `Groupcompress <groupcompress-design.html>`_ |--| Notes on the compression
+  technology used in CHK repositories.
+
+* `Indices <indices.html>`_ |--| The index facilities available within bzrlib.
+
+* `Inventories <inventory.html>`_ |--| Tree shape abstraction.
+
+* `LCA merge <lca-merge.html>`_ |--| A nice new merge algorithm.
+
+* `Network protocol <network-protocol.html>`_ |--| Custom network protocol.
+
+* `Plugin APIs <plugin-api.html>`_ |--| APIs plugins should use.
+
+* `Repositories <repository.html>`_ |--| What repositories do and are used for.
+
+* `Repository stream <repository-stream.html>`_ |--| Notes on streaming data
+  for repositories (a layer above the container format).
+
+* `Integration Guide <integration.html>`_ |--| A guide to integrate bzrlib into
+  any python application.
+
+* `Bazaar and case-insensitive file systems <case-insensitive-file-systems.html>`_
+  |--| How Bazaar operates on case-insensitive file systems such as commonly
+  found on Windows, USB sticks, etc.
+
+* `Development repository formats <development-repo.html>`_ |--| How to
+  work with repository formats that are still under development.
+  Contains instructions for those implementing new formats, of course,
+  but also for (bleeding-edge) end users of those formats.
+
+Data formats
+============
+
+* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories
+  (new in Bazaar 0.92).
+
+Implementation notes
+====================
+
+* `BTree Index Prefetch <btree_index_prefetch.html>`_ |--| How bzr decides
+  to pre-read extra nodes in the btree index.
+
+* `Computing last_modified values <last-modified.html>`_ for inventory
+  entries
+
+* `Content filtering <content-filtering.html>`_
+
+* `LCA Tree Merging <lca_tree_merging.html>`_ |--| Merging tree-shape when
+  there is not a single unique ancestor (criss-cross merge).
+
+Miscellaneous
+=============
+
+* `dirstate <dirstate.html>`_ |--| An observation re. the dirstate file
+
+* `"bzr update" performance analysis <update.html>`_ |--| "bzr update"
+  performance analysis
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/index.txt'
--- doc/developers/index.txt	2009-08-26 03:20:32 +0000
+++ doc/developers/index.txt	2009-12-02 20:34:07 +0000
@@ -3,141 +3,53 @@
 =================================
 
 
-Overall developer documentation
-===============================
-
-* `Developer Guide <../en/developer-guide/HACKING.html>`_
-
-* `Architectural Overview <overview.html>`_ |--| describes some of the
-  most important classes and concepts.
-
-* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_ 
-  (external link)
-  |--| automatically generated API reference information
-
-* `Integrating with Bazaar <http://bazaar-vcs.org/Integrating_with_Bazaar>`_
-  (wiki) |--| a guide for writing Python programs that work with Bazaar.
-
-* `Revision Properties <revision-properties.html>`_ |--| An application
-  can set arbitrary per-revision key/value pairs to store app-specific
-  data.
-
-* `Testing <testing.html>`_ |--| Guide to writing tests for Bazaar.
-
-* `Writing plugins <http://bazaar-vcs.org/WritingPlugins>`_ (wiki) 
-  |--| specific advice on writing Bazaar plugins.
-
-Process
-=======
-
-* `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
-  development cycle and how to run it.
-  
-* `Releasing Bazaar <releasing.html>`_ |--| 
-  Checklist to make a release of Bazaar.
-
-* `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
-
-* `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
-  your changes to Bazaar integrated into a release.
-
-* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile 
-  bzr code and visualize the results.
-
-* `EC2 resources <ec2.html>`_ |--| A team resource for 
-  Windows packaging and testing, and Ubuntu testing.
-
-* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug 
-  tracker.
-
-Plans
-=====
-
-* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap 
-  for fixing performance in bzr over the next few releases.
-
-* `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
-  for storing multiple branches in one file-system directory.
-
-* `Bazaar Windows Shell Extension Options <tortoise-strategy.html>`_ |--|
-  Implmentation strategy for Bazaar Windows Shell Extensions, aka
-  TortoiseBzr.
-
-* `CHK Optimized index <improved_chk_index.html>`_
-
-Specifications
-==============
-
-* `API versioning <api-versioning.html>`_ |--| bzrlib API versioning.
-
-* `Apport error reporting <apport.html>`_ |--| Capture data to report
-  bugs.
-
-* `Authentication ring <authentication-ring.html>`_ |--| Configuring
-  authentication.
-
-* `Bundles <bundles.html>`_ |--| All about bzr bundles.
-
-* `Container format <container-format.html>`_ |--| Notes on a container format
-  for streaming and storing Bazaar data.
-
-* `Groupcompress <groupcompress-design.html>`_ |--| Notes on the compression
-  technology used in CHK repositories.
-
-* `Indices <indices.html>`_ |--| The index facilities available within bzrlib.
-
-* `Inventories <inventory.html>`_ |--| Tree shape abstraction.
-
-* `LCA merge <lca-merge.html>`_ |--| A nice new merge algorithm.
-
-* `Network protocol <network-protocol.html>`_ |--| Custom network protocol.
-
-* `Plugin APIs <plugin-api.html>`_ |--| APIs plugins should use.
-
-* `Repositories <repository.html>`_ |--| What repositories do and are used for.
-
-* `Repository stream <repository-stream.html>`_ |--| Notes on streaming data
-  for repositories (a layer above the container format).
-
-* `Integration Guide <integration.html>`_ |--| A guide to integrate bzrlib into
-  any python application.
-
-* `Bazaar and case-insensitive file systems <case-insensitive-file-systems.html>`_
-  |--| How Bazaar operates on case-insensitive file systems such as commonly
-  found on Windows, USB sticks, etc.
-
-* `Development repository formats <development-repo.html>`_ |--| How to
-  work with repository formats that are still under development.
-  Contains instructions for those implementing new formats, of course,
-  but also for (bleeding-edge) end users of those formats.
-
-Data formats
+Introduction
 ============
 
-* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories 
-  (new in Bazaar 0.92).
-
-Implementation notes
-====================
-
-* `BTree Index Prefetch <btree_index_prefetch.html>`_ |--| How bzr decides
-  to pre-read extra nodes in the btree index.
-
-* `Computing last_modified values <last-modified.html>`_ for inventory
-  entries
-
-* `Content filtering <content-filtering.html>`_
-
-* `LCA Tree Merging <lca_tree_merging.html>`_ |--| Merging tree-shape when
-  there is not a single unique ancestor (criss-cross merge).
-
-Miscellaneous
-=============
-
-* `dirstate <dirstate.html>`_ |--| An observation re. the dirstate file
-
-* `"bzr update" performance analysis <update.html>`_ |--| "bzr update"
-  performance analysis
+.. toctree::
+   :maxdepth: 1
+
+   contribution-quickstart
+
+
+Enhancing Bazaar
+================
+
+.. toctree::
+   :maxdepth: 1
+
+   process
+   HACKING
+   testing
+
+* `Bazaar Writer Guide <http://bazaar-vcs.org/ContributingToTheDocs>`_ (web link)
+
+
+Developing using bzrlib
+=======================
+
+.. toctree::
+   :maxdepth: 1
+
+   overview
+   integration
+
+* `Writing plugins for Bazaar <http://bazaar-vcs.org/WritingPlugins>`_ (web link)
+
+* `bzrlib API reference <http://starship.python.net/crew/mwh/bzrlibapi/>`_
+  (web link)
+
+
+Other documents
+===============
+
+.. toctree::
+   :maxdepth: 1
+
+   plans
+   specifications
+   implementation-notes
+   miscellaneous-notes
 
 
 .. |--| unicode:: U+2014

=== modified file 'doc/developers/integration.txt'
--- doc/developers/integration.txt	2008-04-08 10:55:41 +0000
+++ doc/developers/integration.txt	2009-09-15 06:07:11 +0000
@@ -197,7 +197,7 @@
 
   from bzrlib import branch
 
-  b = branch.Branch.open('http://bazaar-vcs.org/bzr/bzr.dev')
+  b = branch.Branch.open('http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev')
   nb = b.bzrdir.sprout('/tmp/newBzrBranch').open_branch()
 
 
@@ -213,7 +213,7 @@
   from bzrlib import branch
 
   b1 = branch.Branch.open('file:///home/user/mybranch')
-  b2 = branch.Branch.open('http://bazaar-vcs.org/bzr/bzr.dev')
+  b2 = branch.Branch.open('http://bazaar.launchpad.net/~bzr-pqm/bzr/bzr.dev')
   b1.push(b2)
 
 
@@ -244,12 +244,12 @@
 
   source.create_checkout('/tmp/newBzrCheckout', None, False, accelerator_tree
 
-==================
+
 History Operations
 ==================
 
 Finding the last revision number or id
-======================================
+--------------------------------------
 
 To get the last revision number and id of a branch use::
 
@@ -263,7 +263,7 @@
 
 
 Getting the list of revision ids that make up a branch
-======================================================
+------------------------------------------------------
 
 IMPORTANT: This should be avoided wherever possible, as it scales with the
 length of history::
@@ -277,7 +277,7 @@
 
 
 Getting a Revision object from a revision id
-============================================
+--------------------------------------------
 
 The Revision object has attributes like "message" to get the information
 about the revision::
@@ -287,7 +287,7 @@
 
 
 Accessing the files from a revision
-===================================
+-----------------------------------
 
 To get the file contents and tree shape for a specific revision you need
 a RevisionTree. These are supplied by the repository for a specific

=== modified file 'doc/developers/inventory.txt'
--- doc/developers/inventory.txt	2009-08-26 03:20:32 +0000
+++ doc/developers/inventory.txt	2009-12-02 20:34:07 +0000
@@ -49,7 +49,7 @@
 that an inventory is stored as. We have a number of goals we want to achieve:
 
  1. Allow commit to write less than the full tree's data in to the repository
-    in the general case. 
+    in the general case.
  2. Allow the data that is written to be calculated without examining every
     versioned path in the tree.
  3. Generate the exact same representation for a given inventory regardless of
@@ -83,7 +83,7 @@
 -----------------
 
 The xml based implementation we use today layers the inventory as a bytestring
-which is stored under a single key; the bytestring is then compressed as a 
+which is stored under a single key; the bytestring is then compressed as a
 delta against the bytestring of its left hand parent by the knit code.
 
 Gap analysis:
@@ -140,8 +140,8 @@
 -------------------------------------------------------------------------
 
  * Split up the logical document into smaller serialised fragements. For
-   instance hash buckets or nodes in a tree of some sort. By serialising in 
-   smaller units, we can increase the number of smaller units rather than 
+   instance hash buckets or nodes in a tree of some sort. By serialising in
+   smaller units, we can increase the number of smaller units rather than
    their size as the tree grows; as long as two similar trees have similar
    serialised forms, the amount of different content should be quite high.
 
@@ -166,7 +166,7 @@
 
  * Working tree to arbitrary history revision deltas/comparisons can be scaled
    up by doing a two-step (fixed at two!) delta combining - delta(tree, basis)
-   and then combine that with delta(basis, arbitrary_revision) using the 
+   and then combine that with delta(basis, arbitrary_revision) using the
    repositories ability to get a delta cheaply.
 
  * The key primitives we need seem to be:
@@ -263,7 +263,7 @@
 
 The path and content maps are populated simply by serialising every inventory
 entry and inserting them into both the path map and the content map. The maps
-start with just a single leaf node with an empty prefix. 
+start with just a single leaf node with an empty prefix.
 
 
 Apply
@@ -439,10 +439,10 @@
    formerly linked. (This will normally bubble down due to keeping densely
    packed nodes).
    To shrink the prefix of a leaf node, create an internal node with the same
-   prefix, then choose a width for the internal node such that the contents 
+   prefix, then choose a width for the internal node such that the contents
    of the leaf all fit into new leaves obeying the min_size and max_size rules.
    The largest prefix possible should be chosen, to obey the
-   higher-nodes-are-denser rule. That rule also gives room in leaf nodes for 
+   higher-nodes-are-denser rule. That rule also gives room in leaf nodes for
    growth without affecting the parent node packing.
 #. Update the CHK pointers - serialise every altered node to generate a CHK,
    and update the CHK placeholder in the nodes parent; then reserialise the
@@ -590,7 +590,7 @@
 
 Different trees can use different algorithms to expand the request as long as
 they produce consistent deltas. As part of getting a consistent UI we require
-that all trees expand the paths requested downwards. Beyond that as long as 
+that all trees expand the paths requested downwards. Beyond that as long as
 the delta is consistent it is up to the tree.
 
 Given two trees, source and target, and a set of selected file ids to check for
@@ -598,7 +598,7 @@
 the following rules, to get consistent deltas. The test for consistency is that
 if the resulting delta is applied to source, to create a third tree 'output',
 and the paths in the delta match the paths in source and output, only one file
-id is at each path in output, and no file ids are missing parents, then the 
+id is at each path in output, and no file ids are missing parents, then the
 delta is consistent.
 
 Firstly, the parent ids to the root for all of the file ids that have actually

=== modified file 'doc/developers/last-modified.txt'
--- doc/developers/last-modified.txt	2007-08-06 22:22:58 +0000
+++ doc/developers/last-modified.txt	2009-12-02 20:34:07 +0000
@@ -30,7 +30,7 @@
 If there is still more than one head, a new last_modified is assigned.
 This points to the merge point in the file graph.
 
-If the file text and properties are the same as the sole remaining head, 
+If the file text and properties are the same as the sole remaining head,
 its last_modified is inherited. Property changes include executable bit,
 filename, and containing directory.
 
@@ -53,7 +53,7 @@
 For the single-parent commit case, we just need to determine which files have
 changed compared to the parent.  If the file was changed, it gets the
 revision id of the new revision; otherwise it inherits the value from the
-parent tree.  
+parent tree.
 
 In the multi-parent commit case (commit of a merge), it can take the value
 from any of the parent trees, or of the new revision.
@@ -74,11 +74,11 @@
 in fact do this even when not using per-file graphs.  In the current
 dirstate format we need to store the full data for all trees because they
 can be extracted from the dirstate, but it could mark some parents as
-already merged.  
+already merged.
 
 Alternatively, we could change the dirstate to include
 only the base and current trees, and cache the merged-in parents
-elsewhere. 
+elsewhere.
 
 (Offtopic other dirstate changes: we could also omit the working-copy
 hash, and just have a stat-fingerprint of when it was last known equal to
@@ -89,7 +89,7 @@
 Generation during conversion
 ----------------------------
 
-Accessing a foreign branch requires synthesizing this information. 
+Accessing a foreign branch requires synthesizing this information.
 If last_modified is removed from a future bzr version, we will also need
 to synthesize it to pull back to earlier formats.
 
@@ -172,5 +172,5 @@
 For a single file, if I am different from all parents, 'new'. (Do not need
 to evaluate last modified).
 
-..   
+..
   vim: ft=rst tw=74

=== added file 'doc/developers/miscellaneous-notes.txt'
--- doc/developers/miscellaneous-notes.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/miscellaneous-notes.txt	2009-09-07 07:44:36 +0000
@@ -0,0 +1,20 @@
+Miscellaneous notes
+===================
+
+.. toctree::
+   :hidden:
+
+   dirstate
+   update
+
+
+* `dirstate <dirstate.html>`_ |--| An observation re. the dirstate file
+
+* `"bzr update" performance analysis <update.html>`_ |--| "bzr update"
+  performance analysis
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/network-protocol.txt'
--- doc/developers/network-protocol.txt	2009-04-04 02:50:01 +0000
+++ doc/developers/network-protocol.txt	2009-12-02 20:34:07 +0000
@@ -172,13 +172,13 @@
 
 An extension to version two allows streamed bodies.  A streamed body looks
 a lot like HTTP's chunked encoding::
- 
+
   STREAMED_BODY := "chunked" NEWLINE CHUNKS TERMINATOR
   CHUNKS := CHUNK [CHUNKS]
   CHUNK := HEX_LENGTH CHUNK_CONTENT
   HEX_LENGTH := HEX_DIGITS NEWLINE
   CHUNK_CONTENT := bytes
-  
+
   TERMINATOR := SUCCESS_TERMINATOR | ERROR_TERMINATOR
   SUCCESS_TERMINATOR := 'END' NEWLINE
   ERROR_TERMINATOR := 'ERR' NEWLINE CHUNKS SUCCESS_TERMINATOR
@@ -201,7 +201,7 @@
 -------------
 
 .. note::
-  
+
   For some discussion of the requirements that led to this new protocol
   version, see `bug #83935`_.
 
@@ -226,7 +226,7 @@
   HEADERS := LENGTH_PREFIX bencoded_dict
   END_MESSAGE := "e"
 
-  BODY := MESSAGE_PART+ 
+  BODY := MESSAGE_PART+
   MESSAGE_PART := ONE_BYTE | STRUCTURE | BYTES
   ONE_BYTE := "o" byte
   STRUCTURE := "s" LENGTH_PREFIX bencoded_structure
@@ -262,10 +262,10 @@
 Conventional requests will send a CONTENTS of ::
 
   CONV_REQ := ARGS SINGLE_OR_STREAMED_BODY?
-  SINGLE_OR_STREAMED_BODY := BYTES 
+  SINGLE_OR_STREAMED_BODY := BYTES
         | BYTES+ TRAILER
-         
-  ARGS := STRUCTURE(argument_tuple) 
+
+  ARGS := STRUCTURE(argument_tuple)
   TRAILER := SUCCESS_STATUS | ERROR
   SUCCESS_STATUS := ONE_BYTE("S")
   ERROR := ONE_BYTE("E") STRUCTURE(argument_tuple)
@@ -276,7 +276,7 @@
   RESP_STATUS := ONE_BYTE("S") | ONE_BYTE("E")
 
 If the RESP_STATUS is success ("S"), the arguments are the
-method-dependent result.  
+method-dependent result.
 
 For errors (where the Status byte of a response or a streamed body is
 "E"), the situation is analagous to requests.  The first item in the
@@ -287,7 +287,7 @@
 Note that the streamed body from version two is now just multiple
 BYTES parts.
 
-The end of the request or response is indicated by the lower-level 
+The end of the request or response is indicated by the lower-level
 END_MESSAGE.  If there's only one BYTES element in the body, the TRAILER
 may or may not be present, depending on whether it was sent as a single
 chunk or as a stream that happens to have one element.
@@ -304,7 +304,7 @@
   initial success and then another byte part with no intervening bytes.
   If we stop sending the final success message and only flag errors
   they'll only get one if the error is detected after streaming starts but
-  before any bytes are actually sent.  Possibly we should wait until at 
+  before any bytes are actually sent.  Possibly we should wait until at
   least the first chunk is ready before declaring success.
 
 For new methods, these sequences are just a convention and may be varied
@@ -320,12 +320,12 @@
   be preserved in the rpc from end to end.  This may be useful when
   there's an iterator on one side feeding in to an iterator on the other,
   if it avoids doing chunking and byte-counting at two levels, and if
-  those iterators are a natural place to get good granularity.  Also, for 
+  those iterators are a natural place to get good granularity.  Also, for
   cases like ``insert_record_stream`` the server can't do much with the
   data until it gets a whole chunk, and so it'll be natural and efficient
   for it to be called with one chunk at a time.
 
-  On the other hand, there may be times when we've got some bytes from the 
+  On the other hand, there may be times when we've got some bytes from the
   network but not a full chunk, and it might be worthwhile to pass it up.
   If we promise to preserve chunks, then to do this we'd need two separate
   streaming interfaces: "we got a chunk" and "we got some bytes but not
@@ -431,11 +431,13 @@
 tricks).  The default implementation in bzrlib does this using the
 `bzrlib.transport.chroot` module.
 
-URLs that include ~ should probably be passed across to the server
-verbatim and the server can expand them.  This will proably not be
-meaningful when limited to a directory?  See `bug 109143`_.
+URLs that include ~ are passed across to the server verbatim and the
+server can expand them.  The default implementation in bzrlib does this
+using `bzrlib.transport.pathfilter` and `os.path.expanduser`, taking care
+to respect the virtual root.
 
-.. _bug 109143: https://bugs.launchpad.net/bzr/+bug/109143
+Paths in request arguments are UTF-8 encoded, except for the legacy VFS
+requests which expect escaped (`bzrlib.urlutils.escape`) paths.
 
 
 Requests

=== modified file 'doc/developers/overview.txt'
--- doc/developers/overview.txt	2009-03-20 02:08:23 +0000
+++ doc/developers/overview.txt	2009-12-02 20:34:07 +0000
@@ -12,16 +12,9 @@
 document, send a merge request or new text to the mailing list.
 
 The current version of this document is available in the file
-``doc/developers/overview.txt`` in the source tree, and from 
-<http://doc.bazaar-vcs.org/bzr.dev/>.
-
-See also:
-
- * `Bazaar Developer Documentation Catalog <index.html>`_.
- * `Bazaar Developer Guide <../en/developer-guide/HACKING.html>`_
-   (particularly the *Coding Style Guidelines* section.)
-
-.. contents::
+``doc/developers/overview.txt`` in the source tree, and available online
+within the developer documentation, <http://doc.bazaar-vcs.org/developers/>.
+
 
 Essential Domain Classes
 ########################
@@ -108,11 +101,11 @@
 store a full text of the inventory, and of every new file text.
 
 At runtime, repository stacking is actually configured by the branch, not
-the repository.  So doing ``a_bzrdir.open_repository()`` 
-gets you just the single physical repository, while 
-``a_bzrdir.open_branch().repository`` gets one configured with a stacking. 
+the repository.  So doing ``a_bzrdir.open_repository()``
+gets you just the single physical repository, while
+``a_bzrdir.open_branch().repository`` gets one configured with a stacking.
 Therefore, to permanently change the fallback repository stored on disk,
-you must use ``Branch.set_stacked_on_url``.  
+you must use ``Branch.set_stacked_on_url``.
 
 Changing away from an existing stacked-on URL will copy across any
 necessary history so that the repository remains usable.

=== modified file 'doc/developers/performance-use-case-analysis.txt'
--- doc/developers/performance-use-case-analysis.txt	2007-06-18 02:04:20 +0000
+++ doc/developers/performance-use-case-analysis.txt	2009-12-02 20:34:07 +0000
@@ -1,6 +1,6 @@
 .. This document describes _how_ to do use case analyses and what we want
 .. to get out of them; for the specific cases see the files referenced by
-.. performance-roadmap.txt 
+.. performance-roadmap.txt
 
 Analysing a specific use case
 =============================
@@ -55,7 +55,7 @@
 - scaling: how does performance change when any of the follow aspects
   of the system are ratcheted massively up or down:
 
-   - number of files/dirs/symlinks/subtrees in a tree (both working and 
+   - number of files/dirs/symlinks/subtrees in a tree (both working and
      revision trees)
    - size of any particular file
    - number of elements within a single directory
@@ -77,9 +77,9 @@
    - bandwidth when performing semantic operations.
 
 - locality of reference: If an operation requires data that is located
-  within a small region at any point, we often get better performance 
+  within a small region at any point, we often get better performance
   than with an implementation of the same operation that requires the
-  same amount of data but with a lower locality of reference. Its 
+  same amount of data but with a lower locality of reference. Its
   fairly tricky to add locality of reference after the fact, so I think
   its worth considering up front.
 
@@ -89,7 +89,7 @@
 measurements, in an ideal world there would be no more than one round
 trip for each semantic operation. What there must not be is one round
 trip per revision involved in the revisionid->dotted number mapping, nor
-per each revision id attributed to a line in the text. 
+per each revision id attributed to a line in the text.
 
 Not all the items mentioned above are created equal. The analysis should
 include the parameters considered and the common case values for each - the

=== modified file 'doc/developers/planned-change-integration.txt'
--- doc/developers/planned-change-integration.txt	2009-06-10 05:03:42 +0000
+++ doc/developers/planned-change-integration.txt	2009-12-02 20:34:07 +0000
@@ -37,7 +37,7 @@
    provide strong feedback to the design process for those things which are
    considered optional or removable, so these APIs should be implemented
    before removing or making optional existing data.
- 
+
  * Deprecating versioned files as a supported API: This collaborates with the
    Repository API but can probably be done by adding a replacement API for
    places where the versioned-file api is used. We may well want to keep a
@@ -54,7 +54,7 @@
    layer changes to inventories so while we can create a revision validator
    API, we cannot create the final one until we have the inventory structural
    changes completed.
- 
+
  * Annotation caching API: This API is a prerequisite for new repository
    formats. If written after they are introduced we may find that the
    repository is lacking in functionality, so the API should be implemented
@@ -87,7 +87,7 @@
    of the newer API for accessing data about a file over time. It can be a
    separate step easily; but as it's in the same area of the library should not
    be done in parallel.
-  
+
  * Repository stacking API: The key dependency/change required for this is that
    repositories must individually be happy with having partial data - e.g. many
    ghosts. However the way the API needs to be used should be driven from the
@@ -97,7 +97,7 @@
    On the data insertion side commit will want to generate new data. The
    commands pull, bundle, merge, push, possibly uncommit will want to copy
    existing data in a streaming fashion.
- 
+
  * New container format: Its hard to tell what the right way to structure the
    layering is. Probably having smooth layering down to the point that code
    wants to operate on the containers directly will make this more clear. As
@@ -129,7 +129,7 @@
  * Delta storage optimisation: This has a strict dependency on a new repository
    format. Optimisation takes many forms - we probably cannot complete the
    desired optimisations under knits though we could use xdelta within a
-   knit-variation. 
+   knit-variation.
 
  * Greatest distance from origin cache: The potential users of this exist
    today, it is likely able to be implemented immediately, but we are not sure

=== modified file 'doc/developers/planned-performance-changes.txt'
--- doc/developers/planned-performance-changes.txt	2009-04-04 02:57:47 +0000
+++ doc/developers/planned-performance-changes.txt	2009-12-02 20:34:07 +0000
@@ -93,7 +93,7 @@
  * New container format to allow single-file description of multiple named
    objects. This will provide the basis for transmission of revisions over the
    network, the new bundle format, and possibly a new repository format as
-   well. [Core implemented] 
+   well. [Core implemented]
 
  * Separate the annotation cache from the storage of actual file texts and make
    the annotation style, and when to do it, configurable. This will reduce data

=== added file 'doc/developers/plans.txt'
--- doc/developers/plans.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/plans.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,29 @@
+Plans
+=====
+
+.. toctree::
+   :hidden:
+
+   performance-roadmap
+   colocated-branches
+   tortoise-strategy
+   improved_chk_index
+
+
+* `Performance roadmap <performance-roadmap.html>`_ |--| The roadmap
+  for fixing performance in bzr over the next few releases.
+
+* `Co-located branches <colocated-branches.html>`_ |--| Planned(?) support
+  for storing multiple branches in one file-system directory.
+
+* `Bazaar Windows Shell Extension Options <tortoise-strategy.html>`_ |--|
+  Implmentation strategy for Bazaar Windows Shell Extensions, aka
+  TortoiseBzr.
+
+* `CHK Optimized index <improved_chk_index.html>`_
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/plugin-api.txt'
--- doc/developers/plugin-api.txt	2009-08-03 11:37:53 +0000
+++ doc/developers/plugin-api.txt	2009-12-02 20:34:07 +0000
@@ -128,7 +128,7 @@
 
   # (look for a .hg directory)
   bzr_control_formats = {"Mercurial":{'.hg/': None}}
-  
+
   # (look for a file called .svn/format with contents 4\n).
   bzr_control_formats = {"Subversion":{'.svn/format': '4\n'}}
 
@@ -137,15 +137,15 @@
 -------
 
 An example setup.py follows::
-  
+
   #!/usr/bin/env python2.4
   from distutils.core import setup
-  
+
   bzr_plugin_name = 'demo'
   bzr_commands = [
       'new-command',
       ]
-  
+
   bzr_branch_formats = {
       "Branch label on disk\n":"demo branch",
       }
@@ -153,10 +153,10 @@
   bzr_control_formats = {"Subversion":{'.svn/format': '4\n'}}
 
   bzr_transports = ["hg+ssh://"]
-  
+
   bzr_plugin_version = (1, 3, 0, 'dev', 0)
   bzr_minimum_version = (1, 0, 0)
-  
+
   if __name__ == 'main':
       setup(name="Demo",
             version="1.3.0dev0",

=== modified file 'doc/developers/ppa.txt'
--- doc/developers/ppa.txt	2009-02-16 10:13:56 +0000
+++ doc/developers/ppa.txt	2009-12-02 20:34:07 +0000
@@ -19,7 +19,7 @@
     Final released versions.
 
 <https://launchpad.net/~bzr-beta-ppa/+archive>
-    Releases and release candidates.    
+    Releases and release candidates.
 
 <https://launchpad.net/~bzr-nightly-ppa/+archive>
     Automatic nightly builds from trunk.
@@ -38,7 +38,7 @@
 versions it is also copied to the main PPA.
 
 The packaging information is kept in branches of bzr on Launchpad, named
-like 
+like
 <https://code.launchpad.net/~bzr/bzr/packaging-hardy>.
 or
 <lp:~bzr/bzr/packaging-hardy>.  These branches are intended to be used
@@ -46,8 +46,8 @@
 
 Preconditions
 -------------
-  
-* You must have a Launchpad account and be a member of the teams 
+
+* You must have a Launchpad account and be a member of the teams
   that own these PPAs (``~bzr``, ``~bzr-beta-ppa``).
 
 * You must have a GPG key registered to your Launchpad account.
@@ -75,7 +75,7 @@
 
     [DEFAULT]
     default_host_main = notspecified
-  
+
 * Configure ``bzr-builddeb`` to sign the package, which is required for
   Launchpad to build it.  Put this in ``~/.bazaar/builddeb.conf`` ::
 
@@ -107,12 +107,16 @@
 release packages is as simple as::
 
   cd ~/dev/bzr/releases/packaging
-  ln ~/dev/bzr/releases/bzr-1.6.tar.gz ./bzr_1.6.orig.tar.gz
-  export UBUNTU_RELEASES="dapper feisty gutsy hardy intrepid"
+  export VERSION="1.17~rc1-1~bazaar1"
+  export PACKAGE="bzr"
+  export UBUNTU_RELEASES="dapper hardy intrepid jaunty karmic"
   ~/dev/bzr/bzr.dev/tools/packaging/update-packaging-branches.sh
-  ~/dev/bzr/bzr.dev/tools/packaging/update-changelogs.sh 1.6~beta3-1~bazaar1
-  ~/dev/bzr/bzr.dev/tools/packaging/build-packages
-  dput bzr-beta-ppa bzr_1.6~beta3-1~bazaar1*.changes
+  ~/dev/bzr/bzr.dev/tools/packaging/update-changelogs.sh
+  ~/dev/bzr/bzr.dev/tools/packaging/update-control.sh 1.16 1.17 1.18
+  ~/dev/bzr/bzr.dev/tools/packaging/build-packages.sh
+  dput bzr-beta-ppa ${PACKAGE}_$VERSION*.changes
+
+Rinse and repeat for all the plugins by changing VERSION and PACKAGE.
 
 Long Form
 ~~~~~~~~~
@@ -121,23 +125,34 @@
    release. Such as ``~/dev/bzr/releases/packaging/hardy``. In each of these
    branches, you will produce the package for the release.
 
+   The scripts will also create the branches and produce packages for
+   bzrtools and bzr-svn.
+
 #. Decide on the final version number.  It should be of this form::
 
-     bzr-1.6~beta3-1~bazaar1~hardy1
+     bzr-1.17~rc1-1~bazaar1~hardy1
 
    **Note:** There are three hyphen-separated parts: the *package name*,
    the *upstream version*, and the *packaging version*.
 
    **Caution:** Upstream betas or release candidates must insert a tilde
    to make them sort before the final release, like this:
-   ``bzr-1.6~beta3-1~bazaar1~hardy1``.
+   ``bzr-1.17~rc1-1~bazaar1~hardy1``.
 
    Final releases will use a release string of the form:
-   ``bzr-1.6-1~bazaar1~hardy1``
+   ``bzr-1.17-1~bazaar1~hardy1``
+
+   Set this base of this up as a usable environment variable::
+
+      export VERSION="1.17~rc1-1~bazaar1"
 
 #. Export the distroreleases that you will be packaging for::
 
-      export UBUNTU_RELEASES="dapper feisty gutsy hardy intrepid jaunty"
+      export UBUNTU_RELEASES="dapper hardy intrepid jaunty karmic"
+
+#. Export the program you are packaging::
+
+      export PACKAGE="bzr"
 
 #. Checkout (or update) the packaging branch for each supported release::
 
@@ -155,26 +170,36 @@
 
    For bzrtools this is typically::
 
-      Build-Depends-Indep: bzr (>= 1.6~), rsync
-      Depends: ${python:Depends}, bzr (>= 1.6~), bzr (<< 1.7~), patch
+      Build-Depends-Indep: bzr (>= 1.17~), rsync
+      Depends: ${python:Depends}, bzr (>= 1.17~), bzr (<< 1.18~), patch
+
+   There is a helper script which will update the control file and commit it
+   for all of your ``$UBUNTU_RELEASES``. It is available as::
+
+    tools/packaging/update-control.sh
+
+   You must supply the versions as arguments as follows
+   OLD_VERSION CURRENT_VERSION NEXT_VERSION, such as::
+
+    tools/packaging/update-control.sh 1.16 1.17 1.18
 
 #. Make a new ``debian/changelog`` entry for the new release,
    either by using ``dch`` or just editing the file::
 
-      dch -v '1.6~beta3-1~bazaar1~hardy1' -D hardy
+      dch -v '1.17~rc1-1~bazaar1~hardy1' -D hardy
 
    dch will default to the distro you're working in and this isn't checked
-   against the version number (which is just our convention), so make sure 
+   against the version number (which is just our convention), so make sure
    to specify it.
 
    Make sure you have the correct email address for yourself (you may need
    export DEBEMAIL=`bzr whoami` if it isn't already set), version number, and
    distribution.  It should look something like this::
 
-       bzr (1.6~beta3-1~bazaar1~hardy1) hardy; urgency=low
-     
+       bzr (1.17~rc1-1~bazaar1~hardy1) hardy; urgency=low
+
         * New upstream release.
-     
+
        -- John Sample <sample@example.com>  Mon, 31 Mar 2008 12:36:27 +1100
 
    If you need to upload the package again to fix a problem, normally you
@@ -185,17 +210,11 @@
 
    You will also want to commit these changes into the packaging branch.
 
-   There is a helper script which will update the changelog and commit it
+   There is a helper script which will build all the packages
    for all of your ``$UBUNTU_RELEASES``. It is available as::
 
       tools/packaging/update-changelogs.sh
 
-   You must supply the release string, such as::
-
-      tools/packaging/update-changelogs.sh 1.6~beta3-1~bazaar1
-
-   It will automatically append the distro numbering on the end.
-
 #. Build the source packages::
 
       cd packaging-$DISTRO; bzr builddeb -S
@@ -207,13 +226,18 @@
 
    where ``$UID`` is the gpg key you want to use to sign the changes.
 
+   There is a helper script which will build the package
+   for all of your ``$UBUNTU_RELEASES``. It is available as::
+
+      tools/packaging/build-packages.sh
+
 #. Upload into the beta PPA for each release::
 
-     dput bzr-beta-ppa bzr_1.6-1*.changes
+     dput bzr-beta-ppa bzr*1.17-1*.changes
 
 #. For final release versions, also copy it into the ``~bzr`` PPA::
 
-     dput bzr-ppa ../bzr_1.6-1\~bazaar1\~hardy1\_source.changes
+     dput bzr-ppa ../bzr_1.17-1\~bazaar1\~hardy1\_source.changes
 
    Alternatively, you can use Launchpad's "copy" feature to copy the
    packages between repositories.
@@ -227,18 +251,20 @@
 Packaging bzr-svn
 ~~~~~~~~~~~~~~~~~
 
-bzr-svn uses a packaging branch that contains both the source 
+bzr-svn uses a packaging branch that contains both the source
 (including any changes against upstream) and the ``debian/`` directory.
 
 To build bzr-svn:
 
 #. Get a checkout of ``lp:~bzr/bzr-svn/hardy-ppa/``
 
-#. Merge from ``http://bzr.debian.org/pkg-bazaar/bzr-svn/experimental/``
-  
+#. Merge from ``http://bzr.debian.org/pkg-bazaar/bzr-svn/unstable/``
+
    This should bring in both upstream and packaging changes for the new
    release, and it's updated as part of the bzr-svn release process.
 
+   It's quite possible you will need to resolve some conflicts.
+
 #. Run ``dch -v 0.4.15-1~bazaar1-hardy1 -D hardy`` or similar
 
 #. Run ``bzr builddeb --source``

=== added file 'doc/developers/process.txt'
--- doc/developers/process.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/process.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,39 @@
+Bazaar Development Processes
+============================
+
+.. toctree::
+   :hidden:
+
+   cycle
+   releasing
+   ppa
+   profiling
+   ec2
+   bug-handling
+
+
+* `The Bazaar Development Cycle <cycle.html>`_ |--| The monthly
+  development cycle and how to run it.
+
+* `Releasing Bazaar <releasing.html>`_ |--|
+  Checklist to make a release of Bazaar.
+
+* `Managing the Bazaar PPA <ppa.html>`_ |--| Packaging Bazaar for Ubuntu.
+
+* `Giving back <http://bazaar-vcs.org/BzrGivingBack>`_ (wiki) |--| How to get
+  your changes to Bazaar integrated into a release.
+
+* `Profiling notes <profiling.html>`_ |--| Instructions on how to profile
+  bzr code and visualize the results.
+
+* `EC2 resources <ec2.html>`_ |--| A team resource for
+  Windows packaging and testing, and Ubuntu testing.
+
+* `Tracking Bugs in Bazaar <bug-handling.html>`_ |--| How we use the bug
+  tracker.
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/profiling.txt'
--- doc/developers/profiling.txt	2007-08-08 14:12:02 +0000
+++ doc/developers/profiling.txt	2009-12-02 20:34:07 +0000
@@ -50,7 +50,7 @@
 global option.
 
 This writes messages into ``~/.bzr.log``.
-At present this only logs actions relating to the on-disk lockdir.  It 
+At present this only logs actions relating to the on-disk lockdir.  It
 doesn't describe actions on in-memory lock counters, or OS locks (which
 are used for dirstate.)
 

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2009-08-28 14:35:26 +0000
+++ doc/developers/releasing.txt	2009-12-02 20:34:07 +0000
@@ -2,11 +2,19 @@
 ================
 
 This document describes the processes for making and announcing a Bazaar
-release, and managing the release process.  This is just one phase of the 
-`overall development cycle <cycle.html>`_, but it's the most complex part.
+release, and managing the release process.  This is just one phase of the
+`overall development cycle <http://doc.bazaar-vcs.org/developers/cycle.html>`_,
+but it's the most complex part.
 This document gives a checklist you can follow from start to end in one
 go.
 
+If you're helping the Release Manager (RM) for one reason or another, you
+may notice that he didn't follow that document scrupulously. He may have
+good reasons to do that but he may also have missed some parts.
+
+Follow the document yourself and don't hesitate to create the missing
+milestones for example (we tend to forget these ones a lot).
+
 .. contents::
 
 
@@ -26,65 +34,55 @@
 #. Create a new series at <https://launchpad.net/bzr/+addseries>. There is one
    series for every *x.y* release.
 
-#. Go to the series web page at <https://launchpad.net/bzr/2.0>
+#. Go to the series web page at <https://launchpad.net/bzr/x.y>
 
 #. Create a new release at
-   <https://launchpad.net/bzr/2.0/+addrelease> and add
+   <https://launchpad.net/bzr/x.y/+addrelease> and add
    information about this release. We will not use it yet, but it
    will be available for targeting or nominating bugs.
 
 #. We create a new pqm-controlled branch for this release series, by
-   asking a Canonical sysadmin.  
+   asking a Canonical sysadmin.
    This branch means that from the first release beta or candidate onwards,
    general development continues on the trunk, and only
    specifically-targeted fixes go into the release branch.
 
-#. Add milestones at <https://edge.launchpad.net/bzr/2.0/+addmilestone> to
+#. Add milestones at <https://edge.launchpad.net/bzr/x.y/+addmilestone> to
    that series for the beta release, release candidate and the final release,
    and their expected dates.
 
 #. Update the version number in the ``bzr`` script, and the
-   ``bzrlib/__init__.py`` file.
+   ``bzrlib/__init__.py`` file. Make sure there is always a corresponding
+   milestone when you change that version number.
 
 #. Send mail to the list with the key dates, who will be the release
    manager, and the main themes or targeted bugs.  Ask people to nominate
    objectives, or point out any high-risk things that are best done early,
    or that interact with other changes. This is called the metronome mail
-   and as RM you're supposed to send other metronome mails at your rythm.
-
-
-Starting the release phase
---------------------------
-
-When it's time to make the first beta release or release candidate:
-
-#. Create a new milestone at <https://launchpad.net/bzr/2.0/+addmilestone>
-   for the beta release or release candidate.
-
-#. Make a beta release or release candidate.
-
-Preparing the tree for release
-------------------------------
-
-#. Make a local branch for preparing this release.  (Only for the first 
+   and is described in `Development cycles <cycle.html>`_.
+
+#. Make a local branch for preparing this release.  (Only for the first
    release in a series, otherwise you should already have a branch.) ::
 
      bzr branch trunk prepare-1.14
 
-#. Configure pqm-submit for this branch, with a section like this in
+#. Configure pqm-submit for this branch, with a section like this (where
+   x.y is the version to release).
    ``~/.bazaar/locations.conf``::
 
-	[/home/mbp/bzr/prepare-1.14]
+	[/home/mbp/bzr/prepare-x.y]
 	pqm_email = Canonical PQM <pqm@bazaar-vcs.org>
-	submit_branch = lp:bzr/2.0
-	public_branch = http://bazaar.example.com/prepare-2.0
+	submit_branch = http://bazaar.launchpad.net/~bzr-pqm/bzr/x.y
+	parent_branch = http://bazaar.launchpad.net/~bzr-pqm/bzr/x.y
+	public_branch = http://bazaar.example.com/prepare-x.y
 	submit_to = bazaar@lists.canonical.com
 	smtp_server = mail.example.com:25
 
-    Please see <http://doc.bazaar-vcs.org/latest/developers/HACKING.html#an-overview-of-pqm>
+    Please see <http://doc.bazaar-vcs.org/developers/HACKING.html#an-overview-of-pqm>
     for more details on PQM
 
 #. In the release branch, update  ``version_info`` in ``./bzrlib/__init__.py``.
+   Make sure the corresponding milestone exists.
    Double check that ./bzr ``_script_version`` matches ``version_info``. Check
    the output of ``bzr --version``.
 
@@ -98,8 +96,21 @@
        version_info = (2, 0, 1, 'candidate', 1)
 
 
+Starting the release phase
+--------------------------
+
+#. Create a new milestone at <https://launchpad.net/bzr/x.y/+addmilestone>
+   for the beta release or release candidate if you haven't already.
+
 #. Add the date and release number to ``./NEWS``
 
+   Depending on whether you're doing a beta or a bugfix release, you'll
+   have to create a NEWS section for your release in the right
+   place. Most of the time, the new section is at the top of the file
+   (look what have been done for the various 2.0x and 2.1.0bx releases).
+   The rule is to keep the sections sorted by date. You'll need to be
+   cautious when merging back to trunk to respect that.
+
 #. To check that all bugs mentioned in ``./NEWS`` are actually marked as
    closed in Launchpad, you can run ``tools/check-newsbugs.py``::
 
@@ -112,18 +123,18 @@
 #. Summarize into one or two paragraphs what's new in this release.
 
 #. Commit these changes to the release branch, using a command like::
-    
-     bzr commit -m "Release 1.14." 
-   
+
+     bzr commit -m "Release 1.14."
+
    The diff before you commit will be something like::
 
      === modified file 'NEWS'
      --- NEWS        2008-09-17 23:09:18 +0000
      +++ NEWS        2008-09-23 16:14:54 +0000
      @@ -4,6 +4,23 @@
-     
+
       .. contents::
-     
+
      +bzr 1.7 2008-09-23
      +------------------
      +
@@ -136,21 +147,21 @@
      +
       bzr 1.7rc2 2008-09-17
       ---------------------
-     
-     
+
+
      === modified file 'bzrlib/__init__.py'
      --- bzrlib/__init__.py  2008-09-16 21:39:28 +0000
      +++ bzrlib/__init__.py  2008-09-23 16:14:54 +0000
      @@ -41,7 +41,7 @@
       # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
       # releaselevel of 'dev' for unreleased under-development code.
-     
+
      -version_info = (1, 7, 0, 'candidate', 2)
      +version_info = (1, 7, 0, 'final', 0)
-     
-     
+
+
       # API compatibility version: bzrlib is currently API compatible with 1.7.
-      
+
 #. Tag the new release::
 
      bzr tag bzr-1.14
@@ -159,7 +170,7 @@
    the Internet. PQM will pull from this repository when it attempts to merge
    your changes. Then submit those changes to PQM for merge into the
    appropriate release branch::
- 
+
      bzr push
      bzr pqm-submit -m "(mbp) prepare 1.14"
 
@@ -170,15 +181,12 @@
 -------------------------
 
 #. Change into the source directory and run ::
-  
+
      make dist
 
-   This also makes a zip file, which is easier to access on Microsoft
-   Windows.
-
 #. Now we'll try expanding this tarball and running the test suite
    to check for packaging problems::
- 
+
      make check-dist-tarball
 
    You may encounter failures while running the test suite caused
@@ -188,10 +196,31 @@
    failures.
 
 
+Publishing the source tarball
+-----------------------------
+
+#. Go to the relevant milestone page in Launchpad.
+
+#. Within that release, upload the source tarball and the GPG
+   signature.  Or, if you prefer, use the
+   ``tools/packaging/lp-upload-release`` script to do this.
+
+
+Announcing the source freeze
+----------------------------
+
+#. Post to the ``bazaar`` list, saying that the source has been frozen.
+   This is the cue for platform maintainers and plugin authors to update
+   their code.  This is done before the general public announcement of the
+   release.
+
+
 Publishing the release
 ----------------------
 
-Now you have the beta or releasable product.  The next step is making it
+There is normally a delay of a few days after the source freeze to allow
+for binaries to be built on various platforms.  Once they have been built,
+we have a releasable product.  The next step is to make it generally
 available to the world.
 
 go to the release
@@ -200,9 +229,14 @@
    signature.  Or, if you prefer, use the
    ``tools/packaging/lp-upload-release`` script to do this.
 
-#. Link from http://bazaar-vcs.org/Download to the tarball and signature.
-
-#. Announce on the `Bazaar home page <http://bazaar-vcs.org/>`_.
+#. Link from http://bazaar-vcs.org/SourceDownloads to the tarball and
+   signature.
+
+#. Announce on the `Bazaar website <http://bazaar-vcs.org/>`_.
+   This page is edited via the lp:bzr-website branch. (Changes
+   pushed to this branch are refreshed by a cron job on escudero.)
+
+#. Announce on the `Bazaar wiki <http://bazaar-vcs.org/Welcome>`_.
 
 #. Check that the documentation for this release is available in
    <http://doc.bazaar-vcs.org>.  It should be automatically build when the
@@ -225,28 +259,28 @@
    ``bazaar-announce`` list too.
 
    For final releases, it should also be cc'd to ``info-gnu@gnu.org``,
-   ``python-announce-list@python.org``, ``bug-directory@gnu.org``.  
+   ``python-announce-list@python.org``, ``bug-directory@gnu.org``.
 
    In all cases, it is good to set ``Reply-To: bazaar@lists.canonical.com``,
    so that people who reply to the announcement don't spam other lists.
 
    The announce mail will look something like this::
-   
+
       Subject: bzr x.yy released!
-      
+
       <<Summary paragraph from news>>
-     
-      The Bazaar team is happy to announce availability of a new 
+
+      The Bazaar team is happy to announce availability of a new
       release of the bzr adaptive version control system.
       Bazaar is part of the GNU system <http://gnu.org/>.
-     
+
       Thanks to everyone who contributed patches, suggestions, and
       feedback.
-      
-      Bazaar is now available for download from 
-      http://bazaar-vcs.org/Download as a source tarball; packages 
+
+      Bazaar is now available for download from
+      http://bazaar-vcs.org/Download as a source tarball; packages
       for various systems will be available soon.
-      
+
       <<NEWS section from this release back to the last major release>>
 
    Feel free to tweak this to your taste.
@@ -257,7 +291,7 @@
    ensuring the new topic text keeps the project name, web site link, etc.
 
 #. Announce on http://freshmeat.net/projects/bzr/
-   
+
    This should be done for beta releases, release candidates and final
    releases. If you do not have a Freshmeat account yet, ask one of the
    existing admins.
@@ -285,10 +319,29 @@
 the version number in ``bzr`` and ``bzrlib/__init__.py``.  Submit this
 back into pqm for bzr.dev.
 
+As soon as you change the version number in trunk, make sure you have
+created the corresponding milestone to ensure the continuity in bug
+targeting or nominating. Depending on the change, you may even have to
+create a new series (if your change the major or minor release number), in
+that case go to `Starting a cycle` and follow the instructions from there.
+
 You should also merge (not pull) the release branch into
 ``lp:~bzr/bzr/current``, so that branch contains the current released code
 at any time.
 
+Releases until the final one
+----------------------------
+
+Congratulations - you have made your first release.  Have a beer
+or fruit juice - it's on the house! If it was a beta, or
+candidate, you're not finished yet. Another beta or candidate or
+hopefully a final release is still to come.
+
+The process is the same as for the first release. Goto `Starting the
+release phase`_ and follow the instructions again. Some details change
+between beta, candidate and final releases, but they should be
+documented. If the instructions aren't clear enough, please fix them.
+
 
 See also
 --------

=== modified file 'doc/developers/repository-stream.txt'
--- doc/developers/repository-stream.txt	2008-04-16 04:07:40 +0000
+++ doc/developers/repository-stream.txt	2009-12-02 20:34:07 +0000
@@ -158,7 +158,7 @@
 record. Each item that the iterator yields is a factory which has metadata
 about the entry and the ability to return the compressed bytes. This
 factory can be decorated to allow obtaining different representations (for
-example from a compressed knit fulltext to a plain fulltext). 
+example from a compressed knit fulltext to a plain fulltext).
 
 In pseudocode::
 

=== modified file 'doc/developers/repository.txt'
--- doc/developers/repository.txt	2008-03-19 09:41:24 +0000
+++ doc/developers/repository.txt	2009-12-02 20:34:07 +0000
@@ -44,7 +44,7 @@
                     introduced by a set of revisions in some cheap form, insert
                     data from a stream, validate data during insertion.
 Garbage Collection  Exclusive lock the repository preventing readers.
-Revert              Delta from working tree to historical tree, and then 
+Revert              Delta from working tree to historical tree, and then
                     arbitrary file access to obtain the texts of differing
                     files.
 Uncommit            Revision graph access.
@@ -98,7 +98,7 @@
                      Scan the inventory data introduced during the selected
                      revisions, and grab the on disk data for the found
                      file texts, annotation region data, per-file-graph
-                     data, piling all this into a stream. 
+                     data, piling all this into a stream.
 Garbage Collection   Basically a mass fetch of all the revisions which
                      branches point at, then a bait and switch with the old
                      repository thus removing unreferenced data.
@@ -106,14 +106,14 @@
                      to, inventory extraction of that revision,
                      dirblock-order file text extract for files that were
                      different.
-Uncommit             Revision graph access to synthesise pending-merges 
+Uncommit             Revision graph access to synthesise pending-merges
                      linear access down left-hand-side, with is_ancestor
                      checks between all the found non-left-hand-side
                      parents.
 Status               Lookup the revisions added by pending merges and their
                      commit messages. Then an inventory difference between
                      the trees involved, which may include a working tree.
-                     If there is a working tree involved then the file 
+                     If there is a working tree involved then the file
                      fingerprint for cache-misses on files will be needed.
                      Note that dirstate caches most of this making
                      repository performance largely irrelevant: but if it
@@ -256,7 +256,7 @@
 delta-compressed ever. Likewise signatures do not need the parent pointers
 at all as there is no 'signature graph'.
 
-Data 
+Data
 ----
 
 Moving to pack based repositories
@@ -273,7 +273,7 @@
 hashing the full file. OTOH hashing the full file is a cheap way to detect
 bit-errors in transfer (such as windows corruption). Non-reused file names
 are required for data integrity, as clients having read an index will
-readv at arbitrary times later. 
+readv at arbitrary times later.
 
 Discovery of files
 ~~~~~~~~~~~~~~~~~~
@@ -304,7 +304,7 @@
 ============================
 
 Repositories try to provide a consistent view of the data within them
-within a 'lock context'. 
+within a 'lock context'.
 
 Locks
 -----
@@ -318,7 +318,7 @@
 write lock, and allow write_groups to be acquired. For some repositories
 the presence of a write lock is exclusive to a single client, for others
 which are lock free or use server side locks (e.g.  svn), the write lock
-simply provides the cache context. 
+simply provides the cache context.
 
 Write Groups
 ------------

=== modified file 'doc/developers/revert.txt'
--- doc/developers/revert.txt	2007-06-05 08:02:04 +0000
+++ doc/developers/revert.txt	2009-12-02 20:34:07 +0000
@@ -21,6 +21,6 @@
  1. Use the hash tree data to tune the work done in finding matching paths/ids which are different in the two trees.
 
 For each thing that needs to change - group by target directory?
- 
+
  1. Extract new content.
  1. Backup old content or replace-in-place (except windows where we move and replace).

=== added file 'doc/developers/specifications.txt'
--- doc/developers/specifications.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/specifications.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,77 @@
+Specifications
+==============
+
+.. toctree::
+   :hidden:
+
+   revision-properties
+   api-versioning
+   apport
+   authentication-ring
+   bundles
+   container-format
+   groupcompress-design
+   indices
+   inventory
+   lca-merge
+   network-protocol
+   plugin-api
+   repository
+   repository-stream
+   case-insensitive-file-systems
+   development-repo
+   packrepo
+
+
+* `Revision Properties <revision-properties.html>`_ |--| An application
+  can set arbitrary per-revision key/value pairs to store app-specific
+  data.
+
+* `API versioning <api-versioning.html>`_ |--| bzrlib API versioning.
+
+* `Apport error reporting <apport.html>`_ |--| Capture data to report
+  bugs.
+
+* `Authentication ring <authentication-ring.html>`_ |--| Configuring
+  authentication.
+
+* `Bundles <bundles.html>`_ |--| All about bzr bundles.
+
+* `Container format <container-format.html>`_ |--| Notes on a container format
+  for streaming and storing Bazaar data.
+
+* `Groupcompress <groupcompress-design.html>`_ |--| Notes on the compression
+  technology used in CHK repositories.
+
+* `Indices <indices.html>`_ |--| The index facilities available within bzrlib.
+
+* `Inventories <inventory.html>`_ |--| Tree shape abstraction.
+
+* `LCA merge <lca-merge.html>`_ |--| A nice new merge algorithm.
+
+* `Network protocol <network-protocol.html>`_ |--| Custom network protocol.
+
+* `Plugin APIs <plugin-api.html>`_ |--| APIs plugins should use.
+
+* `Repositories <repository.html>`_ |--| What repositories do and are used for.
+
+* `Repository stream <repository-stream.html>`_ |--| Notes on streaming data
+  for repositories (a layer above the container format).
+
+* `Bazaar and case-insensitive file systems <case-insensitive-file-systems.html>`_
+  |--| How Bazaar operates on case-insensitive file systems such as commonly
+  found on Windows, USB sticks, etc.
+
+* `Development repository formats <development-repo.html>`_ |--| How to
+  work with repository formats that are still under development.
+  Contains instructions for those implementing new formats, of course,
+  but also for (bleeding-edge) end users of those formats.
+
+* `Knit pack repositories <packrepo.html>`_ |--| KnitPack repositories
+  (new in Bazaar 0.92).
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/developers/status.txt'
--- doc/developers/status.txt	2007-07-02 07:11:25 +0000
+++ doc/developers/status.txt	2009-12-02 20:34:07 +0000
@@ -54,7 +54,7 @@
    our hash cache from the dirstate allows us to avoid reading the file in the
    common case. There are alternative ways to achieve this - we could record
    a pointer to a revision which contained this fileid with the current content
-   rather than storing the content's hash; but this seems to be a pointless 
+   rather than storing the content's hash; but this seems to be a pointless
    double-indirection unless we save enough storage in the working tree. A
    variation of this is to not record an explicit pointer but instead
    define an implicit pointer as being to the left-hand-parent tree.
@@ -92,7 +92,7 @@
   difference for the top level of the selected path) then we can gain a
   larger win. This strongly suggests that path expansion and tree
   difference generation should be linked in terms of API.
- 
+
 
 
 ..

=== modified file 'doc/developers/testing.txt'
--- doc/developers/testing.txt	2009-03-03 01:45:32 +0000
+++ doc/developers/testing.txt	2009-12-02 20:34:07 +0000
@@ -1,11 +1,7 @@
-=======================
-Guide to Testing Bazaar
-=======================
-
-.. contents::
-
-Testing Bazaar
-##############
+====================
+Bazaar Testing Guide
+====================
+
 
 The Importance of Testing
 =========================
@@ -34,10 +30,10 @@
 down the track do not break new features or bug fixes that you are
 contributing today.
 
-As of May 2008, Bazaar ships with a test suite containing over 12000 tests
-and growing. We are proud of it and want to remain so. As community
-members, we all benefit from it. Would you trust version control on
-your project to a product *without* a test suite like Bazaar has?
+As of September 2009, Bazaar ships with a test suite containing over
+23,000 tests and growing. We are proud of it and want to remain so. As
+community members, we all benefit from it. Would you trust version control
+on your project to a product *without* a test suite like Bazaar has?
 
 
 Running the Test Suite
@@ -158,7 +154,7 @@
     cmd_object.run() method directly. This is a lot faster than
     subprocesses and generates the same logging output as running it in a
     subprocess (which invoking the method directly does not).
- 
+
  3. Only test the one command in a single test script. Use the bzrlib
     library when setting up tests and when evaluating the side-effects of
     the command. We do this so that the library api has continual pressure
@@ -201,6 +197,98 @@
   __ http://docs.python.org/lib/module-doctest.html
 
 
+Shell-like tests
+~~~~~~~~~~~~~~~~
+
+``bzrlib/tests/script.py`` allows users to write tests in a syntax very close to a shell session,
+using a restricted and limited set of commands that should be enough to mimic
+most of the behaviours.
+
+A script is a set of commands, each command is composed of:
+
+ * one mandatory command line,
+ * one optional set of input lines to feed the command,
+ * one optional set of output expected lines,
+ * one optional set of error expected lines.
+
+Input, output and error lines can be specified in any order.
+
+Except for the expected output, all lines start with a special
+string (based on their origin when used under a Unix shell):
+
+ * '$ ' for the command,
+ * '<' for input,
+ * nothing for output,
+ * '2>' for errors,
+
+Comments can be added anywhere, they start with '#' and end with
+the line.
+
+The execution stops as soon as an expected output or an expected error is not
+matched.
+
+When no output is specified, any ouput from the command is accepted
+and execution continue.
+
+If an error occurs and no expected error is specified, the execution stops.
+
+An error is defined by a returned status different from zero, not by the
+presence of text on the error stream.
+
+The matching is done on a full string comparison basis unless '...' is used, in
+which case expected output/errors can be less precise.
+
+Examples:
+
+The following will succeeds only if 'bzr add' outputs 'adding file'::
+
+  $ bzr add file
+  >adding file
+
+If you want the command to succeed for any output, just use::
+
+  $ bzr add file
+
+The following will stop with an error::
+
+  $ bzr not-a-command
+
+If you want it to succeed, use::
+
+  $ bzr not-a-command
+  2> bzr: ERROR: unknown command "not-a-command"
+
+You can use ellipsis (...) to replace any piece of text you don't want to be
+matched exactly::
+
+  $ bzr branch not-a-branch
+  2>bzr: ERROR: Not a branch...not-a-branch/".
+
+This can be used to ignore entire lines too::
+
+  $ cat
+  <first line
+  <second line
+  <third line
+  # And here we explain that surprising fourth line
+  <fourth line
+  <last line
+  >first line
+  >...
+  >last line
+
+You can check the content of a file with cat::
+
+  $ cat <file
+  >expected content
+
+You can also check the existence of a file with cat, the following will fail if
+the file doesn't exist::
+
+  $ cat file
+
+
+
 .. Effort tests
 .. ~~~~~~~~~~~~
 
@@ -255,7 +343,7 @@
         The test exists but is known to fail, for example this might be
         appropriate to raise if you've committed a test for a bug but not
         the fix for it, or if something works on Unix but not on Windows.
-        
+
         Raising this allows you to distinguish these failures from the
         ones that are not expected to fail.  If the test would fail
         because of something we don't expect or intend to fix,
@@ -281,7 +369,7 @@
 UnavailableFeature      fail    pass    pass
 KnownFailure            fail    pass    pass
 ======================= ======= ======= ========
-     
+
 
 Test feature dependencies
 -------------------------
@@ -328,13 +416,13 @@
 ``_probe`` and ``feature_name`` methods.  For example::
 
     class _SymlinkFeature(Feature):
-    
+
         def _probe(self):
             return osutils.has_symlinks()
-    
+
         def feature_name(self):
             return 'symlinks'
-    
+
     SymlinkFeature = _SymlinkFeature()
 
 

=== modified file 'doc/developers/tortoise-strategy.txt'
--- doc/developers/tortoise-strategy.txt	2008-05-21 06:33:35 +0000
+++ doc/developers/tortoise-strategy.txt	2009-12-02 20:34:07 +0000
@@ -42,15 +42,15 @@
 exist in a separate process - DLLs are the only option, and they are loaded
 into other processes which take advantage of the Windows shell (although
 obviously this DLL is free to do whatever it likes).
- 
+
 For the sake of this discussion, there are 2 categories of shell extensions:
- 
+
 * Ones that create a new "namespace". The file-system itself is an example of
   such a namespace, as is the "Recycle Bin". For a user-created example,
   picture a new tree under "My Computer" which allows you to browse a remote
   server - it creates a new, stand-alone tree that doesn't really interact
   with the existing namespaces.
- 
+
 * Ones that enhance existing namespaces, including the filesystem. An example
   would be an extension which uses Icon Overlays to modify how existing files
   on disk are displayed or add items to their context menu, for example.
@@ -71,7 +71,7 @@
 this illustration is contrived - the code from these DLLs are already in
 memory and there is no reason to suggest TSVN adds any other unreasonable
 burden - but the general point remains valid.)
- 
+
 This has wide-ranging implications. It means that such shell extensions
 should be developed using a tool which can never cause conflict with
 arbitrary processes. For this very reason, MS recommend against using .NET
@@ -113,7 +113,7 @@
 commands. The command-line to the app has even been documented for people who
 wish to automate tasks using that GUI. This GUI is also implemented in C++
 using Windows resource files.
- 
+
 TortoiseSvn has an option (enabled by default) which enabled a cache using a
 separate process, aptly named TSVNCache.exe. It uses a named pipe to accept
 connections from other processes for various operations. When enabled, TSVN
@@ -149,11 +149,11 @@
 application using the shell. The GUI in the external application is written
 in PyGTK, which may not offer the best Windows "look and feel", but that
 discussion is beyond the scope of this document.
- 
+
 It has a better story for logging and debugging for the developer - but not
 for diagnosing issues in the field - although again, much of the heavy
 lifting remains done by the external application.
- 
+
 It uses a rudimentary in-memory cache for the status of files and
 directories, the implementation of which isn't really suitable (ie, no
 theoretical upper bound on cache size), and also means that there is no
@@ -261,7 +261,7 @@
 We will also allow all of the above to be disabled via user preferences.
 Thus, Icon Overlays could be disabled if it did cause a problem for some
 people, for example.
- 
+
 RPC options
 ~~~~~~~~~~~
 
@@ -433,7 +433,7 @@
   version. We will fork the current TSVN sources, including its new
   support for sharing icon overlays (although advice on how to setup this
   fork is needed!)
- 
+
 * Implement property pages and context menus in C++. Expand RPC server as
   necessary.
 

=== modified file 'doc/developers/update.txt'
--- doc/developers/update.txt	2007-09-03 02:37:35 +0000
+++ doc/developers/update.txt	2009-12-02 20:34:07 +0000
@@ -1,7 +1,7 @@
 "bzr update" performance analysis
 =================================
 
-There are 5 different slightly different situations in which bzr update 
+There are 5 different slightly different situations in which bzr update
 can be used:
 
 * local only (no-op)
@@ -27,7 +27,7 @@
 
 potential issue w/ serialized is having 50k files in limbo/
 
-the limbo/ directory could be avoided in some cases, for example when 
+the limbo/ directory could be avoided in some cases, for example when
 adding new files in new directories.
 
 modifying in place: reduces fragmentation of fs, not atomic
@@ -36,9 +36,9 @@
 
 "local mod" is diff between disk and last commit, not merge base
 
-Detecting name conflicts should be O(siblings). Alternatively, conflicts 
-with existing files can be detected using stat() and conflicts with new files 
-can be detected by examining the pending transform. This changes 
+Detecting name conflicts should be O(siblings). Alternatively, conflicts
+with existing files can be detected using stat() and conflicts with new files
+can be detected by examining the pending transform. This changes
 complexity to O(changes).
 
 out of date heavyweight checkout, out of date w/master

=== added file 'doc/developers/win32_build_setup.txt'
--- doc/developers/win32_build_setup.txt	1970-01-01 00:00:00 +0000
+++ doc/developers/win32_build_setup.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,208 @@
+===============================
+Setting Up A Windows Build Host
+===============================
+
+This document describes the steps taken to set up a Windows build host. It is
+intended to be step-by-step instructions of what packages need to be installed,
+where they can be gotten from, and how they are configured.
+
+
+Baseline
+========
+
+This was written as a step-by-step as I set up the Amazon EC2 'desolation'
+instance. This was based on an Amazon Windows 2003 instance. Also note that for
+Amazon EC2, all programs were installed into the "C:" drive, as the "D:" drive
+is essentially ``/tmp`` and is not preserved between launched instances.
+
+
+Install Packages
+================
+
+1) Download cygwin's setup.exe from http://www.cygwin.com
+   At present the current version is 1.5.25-15. This is used primarily to
+   install the build scripts and gcc-mingw. Note that we explicitly *don't*
+   install cygwin's python or bzr package. As we are only interested in
+   running the native version of bzr. For information on running the cygwin
+   port of bzr, look elsewhere.
+
+   Probably not all of these packages are necessary, but they make life easier.
+
+   a) gcc-mingw32
+   b) make
+   c) openssh
+   d) rsync
+   e) vim
+   f) wget
+   g) zip
+   h) unzip
+   i) patch
+
+
+2) Download the supported versions of python from http://www.python.org
+
+   a) python 2.6.4
+   b) python 2.5.4 http://www.python.org/ftp/python/2.5.4/python-2.5.4.msi
+   c) python 2.4.4 (there is no Windows installer for 2.4.5 or 2.4.6)
+      http://www.python.org/ftp/python/2.4.4/python-2.4.4.msi
+
+   Note that for Amazon EC2, all of these were installed int
+
+3) Configure 'distutils' for the compiler that you will be using. For python
+   2.4 and 2.5 we use gcc-mingw32, for 2.6 we use Visual Studio 2008.
+
+   Edit ``D:\Python25\Lib\disutils\distutils.cfg`` (you have to create the
+   file). You want to add a section like::
+
+     [build]
+     compiler = mingw32
+
+   This also requires 'fixing' the cygwin gcc installation so that distutils
+   can find it. Specifically, it knows to look for ``gcc.exe`` however, the
+   latest versions of cygwin start using "alternatives" and making ``gcc`` just
+   a symlink.
+
+   You also need to add ``C:\cygwin\bin`` and ``C:\cygwin\lib`` into your
+   environment path. This is generally done with::
+
+        Right Click My Computer / Properties / Advanced / Environment Variables
+        System Variables / Select 'PATH' / Edit
+
+4) Download important python libraries. At the moment, the official Windows
+   all-in-one installer is built using python 2.5. We will likely soon switch
+   to python 2.6.
+
+   a) http://pypi.python.org/pypi/setuptools
+
+      Installing this first should make it easier to install some of the other
+      tools. To install something using easy install, it is generally best to
+      open up a ``cmd.exe`` shell (*not* a cygwin shell) and do::
+
+        cd C:\Python25
+        python.exe Scripts\easy_install-script.py -Z -O1 PACKAGE
+
+      The '-Z' tells it to install as a regular directory. This generally works
+      better with py2exe.
+
+   b) pywin32 http://sourceforge.net/projects/pywin32/files/
+   c) easy_install paramiko
+      This will also bring in PyCrypto and compile it, so it is important to
+      have configured step (3) correctly.
+   d) easy_install Pyrex    (or Cython)
+      Note, you should probably install pyrex for all versions of python. All
+      of them need to run 'setup.py bdist_wininst' and so it is good to have it
+      build automatically, rather than setting up an explicit build order based
+      on which one has pyrex.
+   e) easy_install cogapp
+   f) install py2exe (easy_install failed)
+      http://sourceforge.net/projects/py2exe/files/
+   g) easy_install docutils
+   h) Install PyQt
+      http://www.riverbankcomputing.co.uk/software/pyqt/download
+
+      Currently they only seem to offer PyQt 4.4.3 for python 2.5 and PyQt
+      4.6.1 for python 2.6. They generally don't make it easy to install old
+      versions of PyQt.
+   i) Install pyreadline
+      https://launchpad.net/pyreadline/+download
+   j) easy_install pygments
+
+5) Get Pageant, not strictly necessary, but it is a pretty good ssh-agent for
+   Windows, and paramiko knows how to use keys from Pageant.
+
+   http://www.chiark.greenend.org.uk/~sgtatham/putty/download.html
+
+   Note that you probably want to set the environment variable
+   ``BZR_SSH=paramiko`` at this time. Otherwise it will try to use the
+   ``ssh.exe`` that it finds on your PATH (as configured in step 3), and
+   cygwin's openssh does *not* know how to access Pageant.
+
+   I usually get the 'all-in-one' installer, but only because it is easier. You
+   only really need ``pageant.exe`` and possibly ``puttygen.exe``.
+
+   If you do this, you'll probably also want to install a shortcut to
+   ``pageant.exe`` in Start / Programs / Startup so that it always starts when
+   you log in (though you still have to manually add your ssh keys.)
+
+   Note that on the Amazon EC2 machine, I'm having problems with temp files
+   being created without the permission for the current user to actually read
+   them. They seem to be owned by ``Administrator`` rather than by
+   ``Administrators``.
+
+6) Install bzr. Usually it is easiest to just get the latest all-in-one
+   installer from https://launchpad.net/bzr/+download
+
+7) Install INNOSetup from:
+   http://www.jrsoftware.org/isdl.php
+
+   After installing, you'll want to add ``C:\Program Files\Inno Setup 5`` to
+   your PATH.
+
+8) Fix distutils for the specific version of gcc. Distutils in python2.4.4 has
+   a bug where it assumes version strings have only 3 digits. The fix is to
+   just change one '?' in the regex into a '*'::
+
+        --- version.py	2009-11-05 14:41:47.497212900 -0800
+        +++ version.py	2009-11-05 14:39:57.684712900 -0800
+        @@ -97,7 +97,7 @@
+             in the distutils documentation.
+             """
+
+        -    version_re = re.compile(r'^(\d+) \. (\d+) (\. (\d+))? ([ab](\d+))?$',
+        +    version_re = re.compile(r'^(\d+) \. (\d+) (\. (\d+))* ([ab](\d+))?$',
+                                     re.VERBOSE)
+
+
+9) If you want to build in the source tree, you need the zlib dll and
+   associated libraries, put somewhere on your path. The buildout routines grab
+   this directly and add it to the build path, but that doesn't work for
+   ``setup.py``.
+   http://www.zlib.net/zlib123-dll.zip
+
+   I usually download and extract this to something like ``C:\local\`` so that
+   I end up with a ``C:\local\lib`` and ``C:\local\include`` directory. I then
+   modify the ``distutils.cfg`` file to tell the compiler where to find these
+   headers and libraries::
+
+      [build_ext]
+      include-dirs = C:/local/include
+      library-dirs = C:/local/lib
+
+   Note that you'll probably want to put the ``zlib1.dll`` into your path. You
+   can:
+
+     1) Add ``C:\local`` to your PATH variable in
+        "My Computer/Properties/Advanced/Environment Variables"
+     2) More logically, move ``zlib1.dll`` to either 'lib' or 'bin'
+        subdirectories and add that.
+     3) Copy it to ``C:\Windows\``.
+
+   I recommend 3, mostly because lots of apps will want to use zlib1.dll in the
+   long run. (You may already have it.)
+
+10) Install Visual Studio 2008 Professional
+    http://www.microsoft.com/downloads/details.aspx?FamilyId=83C3A1EC-ED72-4A79-8961-25635DB0192B&displaylang=en
+
+    This is a 3GB DVD iso image. You can mount it directly with Microsofts
+    iso mounting utility:
+    http://download.microsoft.com/download/7/b/6/7b6abd84-7841-4978-96f5-bd58df02efa2/winxpvirtualcdcontrolpanel_21.exe
+
+    You need at least Windows XP (which introduced direct iso support, I
+    believe.)
+
+    Note that there is a Service Pack 1 for Visual Studio. The ISO can be
+    downloaded here:
+    http://www.microsoft.com/downloads/thankyou.aspx?familyId=27673c47-b3b5-4c67-bd99-84e525b5ce61&displayLang=en
+
+    However, on EC2, there isn't enough room on C: to actually run the
+    installer. You need approx 6GB of free disk space. And EC2 only gives your
+    10GB and Windows itself takes up about 5GB. So we are currently running
+    stock VS 2008 with no service packs. (Even installing VS 2008 to a
+    different drive doesn't leave enough room on C: to run the upgrader.)
+
+    When installing on EC2, it seems their 2003 Server comes with a Visual
+    Studio key already supplied. There is also the possibility of using Visual
+    Studio Express Edition, but it is currently unable to compile TortoiseBzr.
+
+..
+   vim: ft=rst tw=79 et

=== renamed file 'doc/Makefile' => 'doc/en/Makefile'
=== renamed directory 'doc/_static' => 'doc/en/_static'
=== renamed file 'doc/_static/en/quick-reference/Makefile' => 'doc/en/_static/en/Makefile'
--- doc/_static/en/quick-reference/Makefile	2009-07-22 14:07:56 +0000
+++ doc/en/_static/en/Makefile	2009-09-09 00:49:50 +0000
@@ -2,8 +2,8 @@
 # doc/*/quick-reference/Makefile and update TARGETS and OBJECTS usages in
 # doc/Makefile
 
-TARGETS=bzr-quick-reference.png bzr-quick-reference.pdf
-OBJECTS=bzr-quick-reference.svg Makefile
+TARGETS=bzr-en-quick-reference.png bzr-en-quick-reference.pdf
+OBJECTS=bzr-en-quick-reference.svg Makefile
 
 all: $(TARGETS)
 
@@ -15,9 +15,9 @@
 .svg.png:
 	rsvg-convert -d 300 -p 300 -z 3.3346 -f png -o $@ $<
 
-bzr-quickref.png: $(OBJECTS)
+bzr-en-quick-reference.png: $(OBJECTS)
 
-bzr-quickref.pdf: $(OBJECTS)
+bzr-en-quick-reference.pdf: $(OBJECTS)
 
 clean:
 	rm -f $(TARGETS)

=== renamed file 'doc/_static/en/quick-reference/bzr-quick-reference.pdf' => 'doc/en/_static/en/bzr-en-quick-reference.pdf'
=== renamed file 'doc/_static/en/quick-reference/bzr-quick-reference.png' => 'doc/en/_static/en/bzr-en-quick-reference.png'
=== renamed file 'doc/_static/en/quick-reference/bzr-quick-reference.svg' => 'doc/en/_static/en/bzr-en-quick-reference.svg'
=== renamed directory 'doc/_templates' => 'doc/en/_templates'
=== modified file 'doc/en/_templates/index.html'
--- doc/_templates/index.html	2009-08-18 00:10:19 +0000
+++ doc/en/_templates/index.html	2009-09-09 11:43:10 +0000
@@ -7,25 +7,39 @@
 
   <table class="contentstable" align="center" style="margin-left: 30px"><tr>
     <td width="50%">
-        <p class="biglink"><a class="biglink" href="{{ pathto("en/user-guide/index") }}">User Guide</a><br/>
+        <p class="biglink"><a class="biglink" href="{{ pathto("user-guide/index") }}">User Guide</a><br/>
         <span class="linkdescr">how to use Bazaar effectively</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/tutorials/index") }}">Tutorials</a><br/>
+      <p class="biglink"><a class="biglink" href="{{ pathto("tutorials/index") }}">Tutorials</a><br/>
       <span class="linkdescr">brief introductions</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/quick-reference/index") }}">Quick Reference</a><br/>
+      <p class="biglink"><a class="biglink" href="{{ pathto("quick-reference/index") }}">Quick Reference</a><br/>
       <span class="linkdescr">for your wall</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/user-reference/bzr_man") }}">User Reference</a><br/>
-      <span class="linkdescr">all the gory details</span>
-      </p>
     </td><td width="50%">
-    <p class="biglink"><a class="biglink" href="{{ pathto("en/release-notes/NEWS") }}">Release Notes</a><br/>
+    <p class="biglink"><a class="biglink" href="{{ pathto("release-notes/index") }}">Release Notes</a><br/>
       <span class="linkdescr">what's new</span>
       </p>
-      <p class="biglink"><a class="biglink" href="{{ pathto("en/upgrade-guide/index") }}">Upgrade Guide</a><br/>
+      <p class="biglink"><a class="biglink" href="{{ pathto("upgrade-guide/index") }}">Upgrade Guide</a><br/>
       <span class="linkdescr">moving to Bazaar 2.x</span>
       </p>
+      <p class="biglink"><a class="biglink" href="{{ pathto("user-reference/index") }}">User Reference</a><br/>
+      <span class="linkdescr">all the gory details</span>
+      </p>
+    </td></tr>
+  </table>
+
+  <h2>Related links</h2>
+
+  <table class="contentstable" align="center" style="margin-left: 30px"><tr>
+    <td width="50%">
+        <p class="biglink"><a class="biglink" href="https://answers.launchpad.net/bzr">FAQ</a><br/>
+      <span class="linkdescr">frequently asked questions</span>
+      </p>
+      <p class="biglink"><a class="biglink" href="http://bazaar-vcs.org/BzrGlossary/">Glossary</a><br/>
+      <span class="linkdescr">help with terminology</span>
+      </p>
+    </td><td width="50%">
       <p class="biglink"><a class="biglink" href="http://doc.bazaar-vcs.org/migration/en/">Migration Docs</a><br/>
       <span class="linkdescr">for refugees of other tools</span>
       </p>
@@ -35,31 +49,7 @@
     </td></tr>
   </table>
 
-  <p>Keen to help? See the <a href="{{ pathto("developers/index") }}">Developer Docs</a>
+  <p>Keen to help? See the <a href="http://doc.bazaar-vcs.org/developers/">Developer Docs</a>
       for policies and tools on contributing code, tests and documentation.</p>
 
-
-  <h2>Related Links</h2>
-
-  <table class="contentstable" align="center" style="margin-left: 30px"><tr>
-    <td width="25%">
-        <p><a href="https://answers.launchpad.net/bzr">FAQ</a>
-        </p>
-    </td><td width="25%">
-        <p><a href="http://bazaar-vcs.org/BzrGlossary/">Glossary</a>
-        </p>
-    </td><td width="25%">
-        <p><a href="{{ pathto("genindex") }}">Index</a>
-        </p>
-    </td><td width="25%">
-        <p><a href="{{ pathto("search") }}">Search</a>
-        </p>
-    </td></tr>
-  </table>
-
-  <hr>
-  <p>Other languages:
-      <a href="{{ pathto("index.es") }}">Spanish</a>,
-      <a href="{{ pathto("index.ru") }}">Russian</a>
-  </p>
 {% endblock %}

=== modified file 'doc/en/_templates/layout.html'
--- doc/_templates/layout.html	2009-07-22 13:41:01 +0000
+++ doc/en/_templates/layout.html	2009-10-30 07:51:16 +0000
@@ -3,5 +3,25 @@
 {% block rootrellink %}
 <li><a href="http://bazaar-vcs.org/">
     <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Home</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/en/">Documentation</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}
+
+{% block document %}
+ <script type="text/javascript">
+  var gaJsHost = (("https:" == document.location.protocol) ?  "https://ssl." : "http://www.");
+  document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
+  </script>
+  <script type="text/javascript">
+  try{
+  var pageTracker = _gat._getTracker("UA-1018242-1");
+  pageTracker._trackPageview();
+  } catch(err) {}
+  try {
+    /* bazaar team tracker */
+    var pageTracker = _gat._getTracker("UA-11329411-2");
+    pageTracker._trackPageview();
+  } catch(err) {}
+</script>
 {{ super() }}
 {% endblock %}

=== renamed file 'doc/conf.py' => 'doc/en/conf.py'
--- doc/conf.py	2009-07-22 13:41:01 +0000
+++ doc/en/conf.py	2009-09-09 13:34:08 +0000
@@ -4,208 +4,86 @@
 # sphinx-quickstart on Tue Jul 21 17:04:52 2009.
 #
 # This file is execfile()d with the current directory set to its containing dir.
-#
-# Note that not all possible configuration values are present in this
-# autogenerated file.
-#
-# All configuration values have a default; values that are commented out
-# serve to show the default.
 
 import sys, os
 
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
-#sys.path.append(os.path.abspath('.'))
-
-# -- General configuration -----------------------------------------------------
-
-# Add any Sphinx extension module names here, as strings. They can be extensions
-# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.ifconfig']
-
-# Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
-
-# The suffix of source filenames.
-source_suffix = '.txt'
-
-# The encoding of source files.
-#source_encoding = 'utf-8'
-
-# The master toctree document.
-master_doc = 'contents'
-
-# General information about the project.
-project = u'Bazaar'
-copyright = u'2009, Canonical Ltd'
-
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-version = '1.18'
-# The full version, including alpha/beta/rc tags.
-release = '1.18dev'
-
-# The language for content autogenerated by Sphinx. Refer to documentation
-# for a list of supported languages.
-#language = None
-
-# There are two options for replacing |today|: either, you set today to some
-# non-false value, then it is used:
-#today = ''
-# Else, today_fmt is used as the format for a strftime call.
-#today_fmt = '%B %d, %Y'
-
-# List of documents that shouldn't be included in the build.
-#unused_docs = []
-
-# List of directories, relative to source directory, that shouldn't be searched
-# for source files.
-exclude_trees = ['_build']
-
-# The reST default role (used for this markup: `text`) to use for all documents.
-#default_role = None
-
-# If true, '()' will be appended to :func: etc. cross-reference text.
-#add_function_parentheses = True
-
-# If true, the current module name will be prepended to all description
-# unit titles (such as .. function::).
-#add_module_names = True
-
-# If true, sectionauthor and moduleauthor directives will be shown in the
-# output. They are ignored by default.
-#show_authors = False
-
-# The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
-
-# A list of ignored prefixes for module index sorting.
-#modindex_common_prefix = []
-
-
-# -- Options for HTML output ---------------------------------------------------
-
-# The theme to use for HTML and HTML Help pages.  Major themes that come with
-# Sphinx are currently 'default' and 'sphinxdoc'.
-html_theme = 'default'
-
-# Theme options are theme-specific and customize the look and feel of a theme
-# further.  For a list of options available for each theme, see the
-# documentation.
-html_theme_options = {
-    'rightsidebar': True,
-
-    # Non-document areas: header (relbar), footer, sidebar, etc.
-    # Some useful colours here:
-    # * blue: darkblue, mediumblue, darkslateblue, cornflowerblue, royalblue,
-    #   midnightblue
-    # * gray: dimgray, slategray, lightslategray
-    'sidebarbgcolor':   "cornflowerblue",
-    'sidebarlinkcolor': "midnightblue",
-    'relbarbgcolor':    "darkblue",
-    'footerbgcolor':    "lightslategray",
-
-    # Text, heading and code colouring
-    'codebgcolor':      "lightyellow",
-    'codetextcolor':    "firebrick",
-    'linkcolor':        "mediumblue",
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'en'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': None,
+        u'Bazaar User Guide': None,
+        u'Bazaar User Reference': None,
+        u'Bazaar Release Notes': None,
+        u'Bazaar Upgrade Guide': None,
+        u'Bazaar in five minutes': None,
+        u'Bazaar Tutorial': None,
+        u'Using Bazaar With Launchpad': None,
+        u'Centralized Workflow Tutorial': None,
     }
-
-# Add any paths that contain custom themes here, relative to this directory.
-#html_theme_path = []
-
-# The name for this set of Sphinx documents.  If None, it defaults to
-# "<project> v<release> documentation".
-#html_title = None
+def bzr_title(s):
+    return bzr_titles.get(s) or s
 
 # A shorter title for the navigation bar.  Default is the same as html_title.
-#html_short_title = None
-
-# The name of an image file (relative to this directory) to place at the top
-# of the sidebar.
-#html_logo = None
-
-# The name of an image file (within the static path) to use as favicon of the
-# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
-# pixels large.
-html_favicon = "bzr.ico"
-
-# Add any paths that contain custom static files (such as style sheets) here,
-# relative to this directory. They are copied after the builtin static files,
-# so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
-
-# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
-# using the given strftime format.
-#html_last_updated_fmt = '%b %d, %Y'
-
-# If true, SmartyPants will be used to convert quotes and dashes to
-# typographically correct entities.
-#html_use_smartypants = True
-
-# Custom sidebar templates, maps document names to template names.
-#html_sidebars = {}
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
 
 # Additional templates that should be rendered to pages, maps page names to
 # template names.
-html_additional_pages = {'contents': 'index.html'}
-
-# If false, no module index is generated.
-#html_use_modindex = True
-
-# If false, no index is generated.
-#html_use_index = True
-
-# If true, the index is split into individual pages for each letter.
-#html_split_index = False
-
-# If true, links to the reST sources are added to the pages.
-html_show_sourcelink = True
-
-# If true, an OpenSearch description file will be output, and all pages will
-# contain a <link> tag referring to it.  The value of this option must be the
-# base URL from which the finished HTML is served.
-#html_use_opensearch = ''
-
-# If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
-#html_file_suffix = ''
+html_additional_pages = {'index': 'index.html'}
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = 'Bazaardoc'
-
-
-# -- Options for LaTeX output --------------------------------------------------
-
-# The paper size ('letter' or 'a4').
-#latex_paper_size = 'letter'
-
-# The font size ('10pt', '11pt' or '12pt').
-#latex_font_size = '10pt'
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass [howto/manual]).
 latex_documents = [
-  ('contents', 'Bazaar.tex', u'Bazaar Documentation',
-   u'Bazaar Developers', 'manual'),
-]
-
-# The name of an image file (relative to this directory) to place at the top of
-# the title page.
-#latex_logo = None
-
-# For "manual" documents, if this is true, then toplevel headings are parts,
-# not chapters.
-#latex_use_parts = False
-
-# Additional stuff for the LaTeX preamble.
-#latex_preamble = ''
-
-# Documents to append as an appendix to all manuals.
-#latex_appendices = []
-
-# If false, no module index is generated.
-#latex_use_modindex = True
+  # Manuals
+  ('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  ('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  ('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  ('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  ('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  ('tutorials/using_bazaar_with_launchpad',
+    'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+    bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  ('tutorials/centralized_workflow',
+    'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+    bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Placeholder for later
+    'admin-guide/index',
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    # Plain-style documentation generation stuff
+    'release-notes/NEWS',
+    'user-reference/bzr_man',
+    'user-guide/index-plain',
+    # Miscellaneous
+    'user-reference/readme',
+]
+

=== removed directory 'doc/en/developer-guide'
=== renamed file 'doc/contents.txt' => 'doc/en/index.txt'
--- doc/contents.txt	2009-08-18 00:10:19 +0000
+++ doc/en/index.txt	2009-09-09 11:43:10 +0000
@@ -4,39 +4,15 @@
    contain the root `toctree` directive.
 
 
-Core documentation
-==================
-
-.. toctree::
-   :maxdepth: 1
-
-   en/user-guide/index
-   en/tutorials/index
-   en/quick-reference/index
-   en/user-reference/index
-
-.. toctree::
-   :maxdepth: 1
-
-   en/release-notes/index
-   en/upgrade-guide/index
-   developers/index
-
-
-Other languages:
-
-.. toctree::
-   :maxdepth: 1
-
-   index.es
-   index.ru
-
-
-Related links
-=============
-
-* `Frequently Asked Questions <http://bazaar-vcs.org/FAQ>`_
-* `Glossary <http://bazaar-vcs.org/BzrGlossary>`_
-* :ref:`genindex`
-* :ref:`search`
-
+Table of Contents
+=================
+
+.. toctree::
+   :maxdepth: 1
+
+   user-guide/index
+   tutorials/index
+   quick-reference/index
+   release-notes/index
+   upgrade-guide/index
+   user-reference/index

=== renamed file 'doc/make.bat' => 'doc/en/make.bat'
=== modified file 'doc/en/mini-tutorial/index.txt'
--- doc/en/mini-tutorial/index.txt	2009-04-04 02:50:01 +0000
+++ doc/en/mini-tutorial/index.txt	2009-12-03 00:44:16 +0000
@@ -2,19 +2,17 @@
 Bazaar in five minutes
 ======================
 
-.. contents::
-
 Introduction
 ============
 
 Bazaar is a distributed version control system that makes it easier for
-people to work together on software projects. 
+people to work together on software projects.
 
 Over the next five minutes, you'll learn how to put your files under
 version control, how to record changes to them, examine your work, publish
 it and send your work for merger into a project's trunk.
 
-If you'd prefer a more detailed introduction, take a look at 
+If you'd prefer a more detailed introduction, take a look at
 `Learning More`_.
 
 
@@ -46,7 +44,7 @@
 Using your name and email address, instead of John Doe's, type::
 
   $ bzr whoami "John Doe <john.doe@gmail.com>"
-  
+
 Bazaar will now create or modify a configuration file, including your
 name and email address.
 
@@ -65,15 +63,15 @@
  $ cd myproject
  $ mkdir subdirectory
  $ touch test1.txt test2.txt test3.txt subdirectory/test4.txt
- 
+
 **Note for Windows users:** use Windows Explorer to create your
-directories, then right-click in those directories and select 
+directories, then right-click in those directories and select
 ``New file`` to create your files.
 
 Now get Bazaar to initialize itself in your project directory::
 
   $ bzr init
-  
+
 If it looks like nothing happened, don't worry. Bazaar has created a
 branch_ where it will store your files and their revision histories.
 
@@ -89,13 +87,13 @@
  added test3.txt
  added subdirectory/test4.txt
 
-Next, take a snapshot of your files by committing them to your branch. Add 
+Next, take a snapshot of your files by committing them to your branch. Add
 a message to explain why you made the commit::
 
   $ bzr commit -m "Initial import"
-  
-As Bazaar is a distributed version control system, it doesn't need to 
-connect to a central server to make the commit. Instead, Bazaar stores your 
+
+As Bazaar is a distributed version control system, it doesn't need to
+connect to a central server to make the commit. Instead, Bazaar stores your
 branch and all its commits inside the directory you're working with; look
 for the ``.bzr`` sub-directory.
 
@@ -158,14 +156,14 @@
 
  $ bzr push --create-prefix sftp://your.name@example.com/~/public_html/myproject
  2 revision(s) pushed.
- 
+
 Bazaar will create a ``myproject`` directory on the remote server and
 push your branch to it.
- 
+
 Now anyone can create their own copy of your branch by typing::
 
  $ bzr branch http://www.example.com/myproject
- 
+
 **Note:** to use sftp, you may need to install ``paramiko`` and
 ``pyCrypto``. See http://bazaar-vcs.org/InstallationFaq for details.
 
@@ -173,7 +171,7 @@
 Publishing your branch with Launchpad
 =====================================
 
-Launchpad is a suite of development and hosting tools for free 
+Launchpad is a suite of development and hosting tools for free
 software projects. You can use it to publish your branch.
 
 If you don't have a Launchpad account, follow the `account signup guide`_
@@ -182,17 +180,19 @@
 .. _account signup guide: https://help.launchpad.net/CreatingYourLaunchpadAccount
 .. _register an SSH key: https://launchpad.net/people/+me/+editsshkeys
 
-Replacing ``john.doe`` with your own Launchpad username, type::
-
- $ bzr push bzr+ssh://john.doe@bazaar.launchpad.net/~john.doe/+junk/myproject
+Replacing ``john.doe`` with your own Launchpad username, type [#]_::
+
+ $ bzr push lp:~john.doe/+junk/myproject
+
+.. [#] Use of the ``lp:`` URL scheme requires bzr 0.92 or later.
 
 **Note:** ``+junk`` means that this branch isn't associated with any particular
 project in Launchpad.
 
 Now, anyone can create their own copy of your branch by typing::
 
- $ bzr branch http://bazaar.launchpad.net/~john.doe/+junk/myproject
- 
+ $ bzr branch lp:~john.doe/+junk/myproject
+
 You can also see information about your branch, including its revision
 history, at https://code.launchpad.net/people/+me/+junk/myproject
 
@@ -200,18 +200,18 @@
 Creating your own copy of another branch
 ========================================
 
-To work with someone else's code, you can make your own copy of their 
+To work with someone else's code, you can make your own copy of their
 branch. Let's take a real-world example, Bazaar's GTK interface::
 
-  $ bzr branch http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk bzr-gtk.john
-  Branched 292 revision(s).                                                        
+  $ bzr branch lp:~bzr/bzr-gtk/trunk bzr-gtk.john
+  Branched 292 revision(s).
 
 Bazaar will download all the files and complete revision history from the
 bzr-gtk project's trunk branch and create a copy called bzr-gtk.john.
 
-Now, you have your own copy of the branch and can commit changes with 
-or without a net connection. You can share your branch at any time by 
-publishing it and, if the  bzr-gtk team want to use your work, Bazaar 
+Now, you have your own copy of the branch and can commit changes with
+or without a net connection. You can share your branch at any time by
+publishing it and, if the  bzr-gtk team want to use your work, Bazaar
 makes it easy for them to merge your branch back into their trunk branch.
 
 
@@ -227,11 +227,11 @@
   $ bzr merge
   Merging from saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
   All changes applied successfully.
-            
+
 Check what has changed::
 
   $ bzr diff
- 
+
 If you're happy with the changes, you can commit them to your personal
 branch::
 
@@ -246,20 +246,20 @@
 send your changes back upstream to the project. The easiest way is to
 use a merge directive.
 
-A merge directive is a machine-readable request to perform a 
-particular merge.  It usually contains a patch preview of the merge 
-and either contains the necessary revisions, or provides a branch 
+A merge directive is a machine-readable request to perform a
+particular merge.  It usually contains a patch preview of the merge
+and either contains the necessary revisions, or provides a branch
 where they can be found.
 
 Replacing ``mycode.patch``, create your merge directive::
 
  $ bzr send -o mycode.patch
  Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
- 
+
 You can now email the merge directive to the bzr-gtk project who, if
 they choose, can use it merge your work back into the parent branch.
- 
- 
+
+
 Learning more
 =============
 

=== modified file 'doc/en/quick-reference/index.txt'
--- doc/en/quick-reference/index.txt	2009-07-22 14:07:56 +0000
+++ doc/en/quick-reference/index.txt	2009-09-09 02:32:10 +0000
@@ -1,6 +1,6 @@
 Quick Reference
 ===============
 
-* `SVG format <../../_static/en/quick-reference/bzr-quick-reference.svg>`_
-* `PDF format <../../_static/en/quick-reference/bzr-quick-reference.pdf>`_
-* `PNG format <../../_static/en/quick-reference/bzr-quick-reference.png>`_
+* `PDF format <../_static/en/bzr-en-quick-reference.pdf>`_
+* `PNG format <../_static/en/bzr-en-quick-reference.png>`_
+* `SVG format <../_static/en/bzr-en-quick-reference.svg>`_

=== modified file 'doc/en/tutorials/centralized_workflow.txt'
--- doc/en/tutorials/centralized_workflow.txt	2009-07-22 13:41:01 +0000
+++ doc/en/tutorials/centralized_workflow.txt	2009-12-02 20:34:07 +0000
@@ -1,6 +1,6 @@
-====================
-Centralized Workflow
-====================
+=============================
+Centralized Workflow Tutorial
+=============================
 
 
 Overview
@@ -23,8 +23,6 @@
 
 .. _Bazaar: http://bazaar-vcs.org
 
-.. contents::
-
 
 Initial Setup
 =============
@@ -40,7 +38,7 @@
 be accurate or unique, it will be used in log messages and
 annotations, so it is better to have something real.
 
-::  
+::
 
    % bzr whoami "John Doe <jdoe@organization.com>"
 
@@ -85,7 +83,7 @@
   % bzr init-repo --no-trees sftp://centralhost/srv/bzr/
 
 You can think of this step as similar to setting up a new cvsroot, or
-subversion repository.  The {{{--no-trees}}} option tells bzr to not
+subversion repository.  The ``--no-trees`` option tells bzr to not
 populate the directory with a working tree.  This is appropriate,
 since no one will be making changes directly in the branches within
 the central repository.
@@ -104,7 +102,7 @@
 
 .. _Tracking Upstream: http://bazaar-vcs.org/TrackingUpstream
 
-.. 
+..
    XXX: We really need a different document for discussing conversion of a
    project. Right now TrackingUpstream is the best we have, though.
 
@@ -284,7 +282,7 @@
 ::
 
   % bzr branch sftp://centralhost/srv/bzr/sigil/user-a \
-               sftp://centralhost/srv/bzr/sigil/user-a/feature 
+               sftp://centralhost/srv/bzr/sigil/user-a/feature
   % cd ~/work/sigil
   % bzr checkout sftp://centralhost/srv/bzr/sigil/user-a/feature myfeature
 
@@ -312,5 +310,5 @@
 well share the storage as well.
 
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/en/tutorials/tutorial.txt'
--- doc/en/tutorials/tutorial.txt	2009-06-27 08:10:13 +0000
+++ doc/en/tutorials/tutorial.txt	2009-12-02 20:34:07 +0000
@@ -2,7 +2,7 @@
 .. into HTML or text.  In the future we plan to extract the example commands
 .. and automatically test them.
 
-.. This text was previously on the wiki at 
+.. This text was previously on the wiki at
 .. http://bazaar.canonical.com/IntroductionToBzr
 .. but has been moved into the source tree so it can be kept in sync with
 .. the source and possibly automatically checked.
@@ -11,8 +11,6 @@
 Bazaar Tutorial
 ===============
 
-Current for bzr-0.91, 2007-08
-
 
 Introduction
 ============
@@ -22,10 +20,10 @@
 on the other hand, you are familiar with revision control but not
 decentralized revision control, then please start at "How DRCS is
 different." Otherwise, get some coffee or tea, get comfortable and get
-ready to catch up. 
+ready to catch up.
 
-The Purposes of Revision Control
-================================
+The purpose of revision control
+===============================
 
 Odds are that you have worked on some sort of textual data -- the sources
 to a program, web sites or the config files that Unix system
@@ -47,7 +45,7 @@
 Revision control systems give users the ability to save changes to a
 branch by "committing a **revision**". The revision created is essentially
 a summary of the changes that were made since the last time the tree was
-saved. 
+saved.
 
 These revisions have other uses as well. For example, one can comment
 revisions to record what the recent set of changes meant by providing an
@@ -55,17 +53,17 @@
 the web template to close the table" and "Added sftp suppport. Fixes #595"
 	
 We keep these logs so that if later there is some sort of problem with
-sftp, we can figure out when the problem probably happened. 
+sftp, we can figure out when the problem probably happened.
 
-How DRCS is Different
----------------------
+How DRCS is different
+=====================
 
 Many Revision Control Systems (RCS) are stored on servers. If one wants to
 work on the code stored within an RCS, then one needs to connect to the
 server and "checkout" the code. Doing so gives one a directory in which a
 person can make changes and then commit. The RCS client then connects to
 the RCS server and stores the changes. This method is known as the
-centralized model. 
+centralized model.
 
 The centralized model can have some drawbacks. A centralized RCS requires
 that one is able to connect to the server whenever one wants to do version
@@ -81,13 +79,13 @@
 user only needs internet access when he wants to access the changes in
 someone else's branch that are somewhere else.
 
- 
+
 A common requirement that many people have is the need to keep track of
 the changes for a directory such as file and subdirectory changes.
 Performing this tracking by hand is a awkward process that over time
 becomes unwieldy. That is, until one considers version control tools such
 as Bazaar. These tools automate the process of storing data by creating
-a **revision** of the directory tree whenever the user asks. 
+a **revision** of the directory tree whenever the user asks.
 
 Revision control software such as Bazaar can do much more than just
 storage and performing undo.  For example, with Bazaar a developer can
@@ -107,7 +105,7 @@
 ==============================
 
 Bazaar installs a single new command, **bzr**.  Everything else is a
-subcommand of this.  You can get some help with ``bzr help``. Some arguments 
+subcommand of this.  You can get some help with ``bzr help``. Some arguments
 are grouped in topics: ``bzr help topics`` to see which topics are available.
 
 One function of a version control system is to keep track of who changed
@@ -149,7 +147,7 @@
 
 .. [1] On Windows, the users configuration files can be found in the
    application data directory. So instead of ``~/.bazaar/branch.conf``
-   the configuration file can be found as: 
+   the configuration file can be found as:
    ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\branch.conf``.
    The same is true for ``locations.conf``, ``ignore``, and the
    ``plugins`` directory.
@@ -232,9 +230,9 @@
 its test suite before committing, to make sure that every revision is a
 known-good state.  You can also review your changes, to make sure you're
 committing what you intend to, and as a chance to rethink your work before
-you permanently record it. 
+you permanently record it.
 
-Two bzr commands are particularly useful here: **status** and **diff**.  
+Two bzr commands are particularly useful here: **status** and **diff**.
 
 bzr status
 ----------
@@ -279,14 +277,15 @@
 Some projects prefer patches to show a prefix at the start of the path
 for old and new files.  The ``--prefix`` option can be used to provide
 such a prefix.
-As a shortcut, ``bzr diff -p1`` produces a form that works with the 
+As a shortcut, ``bzr diff -p1`` produces a form that works with the
 command ``patch -p1``.
 
+
 Committing changes
 ==================
 
 When the working tree state is satisfactory, it can be **committed** to
-the branch, creating a new revision holding a snapshot of that state.  
+the branch, creating a new revision holding a snapshot of that state.
 
 bzr commit
 ----------
@@ -308,7 +307,7 @@
 can also be useful when you pick up your work after a break.)
 
 Message from an editor
-======================
+----------------------
 
 If you use neither the ``-m`` nor the ``-F`` option then bzr will open an
 editor for you to enter a message.  The editor to run is controlled by
@@ -355,9 +354,13 @@
 given then only those ones will be affected. ``bzr revert`` also clears the
 list of pending merges revisions.
 
+
 Ignoring files
 ==============
 
+The .bzrignore file
+-------------------
+
 Many source trees contain some files that do not need to be versioned,
 such as editor backups, object or bytecode files, and built programs.  You
 can simply not add them, but then they'll always crop up as unknown files.
@@ -400,7 +403,27 @@
     % bzr commit -m "Add ignore patterns"
 
 
-Global Ignores
+bzr ignore
+----------
+
+As an alternative to editing the ``.bzrignore`` file, you can use the
+``bzr ignore`` command. The ``bzr ignore`` command takes filenames and/or
+patterns as arguments and then adds them to the ``.bzrignore`` file. If a
+``.bzrignore`` file does not exist the ``bzr ignore`` command will
+automatically create one for you, and implicitly add it to be versioned::
+
+    % bzr ignore tags
+    % bzr status
+    added:
+      .bzrignore
+
+Just like when editing the ``.bzrignore`` file on your own, you should
+commit the automatically created ``.bzrignore`` file::
+
+    % bzr commit -m "Added tags to ignore file"
+
+
+Global ignores
 --------------
 
 There are some ignored files which are not project specific, but more user
@@ -432,7 +455,7 @@
 =================
 
 The ``bzr info`` command shows some summary information about the working
-tree and the branch history.  
+tree and the branch history.
 
 
 Versioning directories
@@ -461,7 +484,7 @@
 
 ``bzr remove`` makes the file un-versioned, but may or may not delete the
 working copy [2]_.  This is useful when you add the wrong file, or decide that
-a file should actually not be versioned. 
+a file should actually not be versioned.
 
 ::
 
@@ -488,7 +511,7 @@
 the existing branch.  Because this new copy is potentially a new branch,
 the command is called **branch**::
 
-    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev 
+    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev
     % cd bzr.dev
 
 This copies down the complete history of this branch, so we can do all
@@ -507,7 +530,7 @@
     % bzr pull
 
 After this change, the local directory will be a mirror of the source. This
-includes the ''revision-history'' - which is a list of the commits done in 
+includes the ''revision-history'' - which is a list of the commits done in
 this branch, rather than merged from other branches.
 
 This command only works if your local (destination) branch is either an
@@ -561,7 +584,7 @@
 
   ::
 
-    % bzr push sftp://servername.com/path/to/directory 
+    % bzr push sftp://servername.com/path/to/directory
 
   (The destination directory must already exist unless the
   ``--create-prefix`` option is used.)
@@ -574,7 +597,8 @@
   rsync, or other related file transfer methods.  This is usually less safe
   than using ``push``, but may be faster or easier in some situations.
 
-Moving changes between trees 
+
+Moving changes between trees
 ============================
 
 It happens to the best of us: sometimes you'll make changes in the wrong

=== modified file 'doc/en/tutorials/using_bazaar_with_launchpad.txt'
--- doc/en/tutorials/using_bazaar_with_launchpad.txt	2009-07-22 13:41:01 +0000
+++ doc/en/tutorials/using_bazaar_with_launchpad.txt	2009-12-02 20:34:07 +0000
@@ -2,8 +2,6 @@
 Using Bazaar with Launchpad
 ===========================
 
-.. contents::
-
 
 Motivation
 ==========
@@ -425,7 +423,7 @@
 Summary
 =======
 
-The communities we join, whether off-line or on-line, 
+The communities we join, whether off-line or on-line,
 say a lot about the sort of people we are. The flip-side
 to this is that the tools you choose for your community - particularly
 the CDE and version control tool - can have a large impact on who

=== modified file 'doc/en/upgrade-guide/data_migration.txt'
--- doc/en/upgrade-guide/data_migration.txt	2009-07-03 05:22:27 +0000
+++ doc/en/upgrade-guide/data_migration.txt	2009-10-02 18:12:29 +0000
@@ -30,17 +30,17 @@
 * **upgrade** - migrate data to a different format.
 
 **reconcile** is rarely needed but it's good practice to run **check**
-before and after runing **upgrade**.
+before and after running **upgrade**.
 
 For detailed help on these commands, see the `Bazaar User Reference`_.
 
-.. _Bazaar User Reference: ../user-reference/bzr_man.html
+.. _Bazaar User Reference: ../user-reference/index.html
 
 
 Communicating with your community
 ---------------------------------
 
-To enable a smooth transistion to the new format, you should:
+To enable a smooth transition to the new format, you should:
 
 1. Make one person responsible for migrating the trunk.
 
@@ -97,22 +97,54 @@
 Migrating branches on Launchpad
 -------------------------------
 
+You have two options for upgrading your Launchpad branches.  You can either
+upgrade them remotely or you can upgrade them locally and push the migrated
+branch to Launchpad.  We recommend the latter.  Upgrading remotely currently
+requires a fast, rock solid network connection to the Launchpad servers, and
+any interruption in that connection can leave you with a partially upgraded
+branch.  The instructions below are the safest and often fastest way to
+upgrade your Launchpad branches.
+
 To allow isolation between public and private branches, Launchpad
 uses stacked branches rather than shared repositories as the core
 technology for efficient branch storage. The process for migrating
 to a new format for projects using Launchpad code hosting is therefore
 different to migrating a personal or in-house project.
 
+In Launchpad, a project can define a *development series* and associate a
+branch with that series.  The branch then becomes the *focus of development*
+and gets special treatment and a shortcut url.  By default, if anybody
+branches your project's focus of development and pushes changes back to
+Launchpad, their branch will be stacked on your development focus branch.
+Also, branches can be associated with other Launchpad artifacts such as bugs
+and merge proposals.  All of these things mean that upgrading your focus of
+development branch is trickier.
+
 Here are the steps to follow:
 
-1. The nominated person grabs a copy of trunk and does the migration.
+1. The nominated person grabs a copy of trunk and does the migration locally.
 
 2. On Launchpad, unset the current trunk from being the development focus.
    (This *must* be done or the following step won't work as expected.)
 
-3. Push the migrated trunk to Launchpad.
-
-4. Set it as the development focus.
+   1. Go to your project's home page on Launchpad
+
+   2. Look for "XXX is the current focus of development"
+
+   3. Click on the edit (pencil) icon
+
+   4. Click on "Change details" in the portlet on the right
+
+   5. Scroll down to where it says "Branch: (Optional)"
+
+   6. Blank out this input field and click "Change"
+
+3. Push the migrated trunk to Launchpad.  See below if you want your
+   new migrated development focus branch to have the same name as your old
+   pre-migration development focus branch.
+
+4. Set it as the development focus.  Follow the instructions above but at step
+   5, enter the name of the newly migrated branch you just pushed.
 
 5. Ask users subscribed to the old trunk to subscribe to the new one.
 
@@ -124,6 +156,20 @@
 You are now ready to tell your community that the new trunk is available
 and to give them instructions on migrating any local branches they have.
 
+If you want your new migrated development focus branch to have the same name
+as your old pre-migration branch, you need to do a few extra things before you
+establish the new development focus.
+
+1. Rename your old pre-migration branch; use something like
+   **foo-obsolete-do-not-use**.  You will really not want to delete this
+   because there will be artifacts (bugs, merge proposals, etc.) associated
+   with it.
+
+2. Rename the new migrated branch to the pre-migration branch's old name.
+
+3. Re-establish the development focus branch using the new migrated branch's
+   new name (i.e. the old pre-migration branch's original name).
+
 
 Migrating local branches after a central trunk has migrated
 -----------------------------------------------------------

=== modified file 'doc/en/upgrade-guide/index.txt'
--- doc/en/upgrade-guide/index.txt	2009-07-22 13:41:01 +0000
+++ doc/en/upgrade-guide/index.txt	2009-09-02 16:03:51 +0000
@@ -8,8 +8,6 @@
 ..   level 3 ~~~~~~~~
 ..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
 
-.. contents::
-
 .. include:: overview.txt
 .. include:: data_migration.txt
 .. include:: tips_and_tricks.txt

=== modified file 'doc/en/user-guide/adv_merging.txt'
--- doc/en/user-guide/adv_merging.txt	2009-04-04 02:50:01 +0000
+++ doc/en/user-guide/adv_merging.txt	2009-11-25 16:04:57 +0000
@@ -47,6 +47,29 @@
 be done at a later time. In other cases, additional conflicts will need
 to be resolved when the changes are merged again.
 
+Merging without parents
+-----------------------
+
+A related technique to cherrypicking, in that it makes changes without
+reference to the revisions that they came from is to perform a merge, but
+forget about the parent revisions before committing.  This has the effect of
+making all of the changes that would have been in the merge happen in a single
+commit.  After the merge and before the corresponding commit, you can do::
+
+  bzr revert --forget-merges
+
+to keep the changes in the working tree, but remove the record of the
+revisions where the changes originated.  The next commit would then record
+all of those changes without any record of the merged revisions.
+
+This is desired by some users to make their history "cleaner", but you should
+be careful that the loss of history does not outweigh the value of cleanliness,
+particularly given Bazaar's capabilities for progressively disclosing merged
+revisions.  In particular, because this will include the changes from the
+source branch, but without attribution to that branch, it can lead to
+additional conflicts on later merges that involve the same source and
+target branches.
+
 
 Reverse cherrypicking
 ---------------------

=== modified file 'doc/en/user-guide/branching_a_project.txt'
--- doc/en/user-guide/branching_a_project.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/branching_a_project.txt	2009-12-02 20:34:07 +0000
@@ -16,11 +16,11 @@
   ===========         ======================================================
   Prefix              Description
   ===========         ======================================================
-  file://             Access using the standard filesystem (default)
-  sftp://             Access using SFTP (most SSH servers provide SFTP).
-  bzr://              Fast access using the Bazaar smart server.
-  ftp://              Access using passive FTP.
-  http://             Read-only access to branches exported by a web server.
+  \file://            Access using the standard filesystem (default)
+  \sftp://            Access using SFTP (most SSH servers provide SFTP).
+  \bzr://             Fast access using the Bazaar smart server.
+  \ftp://             Access using passive FTP.
+  \http://            Read-only access to branches exported by a web server.
   ===========         ======================================================
 
 As indicated above, branches are identified using URLs with the
@@ -37,9 +37,10 @@
 where to put it on your filesystem. For maximum storage
 efficiency down the track, it is recommended that branches
 be created somewhere under a directory that has been set up
-as a shared repository. (See `Feature branches`_ in
-n `Organizing your workspace`_ for a commonly used layout.)
-For example::
+as a shared repository. (See `Feature branches
+<organizing_your_workspace.html#feature-branches>`_ in
+`Organizing your workspace <organizing_your_workspace.html>`_
+for a commonly used layout.) For example::
 
   bzr init-repo my-repo
   cd my-repo
@@ -91,7 +92,7 @@
 the latest version.
 
 As explained in later chapters, Bazaar also has support for
-`lightweight checkouts <#getting-a-lightweight-checkout>`_ 
+`lightweight checkouts <using_checkouts.html#getting-a-lightweight-checkout>`_
 of a branch, i.e. working trees with
 no local storage of history. Of course, disconnected usage
 is not available then but that's a tradeoff you can decide

=== modified file 'doc/en/user-guide/browsing_history.txt'
--- doc/en/user-guide/browsing_history.txt	2009-03-26 12:57:41 +0000
+++ doc/en/user-guide/browsing_history.txt	2009-09-09 15:06:00 +0000
@@ -87,7 +87,7 @@
 
 History browsing is one area where GUI tools really make life easier.
 Bazaar has numerous plug-ins that provide this capability including
-QBzr and bzr-gtk. See `Using plugins`_ for details on how to install
+QBzr and bzr-gtk. See `Using plugins <plugins.html>`_ for details on how to install
 these if they are not already installed.
 
 To use the graphical viewer from QBzr::

=== modified file 'doc/en/user-guide/configuring_bazaar.txt'
--- doc/en/user-guide/configuring_bazaar.txt	2008-08-14 17:25:43 +0000
+++ doc/en/user-guide/configuring_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -13,7 +13,7 @@
 identifier you want::
 
     % bzr whoami "Your Name <email@example.com>"
- 
+
 If ``whoami`` is used without an argument, the current value is displayed.
 
 Configuration files

=== modified file 'doc/en/user-guide/controlling_registration.txt'
--- doc/en/user-guide/controlling_registration.txt	2008-04-18 01:06:17 +0000
+++ doc/en/user-guide/controlling_registration.txt	2009-12-02 20:34:07 +0000
@@ -100,7 +100,7 @@
 
 .. [#] On Windows, the users configuration files can be found in the
    application data directory. So instead of ``~/.bazaar/branch.conf``
-   the configuration file can be found as: 
+   the configuration file can be found as:
    ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\branch.conf``.
    The same is true for ``locations.conf``, ``ignore``, and the
    ``plugins`` directory.

=== modified file 'doc/en/user-guide/core_concepts.txt'
--- doc/en/user-guide/core_concepts.txt	2008-10-16 10:57:16 +0000
+++ doc/en/user-guide/core_concepts.txt	2009-09-09 15:06:00 +0000
@@ -50,9 +50,10 @@
 depend on which revision is the tip (i.e. most recent revision)
 in the branch.
 
-See `Specifying revisions`_ in the appendices for a closer look at
-the numerous ways that revisions and ranges of revisions can be specified
-in Bazaar, and `Understanding Revision Numbers`_ for a more detailed
+See `Specifying revisions <specifying_revisions.html>`_ in the appendices
+for a closer look at the numerous ways that revisions and ranges of
+revisions can be specified in Bazaar, and `Understanding Revision Numbers
+<zen.html#understanding-revision-numbers>`_ for a more detailed
 description of revision numbering.
 
 .. *TODO: add diagram*
@@ -108,15 +109,15 @@
 to use a *standalone tree*, which has a working tree, branch, and repository
 all in a single location. Other common scenarios include:
 
-* `Shared repositories <#a-reminder-about-shared-repositories>`_ - working
-  tree and branch are colocated, but the repository is in a higher level
+* `Shared repositories <branching_a_project.html#a-reminder-about-shared-repositories>`_
+  - working tree and branch are colocated, but the repository is in a higher level
   directory.
 
-* `Stacked branches <#using-stacked-branches>`_ - branch stores just its
+* `Stacked branches <stacked.html>`_ - branch stores just its
   unique revisions, using its parent's repository for common revisions.
 
-* `Lightweight checkouts <#getting-a-lightweight-checkout>`_ - branch is 
-  stored in a different location to the working tree.
+* `Lightweight checkouts <using_checkouts.html#getting-a-lightweight-checkout>`_
+  - branch is stored in a different location to the working tree.
 
 The best way to use Bazaar, however, depends on your needs. Let's take a
 look at some common workflows next.

=== modified file 'doc/en/user-guide/distributed_intro.txt'
--- doc/en/user-guide/distributed_intro.txt	2008-05-06 14:34:57 +0000
+++ doc/en/user-guide/distributed_intro.txt	2009-12-02 20:34:07 +0000
@@ -19,5 +19,5 @@
 
 Other distributed workflows are explored later in this chapter.
 
-.. 
+..
    vim: tw=74 ft=rst

=== modified file 'doc/en/user-guide/filtered_views.txt'
--- doc/en/user-guide/filtered_views.txt	2009-03-31 14:12:27 +0000
+++ doc/en/user-guide/filtered_views.txt	2009-10-19 04:55:02 +0000
@@ -25,10 +25,8 @@
 a view implicitly so that it is clear that the operation or output is
 being masked accordingly.
 
-Note: Bazaar's default format does not yet support filtered views. That
-is likely to change in the near future. To use filtered views in the
-meantime, you currently need to upgrade to ``development-wt6`` (or
-``development-wt6-rich-root``) format first.
+Note: Filtered views are only supported in format 2a, the default in
+Bazaar 2.0, or later.
 
 
 Creating a view

=== modified file 'doc/en/user-guide/getting_help.txt'
--- doc/en/user-guide/getting_help.txt	2007-11-28 00:07:56 +0000
+++ doc/en/user-guide/getting_help.txt	2009-09-14 02:30:23 +0000
@@ -1,18 +1,20 @@
 Getting help
 ============
 
-Bazaar comes with a built-in on-line help system. To see the list of topics,
-the command is::
+Bazaar comes with a built-in on-line help system, accessed through::
 
   bzr help
 
-To see the list of commands, the command is::
+You can ask for help on a command, or on non-command topics.  To see a
+list of available help of each kind, use either::
 
   bzr help commands
-
-To get help on topic xxx or command xxx, the command is::
-
-  bzr help xxx
+  bzr help topics
+
+For help on a particular command, use either of these forms::
+
+  bzr help status
+  bzr status --help
 
 If you wish to search the help or read it as a larger document, the
 information is also available in the Bazaar User Reference.

=== modified file 'doc/en/user-guide/http_smart_server.txt'
--- doc/en/user-guide/http_smart_server.txt	2008-10-20 09:26:03 +0000
+++ doc/en/user-guide/http_smart_server.txt	2009-12-02 20:34:07 +0000
@@ -30,7 +30,7 @@
 
     LoadModule fastcgi_module /usr/lib/apache2/modules/mod_fastcgi.so
     FastCgiIpcDir /var/lib/apache2/fastcgi
-    
+
 In our example, we're already serving `/srv/example.com/www/code` at
 `http://example.com/code`, so our existing Apache configuration would look
 like::
@@ -51,7 +51,7 @@
         RewriteBase /code
         RewriteRule ^(.*/|)\.bzr/smart$ /srv/example.com/scripts/bzr-smart.fcgi
     </Directory>
-    
+
     # bzr-smart.fcgi isn't under the DocumentRoot, so Alias it into the URL
     # namespace so it can be executed.
     Alias /srv/example.com/scripts/bzr-smart.fcgi /srv/example.com/scripts/bzr-smart.fcgi
@@ -61,7 +61,7 @@
             SetHandler fastcgi-script
         </Files>
     </Directory>
-    
+
 This instructs Apache to hand requests for any URL ending with `/.bzr/smart`
 inside `/code` to a Bazaar smart server via FastCGI.
 
@@ -136,11 +136,11 @@
         prefix='/code/',
         path_var='REQUEST_URI',
         readonly=True,
-        load_plugins=True, 
+        load_plugins=True,
         enable_logging=True)
 
     fcgi.WSGIServer(smart_server_app).run()
-        
+
 The `fcgi` module can be found at http://svn.saddi.com/py-lib/trunk/fcgi.py.  It
 is part of flup_.
 
@@ -162,14 +162,14 @@
         prefix='/code/',
         path_var='REQUEST_URI',
         readonly=True,
-        load_plugins=True, 
+        load_plugins=True,
         enable_logging=True)
 
     def handler(request):
         """Handle a single request."""
         wsgi_server = modpywsgi.WSGIServer(smart_server_app)
         return wsgi_server.run(request)
-        
+
 The `modpywsgi` module can be found at
 http://dev.pocoo.org/projects/pocoo/browser/pocoo/wrappers/modpy.py. It is
 part of pocoo_. You sould make sure you place modpywsgi.py in the same
@@ -232,5 +232,5 @@
 writable server, and plain HTTP allow read-only access.
 
 
-.. 
+..
    vim: ft=rst tw=74 et

=== added file 'doc/en/user-guide/index-plain.txt'
--- doc/en/user-guide/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/en/user-guide/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,119 @@
+#################
+Bazaar User Guide
+#################
+
+.. Please mark sections in included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+.. contents:: :depth: 3
+
+
+Introduction
+############
+
+.. include:: introducing_bazaar.txt
+.. include:: core_concepts.txt
+.. include:: bazaar_workflows.txt
+
+
+Getting started
+###############
+
+.. include:: installing_bazaar.txt
+.. include:: entering_commands.txt
+.. include:: getting_help.txt
+.. include:: configuring_bazaar.txt
+.. include:: using_aliases.txt
+.. include:: plugins.txt
+.. include:: zen.txt
+
+
+Personal version control
+########################
+
+.. include:: solo_intro.txt
+.. include:: starting_a_project.txt
+.. include:: controlling_registration.txt
+.. include:: reviewing_changes.txt
+.. include:: recording_changes.txt
+.. include:: browsing_history.txt
+.. include:: releasing_a_project.txt
+.. include:: undoing_mistakes.txt
+
+
+Sharing with peers
+##################
+
+.. include:: partner_intro.txt
+.. include:: branching_a_project.txt
+.. include:: merging_changes.txt
+.. include:: resolving_conflicts.txt
+.. include:: annotating_changes.txt
+
+
+Team collaboration, central style
+#################################
+
+.. include:: central_intro.txt
+.. include:: publishing_a_branch.txt
+.. include:: using_checkouts.txt
+.. include:: working_offline_central.txt
+.. include:: reusing_a_checkout.txt
+
+
+Team collaboration, distributed style
+#####################################
+
+.. include:: distributed_intro.txt
+.. include:: organizing_branches.txt
+.. include:: using_gatekeepers.txt
+.. include:: sending_changes.txt
+
+
+Miscellaneous topics
+####################
+
+.. include:: part2_intro.txt
+.. include:: adv_merging.txt
+.. include:: shelving_changes.txt
+.. include:: filtered_views.txt
+.. include:: stacked.txt
+.. include:: server.txt
+.. include:: hooks.txt
+.. include:: version_info.txt
+
+
+A brief tour of some popular plugins
+####################################
+
+.. include:: bzrtools_plugin.txt
+.. include:: svn_plugin.txt
+.. include later looms_plugin.txt
+
+
+Integrating Bazaar into your environment
+########################################
+
+.. include:: web_browsing.txt
+.. include later - file_explorers.txt
+.. include later - desktop_integration.txt
+.. include later - editors_and_ides.txt
+.. include later - email.txt
+.. include:: bug_trackers.txt
+
+
+Appendices
+##########
+
+.. include:: specifying_revisions.txt
+.. include:: organizing_your_workspace.txt
+.. include:: shared_repository_layouts.txt
+.. include:: setting_up_email.txt
+.. include:: http_smart_server.txt
+.. include:: writing_a_plugin.txt
+
+.. |--| unicode:: U+2014
+

=== removed file 'doc/en/user-guide/index.txt'
--- doc/en/user-guide/index.txt	2009-07-26 15:58:33 +0000
+++ doc/en/user-guide/index.txt	1970-01-01 00:00:00 +0000
@@ -1,118 +0,0 @@
-#################
-Bazaar User Guide
-#################
-
-.. Please mark sections in included files as following:
-..   level 1 ========
-..   level 2 --------
-..   level 3 ~~~~~~~~
-..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
-
-.. contents:: :depth: 3
-
-
-Introduction
-############
-
-.. include:: introducing_bazaar.txt
-.. include:: core_concepts.txt
-.. include:: bazaar_workflows.txt
-
-
-Getting started
-###############
-
-.. include:: installing_bazaar.txt
-.. include:: entering_commands.txt
-.. include:: getting_help.txt
-.. include:: configuring_bazaar.txt
-.. include:: using_aliases.txt
-.. include:: plugins.txt
-.. include:: zen.txt
-
-
-Personal version control
-########################
-
-.. include:: solo_intro.txt
-.. include:: starting_a_project.txt
-.. include:: controlling_registration.txt
-.. include:: reviewing_changes.txt
-.. include:: recording_changes.txt
-.. include:: browsing_history.txt
-.. include:: releasing_a_project.txt
-.. include:: undoing_mistakes.txt
-
-
-Sharing with peers
-##################
-
-.. include:: partner_intro.txt
-.. include:: branching_a_project.txt
-.. include:: merging_changes.txt
-.. include:: resolving_conflicts.txt
-.. include:: annotating_changes.txt
-
-
-Team collaboration, central style
-#################################
-
-.. include:: central_intro.txt
-.. include:: publishing_a_branch.txt
-.. include:: using_checkouts.txt
-.. include:: working_offline_central.txt
-.. include:: reusing_a_checkout.txt
-
-
-Team collaboration, distributed style
-#####################################
-
-.. include:: distributed_intro.txt
-.. include:: organizing_branches.txt
-.. include:: using_gatekeepers.txt
-.. include:: sending_changes.txt
-
-
-Miscellaneous topics
-####################
-
-.. include:: part2_intro.txt
-.. include:: adv_merging.txt
-.. include:: shelving_changes.txt
-.. include:: filtered_views.txt
-.. include:: stacked.txt
-.. include:: server.txt
-.. include:: hooks.txt
-.. include:: version_info.txt
- 
-
-A brief tour of some popular plugins
-####################################
-
-.. include:: bzrtools_plugin.txt
-.. include:: svn_plugin.txt
-.. include later looms_plugin.txt
-
-
-Integrating Bazaar into your environment
-########################################
-
-.. include:: web_browsing.txt
-.. include later - file_explorers.txt
-.. include later - desktop_integration.txt
-.. include later - editors_and_ides.txt
-.. include later - email.txt
-.. include:: bug_trackers.txt
-
-
-Appendices
-##########
-
-.. include:: specifying_revisions.txt
-.. include:: organizing_your_workspace.txt
-.. include:: shared_repository_layouts.txt
-.. include:: setting_up_email.txt
-.. include:: http_smart_server.txt
-.. include:: writing_a_plugin.txt
-
-.. |--| unicode:: U+2014

=== renamed file 'doc/en/user-guide/index-for-2x.txt' => 'doc/en/user-guide/index.txt'
--- doc/en/user-guide/index-for-2x.txt	2009-07-22 15:04:22 +0000
+++ doc/en/user-guide/index.txt	2009-12-02 20:34:07 +0000
@@ -103,7 +103,7 @@
    server
    hooks
    version_info
- 
+
 
 A brief tour of some popular plugins
 ####################################

=== modified file 'doc/en/user-guide/installing_bazaar.txt'
--- doc/en/user-guide/installing_bazaar.txt	2009-05-01 03:35:18 +0000
+++ doc/en/user-guide/installing_bazaar.txt	2009-09-09 15:08:17 +0000
@@ -85,9 +85,9 @@
 
   2. Get a copy of the development version like this::
 
-       bzr branch http://bazaar-vcs.org/bzr/bzr.dev
+       bzr branch lp:bzr
 
-  3. Put the created directory (bzr.dev) on your PATH.
+  3. Put the created directory on your PATH.
 
 Advanced users may also wish to build the optional C extensions for greater
 speed. This can be done using ``make`` and requires ``pyrex`` and a C compiler.

=== modified file 'doc/en/user-guide/introducing_bazaar.txt'
--- doc/en/user-guide/introducing_bazaar.txt	2009-06-01 22:45:06 +0000
+++ doc/en/user-guide/introducing_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -18,7 +18,7 @@
 
 This guide takes you through installing Bazaar and how to use it,
 whether on your own or with a team of other people. If you're already
-familiar with distributed version control and want to dive straight in, 
+familiar with distributed version control and want to dive straight in,
 you may wish to skim this section and jump straight to
 `Learning more`_.
 
@@ -49,7 +49,7 @@
 To record or *commit* these changes, the user needs access to the central
 server and they need to ensure they have merged their work with the latest
 version stored before trying to commit. This approach is known as the
-centralized model. 
+centralized model.
 
 The centralized model has proven useful over time but it can have some notable
 drawbacks. Firstly, a centralized VCS requires that one is able to connect
@@ -87,7 +87,7 @@
      move them into the core
 
  * in companies, easier to work with distributed and outsourced teams.
-   
+
 For a detailed look at the advantages of distributed VCS tools over
 centralized VCS tools, see http://bazaar-vcs.org/BzrWhy.
 

=== modified file 'doc/en/user-guide/merging_changes.txt'
--- doc/en/user-guide/merging_changes.txt	2007-12-04 12:56:31 +0000
+++ doc/en/user-guide/merging_changes.txt	2009-09-09 15:06:00 +0000
@@ -53,7 +53,7 @@
 
 Note that some merges can only be completed with the assistance
 of a human. Details on how to resolve these are given in
-`Resolving conflicts`_.
+`Resolving conflicts <resolving_conflicts.html>`_.
 
 Recording a merge
 -----------------

=== modified file 'doc/en/user-guide/organizing_your_workspace.txt'
--- doc/en/user-guide/organizing_your_workspace.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/organizing_your_workspace.txt	2009-09-09 15:30:59 +0000
@@ -172,5 +172,5 @@
 ----------------
 
 If you wish, you can put together your own layout based on how **you** like
-things organized. See `Advanced shared repository layouts`_ for examples
-and inspiration.
+things organized. See `Advanced shared repository layouts
+<shared_repository_layouts.html>`_ for examples and inspiration.

=== modified file 'doc/en/user-guide/plugins.txt'
--- doc/en/user-guide/plugins.txt	2007-12-14 07:35:49 +0000
+++ doc/en/user-guide/plugins.txt	2009-12-02 20:34:07 +0000
@@ -15,7 +15,7 @@
 * adding new commands
 * providing additional network transports
 * customizing log output.
-  
+
 The sky is the limit for the customization that can be done through plugins.
 In fact, plugins often work as a way for developers to test new features for
 Bazaar prior to inclusion in the official codebase. Plugins are helpful
@@ -25,12 +25,12 @@
 Plugins are good for users, good for external developers and good for
 Bazaar itself.
 
-Where to find plugins 
+Where to find plugins
 ---------------------
 
 We keep our list of plugins on the http://bazaar-vcs.org/BzrPlugins page.
 
-How to install a plugin 
+How to install a plugin
 -----------------------
 
 Installing a plugin is very easy! If not already created, create a
@@ -42,7 +42,7 @@
 
 Plugins work particularly well with Bazaar branches. For example, to
 install the bzrtools plugins for your main user account on Linux,
-one can perform the following:: 
+one can perform the following::
 
     bzr branch http://panoramicfeedback.com/opensource/bzr/bzrtools
     ~/.bazaar/plugins/bzrtools
@@ -56,23 +56,11 @@
 Alternative plugin locations
 ----------------------------
 
-If you have the necessary permissions, plugins can also be installed on
-a system-wide basis. Two locations are currently checked for plugins:
-
- 1. the system location - bzrlib/plugins
- 2. the personal location - $BZR_HOME/plugins.
-
-On a Linux installation, these locations are typically
-``/usr/lib/python2.4/site-packages/bzrlib/plugins/`` and
-``$HOME/.bazaar/plugins/``.
-On a Windows installation, the system location might be
-``C:\\Program Files\\Bazaar\\plugins``
-while the personal location might be
-``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\plugins``.
-
-One can additionally override the personal plugins location
-by setting the environment variable ``BZR_PLUGIN_PATH``
-to a directory that contains plugins.
+If you have the necessary permissions, plugins can also be installed on a
+system-wide basis.  One can additionally override the personal plugins
+location by setting the environment variable ``BZR_PLUGIN_PATH`` (see `User
+Reference <../user-reference/bzr_man.html#bzr-plugin-path>`_ for a detailed
+explanation).
 
 Listing the installed plugins
 -----------------------------
@@ -106,4 +94,5 @@
   ================ ================= ==================================
 
 If you wish to write your own plugins, it is not difficult to do.
-See `Writing a plugin`_ in the appendices to get started.
+See `Writing a plugin <writing a plugin.html>`_ in the appendices to get
+started.

=== modified file 'doc/en/user-guide/publishing_a_branch.txt'
--- doc/en/user-guide/publishing_a_branch.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/publishing_a_branch.txt	2009-12-02 11:03:35 +0000
@@ -19,8 +19,8 @@
 You can think of this step as similar to setting up a new cvsroot or
 Subversion repository. However, Bazaar gives you more flexibility
 in how branches may be organised in your repository. See
-`Advanced shared repository layouts`_ in the appendices for
-guidelines and examples.
+`Advanced shared repository layouts <shared_repository_layouts.html>`_
+in the appendices for guidelines and examples.
 
 
 Starting a central branch
@@ -55,7 +55,6 @@
   bzr add                (populate repository; start version control)
   bzr commit -m "Initial import"
                          (publish to central repository)
-  bzr push sftp://centralhost/srv/bzr/project/trunk
 
 Note that committing inside a working tree created using
 the ``checkout`` command implicitly commits the content to

=== modified file 'doc/en/user-guide/recording_changes.txt'
--- doc/en/user-guide/recording_changes.txt	2009-03-02 13:02:13 +0000
+++ doc/en/user-guide/recording_changes.txt	2009-12-02 20:34:07 +0000
@@ -5,7 +5,7 @@
 ----------
 
 When the working tree state is satisfactory, it can be **committed** to
-the branch, creating a new revision holding a snapshot of that state.  
+the branch, creating a new revision holding a snapshot of that state.
 
 The **commit** command takes a message describing the changes in the
 revision.  It also records your userid, the current time and timezone, and

=== modified file 'doc/en/user-guide/resolving_conflicts.txt'
--- doc/en/user-guide/resolving_conflicts.txt	2008-03-05 10:26:17 +0000
+++ doc/en/user-guide/resolving_conflicts.txt	2009-12-02 20:34:07 +0000
@@ -35,7 +35,7 @@
 each file in question, fixing the relevant areas and removing the
 conflict markers as you go.
 
-After fixing all the files in conflict, and removing the markers, 
+After fixing all the files in conflict, and removing the markers,
 ask Bazaar to mark them as resolved using the ``resolve`` command like this::
 
   bzr resolve

=== modified file 'doc/en/user-guide/reviewing_changes.txt'
--- doc/en/user-guide/reviewing_changes.txt	2007-11-21 07:39:16 +0000
+++ doc/en/user-guide/reviewing_changes.txt	2009-12-02 20:34:07 +0000
@@ -8,7 +8,7 @@
 prior to permanently recording it. This way, you can make sure you'll be
 committing what you intend to.
 
-Two bzr commands are particularly useful here: **status** and **diff**.  
+Two bzr commands are particularly useful here: **status** and **diff**.
 
 bzr status
 ----------
@@ -45,6 +45,14 @@
     % bzr diff -r 1000..          # everything since r1000
     % bzr diff -r 1000..1100      # changes from 1000 to 1100
 
+To see the changes introduced by a single revision, you can use the ``-c``
+option to diff.
+
+::
+
+    % bzr diff -c 1000            # changes from r1000
+                                  # identical to -r999..1000
+
 The ``--diff-options`` option causes bzr to run the external diff program,
 passing options.  For example::
 
@@ -53,6 +61,6 @@
 Some projects prefer patches to show a prefix at the start of the path
 for old and new files.  The ``--prefix`` option can be used to provide
 such a prefix.
-As a shortcut, ``bzr diff -p1`` produces a form that works with the 
+As a shortcut, ``bzr diff -p1`` produces a form that works with the
 command ``patch -p1``.
 

=== modified file 'doc/en/user-guide/sending_changes.txt'
--- doc/en/user-guide/sending_changes.txt	2008-04-24 01:27:26 +0000
+++ doc/en/user-guide/sending_changes.txt	2009-12-02 20:34:07 +0000
@@ -34,11 +34,11 @@
 Creating a merge directive
 --------------------------
 
-To create and optionally send a merge directive, use the ``send`` command. 
+To create and optionally send a merge directive, use the ``send`` command.
 
 By default, ``send`` will email the merge directive to the "submission
 address" for the branch, which is typically the lead developer or the
-development mailing list.  
+development mailing list.
 ``send`` without options will create a merge directive, fire up your email
 tool and attach it, ready for you to add the explanatory text bit.
 (See the online help for ``send`` and

=== modified file 'doc/en/user-guide/server.txt'
--- doc/en/user-guide/server.txt	2009-02-22 16:54:02 +0000
+++ doc/en/user-guide/server.txt	2009-12-02 20:34:07 +0000
@@ -36,18 +36,24 @@
 SSH
 ~~~
 
-Using Bazaar over SSH requires no special configuration on the server::
+Using Bazaar over SSH requires no special configuration on the server; so long
+as Bazaar is installed on the server you can use ``bzr+ssh`` URLs, e.g.::
+
+    bzr log bzr+ssh://host/path/to/branch
+
+If `bzr` is not installed system-wide on the server you may need to explicitly
+tell the local `bzr` where to find the remote `bzr`::
 
     BZR_REMOTE_PATH=~/bin/bzr bzr log bzr+ssh://host/path/to/branch
 
 The ``BZR_REMOTE_PATH`` environment variable adjusts how `bzr` will be
 invoked on the remote system.  By default, just `bzr` will be invoked,
-which requires the `bzr` executable to be on the default search path.
+which requires the `bzr` executable to be on the default search path.  You can
+also set this permanently per-location in ``locations.conf``.
 
-The ``bzr+ssh://`` URL scheme only supports absolute paths from the
-root of the filesystem.  Future versions are expected to support ``~``
-in the same way as ``sftp://`` URLs
-(https://bugs.launchpad.net/bzr/+bug/109143).
+Like SFTP, paths starting with ``~`` are relative to your home directory, e.g.
+``bzr+ssh://example.com/~/code/proj``.  Additionally, paths starting with
+``~user`` will be relative to that user's home directory.
 
 inetd
 ~~~~~
@@ -65,6 +71,10 @@
 
     bzr log bzr://host/branchname
 
+If possible, paths starting with ``~`` and ``~user`` will be expanded as for
+``bzr+ssh``.  Home directories outside the ``--directory`` specified to ``bzr
+serve`` will not be accessible.
+
 Dedicated
 ~~~~~~~~~
 
@@ -88,7 +98,7 @@
 server::
 
     bzr serve --port=localhost:1234 --directory=/srv/bzr/repo
-    
+
 client::
 
     bzr log bzr://localhost:1234/branchname

=== modified file 'doc/en/user-guide/setting_up_email.txt'
--- doc/en/user-guide/setting_up_email.txt	2009-04-04 02:50:01 +0000
+++ doc/en/user-guide/setting_up_email.txt	2009-12-02 20:34:07 +0000
@@ -13,7 +13,7 @@
 the email address in a revision gives others a way to contact the
 author of a revision for credit and/or blame.  :)
 
-How to set up your email address 
+How to set up your email address
 --------------------------------
 
 Bazaar will try to guess an email address based on your username and the
@@ -44,7 +44,7 @@
 
     % bzr whoami
     Joe Cool <joe@example.com>
-    
+
 Setting email via the 'whoami' command
 --------------------------------------
 

=== modified file 'doc/en/user-guide/shared_repository_layouts.txt'
--- doc/en/user-guide/shared_repository_layouts.txt	2009-02-26 11:28:50 +0000
+++ doc/en/user-guide/shared_repository_layouts.txt	2009-12-02 20:34:07 +0000
@@ -1,7 +1,7 @@
 Advanced shared repository layouts
 ==================================
 
-Bazaar is designed to give you flexibility in how you layout branches inside a shared repository. 
+Bazaar is designed to give you flexibility in how you layout branches inside a shared repository.
 This flexibility allows users to tailor Bazaar to their workflow,
 but it also leads to questions about what is a "good" layout.
 We present some alternatives and give some discussion about the benefits of each.
@@ -15,7 +15,7 @@
 "SVN-Style" (``trunk/``, ``branches/``)
 ---------------------------------------
 
-Most people coming from SVN will be familiar with their "standard" project layout. 
+Most people coming from SVN will be familiar with their "standard" project layout.
 Which is to layout the repository as::
 
   repository/       # Overall repository
@@ -27,11 +27,11 @@
        +- release-X # A branch specific to mark a given release version
           ...
 
-With Bazaar, that is a perfectly reasonable layout. 
-It has the benefit of being familiar to people coming from SVN, 
+With Bazaar, that is a perfectly reasonable layout.
+It has the benefit of being familiar to people coming from SVN,
 and making it clear where the development focus is.
 
-When you have multiple projects in the same repository, 
+When you have multiple projects in the same repository,
 the SVN layout is a little unclear what to do.
 
 
@@ -52,8 +52,8 @@
        +- branches/      # Container for project2 branches
 
 
-This also works with Bazaar. 
-However, with Bazaar repositories are cheap to create 
+This also works with Bazaar.
+However, with Bazaar repositories are cheap to create
 (a simple ``bzr init-repo`` away), and their primary benefit is when the
 branches share a common ancestry.
 
@@ -64,7 +64,7 @@
      +- branches/      # A container directory
          +- foo/       # Branch for developing feature foo of project1
            ...
-    
+
     project2/          # A repository for project2
      +- trunk/         # Mainline for project2
      +- branches/      # Container for project2 branches
@@ -100,17 +100,17 @@
         +- project1-foo/  # Branch 'foo' of project1
         +- project2-bar/  # Branch 'bar' of project2
 
-I believe the reason for this in SVN, is so that someone 
+I believe the reason for this in SVN, is so that someone
 can checkout all of "``trunk/``" and get the all the mainlines for all projects.
 
 This layout can be used for Bazaar, but it is not generally recommended.
 
- 1) ``bzr branch/checkout/get`` is a single branch at a time. 
+ 1) ``bzr branch/checkout/get`` is a single branch at a time.
     So you don't get the benefit of getting all mainlines with a single command. [1]_
 
- 2) It is less obvious of whether ``repository/trunk/foo`` is the ``trunk`` of project 
+ 2) It is less obvious of whether ``repository/trunk/foo`` is the ``trunk`` of project
     ``foo`` or it is just the ``foo`` directory in the ``trunk`` branch.
-    Some of this confusion is due to SVN, because it uses the same "namespace" 
+    Some of this confusion is due to SVN, because it uses the same "namespace"
     for files in a project that it uses for branches of a project.
     In Bazaar, there is a clear distinction of what files make up a project, versus
     the location of the Branch. (After all, there is only one ``.bzr/`` directory per branch,
@@ -148,7 +148,7 @@
       +- 1.0/
           +- 1.1.1/
 
-The idea with this layout is that you are creating a hierarchical layout for branches. 
+The idea with this layout is that you are creating a hierarchical layout for branches.
 Where changes generally flow upwards in the namespace. It also gives people a little
 corner of the namespace to work on their stuff.
 One nice feature of this layout, is it makes branching "cheaper" because it gives you
@@ -162,7 +162,7 @@
   bzr branch http://host/repository/project/branches/joe-feature-foo-bugfix-10/
 
 Versus::
-  
+
   bzr branch http://host/project/joe/foo/bugfix-10
 
 
@@ -175,7 +175,7 @@
   joe-bugfix-13/
   joe-frizban/
 
-Versus having these broken out by developer. 
+Versus having these broken out by developer.
 If the number of branches are small, ``branches/`` has the nice advantage
 of being able to see all branches in a single view.
 If the number of branches is large, ``branches/`` has the distinct disadvantage
@@ -183,7 +183,7 @@
 branch you are interested in, when there are 100 branches to look through).
 
 Nested branching seems to scale better to larger number of branches.
-However, each individual branch is less discoverable. 
+However, each individual branch is less discoverable.
 (eg. "Is Joe working on bugfix 10 in his feature foo branch, or his feature bar branch?")
 
 One other small advantage is that you can do something like::
@@ -192,7 +192,7 @@
   or
    bzr branch http://host/project/release/1/1/2
 
-To indicate release 1.1.1 and 1.1.2. This again depends on how many releases you have 
+To indicate release 1.1.1 and 1.1.2. This again depends on how many releases you have
 and whether the gain of splitting things up outweighs the ability to see more at a glance.
 
 
@@ -217,7 +217,7 @@
 It lets you see what branches are actively being developed on, which is usually
 only a small number, versus the total number of branches ever created.
 Old branches are not lost (versus deleting them), but they are "filed away",
-such that the more likely you are to want a branch the easier it is to find. 
+such that the more likely you are to want a branch the easier it is to find.
 (Conversely, older branches are likely to be harder to find).
 
 The biggest disadvantage with this layout, is that branches move around.
@@ -237,7 +237,7 @@
 that could be changed.
 This is actually how `Launchpad`_ allows you to ``bzr checkout https://launchpad.net/bzr``.
 Effectively a ``BranchReference`` is a symlink, but it allows you to reference any other URL.
-If it is extended to support relative references, it would even work over http, sftp, 
+If it is extended to support relative references, it would even work over http, sftp,
 and local paths.
 
 .. _Launchpad: https://launchpad.net
@@ -247,7 +247,7 @@
 --------------------------------------------------------------------------
 
 Another method of allowing some scalability while also allowing the
-browsing of "current" branches. Basically, this works on the assumption 
+browsing of "current" branches. Basically, this works on the assumption
 that actively developed branches will be "new" branches, and older branches
 are either merged or abandoned.
 
@@ -292,8 +292,8 @@
 The general idea is that by targeting a release, you can look at what branches are
 waiting to be merged. It doesn't necessarily give you a good idea of what the
 state of the branch (is it in development or finished awaiting review).
-It also has a history-hiding effect, and otherwise has the same benefits 
-and deficits as a date-based sorting. 
+It also has a history-hiding effect, and otherwise has the same benefits
+and deficits as a date-based sorting.
 
 
 Simple developer naming (``project/joe/foo``, ``project/barry/bar``)

=== modified file 'doc/en/user-guide/shelving_changes.txt'
--- doc/en/user-guide/shelving_changes.txt	2009-03-12 06:04:54 +0000
+++ doc/en/user-guide/shelving_changes.txt	2009-12-02 20:34:07 +0000
@@ -15,7 +15,7 @@
   +++ description.txt
   @@ -2,7 +2,7 @@
    ===============
-   
+
    These plugins
   -by Michael Ellerman
   +written by Michael Ellerman
@@ -23,7 +23,7 @@
    fine-grained 'undo'
    facility
   @@ -11,6 +11,6 @@
-   This allows you to 
+   This allows you to
    undo some of
    your changes,
   -commit, and get
@@ -39,7 +39,7 @@
   +++ description.txt
   @@ -2,7 +2,7 @@
    ===============
-   
+
    These plugins
   -by Michael Ellerman
   +written by Michael Ellerman
@@ -51,7 +51,7 @@
   --- description.txt
   +++ description.txt
   @@ -11,6 +11,6 @@
-   This allows you to 
+   This allows you to
    undo some of
    your changes,
   -commit, and get
@@ -63,7 +63,7 @@
   Shelve 2 change(s)? [yNfrq?]', 'y'
   Selected changes:
    M  description.txt
-  Changes shelved with id "1".  
+  Changes shelved with id "1".
 
 If there are lots of changes in the working tree, you
 can provide the ``shelve`` command with a list of files
@@ -77,7 +77,7 @@
   +++ description.txt
   @@ -2,7 +2,7 @@
    ===============
-   
+
    These plugins
   -by Michael Ellerman
   +written by Michael Ellerman

=== modified file 'doc/en/user-guide/specifying_revisions.txt'
--- doc/en/user-guide/specifying_revisions.txt	2009-04-04 02:57:47 +0000
+++ doc/en/user-guide/specifying_revisions.txt	2009-12-02 23:09:40 +0000
@@ -36,17 +36,23 @@
  +----------------------+------------------------------------+
  | *number*             | revision number                    |
  +----------------------+------------------------------------+
- | **revno**:*number*   | positive revision number           |
+ | **revno**:*number*   | revision number                    |
  +----------------------+------------------------------------+
  | **last**:*number*    | negative revision number           |
  +----------------------+------------------------------------+
+ | *guid*               | globally unique revision id        |
+ +----------------------+------------------------------------+
  | **revid**:*guid*     | globally unique revision id        |
  +----------------------+------------------------------------+
  | **before**:*rev*     | leftmost parent of ''rev''         |
  +----------------------+------------------------------------+
- | **date**:*value*     | first entry after a given date     |
- +----------------------+------------------------------------+
- | **tag**:*value*      | revision matching a given tag      |
+ | *date-value*         | first entry after a given date     |
+ +----------------------+------------------------------------+
+ | **date**:*date-value*| first entry after a given date     |
+ +----------------------+------------------------------------+
+ | *tag-name*           | revision matching a given tag      |
+ +----------------------+------------------------------------+
+ | **tag**:*tag-name*   | revision matching a given tag      |
  +----------------------+------------------------------------+
  | **ancestor**:*path*  | last merged revision from a branch |
  +----------------------+------------------------------------+
@@ -81,7 +87,7 @@
 ~~~~~
 
 **revid** allows specifying a an internal revision ID, as shown by ``bzr
-log`` and some other commands.
+log --show-ids`` and some other commands.
 
 For example::
 
@@ -128,7 +134,7 @@
 ~~~~~~~~
 
 **ancestor**:*path*
-    specifies the common ancestor between the current branch and a 
+    specifies the common ancestor between the current branch and a
     different branch. This is the same ancestor that would be used for
     merging purposes.
 

=== modified file 'doc/en/user-guide/stacked.txt'
--- doc/en/user-guide/stacked.txt	2009-07-20 08:47:58 +0000
+++ doc/en/user-guide/stacked.txt	2009-12-02 20:34:07 +0000
@@ -18,7 +18,7 @@
   than leaving them in a shared repository).
 
 * Security is improved over shared repositories, because the stacked-on
-  repository can be physically readonly to developers committing to stacked 
+  repository can be physically readonly to developers committing to stacked
   branches.
 
 These benefits make stacked branches ideal for various scenarios

=== modified file 'doc/en/user-guide/svn_plugin.txt'
--- doc/en/user-guide/svn_plugin.txt	2009-06-10 03:56:49 +0000
+++ doc/en/user-guide/svn_plugin.txt	2009-09-25 10:22:44 +0000
@@ -30,13 +30,11 @@
 GNOME project like **beagle**. Firstly, setup a local shared repository
 for storing your branches in and checkout the trunk::
 
-  bzr init-repo --default-rich-root beagle-repo
+  bzr init-repo beagle-repo
   cd beagle-repo
   bzr checkout svn+ssh://svn.gnome.org/svn/beagle/trunk beagle-trunk
 
-Note that using the ``default-rich-root`` option to ``init-repo`` is
-important as bzr-svn requires some extra metadata not yet supported in Bazaar's
-default repository format. Next, create a feature branch and hack away::
+Next, create a feature branch and hack away::
 
   bzr branch beagle-trunk beagle-feature1
   cd beagle-feature1
@@ -71,7 +69,7 @@
 
 Here's the recipe from above updated to use a central Bazaar mirror::
 
-  bzr init-repo --default-rich-root beagle-repo
+  bzr init-repo beagle-repo
   cd beagle-repo
   bzr branch bzr+ssh://bzr.gnome.org/beagle.bzr/trunk beagle-trunk
   bzr branch beagle-trunk beagle-feature1

=== modified file 'doc/en/user-guide/undoing_mistakes.txt'
--- doc/en/user-guide/undoing_mistakes.txt	2009-04-04 02:50:01 +0000
+++ doc/en/user-guide/undoing_mistakes.txt	2009-11-23 15:29:24 +0000
@@ -97,8 +97,9 @@
 chapter, it is worth noting now that ``uncommit`` restores any pending
 merges. (Running ``bzr status`` after ``uncommit`` will show these.)
 ``merge`` can also be used to effectively undo just a selected commit
-earlier in history. For more information on ``merge``, see `Merging changes`_
-in the next chapter and the Bazaar User Reference.
+earlier in history. For more information on ``merge``, see
+`Merging changes <merging_changes.html>`_ in the next chapter and the
+Bazaar User Reference.
 
 Undoing multiple commits
 ------------------------
@@ -132,7 +133,8 @@
 This will change your entire tree back to the state as of revision 19,
 which is probably only what you want if you haven't made any new commits
 since then. If you have, the ``revert`` would wipe them out as well. In that
-case, you probably want to use `Reverse cherrypicking`_ instead to
+case, you probably want to use `Reverse cherrypicking
+<adv_merging.html#reverse-cherrypicking>`_ instead to
 back out the bad fix.
 
 Note: As an alternative to using an absolute revision number (like 19), you can

=== modified file 'doc/en/user-guide/using_checkouts.txt'
--- doc/en/user-guide/using_checkouts.txt	2008-12-24 03:14:16 +0000
+++ doc/en/user-guide/using_checkouts.txt	2009-09-09 15:30:59 +0000
@@ -66,8 +66,9 @@
 Note: If your code base is really large and disk space on your computer
 is limited, lightweight checkouts may be the right choice for you.
 Be sure to consider all your options though including
-`shared repositories <#a-reminder-about-shared-repositories>`_,
-`stacked branches <#using-stacked-branches>`_, and `reusing a checkout`_.
+`shared repositories <branching_a_project.html#a-reminder-about-shared-repositories>`_,
+`stacked branches <stacked.html>`_, and
+`reusing a checkout <reusing_a_checkout.html>`_.
 
 Updating to the latest content
 ------------------------------

=== modified file 'doc/en/user-guide/version_info.txt'
--- doc/en/user-guide/version_info.txt	2008-03-13 18:51:13 +0000
+++ doc/en/user-guide/version_info.txt	2009-12-02 20:34:07 +0000
@@ -104,5 +104,5 @@
 set the ``clean`` flag in ``version_info``, as well as set entries in
 ``file_revisions`` as ``modified`` where appropriate.
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/en/user-guide/web_browsing.txt'
--- doc/en/user-guide/web_browsing.txt	2009-03-21 02:00:59 +0000
+++ doc/en/user-guide/web_browsing.txt	2009-12-02 20:34:07 +0000
@@ -5,10 +5,10 @@
 --------
 
 There are a range of options available for providing a web view of a
-Bazaar repository, the main one being Loggerhead. The homepage of Loggerhead 
+Bazaar repository, the main one being Loggerhead. The homepage of Loggerhead
 can be found at https://launchpad.net/loggerhead.
 
-A list of alternative web viewers including download links can be found on 
+A list of alternative web viewers including download links can be found on
 http://bazaar-vcs.org/WebInterface.
 
 Note: If your project is hosted or mirrored on Launchpad,

=== modified file 'doc/en/user-guide/writing_a_plugin.txt'
--- doc/en/user-guide/writing_a_plugin.txt	2008-10-15 19:34:48 +0000
+++ doc/en/user-guide/writing_a_plugin.txt	2009-08-20 13:26:36 +0000
@@ -32,11 +32,14 @@
 Plugin searching rules
 ----------------------
 
-Bzr will scan ``bzrlib/plugins`` and ``~/.bazaar/plugins`` for plugins
-by default.  You can override this with ``BZR_PLUGIN_PATH``.  Plugins
-may be either modules or packages.  If your plugin is a single file,
-you can structure it as a module.  If it has multiple files, or if you
-want to distribute it as a bzr branch, you should structure it as a
+Bzr will scan ``~/.bazaar/plugins``  and ``bzrlib/plugins`` for plugins
+by default.  You can override this with  ``BZR_PLUGIN_PATH``
+(see `User Reference <../user-reference/bzr_man.html#bzr-plugin-path>`_
+for details).
+
+Plugins may be either modules or packages.  If your plugin is a single
+file, you can structure it as a module.  If it has multiple files, or if
+you want to distribute it as a bzr branch, you should structure it as a
 package, i.e. a directory with an ``__init__.py`` file.
 
 More information

=== modified file 'doc/en/user-guide/zen.txt'
--- doc/en/user-guide/zen.txt	2008-06-06 11:55:58 +0000
+++ doc/en/user-guide/zen.txt	2009-12-02 20:34:07 +0000
@@ -56,7 +56,7 @@
   102: Add code and tests for X
   101: Add tests for Y
   100: ...
-  
+
 Many teams use this approach because their tools make branching and merging
 difficult. As a consequence, developers update from and commit to the trunk
 frequently, minimizing integration pain by spreading it over every commit.

=== added directory 'doc/es/_static'
=== added file 'doc/es/_static/bzr icon 16.png'
Binary files doc/es/_static/bzr icon 16.png and doc/es/_static/bzr icon 16.png differ
=== added file 'doc/es/_static/bzr.ico'
Binary files doc/es/_static/bzr.ico and doc/es/_static/bzr.ico differ
=== added directory 'doc/es/_static/es'
=== renamed file 'doc/es/quick-reference/Makefile' => 'doc/es/_static/es/Makefile'
--- doc/es/quick-reference/Makefile	2009-06-29 11:02:31 +0000
+++ doc/es/_static/es/Makefile	2009-09-09 00:49:50 +0000
@@ -1,5 +1,5 @@
-TARGETS=quick-start-summary.png quick-start-summary.pdf
-OBJECTS=quick-start-summary.svg Makefile
+TARGETS=bzr-es-quick-reference.png bzr-es-quick-reference.pdf
+OBJECTS=bzr-es-quick-reference.svg Makefile
 
 all: $(TARGETS)
 
@@ -11,9 +11,9 @@
 .svg.png:
 	rsvg-convert -d 300 -p 300 -z 3.3346 -f png -o $@ $<
 
-bzr-quickref.png: $(OBJECTS)
+bzr-es-quick-reference.png: $(OBJECTS)
 
-bzr-quickref.pdf: $(OBJECTS)
+bzr-es-quick-reference.pdf: $(OBJECTS)
 
 clean:
 	rm -f $(TARGETS)

=== renamed file 'doc/es/quick-reference/quick-start-summary.pdf' => 'doc/es/_static/es/bzr-es-quick-reference.pdf'
=== renamed file 'doc/es/quick-reference/quick-start-summary.png' => 'doc/es/_static/es/bzr-es-quick-reference.png'
=== renamed file 'doc/es/quick-reference/quick-start-summary.svg' => 'doc/es/_static/es/bzr-es-quick-reference.svg'
=== added directory 'doc/es/_templates'
=== added file 'doc/es/_templates/layout.html'
--- doc/es/_templates/layout.html	1970-01-01 00:00:00 +0000
+++ doc/es/_templates/layout.html	2009-10-30 07:51:16 +0000
@@ -0,0 +1,27 @@
+{% extends "!layout.html" %}
+
+{% block rootrellink %}
+<li><a href="http://bazaar-vcs.org/">
+    <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Inicio</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/en/">Documentación</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}
+
+{% block document %}
+ <script type="text/javascript">
+  var gaJsHost = (("https:" == document.location.protocol) ?  "https://ssl." : "http://www.");
+  document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
+  </script>
+  <script type="text/javascript">
+  try{
+  var pageTracker = _gat._getTracker("UA-1018242-1");
+  pageTracker._trackPageview();
+  } catch(err) {}
+  try {
+    /* bazaar team tracker */
+    var pageTracker = _gat._getTracker("UA-11329411-2");
+    pageTracker._trackPageview();
+  } catch(err) {}
+</script>
+{{ super() }}
+{% endblock %}

=== added file 'doc/es/conf.py'
--- doc/es/conf.py	1970-01-01 00:00:00 +0000
+++ doc/es/conf.py	2009-09-09 15:51:18 +0000
@@ -0,0 +1,89 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'es'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': u'Contenidos (%s)',
+        u'Bazaar User Guide': u'Guia de Usuario',
+        u'Bazaar User Reference': None,
+        u'Bazaar Release Notes': None,
+        u'Bazaar Upgrade Guide': None,
+        u'Bazaar in five minutes': u'Bazaar en cinco minutos',
+        u'Bazaar Tutorial': None,
+        u'Using Bazaar With Launchpad': None,
+        u'Centralized Workflow Tutorial': None,
+    }
+def bzr_title(s):
+    return bzr_titles.get(s) or s
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+language = bzr_locale
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  # Manuals
+  ('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  #('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  #('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  #('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  #('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  #('tutorials/using_bazaar_with_launchpad',
+  #  'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+  #  bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  #('tutorials/centralized_workflow',
+  #  'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+  #  bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    'user-guide/resolving_conflicts',
+    'user-guide/version_info',
+    # Plain-style documentation generation stuff
+    'user-guide/index-plain',
+]
+

=== removed directory 'doc/es/developer-guide'
=== renamed file 'doc/index.es.txt' => 'doc/es/index.txt'
--- doc/index.es.txt	2009-06-29 11:02:31 +0000
+++ doc/es/index.txt	2009-12-02 20:34:07 +0000
@@ -1,46 +1,40 @@
-==================================
+=================================
 Indice de Documentacion de Bazaar
-==================================
+=================================
 
 Las ultimas versiones de estos documentos se encuentran disponibles
-en la pagina de  Bazaar, http://doc.bazaar-vcs.org.
+en la pagina de  Bazaar, http://doc.bazaar-vcs.org/en/.
 
 Documentacion Principal
 =======================
 
-* `Mini Tutorial <es/mini-tutorial/index.html>`_ 
-
-* `Referencia Rapida <es/quick-reference/quick-start-summary.svg>`_
-
-* `Guia de Usuario <es/user-guide/index.html>`_ 
-
-* `Referencia <es/user-reference/bzr_man.html>`_ 
-
-* `Notas sobre la Version <es/release-notes/NEWS.html>`_
-
-* `Guia del Desarrollador <es/developer-guide/HACKING.html>`_
+.. toctree::
+   :maxdepth: 1
+
+   mini-tutorial/index
+   quick-reference/index
+   user-guide/index
 
 
 Otra Documentacion
-===================
+==================
 
 Mudandose a Bazaar (enlances web):
 
-* `Guias de Mudanzas <http://bazaar-vcs.org/BzrSwitching>`_ 
-  - para los usuarios que se mudan de otros SCV
-
-* `Guias de Migracion <http://bazaar-vcs.org/BzrMigration>`_
+* `Guias de Migracion <http://doc.bazaar-vcs.org/migration/en/>`_
   - para equipos que mudan el historial de otros SCV
 
+* `Guias de Plugins <http://doc.bazaar-vcs.org/plugins/en/>`_
+
 Otros Documentos (enlances web):
 
 * `Glosario <http://bazaar-vcs.org/BzrGlossary>`_
 
-* `Preguntas Frecuentes <http://bazaar-vcs.org/FAQ>`_
+* `Preguntas Frecuentes <https://answers.launchpad.net/bzr>`_
 
 * `Referencia del API bzrlib <http://bazaar-vcs.org/BzrLib>`_
 
 Especificaciones tecnicas, planes a futuro y varias
 notas tecnicas varias en Ingles:
 
-* `Catalogo de Documentos para Desarrolladores <developers/index.html>`_
+* `Catalogo de Documentos para Desarrolladores <http://doc.bazaar-vcs.org/latest/developers/>`_

=== modified file 'doc/es/mini-tutorial/index.txt'
--- doc/es/mini-tutorial/index.txt	2009-06-29 11:02:31 +0000
+++ doc/es/mini-tutorial/index.txt	2009-12-02 20:34:07 +0000
@@ -2,17 +2,15 @@
 Bazaar en cinco minutos
 =======================
 
-.. contents:: Contenidos
-
 Introducción
 ============
 
 Bazaar es un sistema de control de versiones distribuido que facilita que
 varias personas puedan trabajar de forma conjunta en proyectos de software.
 
-A lo largo de los próximos cinco minutos, aprenderá cómo poner sus archivos 
-bajo control de versiones, como registrar cambios en ellos, examinar su 
-trabajo, publicarlo y enviar su trabajo para que sea integrado en el trunk de 
+A lo largo de los próximos cinco minutos, aprenderá cómo poner sus archivos
+bajo control de versiones, como registrar cambios en ellos, examinar su
+trabajo, publicarlo y enviar su trabajo para que sea integrado en el trunk de
 un proyecto.
 
 Si prefiere una introducción más detallada, eche un vistazo a
@@ -41,14 +39,14 @@
 Preséntese
 ==========
 
-Antes de empezar a trabajar, es conveniente que le diga a Bazaar quién es 
-usted. De ese modo su trabajo será identificando correctamente en los logs 
+Antes de empezar a trabajar, es conveniente que le diga a Bazaar quién es
+usted. De ese modo su trabajo será identificando correctamente en los logs
 de revisión.
 
 Utilice su nombre y dirección de email en lugar de John Doe, teclee::
 
   $ bzr whoami "John Doe <john.doe@gmail.com>"
-  
+
 Bazaar creará o modificará ahora un archivo de configuración, incluyendo su
 nombre y dirección de email.
 
@@ -67,7 +65,7 @@
  $ cd miproyecto
  $ mkdir subdirectorio
  $ touch test1.txt test2.txt test3.txt subdirectorio/test4.txt
- 
+
 **Nota para usuarios de Windows:** utilice Windows Explorer para crear sus
 directorios, luego haga click derecho en dichos directorios y seleccione
 ``Nuevo archivo`` para crear sus archivos.
@@ -75,14 +73,14 @@
 Ahora vamos a hacer que Bazaar se inicialize en el directorio de su proyecto::
 
   $ bzr init
-  
+
 Si parece que no ha ocurrido nada no se preocupe. Bazaar ha creado un
 branch_ dónde guardará sus archivos y su histórico de revisiones.
 
 .. _branch: http://bazaar-vcs.org/Branch
 
 El siguiente paso es decirle a Bazaar a que archivos desea seguirles la pista.
-Ejecutando ``bzr add`` agregará recursivamente todos los elementos dentro del 
+Ejecutando ``bzr add`` agregará recursivamente todos los elementos dentro del
 proyecto::
 
  $ bzr add
@@ -92,11 +90,11 @@
  added test3.txt
  added subdirectorio/test4.txt
 
-A continuación tome una instantánea de sus archivos agregándolos a su branch. 
+A continuación tome una instantánea de sus archivos agregándolos a su branch.
 Agregue un mensaje para explicar por qué hace el commit::
 
   $ bzr commit -m "Importación inicial"
-  
+
 Como Bazaar es un sistema de control de versiones distribuido, no necesita
 conectar con un servidor central para hacer el commit. Bazaar guarda su
 branch y todos sus commits dentro del directorio con el que está trabajando,
@@ -160,14 +158,14 @@
 
  $ bzr push --create-prefix sftp://su.nombre@example.com/~/public_html/miproyecto
  2 revision(s) pushed.
- 
+
 Bazaar creará un directorio ``miproyecto`` en el servidor remoto e
 introducirá su branch en él.
- 
+
 Ahora cualquiera podrá crear su propia copia de su branch tecleando::
 
  $ bzr branch http://www.example.com/miproyecto
- 
+
 **Nota:** para utilizar sftp deberá instalar ``paramiko`` y
 ``pyCrypto``. Vea http://bazaar-vcs.org/InstallationFaq para más información.
 
@@ -188,13 +186,13 @@
 
  $ bzr push bzr+ssh://john.doe@bazaar.launchpad.net/~john.doe/+junk/miproyecto
 
-**Nota:** ``+junk`` significa que este branch no está asociado con ningún proyecto 
+**Nota:** ``+junk`` significa que este branch no está asociado con ningún proyecto
 concreto en Launchpad.
 
 Ahora cualquiera podrá crear su propia copia de su branch tecleando::
 
  $ bzr branch http://bazaar.launchpad.net/~john.doe/+junk/miproyecto
- 
+
 También puede ver información sobre su branch, histórico de revisiones
 incluido, en https://code.launchpad.net/people/+me/+junk/miproyecto
 
@@ -206,7 +204,7 @@
 copia de su branch. Vamos a coger un ejemplo real, la interfaz GTK de Bazaar::
 
   $ bzr branch http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk bzr-gtk.john
-  Branched 292 revision(s).                                                        
+  Branched 292 revision(s).
 
 Bazaar descargará todos los archivos y el histórico de revisiones completo
 del trunk branch del proyecto bzr-gtk y creará una copia llamada
@@ -230,11 +228,11 @@
   $ bzr merge
   Merging from saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
   All changes applied successfully.
-            
+
 Compruebe qué ha cambiado::
 
   $ bzr diff
- 
+
 Si está contento con los cambios puede añadirlos en su branch personal::
 
   $ bzr commit -m "Integración desde el branch principal"
@@ -257,12 +255,12 @@
 
  $ bzr send -o mycode.patch
  Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
- 
+
 Ahora puede enviar por email la instruccion merge al proyecto bzr-gtk
 quien, si así lo quieren, pueden utilizarla para integrar su trabajo
 dentro del branch principal.
- 
- 
+
+
 Aprendiendo más
 ===============
 

=== added file 'doc/es/quick-reference/index.txt'
--- doc/es/quick-reference/index.txt	1970-01-01 00:00:00 +0000
+++ doc/es/quick-reference/index.txt	2009-09-09 02:32:10 +0000
@@ -0,0 +1,6 @@
+Referencia Rapida
+=================
+
+* `PDF format <../_static/es/bzr-es-quick-reference.pdf>`_
+* `PNG format <../_static/es/bzr-es-quick-reference.png>`_
+* `SVG format <../_static/es/bzr-es-quick-reference.svg>`_

=== removed directory 'doc/es/release-notes'
=== added file 'doc/es/user-guide/index-plain.txt'
--- doc/es/user-guide/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/es/user-guide/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,114 @@
+##########################
+Guia de Usuarios de Bazaar
+##########################
+
+.. Files are currently links but will become includes once the
+.. content makes more sense as a whole.
+.. Please mark sections in linked/included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+
+Introducción
+############
+
+.. include later - introducing_bazaar.txt
+.. include later - core_concepts.txt
+.. include later - bazaar_workflows.txt
+
+
+Empezando
+#########
+
+.. include later - installing_bazaar.txt
+.. include later -  entering_commands.txt
+.. include later - revnos.txt
+.. include later - getting_help.txt
+.. include later - configuring_bazaar.txt
+.. include later - using_aliases.txt
+.. include later - plugins.txt
+
+
+Control de Versionamiento Personal
+##################################
+
+.. include later - solo_intro.txt
+.. include later - starting_a_project.txt
+.. include later - controlling_registration.txt
+.. include later - reviewing_changes.txt
+.. include later - recording_changes.txt
+.. include later - browsing_history.txt
+.. include later - releasing_a_project.txt
+.. include later - undoing_mistakes.txt
+
+
+Compartiendo con tus pares
+##########################
+
+.. include later - partner_intro.txt
+.. include later - branching_a_project.txt
+.. include later - merging_changes.txt
+.. include:: resolving_conflicts.txt
+.. include later - annotating_changes.txt
+
+
+Colaboración en equipo, modo centralizado
+#########################################
+
+.. include later - central_intro.txt
+.. include later - publishing_a_branch.txt
+.. include later - using_checkouts.txt
+.. include later - working_offline_central.txt
+.. include later - reusing_a_checkout.txt
+
+
+Colaboracion en equipo, modo distribuido
+########################################
+
+.. include later - distributed_intro.txt
+.. include later - organizing_branches.txt
+.. include later - using_gatekeepers.txt
+.. include later - sending_changes.txt
+
+
+Un tour breve de los plugins mas populares
+##########################################
+
+.. include later - part2_intro.txt
+.. include later - bzrtools_plugin.txt
+.. include later - svn_plugin.txt
+.. include later looms_plugin.txt
+
+
+Integrando Bazaar en tu entorno
+###############################
+
+.. include later - web_browsing.txt
+.. include later - file_explorers.txt
+.. include later - desktop_integration.txt
+.. include later - editors_and_ides.txt
+.. include later - email.txt
+.. include later - bug_trackers.txt
+
+
+Temas varios
+############
+
+.. include later - adv_merging.txt
+.. include later - server.txt
+.. include later - hooks.txt
+.. include:: version_info.txt
+
+
+Apéndice
+########
+
+.. include later - specifying_revisions.txt
+.. include later - shared_repository_layouts.txt
+.. include later - setting_up_email.txt
+.. include later - http_smart_server.txt
+.. include later - writing_a_plugin.txt
+
+.. |--| unicode:: U+2014

=== modified file 'doc/es/user-guide/index.txt'
--- doc/es/user-guide/index.txt	2008-05-12 00:59:13 +0000
+++ doc/es/user-guide/index.txt	2009-12-02 20:34:07 +0000
@@ -10,9 +10,6 @@
 ..   level 3 ~~~~~~~~
 ..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
 
-.. contents:: :depth: 2
-.. sectnum::
-
 
 Introducción
 ############
@@ -103,7 +100,7 @@
 .. include later - server.txt
 .. include later - hooks.txt
 .. include:: version_info.txt
- 
+
 
 Apéndice
 ########

=== modified file 'doc/es/user-guide/resolving_conflicts.txt'
--- doc/es/user-guide/resolving_conflicts.txt	2008-05-12 00:59:13 +0000
+++ doc/es/user-guide/resolving_conflicts.txt	2009-12-02 20:34:07 +0000
@@ -5,7 +5,7 @@
 Algunas operaciones, como merge, revert y pull, modifican el contenido de su
 working tree. Estas modificaciones son generadas automaticamente, con lo cual
 pueden tener conflictos con el estado actual de su working tree.  Muchos tipos
-de cambios pueden ser combinados automaticamentem pero a veces solo algunos 
+de cambios pueden ser combinados automaticamentem pero a veces solo algunos
 humanos pueden determinar la decision correcta a tomar.  Cuando esto sucede,
 Bazaar lo informara que hay un conflict y pedira que lo resuelva. El comando
 para resolverlo es ``resolve``, pero debe realizar alguna accion antes de
@@ -25,7 +25,7 @@
 reconciliado entre dos cambios. Bazaar emitira archivos para cada version con
 extensiones THIS, OTHER, y BASE.  THIS es la version del archivo del tree
 de destino, por ejemplo, el tree al que estan unificando los cambios. OTHER
-es la version que estan uniendo al tree de destino. BASE es la version 
+es la version que estan uniendo al tree de destino. BASE es la version
 anterior que es usado como base para la comparacion.
 
 En la copia principal del archivo, Bazaar incluira los cambios que puede
@@ -33,7 +33,7 @@
 "herringbone" como ``<<<<<<<``.
 
 Digamos que el texto inicial es "El lider del proyecto lo lanzo.", y THIS lo
-modifica a "Martin Pool lo lanzo.", mientras que OTHER lo modifica a "El lider 
+modifica a "Martin Pool lo lanzo.", mientras que OTHER lo modifica a "El lider
 del proyecto lanzo Bazaar."  Un conflicto se veria asi::
 
   <<<<<<< TREE
@@ -45,16 +45,16 @@
 La resulucion correcta seria "Martin Pool lanzo Bazaar."
 
 Puede manejar conflictos de texto o editando la copia principal del archivo,
-o invocando herramientas externas on las versiones THIS, OTHER y BASE. Vale 
+o invocando herramientas externas on las versiones THIS, OTHER y BASE. Vale
 la pena mencionar que resolver conflictos de texto rara vez involucra elegir
-un conjunto de cambios u otros. Los mas comun es que tenga que combinar 
+un conjunto de cambios u otros. Los mas comun es que tenga que combinar
 inteligentemente.
 
 Si modifica la copia principal, asegurese de sacar los marcadores "herringbone".
-Cuando termino de modificar, el archivo debe estar como si nunca hubiese estado 
+Cuando termino de modificar, el archivo debe estar como si nunca hubiese estado
 con conflictos, y estar listo para hacer commit.
 
-Cuando resolvio los conflictos de texto, solo ejecute "bzr resolve", y Bazaar 
+Cuando resolvio los conflictos de texto, solo ejecute "bzr resolve", y Bazaar
 detectera automaticamente que resolvio.
 
 
@@ -64,19 +64,19 @@
 
   Contents conflict in ARCHIVO
 
-Este conflicto sucede cuando hay cambios que crean conflictos en el tree de 
-destino y el fuente a unificar, pero los items con conflictos no son archivos 
-de texto.  Pueden ser archivos binarios, symlinks o directorios.  Pueden suceder 
+Este conflicto sucede cuando hay cambios que crean conflictos en el tree de
+destino y el fuente a unificar, pero los items con conflictos no son archivos
+de texto.  Pueden ser archivos binarios, symlinks o directorios.  Pueden suceder
 con archivos que fueron eliminados en un lado, y modificados en el otro.
 
 Como los conflictos de texto, Bazaar creara archivos THIS, OTHER y BASE.
-(pueden ser archivos normales, symlinks o directorios).  Esto no incluira 
-la "copia principal" del archivo con marcadores "herringbone".  Parecera que la 
+(pueden ser archivos normales, symlinks o directorios).  Esto no incluira
+la "copia principal" del archivo con marcadores "herringbone".  Parecera que la
 "copia principal" fue renombrado a THIS o OTHER.
 
-Para resolver esto, utilice "bzr mv" para renombrar el archivo a su nombre 
-original, y combine los cambios manualmente. Cuando este satisfecho, ejecute 
-"bzr resolve ARCHIVO".  Bazaar no puede detectar cuando cambios de este tipo 
+Para resolver esto, utilice "bzr mv" para renombrar el archivo a su nombre
+original, y combine los cambios manualmente. Cuando este satisfecho, ejecute
+"bzr resolve ARCHIVO".  Bazaar no puede detectar cuando cambios de este tipo
 fueron resueltos.
 
 
@@ -87,9 +87,9 @@
   Conflict adding file ARCHIVO.  Moved existing file to ARCHIVO.moved.
 
 Bazaar a veces intentara crear un archivo usando la ruta que ya fue usada.
-El archivo existente ser renombrado a "ARCHIVO.moved".  Si lo desea, puede 
-renombrar cualquiera de estos archivos, o combinar su contenido. Cuando 
-este satisfecho, puede ejecutar "bzr resolve ARCHIVO" para marcar que el 
+El archivo existente ser renombrado a "ARCHIVO.moved".  Si lo desea, puede
+renombrar cualquiera de estos archivos, o combinar su contenido. Cuando
+este satisfecho, puede ejecutar "bzr resolve ARCHIVO" para marcar que el
 conflicto fue resuelto.
 
 
@@ -99,12 +99,12 @@
 
     Conflict because ARCHIVO no esta versionado, pero tiene hijos versionados.
 
-A veces Bazaar intentara crear un archivo cuyo directorio padre no esta 
-versionado. Esto sucede cuando el directorio fue eliminado en el destino, 
-pero tiene un hijo nuevo en origen, o vice versa. En esta situacion, Bazaar 
-versionara al directorio padre tambien.  Resolver este tema depende mucho 
-en el escenario particular.  Puede que quiera renombrar o eliminar o renombrar 
-cualquier archivo o directorio.  Cuando esta satisfecho, puede ejecutar "bzr 
+A veces Bazaar intentara crear un archivo cuyo directorio padre no esta
+versionado. Esto sucede cuando el directorio fue eliminado en el destino,
+pero tiene un hijo nuevo en origen, o vice versa. En esta situacion, Bazaar
+versionara al directorio padre tambien.  Resolver este tema depende mucho
+en el escenario particular.  Puede que quiera renombrar o eliminar o renombrar
+cualquier archivo o directorio.  Cuando esta satisfecho, puede ejecutar "bzr
 resolve ARCHIVO" para marcar el conflicto como resuelto.
 
 
@@ -114,12 +114,12 @@
 
   Conflict adding files to ARCHIVO.  Created directory.
 
-Esto sucede cuando un archivo fue eliminado en el destino, pero tiene hijos 
-en el origen.  Esto es similar al conflicto "Padre sin versionar", excepto 
-que el directorio padre *no existe*, en vez de no estar versionado. En esta 
-situacion, Bazaar creara al padre faltante.  Resolver estos temas depende 
-mucho de cada caso particular. Usted puede querer renombrar o eliminar 
-cualquiera de los archivos o directorios.  Cuando este satisfecho, puede 
+Esto sucede cuando un archivo fue eliminado en el destino, pero tiene hijos
+en el origen.  Esto es similar al conflicto "Padre sin versionar", excepto
+que el directorio padre *no existe*, en vez de no estar versionado. En esta
+situacion, Bazaar creara al padre faltante.  Resolver estos temas depende
+mucho de cada caso particular. Usted puede querer renombrar o eliminar
+cualquiera de los archivos o directorios.  Cuando este satisfecho, puede
 ejecutar "bzr resolve ARCHIVO" para marcar al archivo resuelto.
 
 
@@ -129,11 +129,11 @@
 
   Conflict: can't delete ARCHIVO because it is not empty.  Not deleting.
 
-Esto es el opuesto a "Padre faltante".  Un directorio es eliminado en el 
+Esto es el opuesto a "Padre faltante".  Un directorio es eliminado en el
 origen, pero tiene hijos en el destino.  Bazaar mantiene el directorio.
-Resolver este tema depende mucho de cada escenario particular.  Quizas quiera 
-renombrar o eliminar cualquiera de los archivos o directorios.  Cuando esta 
-satisfecho, puede ejecutar "bzr resolver ARCHIVO" para marcar al conflicto 
+Resolver este tema depende mucho de cada escenario particular.  Quizas quiera
+renombrar o eliminar cualquiera de los archivos o directorios.  Cuando esta
+satisfecho, puede ejecutar "bzr resolver ARCHIVO" para marcar al conflicto
 como resuelto.
 
 
@@ -143,9 +143,9 @@
 
   Path conflict: RUTA1 / RUTA2
 
-Esto sucede cuando en el origen y el destino han sido modificados el nombre 
-o directorio padre de un archivo. Bazaar usara la ruta de los elementos del 
-origen. Puede renombrar el archivo, y una vez que lo ha hecho, ejecutar 
+Esto sucede cuando en el origen y el destino han sido modificados el nombre
+o directorio padre de un archivo. Bazaar usara la ruta de los elementos del
+origen. Puede renombrar el archivo, y una vez que lo ha hecho, ejecutar
 "bzr resolve ARCHIVO" para marcarl el conflicto como resuelto.
 
 
@@ -155,8 +155,8 @@
 
   Conflict moving ARCHIVO into DIRECTORIO.  Cancelled move.
 
-Esto sucede cuando en el origen y el destino se han movido directorios, de 
-tal forma que, si se aplicaran los cambios, el directorios se contendria a 
+Esto sucede cuando en el origen y el destino se han movido directorios, de
+tal forma que, si se aplicaran los cambios, el directorios se contendria a
 si mismo.
 Por ejemplo::
 
@@ -172,14 +172,14 @@
   $ bzr merge ../other
 
 En esta situacion, Bazaar cancelara el movimiento, y dejara "a" en "b".
-Puede renombrar los directorios como desee, y una vez que lo ha hecho, 
+Puede renombrar los directorios como desee, y una vez que lo ha hecho,
 ejecute "bzr resolve ARCHIVO" para marcar el conflicto como resuelto.
 
 
 MalformedTransform
 ==================
 Es posible (aunque muy raro) que Bazaar de una excepcion MalformedTransform.
-Esto quiere decir que Bazaar encontro un conflicto en el sistema de archivos 
-que no le fue posible resolver.  Esto usualmente indica un bug.  Por favor 
-haganoslo saber si se encuentra en esta situacion. Nuestro sistema de bugs 
+Esto quiere decir que Bazaar encontro un conflicto en el sistema de archivos
+que no le fue posible resolver.  Esto usualmente indica un bug.  Por favor
+haganoslo saber si se encuentra en esta situacion. Nuestro sistema de bugs
 se encuentra en https://launchpad.net/bzr/+bugs

=== modified file 'doc/es/user-guide/version_info.txt'
--- doc/es/user-guide/version_info.txt	2008-05-04 18:17:45 +0000
+++ doc/es/user-guide/version_info.txt	2009-12-02 20:34:07 +0000
@@ -5,7 +5,7 @@
 Repaso General
 ==============
 
-Este documento describe las formas de usar ``bzr version-info`` como 
+Este documento describe las formas de usar ``bzr version-info`` como
 parte del proceso de embeber la informacion de vesion a un proyecto.
 
 
@@ -14,7 +14,7 @@
 
 TODO: Figure out how to attach into ``setup.py``
 
-Si usa un archivo Makefile para construir su proyecto, puede generar un 
+Si usa un archivo Makefile para construir su proyecto, puede generar un
 archivo on la informacion de version tan simple como::
 
   library/_version.py:
@@ -25,29 +25,29 @@
   * `version_info`: Un diccionario conteniendo informacion basica sobre el
     estado actual
 
-  * `revisions`: Un diccionario listando todas las revisiones en 
-    el historial del tree, junto con los tiempos y los mensajes de 
-    los commits. Esto por defecto esta en blanco salvi que use ``--all`` 
-    o `--include-history`` es provisto. Esto es util si quiere seguir 
-    que bugs arregla el lanzamiento de esa version. Para muchos proyectos 
+  * `revisions`: Un diccionario listando todas las revisiones en
+    el historial del tree, junto con los tiempos y los mensajes de
+    los commits. Esto por defecto esta en blanco salvi que use ``--all``
+    o `--include-history`` es provisto. Esto es util si quiere seguir
+    que bugs arregla el lanzamiento de esa version. Para muchos proyectos
     es mas informacion de la que se va a necesitar.
 
   * `file_revisions`: Un diccionario listando la revision que modifico
-    por ultima vez todos los archivos del proyecto. Esto puede ser usado 
-    similarmente a como se usan las palabras claves ``$Id$`` en los 
-    archivos controlados en CVS. La ultima fecha de modificacion puede 
-    ser determinada mirando en el mapa de ``revisions``. Esto tambien 
+    por ultima vez todos los archivos del proyecto. Esto puede ser usado
+    similarmente a como se usan las palabras claves ``$Id$`` en los
+    archivos controlados en CVS. La ultima fecha de modificacion puede
+    ser determinada mirando en el mapa de ``revisions``. Esto tambien
     esta vacio por defecto, y habilitado solo por ``--all`` o
     ``--include-file-revisions``.
-    
+
 
 Check Clean
 ===========
 
-La mayoria de la informacion sobre el contenido del proyecto puede 
+La mayoria de la informacion sobre el contenido del proyecto puede
 ser determinada a muy bajo costo con solo leer las entradas de revisiones.
-Sin embargo, puede ser util si el working tree fue actualizado completamente 
-cuando fue empaquetado, o si hubo alguna modificacion local. Al proveer 
-``--all`` o ``--check-clean``, ``bzr`` va a inspeccionar el working tree, 
-y definir el ``clean`` flag en ``version_info``, al igual que definir 
+Sin embargo, puede ser util si el working tree fue actualizado completamente
+cuando fue empaquetado, o si hubo alguna modificacion local. Al proveer
+``--all`` o ``--check-clean``, ``bzr`` va a inspeccionar el working tree,
+y definir el ``clean`` flag en ``version_info``, al igual que definir
 entradas en ``file_revisions`` como ``modified`` donde es apropiado.

=== removed directory 'doc/es/user-reference'
=== added file 'doc/index.es.txt'
--- doc/index.es.txt	1970-01-01 00:00:00 +0000
+++ doc/index.es.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,46 @@
+==================================
+Indice de Documentacion de Bazaar
+==================================
+
+Las ultimas versiones de estos documentos se encuentran disponibles
+en la pagina de  Bazaar, http://doc.bazaar-vcs.org.
+
+Documentacion Principal
+=======================
+
+* `Mini Tutorial <es/mini-tutorial/index.html>`_
+
+* `Referencia Rapida <es/_static/es/bzr-es-quick-reference.svg>`_
+
+* `Guia de Usuario <es/user-guide/index-plain.html>`_
+
+* `Referencia <en/user-reference/bzr_man.html>`_
+
+* `Notas sobre la Version <en/release-notes/NEWS.html>`_
+
+* `Guia del Desarrollador <developers/HACKING.html>`_
+
+
+Otra Documentacion
+===================
+
+Mudandose a Bazaar (enlances web):
+
+* `Guias de Mudanzas <http://bazaar-vcs.org/BzrSwitching>`_
+  - para los usuarios que se mudan de otros SCV
+
+* `Guias de Migracion <http://bazaar-vcs.org/BzrMigration>`_
+  - para equipos que mudan el historial de otros SCV
+
+Otros Documentos (enlances web):
+
+* `Glosario <http://bazaar-vcs.org/BzrGlossary>`_
+
+* `Preguntas Frecuentes <http://bazaar-vcs.org/FAQ>`_
+
+* `Referencia del API bzrlib <http://bazaar-vcs.org/BzrLib>`_
+
+Especificaciones tecnicas, planes a futuro y varias
+notas tecnicas varias en Ingles:
+
+* `Catalogo de Documentos para Desarrolladores <developers/index.html>`_

=== added file 'doc/index.ja.txt'
--- doc/index.ja.txt	1970-01-01 00:00:00 +0000
+++ doc/index.ja.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,85 @@
+===========================
+Bazaarのメインドキュメント
+===========================
+
+これらのドキュメントの最新版はBazaarのドキュメントのサイト、 http://doc.bazaar-vcs.org/ から入手可能で、
+詳しい情報は http://bazaar-vcs.org/Documentation のページからリンクされています。
+
+
+コアドキュメント
+================
+
+* `ユーザーガイド <ja/user-guide/index.html>`_
+
+* `ユーザーリファレンス <ja/user-reference/bzr_man.html>`_
+
+* `クィックスタートカード(PNG) <http://gigo-ice.org/scm/bazaar/wiki/bzr-quickref.ja.png>`_
+  `(PDF) <http://gigo-ice.org/scm/bazaar/wiki/bzr-quickref.ja.pdf>`_
+
+* `リリースノート(英語) <en/release-notes/NEWS.html>`_
+
+* `2.0 Upgrade Guide (英語) <en/upgrade-guide/index.html>`_
+
+チュートリアル
+===============
+
+* `5分でBazaar <ja/mini-tutorial/index.html>`_
+
+* `A longer tutorial (英語) <en/tutorials/tutorial.html>`_
+
+* `Using Bazaar with Launchpad (英語) <en/tutorials/using_bazaar_with_launchpad.html>`_
+
+* `Centralized workflow (英語) <en/tutorials/centralized_workflow.html>`_
+
+
+Developer Documentation
+=======================
+
+* `Developer Document Catalog <developers/index-plain.html>`_ |--| for developers
+  of Bazaar and plugins
+
+
+ウェブリンク
+=============
+
+* `切り替えガイド <http://bazaar-vcs.org/BzrSwitching>`_
+  |--| 別のVCSツールから移ってきたユーザー用
+
+* `移行ガイド <http://bazaar-vcs.org/BzrMigration>`_
+  |--| 別のVCSツールから履歴を移行するチーム用
+
+* `用語 <http://bazaar-vcs.org/BzrGlossary>`_
+
+* `よく聞かれる質問 <http://bazaar-vcs.org/FAQ>`_
+
+
+TortoiseBzrをインストールするには？
+===================================
+
+https://launchpad.net/bzr/+download からbzr-setup-x.xxx.exeを入手し、
+ファイルをダブルクリックをしてインストールウィザードを起動させます。
+その後の作業はインストールウィザードに従います。
+インストールウィザードが終了した後で再起動します。
+
+最新バージョンでも正常に動作しないことがあるので、
+その場合は古いバージョンをインストールします。
+2009年1月時点で筆者はbzr-setup-1.9.exeの基本的な動作を確認しています。
+
+もしPythonインタープリタにbzrをインストールした場合、インストールしたディレクトリによって
+bzr.exe(デフォルトでは `C:\Program Files\Bazaar` )よりもbzr.bat(`C:\PythonXX\Scripts`)が
+優先されるので、コマンドプロンプトでbzrと入力したときにbzr.exeが実行されるようにするには、
+bzr.batをbzr.txtなどにリネームします。
+
+
+Other Languages
+===============
+
+* `Spanish Documentation <index.es.html>`_
+* `Russian Documentation <index.ru.html>`_ |--| документация на русском
+* `Japanese Documentation <index.ja.html>`_ |--| 日本語ドキュメント
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== added file 'doc/index.ru.txt'
--- doc/index.ru.txt	1970-01-01 00:00:00 +0000
+++ doc/index.ru.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,63 @@
+=================================
+Главный каталог документов Bazaar
+=================================
+
+Последняя версия этих документов доступа со страницы документации
+на сайте Bazaar, <http://doc.bazaar-vcs.org/>. Еще больше информации
+можно получить по адресу <http://bazaar-vcs.org/Documentation>.
+
+Основная документация
+=====================
+
+* `Руководство пользователя <ru/user-guide/index-plain.html>`_
+
+* `Справочник пользователя <en/user-reference/bzr_man.html>`_ (англ.)
+
+* `Карточка быстрого старта <ru/_static/ru/bzr-ru-quick-reference.svg>`_
+  (`PDF <ru/_static/ru/bzr-ru-quick-reference.pdf>`_,
+  `PNG <ru/_static/ru/bzr-ru-quick-reference.png>`_)
+
+* `Список изменений <en/release-notes/NEWS.html>`_ (англ.)
+
+* `Каталог информации для разработчиков <developers/index-plain.html>`_ (англ.) |--|
+  для разработчиков Bazaar и плагинов
+
+Учебники
+========
+
+* `Базар за пять минут <ru/mini-tutorial/index.html>`_
+
+* `Большой учебник <ru/tutorials/tutorial.html>`_
+
+* `Использование Bazaar с Launchpad
+  <ru/tutorials/using_bazaar_with_launchpad.html>`_
+
+* `Работа в централизованном стиле
+  <ru/tutorials/centralized_workflow.html>`_
+
+Ссылки в сети
+=============
+
+* `Руководства по переходу <http://bazaar-vcs.org/BzrSwitching>`_
+  |--| для пользователей переходящих с других систем контроля версий
+
+* `Руководство по миграции <http://bazaar-vcs.org/BzrMigration>`_
+  |--| для команд переносящих историю с других систем контроля версий
+
+* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.),
+  см. также `русскую версию`__
+
+__  http://groups.google.com/group/ru_bzr/web/%D0%B3%D0%BB%D0%BE%D1%81%D1%81%D0%B0%D1%80%D0%B8%D0%B9
+
+* `Часто задаваемые вопросы <http://bazaar-vcs.org/FAQ>`_ (англ.)
+
+Другие языки
+============
+
+* `Документация на английском <index.html>`_ |--| English Documentation
+* `Документация на испанском <index.es.html>`_
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== modified file 'doc/index.txt'
--- doc/index.txt	2009-08-10 06:53:44 +0000
+++ doc/index.txt	2009-10-29 10:01:19 +0000
@@ -9,41 +9,41 @@
 Core Documentation
 ==================
 
-* `User Guide <en/user-guide/index.html>`_ 
-
-* `User Reference <en/user-reference/bzr_man.html>`_ 
-
-* `Quick Start Card <_static/en/quick-reference/bzr-quick-reference.svg>`_
-  (`PDF <_static/en/quick-reference/bzr-quick-reference.pdf>`_,
-  `PNG <_static/en/quick-reference/bzr-quick-reference.png>`_)
+* `User Guide <en/user-guide/index-plain.html>`_
+
+* `User Reference <en/user-reference/bzr_man.html>`_
+
+* `Quick Start Card <en/_static/en/bzr-en-quick-reference.svg>`_
+  (`PDF <en/_static/en/bzr-en-quick-reference.pdf>`_,
+  `PNG <en/_static/en/bzr-en-quick-reference.png>`_)
 
 * `Release Notes <en/release-notes/NEWS.html>`_
 
-* `2.0 Upgrade Guide <en/upgrade-guide/index.html>`_ 
+* `2.0 Upgrade Guide <en/upgrade-guide/index.html>`_
 
 
 Tutorials
 =========
 
-* `Bazaar in five minutes <en/mini-tutorial/index.html>`_ 
-
-* `A longer tutorial <en/tutorials/tutorial.html>`_ 
-
-* `Using Bazaar with Launchpad <en/tutorials/using_bazaar_with_launchpad.html>`_ 
-
-* `Centralized workflow <en/tutorials/centralized_workflow.html>`_ 
+* `Bazaar in five minutes <en/mini-tutorial/index.html>`_
+
+* `A longer tutorial <en/tutorials/tutorial.html>`_
+
+* `Using Bazaar with Launchpad <en/tutorials/using_bazaar_with_launchpad.html>`_
+
+* `Centralized workflow <en/tutorials/centralized_workflow.html>`_
 
 
 Developer Documentation
 =======================
 
-* `Developer Document Catalog <developers/index.html>`_ |--| for developers
+* `Developer Document Catalog <developers/index-plain.html>`_ |--| for developers
   of Bazaar and plugins
 
 Web links
 =========
 
-* `Switching Guides <http://bazaar-vcs.org/BzrSwitching>`_ 
+* `Switching Guides <http://bazaar-vcs.org/BzrSwitching>`_
   |--| for users moving from another VCS tool
 
 * `Migration Guide <http://bazaar-vcs.org/BzrMigration>`_
@@ -59,6 +59,7 @@
 
 * `Spanish Documentation <index.es.html>`_
 * `Russian Documentation <index.ru.html>`_ |--| документация на русском
+* `Japanese Documentation <index.ja.html>`_ |--| 日本語のドキュメント
 
 .. |--| unicode:: U+2014
 

=== added directory 'doc/ja'
=== added directory 'doc/ja/_static'
=== added file 'doc/ja/_static/bzr icon 16.png'
Binary files doc/ja/_static/bzr icon 16.png and doc/ja/_static/bzr icon 16.png differ
=== added file 'doc/ja/_static/bzr.ico'
Binary files doc/ja/_static/bzr.ico and doc/ja/_static/bzr.ico differ
=== added directory 'doc/ja/_templates'
=== added file 'doc/ja/conf.py'
--- doc/ja/conf.py	1970-01-01 00:00:00 +0000
+++ doc/ja/conf.py	2009-11-18 06:18:14 +0000
@@ -0,0 +1,93 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'ja'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': u'目次 (%s)',
+        u'Bazaar User Guide': u'ユーザーガイド',
+        u'Bazaar User Reference': u'ユーザーリファレンス',
+        u'Bazaar Release Notes': u'リリースノート',
+        u'Bazaar Upgrade Guide': u'アップグレードガイド',
+        u'Bazaar in five minutes': u'5分でBazaar',
+        u'Bazaar Tutorial': u'チュートリアル',
+        u'Using Bazaar With Launchpad': None,
+        u'Centralized Workflow Tutorial': None,
+    }
+def bzr_title(s):
+    return bzr_titles.get(s) or s
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+language = bzr_locale
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+# html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  # Manuals
+  ('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  ('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  #('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  #('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  #('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  #('tutorials/using_bazaar_with_launchpad',
+  #  'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+  #  bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  #('tutorials/centralized_workflow',
+  #  'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+  #  bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    #'user-guide/resolving_conflicts',
+    #'user-guide/version_info',
+    # Plain-style documentation generation stuff
+    'release-notes/NEWS',
+    'user-reference/bzr_man',
+    'user-guide/index-plain',
+    # Miscellaneous
+    'user-reference/readme',
+]
+

=== added file 'doc/ja/index.txt'
--- doc/ja/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/index.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,56 @@
+===========================
+Bazaarのメインドキュメント
+===========================
+
+これらのドキュメントの最新版はBazaarのドキュメントのサイト、 http://doc.bazaar-vcs.org/ から入手可能で、
+詳しい情報は http://bazaar-vcs.org/Documentation のページからリンクされています。
+
+
+目次
+=====
+
+.. toctree::
+   :maxdepth: 1
+
+   tutorials/index
+   user-guide/index
+   user-reference/bzr_man
+
+
+ウェブリンク
+=============
+
+* `切り替えガイド <http://bazaar-vcs.org/BzrSwitching>`_
+  |--| 別のVCSツールから移ってきたユーザー用
+
+* `移行ガイド <http://bazaar-vcs.org/BzrMigration>`_
+  |--| 別のVCSツールから履歴を移行するチーム用
+
+* `用語 <http://bazaar-vcs.org/BzrGlossary>`_
+
+* `よく聞かれる質問 <http://bazaar-vcs.org/FAQ>`_
+
+
+TortoiseBzrをインストールするには？
+===================================
+
+https://launchpad.net/bzr/+download からbzr-setup-x.xxx.exeを入手し、
+ファイルをダブルクリックをしてインストールウィザードを起動させます。
+その後の作業はインストールウィザードに従います。
+インストールウィザードが終了した後で再起動します。
+
+最新バージョンでも正常に動作しないことがあるので、
+その場合は古いバージョンをインストールします。
+2009年1月時点で筆者はbzr-setup-1.9.exeの基本的な動作を確認しています。
+
+もしPythonインタープリタにbzrをインストールした場合、インストールしたディレクトリによって
+bzr.exe(デフォルトでは ``C:\Program Files\Bazaar`` )よりもbzr.bat(``C:\PythonXX\Scripts``)が
+優先されるので、コマンドプロンプトでbzrと入力したときにbzr.exeが実行されるようにするには、
+bzr.batをbzr.txtなどにリネームします。
+
+
+
+.. |--| unicode:: U+2014
+
+..
+   vim: ft=rst tw=74 ai

=== added directory 'doc/ja/mini-tutorial'
=== added file 'doc/ja/mini-tutorial/index.txt'
--- doc/ja/mini-tutorial/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/mini-tutorial/index.txt	2009-10-29 16:52:18 +0000
@@ -0,0 +1,275 @@
+=================
+5分でわかるBazaar
+=================
+
+.. _introduction:
+
+イントロダクション
+===================
+
+Bazaarは分散型バージョン管理システムで、ソフトウェアプロジェクトの共同作業を楽にしてくれます。
+
+これから5分ほどで、ファイルをバージョン管理下に置き、変更をそれらに記録して、\
+作業内容を確認し、公開して作業内容をマージしてもらうためにプロジェクトのtrunkに\
+送る方法などを学びます。
+
+詳細な紹介内容を望むのであれば、 `さらに学ぶ`_ をご覧ください。
+
+
+インストール方法
+=================
+
+このガイドではBazaarをインストールする方法を説明しませんが、通常はとても簡単です。
+インストール方法の手引きは次の通りです:
+
+- **GNU/Linux:** おそらくBazaarはあなたのGNU/Linuxディストリビューションに含まれています。
+- **Windows:** `Windowsのためのインストールの手引き`_.
+- **Mac OS X:** `Mac OS Xのためのインストールの手引き`_.
+
+別のプラットフォームとソースコードからインストールする方法に関しては、 ダウンロード_
+と インストール方法_ のページを参照してください。
+
+.. _Windowsのためのインストールの手引き: http://bazaar-vcs.org/WindowsDownloads
+.. _Mac OS Xのためのインストールの手引き: http://bazaar-vcs.org/MacOSXBundle
+.. _ダウンロード: http://bazaar-vcs.org/Download
+.. _インストール方法: http://bazaar-vcs.org/InstallationFaq
+
+
+まずは自己紹介
+=================
+
+作業にとりかかる前に、まずあなたが誰なのかをBazaarに教えてあげましょう。
+そうすることで、履歴の中からあなたの作業を正確に識別することができます。
+
+次のように入力してください(もちろん、あなたの名前とEメールアドレスで)::
+
+  $ bzr whoami "John Doe <john.doe@gmail.com>"
+
+こうするとBazaarは、あなたの名前やEメールアドレスが入った設定ファイルを作成\
+もしくは修正します。
+
+名前とEメールアドレスが正しく登録されているか確認しましょう ::
+
+  $ bzr whoami
+  John Doe <john.doe@gmail.com>
+
+
+ファイルをバージョン管理する
+=============================
+
+Bazaarで扱うディレクトリといくつかのファイルを作りましょう::
+
+ $ mkdir myproject
+ $ cd myproject
+ $ mkdir subdirectory
+ $ touch test1.txt test2.txt test3.txt subdirectory/test4.txt
+
+**Windowsユーザーのための注意:** Windows Explorerを使ってディレクトリを作成し、\
+そのディレクトリの中で右クリックをして ``新規作成`` を選択し、ファイルを作成します。
+
+Bazaarにあなたのプロジェクトディレクトリを初期化させましょう::
+
+  $ bzr init
+
+何も起きていないように見えても心配しないでください。
+Bazaarはファイルとリビジョンの履歴を保存する branch_ を作りました。
+
+.. _branch: http://bazaar-vcs.org/Branch
+
+次のステップはBazaarに管理して欲しいファイルを教えることです。
+``bzr add`` を実行するとすべてのディレクトリとファイルがプロジェクトに\
+再帰的に追加されます::
+
+ $ bzr add
+ added subdirectory
+ added test1.txt
+ added test2.txt
+ added test3.txt
+ added subdirectory/test4.txt
+
+次に、これらをブランチにコミットしてスナップショットをとります。
+コミットを行った理由を説明するメッセージを追加します::
+
+  $ bzr commit -m "Initial import"
+
+Bazaarは分散型バージョン管理システムなので、コミットするために\
+サーバーに接続する必要はありません。
+代わりに、Bazaarはブランチとすべてのコミットをあなたが作業している\
+ディレクトリ内部に保存します;
+``.bzr`` というサブディレクトリをご覧ください。
+
+
+ファイルを変更する
+===================
+
+ファイルを変更してブランチにその変更をコミットしてみましょう。
+
+好きなエディタで ``test1.txt`` を編集し、何を行ったのかを確認します::
+
+ $ bzr diff
+ === modified file 'test1.txt'
+ --- test1.txt   2007-10-08 17:56:14 +0000
+ +++ test1.txt   2007-10-08 17:46:22 +0000
+ @@ -0,0 +1,1 @@
+ +test test test
+
+作業をBazaarのブランチにコミットします::
+
+  $ bzr commit -m "Added first line of text"
+  Committed revision 2.
+
+
+リビジョンのログを眺める
+=========================
+
+ログを閲覧することでブランチの履歴がわかります::
+
+  $ bzr log
+  ------------------------------------------------------------
+  revno: 2
+  committer: John Doe <john.doe@gmail.com>
+  branch nick: myproject
+  timestamp: Mon 2007-10-08 17:56:14 +0000
+  message:
+    Added first line of text
+  ------------------------------------------------------------
+  revno: 1
+  committer: John Doe <john.doe@gmail.com>
+  branch nick: myproject
+  timestamp: Mon 2006-10-08 17:46:22 +0000
+  message:
+    Initial import
+
+
+sftpでブランチを公開する
+=========================
+
+ブランチを公開する方法は複数あります。
+SFTPサーバーがすでにあるもしくは容易にセットアップできるのであれば、\
+ブランチをそこで公開できます。
+
+そうでなければ、このセクションをとばして、Bazaarのための無料ホスティング\
+サービスである、 Launchpad_ で公開しましょう。
+
+.. _Launchpad: https://launchpad.net/
+
+``www.example.com/myproject`` でブランチを公開することを前提とします::
+
+ $ bzr push --create-prefix sftp://your.name@example.com/~/public_html/myproject
+ 2 revision(s) pushed.
+
+Bazaarはリモートサーバー上で ``myproject`` ディレクトリを作りブランチを\
+そこにpushします。
+
+これで誰でも次のコマンドを入力すればあなたのブランチをコピーできます::
+
+ $ bzr branch http://www.example.com/myproject
+
+**注:** sftpを使うためには、 ``paramiko`` と ``pyCrypto`` をインストールする必要があります。
+詳細は http://bazaar-vcs.org/InstallationFaq を参照してください。
+
+
+Launchpadでブランチを公開する
+==============================
+
+Launchpadはフリーソフトウェアのための開発とホスティングのためのツールが\
+ひとまとめになったものです。これをブランチを公開するために利用できます。
+
+Launchpadのアカウントを持っていなければ、 `アカウントのサインアップのガイド`_
+に従ってアカウントを作り、 `SSHキーを登録`_ してください。
+
+.. _アカウントのサインアップのガイド: https://help.launchpad.net/CreatingYourLaunchpadAccount
+.. _SSHキーを登録: https://launchpad.net/people/+me/+editsshkeys
+
+次のコマンドを(``john.doe`` を自分のLaunchpadアカウント名に変更して)実行してください::
+
+ $ bzr push bzr+ssh://john.doe@bazaar.launchpad.net/~john.doe/+junk/myproject
+
+**注:** ``+junk`` はこのブランチがLaunchpad上の特定のプロジェクトに関連していないことを意味します。
+
+これで、誰でも次のコマンドを入力することでブランチのコピーを作ることができます::
+
+ $ bzr branch http://bazaar.launchpad.net/~john.doe/+junk/myproject
+
+ブランチとリビジョンの履歴に関する情報は https://code.launchpad.net/people/+me/+junk/myproject
+でも見ることができます。
+
+別のブランチから自分用のコピーを作る
+=====================================
+
+他人のコードに取り組むために、ブランチのコピーを作ることができます。
+実際の世界の例として、BazaarのGTKインターフェイスを見てみましょう::
+
+  $ bzr branch http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk bzr-gtk.john
+  Branched 292 revision(s).
+
+Bazaarはbzr-gtkのtrunkブランチからすべてのファイルをダウンロードして\
+リビジョンの履歴をそろえ、bzr-gtk.johnというコピーを作ります。
+
+これで、ブランチのコピーを手に入れたのでネットの接続のあるなしに\
+関わらず変更をコミットできます。
+ブランチはいつでも公開することで共有でき、bzr-gtkチームがあなたの作品を\
+使いたいと思ったときにBazaarは彼らがあなたのブランチから彼らのブランチに\
+マージし直す作業を簡単にしてくれます。
+
+
+メインのブランチから自分のブランチを更新する
+=============================================
+
+変更を自分のブランチにコミットする一方で、他の人がコードを親のブランチに\
+コミットしているということもよくあります。
+
+自分のブランチを最新に維持するには、親ブランチから自分のブランチへと変更を\
+マージします::
+
+  $ bzr merge
+  Merging from saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
+  All changes applied successfully.
+
+何が変更されたのか確認します::
+
+  $ bzr diff
+
+変更に満足したら、それらを自分のブランチにコミットします::
+
+  $ bzr commit -m "Merge from main branch"
+  Committed revision 295.
+
+
+作業を親のブランチにマージする
+==============================
+
+bzr-gtkの個人ブランチに取り組んだ後で、あなたの変更を上流のプロジェクトに\
+戻したいことがあるかもしれません。
+最も簡単な方法はマージディレクティブを使うことです。
+
+マージディレクティブ(merge directive)とは、コンピュータに特定のマージを実行\
+させるためのリクエストです。
+マージディレクティブは大抵、マージをレビューするためのパッチと、マージを実行する\
+のに必要となるリビジョン、もしくはリビジョンを取得できるブランチを含みます。
+
+次のコマンドの ``mycode.patch`` を適当な名前に書き換えて、マージのディレクティブを作ります::
+
+ $ bzr send -o mycode.patch
+ Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
+
+これでbzr-gtkのプロジェクトにマージディレクティブをEメールで送ることが可能に\
+なりました。彼らが納得すれば、親ブランチにマージすることができます。
+
+
+さらに学ぶ
+==========
+
+Bazaarに関する詳細な内容は `Bazaarのユーザーガイド <../user-guide/index.html>`_ で調べることができます。
+
+コマンドラインでBazaarを学ぶには::
+
+  $ bzr help
+
+Bazaarのコマンドを学ぶには::
+
+  $ bzr help commands
+
+''foo'' トピックもしくはコマンドを学ぶには::
+
+  $ bzr help foo

=== added directory 'doc/ja/tutorials'
=== added file 'doc/ja/tutorials/centralized_workflow.txt'
--- doc/ja/tutorials/centralized_workflow.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/tutorials/centralized_workflow.txt	2009-10-29 16:52:18 +0000
@@ -0,0 +1,276 @@
+========================================
+集中型ワークフローのチュートリアル
+========================================
+
+
+概要
+====
+
+この文書では、 Bazaar_ を使用することで実現可能なワークフローについて説明します。
+つまり、分散バージョンコントロールシステムである Bazaar_ を、集中型のやり方で使用するためのワークフローです。 
+Bazaar_ は、非常にフレキシブルに設計されており、完全な分散型からほとんど集中型のワークフローまで、\
+いくつかの異なるワークフローを受け入れることができます。
+このワークフローは、初めてのユーザでも簡単に Bazaar_ を使いこなすことができ、\
+分散型と集中型のオペレーションを組み合わせた業務にも対応できるようになっています。
+
+基本的に、この文書はCVSやSubvresionのような集中型バージョンコントロールシステムの経験があるユーザ向けに書かれています。
+これらの環境では、一般的に、コードベースをホストする単一の中央サーバが存在し、複数の人々がこのコードベース上で作業して、\
+お互いの作業の同期をとることになります。 
+また、このワークフローは、一人の開発者が複数のマシーン上で作業をする場合にも適用できます。
+
+.. _Bazaar: http://bazaar-vcs.org
+
+
+初期セットアップ
+================
+
+Bazaar_ がうまく動くようにするための、まあまあ簡単なセットアップ手順があります。
+
+ユーザのEメールの設定
+---------------------
+
+ユーザIDは各コミットに保存されます。これは正確だったり一意だったりする必要はありませんが、\
+ログメッセージや注釈で使用されるため、何かしら実在する値を設定しておいた方がよいでしょう。
+
+::  
+
+   % bzr whoami "John Doe <jdoe@organization.com>"
+
+
+ローカルリポジトリのセットアップ
+--------------------------------
+
+Bazaar_ のブランチは、通常は履歴のコピーを持っています。そのおかげで分散型での作業ができるわけです。
+最適化の方法の一つとして、関連するブランチ同士の情報を統合して、\
+新しいブランチを作るたびに履歴情報を丸ごとコピーしなくてもいいようにすることができます。
+
+そのための一番いい方法は、 `共用リポジトリ`_ を作成することです。
+一般に、 `共用リポジトリ`_ のサブディレクトリ内に複数のブランチがある場合、お互いの記憶領域を共有します。
+ですので、ホームディレクトリに `共用リポジトリ`_ を作成するようにしましょう。
+そうすれば、その下に作成したすべてのブランチは、履歴情報の領域を共有することになります。
+
+::
+
+  % bzr init-repo --trees ~
+
+
+リモートリポジトリのセットアップ
+---------------------------------
+
+作業用の領域とは別に、データを蓄積しておく領域が欲しいというのはよくあることです。
+集中型のシステム(CVS/SVN)では、このようなワークフローが必要になります。
+たいていは、これらは別々のマシーンに分けて配置されます。(そうでないこともあります。)
+実際のところ、これは、特に職場ではとてもよい設定です。
+蓄積されたデータはバックアップを確実にとることができ、開発者のマシーンに何かトラブルが起こっても\
+コミットされたデータはけっして無くなりません。
+
+それでは、プロジェクト内で共有する ``centralhost`` というマシーンを用意しましょう。
+先ほども言いましたが、ディスクの使用量を節約するために、 `共用リポジトリ`_ を使用します。
+
+::
+
+  % bzr init-repo --no-trees sftp://centralhost/srv/bzr/
+
+この手順は、新しくcvsrootやSubversionのリポジトリを作るのと同じようなものだと考えることができます。
+{{{--no-tree}}} オプションの指定によって、ワーキングツリーを作らないようになります。
+中央リポジトリ内のブランチを直接変更することは無いので、このオプションを指定しておくとよいでしょう。
+
+
+既存のプロジェクトからの移行
+=============================
+
+リポジトリができましたので、プロジェクトの作成にかかりましょう。
+たいていの場合、 Bazaar_ でバージョン管理したい作業中のコードがすでにあるはずです。
+もし、そのコードがもともとソース管理されていたのであれば、履歴の情報を保ったまま Bazaar_ に\
+変換する方法がたくさんあります。
+しかしながら、それについてはここでは説明しません。詳しくは、 `Tracking Upstream`_ の\
+"Converting and keeping history"セクションを見てください。
+
+.. _Tracking Upstream: http://bazaar-vcs.org/TrackingUpstream
+
+.. 
+   XXX: プロジェクトの変換について話をするための別の文書が必要なのですが、\
+   今ある中ではTrackingUpstreamが一番よい文書です。
+
+
+Developer 1: 最初のリビジョンを作成する
+-----------------------------------------
+
+まず最初に、プロジェクトをホストするリモートリポジトリに、ブランチを作成したいと思います。
+仮に、"sigil"というプロジェクトをバージョン管理しようとしているとしましょう。
+
+::
+
+  % bzr init sftp://centralhost/srv/bzr/sigil
+
+これは、CVSで言うところの"HEAD"ブランチ、Subversionなら"trunk"にあたるものだと考えてかまいません。
+これを ``dev`` ブランチと呼ぶことにしましょう。
+
+他のファイルとの競合を避けるために、ホームディレクトリのサブディレクトリ内で作業するのが私の好みです。
+同じように、最終的にでき上がるすべてのブランチを格納できるプロジェクトディレクトリも欲しいですね。 
+::
+
+  % cd ~
+  % mkdir work
+  % cd work
+  % mkdir sigil
+  % cd sigil
+  % bzr checkout sftp://centralhost/srv/bzr/sigil dev
+  % cd dev
+  % cp -ar ~/sigil/* .
+  % bzr add
+  % bzr commit -m "Initial import of Sigil"
+
+前のセクションでは、空のブランチ(``sigil`` ブランチ)を ``centralhost`` に作成して、\
+それをクライアント端末にチェックアウトしたあと、元々あったプロジェクトのファイルを追加しています。
+作業ディレクトリをセットアップするための方法はたくさんありますが、この方法を使うと機能追加用/バグフィックス用\
+のブランチを使った作業が簡単にできます。
+そして、複数のブランチをとてもうまく扱えるというのが、 Bazaar_ の長所の一つなのです。
+
+この場合、リモートブランチのチェックアウトを持っているので、 ``~/work/sigil/dev/`` に対してコミットした内容が、\
+ローカルと ``centralhost`` の両方に自動的に保存される訳です。
+
+
+Developer N: プロジェクトの作業コピーを取得する
+--------------------------------------------------
+
+プロジェクトの作成に関するすべての作業は1人目の開発者がしてしまっているので、\
+他のみんなは単にそのブランチをチェックアウトするだけです。
+**ただし、** `ユーザのEメールの設定`_ **と** `ローカルリポジトリのセットアップ`_ **は見ておいてください。**
+
+現在開発中のツリーのコピーを取得するためには::
+
+  % cd ~/work/sigil
+  % bzr checkout sftp://centralhost/srv/bzr/sigil dev
+
+今、二人の人が ``sftp://centralhost/srv/bzr/sigil`` のチェックアウトを持っている状態なので、\
+片方のチェックアウトが最新のものより古くなってしまうタイミングが出てきます。
+コミットの時に、チェックアウトが古いければ Bazaar_ がエラーを返して、コミットは失敗します。
+チェックアウトを最新にするには、よそで変更されたツリーに対して ``bzr update`` を使用します。
+この時、もし同じファイルが変更されていれば、競合の解決が必要になるかもしれません。
+
+
+別ブランチでの開発
+====================
+
+ここまでは、全員が同じブランチで作業して、変更をコミットしていました。
+これはつまり、全員が適正かつ定期的にアップデートを行い、他の人の変更を取り扱う必要があると\
+いうことです。
+また、誰か一人が何かコードを壊すような変更をコミットして、それが同期されれば、\
+全員が問題を抱えることになります。
+
+たいていの場合、別のブランチ上で開発を行い、コードが安定してからメインのブランチに統合する\
+というやり方の方が優れています。これが、CVSやSVNとの一番大きな違いです。
+CVSやSVNも別ブランチでの開発はできますが、マージのアルゴリズムがかなり貧弱なので、\
+ブランチ間できちんと同期がとれた状態に保つのは難しいことです。
+Bazaar_ は、何がマージ済みかを記憶し、たとえファイルが変名されてる場合でもちゃんと変更を\
+適用することができます。
+
+
+新しいブランチを作成してそこで作業する
+---------------------------------------
+まだ変更が完了していない場合でも、他の人がその変更内容にアクセスできるようにしておきたいですよね。
+そこで、 ``centralhost`` 上に新しい公開ブランチを作成して、それを手元に持ってくることにしましょう。
+
+::
+
+  % cd ~/work/sigil
+  % bzr branch sftp://centralhost/srv/bzr/sigil \
+               sftp://centralhost/srv/bzr/sigil/doodle-fixes
+  % bzr checkout sftp://centralhost/srv/bzr/sigil/doodle-fixes doodle-fixes
+  % cd doodle-fixes
+
+これで、 ``doodle`` に必要な修正を当てるための場所ができました。
+また、他の部分の修正をする人に邪魔されることもありません。
+チェックアウトを持っているため、 ``~/work/sigil/doodle-fixes/`` に対してコミットした内容は\
+``centralhost`` 上にも現れます。
+[#nestedbranches]_ ``dev`` ブランチと同じように、このようなブランチ上で二人の開発者が共同で\
+作業することもできます。
+[#cbranch]_
+
+.. [#nestedbranches] あるブランチのサブディレクトリに別のブランチがあるというのはおかしなこと\
+   に見えるかもしれませんが、これは何もおかしくありません。入れ子になったブランチは外側のブランチ\
+   から派生しているという点で、名前空間の階層と同じようなものだと考えることができます。
+
+.. [#cbranch] たくさんの独立したブランチを使っている場合、毎回フルURLを入力するのは大変です。
+   このURLの入力を簡単にするために、ブランチエイリアスなどたくさんの方法を検討しています。
+   今のところ、 bzrtools_ プラグインが ``bzr cbranch`` コマンドを提供しています。
+   これは、ベースとなるブランチを指定して、新しく公開ブランチを作成し、そのチェックアウトを作成する\
+   ことを少ない入力でできるように設計されています。
+   ``cbranch`` の使い方についてはこの文書の範囲外ですが、最後のコマンドについてはこんな感じです。:
+
+::
+
+   % bzr cbranch dev my-feature-branch
+
+.. _bzrtools: http://bazaar-vcs.org/BzrTools
+
+
+変更内容をマージする
+----------------------
+
+``doodle-fixes`` での変更内容をメインのブランチにマージすることになったら、単にこうするだけです。::
+
+  % cd ~/work/sigil/dev
+  % bzr merge ../doodle-fixes
+
+これで、変更内容は ``dev`` ブランチ上でもアクセスできるようになりますが、まだコミットはされていません。
+最終的な変更内容をレビューして、コードがちゃんとコンパイルでき、テストをパスすることを確認したいならこの時です。
+``bzr status`` コマンドと ``bzr diff`` コマンドがここで役立ちます。
+また、競合を解決するのもこの時です。Bazaar_ では、競合を解決するまではコミットできないようになっています。
+そのため、間違って競合マーカーをコミットしてしまうことはありません。
+``bzr status`` コマンドを使えば、他の変更内容と一緒に競合の情報も表示されます。
+``bzr conflicts`` なら、競合の情報だけが表示されます。
+競合を解決し終わったら、``bzr resolve file/name`` か ``bzr resolve --all`` を実行してください。
+[#resolve]_ もし、解決が特に難しい競合がある場合は、 ``bzr remerge`` コマンドを使いたいと思うかもしれません。
+このコマンドで、別のマージアルゴリズムを試してみることができ、さらに元のソース行を表示する\
+こともできます。(``--show-base``)
+
+.. [#resolve] マージ実行中に競合の解決をさせるシステムもあります。
+   私たちは、ファイルごとに競合を解決するよりも、ツリー全体を見ながら競合を解決する方がたいていは簡単である\
+   ことに気づきました。
+   そうすれば、よりたくさんの情報を得られますし、問題を解決したときにテストを実行することもできます。
+
+
+推奨のブランチ構成
+---------------------
+
+とても一般的なブランチ構成として、開発者ごとにひとつずつ専用のブランチを割り当て、中央サーバにも開発者ごとの\
+作業領域を用意するという方法があります。これは以下のコマンドでできます。::
+
+  % bzr branch sftp://centralhost/srv/bzr/sigil \
+               sftp://centralhost/srv/bzr/sigil/user-a
+  % bzr branch sftp://centralhost/srv/bzr/sigil \
+               sftp://centralhost/srv/bzr/sigil/user-b
+
+これで、開発者ごとに専用の作業用ブランチを割り当てています。
+さらに、開発者自身で [#cbranch]_ を使用して新しく新機能開発用ブランチを作成することも簡単にできます。
+::
+
+  % bzr branch sftp://centralhost/srv/bzr/sigil/user-a \
+               sftp://centralhost/srv/bzr/sigil/user-a/feature 
+  % cd ~/work/sigil
+  % bzr checkout sftp://centralhost/srv/bzr/sigil/user-a/feature myfeature
+
+
+用語解説
+=========
+
+共用リポジトリ
+--------------
+
+Bazaar_ には、”共用リポジトリ”という概念があります。これは、CVSやSubversionのようなの他のRCSが持つ\
+旧来の概念に似ています。
+たとえば、Subversionでは、サーバ上のリポジトリにすべての履歴情報が保存されていて、手元には履歴情報は\
+全くなく、作業ツリーのファイルのチェックアウトがあるだけです。
+ここで言う”共用”というのは、ブランチ同士の間で共用するという意味であることに注意してください。
+開発者間でも共用される *かも知れません* が、開発者間での共用はスタンドアロンブランチでも可能です。
+
+Bazaar_ の用語では、"共用リポジトリ"とは複数のブランチが履歴情報を **共有** できる場所のことです。
+分散型のワークフローに対応するためには、それぞれのブランチが履歴情報を持っている必要があります。
+しかし、しばしばこれは非効率です。関連するブランチ同士は履歴を共有しており、ディスクも共有した方が\
+いいためです。
+
+
+.. 
+   vim: tw=74 ft=rst

=== added file 'doc/ja/tutorials/index.txt'
--- doc/ja/tutorials/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/tutorials/index.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,11 @@
+チュートリアル
+==============
+
+.. toctree::
+   :maxdepth: 1
+
+   ../mini-tutorial/index
+   tutorial
+   using_bazaar_with_launchpad
+   centralized_workflow
+

=== added file 'doc/ja/tutorials/tutorial.txt'
--- doc/ja/tutorials/tutorial.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/tutorials/tutorial.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,843 @@
+.. This file is in Python ReStructuredText format - it can be formatted
+.. into HTML or text.  In the future we plan to extract the example commands
+.. and automatically test them.
+
+.. This text was previously on the wiki at
+.. http://bazaar.canonical.com/IntroductionToBzr
+.. but has been moved into the source tree so it can be kept in sync with
+.. the source and possibly automatically checked.
+
+======================
+Bazaar チュートリアル
+======================
+
+
+.. Introduction
+
+はじめに
+============
+
+もし、もう分散型バージョン管理に慣れ親しんでいるなら、
+"Bazaarに自己紹介する" の節までとばしてください。
+もし、分散型でないバージョン管理に慣れ親しんでいるけれど分散型バージョン管理は\
+よくわからないのであれば、"分散バージョン管理と分散でないバージョン管理の違い"まで\
+とばしてください。
+それ以外の場合、コーヒーか紅茶(訳注:日本茶でもいいですよ)を用意して、\
+リラックスして読み始めてください。
+
+バージョン管理の目的
+====================
+
+なにかのテキストデータ(プログラムのソースコード、Webサイト、Unixシステムでの\
+設定ファイルなど)を扱う作業をしているとしましょう。
+なにかミスをして、重大なデグレードを引き起こしてしまうかもしれません。
+例えばメールサーバーの設定ファイルを消してしまったり、だいじなプロジェクトの\
+ソースコードを壊してしまったりすることがあります。
+だいじな情報を失って、何が何でも取り戻したいと思った経験があるのであれば、\
+きっとあなたはBazaarを使う準備ができています。
+
+Bazaarをはじめとするバージョン管理システムは、ディレクトリに起こった変更を\
+**ブランチ (branch)** というディレクトリよりも複雑なものの中に入れて\
+追跡します。
+ブランチはディレクトリの中に何が入っているかだけでなく、過去のいろいろな\
+時点でのディレクトリの中身を格納しています。
+なので、望まぬ変更をしてしまったときには過去の時点の状態に戻すことができます。
+
+バージョン管理システムは、ユーザーが "**リビジョン (revision)** をコミット"
+することで変更をブランチに保存します。
+このときに生成されるリビジョンとは、本質的にいって、前回保存したときからの\
+変更点になります。
+
+リビジョンはそれ以外のものも持っています(原文:These revisions have other
+uses as well.)
+たとえば、オプションのログメッセージをつけることで、変更が何を意味して\
+いるのかというコメントを残すことができます。
+実際に利用されるログメッセージは、 "Webテンプレートをテーブルを閉じるように\
+修正" とか "sftpに対応した。 #595 を修正。" といったものです。
+
+こういったログが保存されているおかげで、たとえば後になって sftp に問題が発生\
+したときに、問題が発生するようになったのがどの時点なのか目星をつけることが\
+できます。
+
+
+分散バージョン管理と分散でないバージョン管理の違い
+===================================================
+
+多くのバージョン管理システムはサーバーに配置されています。
+バージョン管理されているコードに対して作業をしたい場合、サーバーに接続して\
+コードを "チェックアウト (checkout)" する必要があります。
+そうすると、変更やコミットができるディレクトリができます。
+バージョン管理システムのクライアントは、バージョン管理システムのサーバーに\
+コミットされた変更を保存します。この方式は集中型として知られています。
+
+集中型にはいくつかの欠点があります。
+集中型バージョン管理システムは、動作するためにサーバーとの接続を要求します。
+このことは、サーバーがどこかインターネット上にあって、あなたのマシンが\
+インターネットに接続できないときに問題になります。
+もしくは、あなたのマシンがインターネットに接続できてもサーバーが落ちている\
+ときにもやはり問題になります。
+
+分散バージョン管理システムは、ブランチをクライアントと同じマシンに置くことで\
+この問題を解決しています。
+Bazaarの場合、ブランチはバージョン管理されているコードと同じディレクトリに\
+保存されます。
+これにより、ユーザーは(たとえオフラインであったとしても)好きなときに変更を保存\
+(**コミット (commit)**)することができます。
+インターネット接続が必要になるのは、どこか別の場所にあるブランチの変更にアクセス\
+するときだけです。
+
+.. TODO:
+.. Performing this tracking by hand is a awkward process that over time
+.. becomes unwieldy. の部分の訳が判らない。
+
+多くの人が必要としていることは、ディレクトリ内でおこったファイルやサブディレクトリ\
+の変更を追跡することです。
+この追跡を手でおこなうのは面倒で不恰好な作業です。
+これは、Bazaarのようなバージョン管理システムの目的のひとつです。
+バージョン管理システムはユーザーが指示したときにディレクトリツリーの
+**リビジョン (revision)** を作ることでこの作業を自動化します。
+
+バージョン管理システムは単に保存したりundoしたりするだけではありません。
+たとえばBazaarでは、ソフトウェアのあるブランチから変更を取り出して、\
+関連する別のブランチに適用することができます。このとき、変更を取り出す\
+ブランチは別の人のものであってもかまいません。これにより、開発者のグループは\
+お互いに書き込み権を与えることなく共同作業することができます。
+
+.. Bazaar remembers the ''ancestry'' of a revision: the previous revisions
+.. that it is based upon.  A single revision may have more than one direct
+.. descendant, each with different changes, representing a divergence in the
+.. evolution of the tree. By branching, Bazaar allows multiple people to
+.. cooperate on the evolution of a project, without all needing to work in
+.. strict lock-step.  Branching can be useful even for a single developer.
+
+Bazaarではリビジョンの ''親 (ancestry)'' 、つまりそのリビジョンの元になった\
+リビジョンを記録しています。
+ひとつのリビジョンは複数の、それぞれ別の変更を含む子供リビジョンを持つことが\
+あり、それはツリーの進化が分岐していることを意味しています。
+Bazaarではブランチを作ることによって、複数の人が厳しい lock-step をとらなくても\
+協力することができます。
+ブランチを作ることは個人での開発でも便利です。
+
+.. Introducing yourself to Bazaar
+
+Bazaarに自己紹介する
+=====================
+
+.. Bazaar installs a single new command, **bzr**.  Everything else is a
+   subcommand of this.  You can get some help with ``bzr help``. Some arguments
+   are grouped in topics: ``bzr help topics`` to see which topics are available.
+
+Bazaarは **bzr** という新しいコマンドをひとつインストールします。
+他の全ては bzr のサブコマンドになります。
+``bzr help`` コマンドでいくつかのヘルプを見られます。
+幾つかの話題は topic にまとめられていて、 ``bzr help topics`` で\
+利用可能なトピックの一覧を見られます。
+
+バージョン管理システムの一つの機能は、誰が何を変更したのかを追跡することです。
+分散型バージョン管理システムでは、各開発者がグローバルユニークなIDを持つ\
+必要があります。
+ほとんどの人はこのIDとして利用できる eメールアドレス を持っています。
+Bazaarはコンピュータのユーザー名とホスト名から自動でメールアドレスを\
+生成します。Bazaarが自動で作成したメールアドレス以外のものを使いたい\
+場合、３つの選択肢があります。
+
+1. ``bzr whoami`` を使ってメールアドレスを設定します。これはグローバルなIDを設定\
+   する最も簡単な方法です。グローバルなIDを設定するには::
+
+      % bzr whoami "Your Name <email@example.com>"
+
+   特定のブランチでべつのアドレスを使いたい場合、そのブランチのディレクトリの\
+   なかで次のコマンドを実行します::
+
+      % bzr whoami --branch "Your Name <email@example.com>"
+
+#. ``?/.bazaar/bazaar.conf`` [1]_ の中のメールアドレスを、以下のようにして\
+   設定します。 ``[DEFAULT]`` の部分が大文字と小文字を区別するので注意して\
+   ください::
+
+       [DEFAULT]
+       email=Your Name <email@isp.com>
+
+   特定のブランチにおける設定は、 ``?/.bazaar/locations.conf``
+   にブランチのセクションを作成して次のように書くことができます。 ::
+
+       [/the/path/to/the/branch]
+       email=Your Name <email@isp.com>
+
+
+#. 環境変数 ``$BZR_EMAIL`` もしくは ``$EMAIL`` (``$BZR_EMAIL`` の方が優先\
+   されます)にメールアドレスを設定することで、上の二つの方法で設定された\
+   オプションを上書きすることができます。
+
+.. [1] Windowsではユーザー設定ファイルはアプリケーションデータディレクトリに\
+   おかれます。なので、設定ファイルの場所は ``?/.bazaar/branch.conf`` ではなく\
+   ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\branch.conf``
+   になります。
+   同じことが ``locations.conf``, ``ignore``, ``plugins`` ディレクトリも\
+   同じです。
+
+ブランチを作る
+==============
+
+履歴はデフォルトではブランチの .bzr ディレクトリの中に保存されます。
+
+.. これは現行のバージョンでできるのでは？: In a
+   future version of Bazaar, there will be a facility to store it in a
+   separate repository, which may be remote.
+
+既存のディレクトリの中で ``bzr init`` をすると新しいブランチを作成できます::
+
+    % mkdir tutorial
+    % cd tutorial
+    % ls -a
+    ./  ../
+    % pwd
+    /home/mbp/work/bzr.test/tutorial
+    %
+    % bzr init
+    % ls -aF
+    ./  ../  .bzr/
+    %
+
+ファイルには３つのクラス、 unknown, ignored, versioned があります。
+**add** コマンドはファイルを versioned にし、そのファイルへの変更の記録を\
+開始します::
+
+    % echo 'hello world' > hello.txt
+    % bzr status
+    unknown:
+      hello.txt
+    % bzr add hello.txt
+    added hello.txt
+    % bzr status
+    added:
+      hello.txt
+
+もし間違えたファイルを add してしまった場合、そのファイルを unversioned
+状態に戻すために ``bzr remove`` してください。
+この場合の ``bzr remove`` は、ほかの場合 [2]_ とちがってファイルを削除\
+しません。
+
+.. [2] ``bzr remove`` はファイルがバージョン管理されていて何も変更されて\
+   いない場合に、そのファイルを削除します。 ``--keep`` オプションで常に\
+   ファイルを残すことができます。 ``--force`` オプションで常にファイルを\
+   削除することもできます。
+
+.. Branch locations
+
+ブランチの場所
+===============
+
+すべての履歴はブランチに格納されます。ブランチとは、管理用のファイルを\
+含んだただのディレクトリです。デフォルトでは、svnやsvkのような、分離した\
+リポジトリやデータベースはありません。分離したリポジトリを作成することも\
+できます(``bzr init-repo`` コマンドを参照してください)。大規模なブランチを\
+利用する場合や、中規模のブランチをたくさん利用する場合にはリポジトリを\
+分離するといいでしょう。
+
+自分のコンピュータのファイルシステム上にあるブランチを参照するときは\
+ブランチを格納しているディレクトリ名で指定できます。 bzr は http や ftp\
+経由でブランチにアクセスすることもできます。例::
+
+    % bzr log http://bazaar-vcs.org/bzr/bzr.dev/
+    % bzr log sftp://bazaar-vcs.org/bzr/bzr.dev/
+
+プラグインをインストールすれば、 rsync プロトコルを使ってブランチにアクセス\
+することもできます。
+
+ブランチを指定した場所に置く方法については、 `ブランチを公開する`_ 節を\
+ご覧ください。
+
+.. Reviewing changes
+
+変更をレビューする
+===================
+
+一仕事終えたら、それを履歴に **コミット (commit)** しましょう。
+新しい機能を追加したり、バグを直したり、コードやドキュメントを更新したら\
+いつでもコミットするのは良いことです。
+すべてのリビジョンが良い状態であるようにするために、コミットする前にコードを\
+コンパイルしたりテストスイートを実行するのも良い習慣です。
+コミットする前にコミットしようとしているものを確認するためにレビューすることが\
+できます。
+
+この目的で便利な二つのコマンドがあります。 **status** と **diff** です。
+
+bzr status
+----------
+
+**status** コマンドは、今の作業ツリーが最後のリビジョンからどのように\
+変更されたのかを教えてくれます::
+
+    % bzr status
+    modified:
+       foo
+
+``bzr status`` は変更が無かったり無視されているファイルを隠します。
+status コマンドはオプションとして、確認対象となる複数のファイル名やディレクトリ名を\
+渡すことができます。
+
+bzr diff
+--------
+
+**diff** コマンドは通常の unified diff フォーマットですべてのファイルの\
+テキストの変更を表示します。
+このコマンドの出力を pipe 経由で、''patch'', ''diffstat'', ''fileterdiff'',
+''colordiff'' といったコマンドに渡すことができます。 ::
+
+    % bzr diff
+    === added file 'hello.txt'
+    --- hello.txt   1970-01-01 00:00:00 +0000
+    +++ hello.txt   2005-10-18 14:23:29 +0000
+    @@ -0,0 +1,1 @@
+    +hello world
+
+
+``-r`` オプションをつけると、作業ツリーを古いリビジョンと比較したり、\
+二つのリビジョン間の差分を見ることができます。 ::
+
+    % bzr diff -r 1000..          # everything since r1000
+    % bzr diff -r 1000..1100      # changes from 1000 to 1100
+
+``--diff-options`` オプションをつけると、 bzr は外部の diff プログラムに\
+オプションをつけて起動します。 例::
+
+    % bzr diff --diff-options --side-by-side foo
+
+プロジェクトによっては二つのファイルに接頭辞がついた patch が好まれます。
+``--prefix`` オプションでそのような接頭辞をつけることができます。
+ショートカットとして、 ``bzr diff -p1`` は ``patch -p1`` コマンドが受け付ける\
+形で差分を出力します。
+
+
+.. Committing changes
+
+変更をコミットする
+==================
+
+作業ツリーの状態に満足したら、ブランチに **コミット (commit)** しましょう。
+コミットとは作業ツリーの状態のスナップショットを保持するリビジョンを新しく作ることです。
+
+bzr commit
+----------
+
+.. The **commit** command takes a message describing the changes in the
+.. revision.  It also records your userid, the current time and timezone, and
+.. the inventory and contents of the tree.  The commit message is specified
+.. by the ``-m`` or ``--message`` option. You can enter a multi-line commit
+.. message; in most shells you can enter this just by leaving the quotes open
+.. at the end of the line.
+
+**commit** コマンドはそのリビジョンの変更を説明するメッセージを受け取ります。
+また、あなたのユーザーID、今の時間とタイムゾーン、ツリーの内容をあわせて記録します。
+コミットメッセージは ``-m`` もしくは ``--message`` オプションで指定できます。
+複数行のコメントも利用できます。多くのシェルはクォートを開いたままで改行する\
+ことで複数行の入力が可能です。
+
+::
+
+    % bzr commit -m "added my first file"
+
+.. You can also use the ``-F`` option to take the message from a file.  Some
+.. people like to make notes for a commit message while they work, then
+.. review the diff to make sure they did what they said they did.  (This file
+.. can also be useful when you pick up your work after a break.)
+
+メッセージをファイルで渡すには ``-F`` オプションを使います。
+コミットメッセージを先に作成し、それとdiffを合わせてレビューすることで、
+コミットメッセージとコミット内容が一致していることを確認する人もいます。
+(このファイルは休憩から戻ってきて作業を思い出すときにも役に立つでしょう)
+
+.. Message from an editor
+
+エディタからメッセージを入力する
+----------------------------------
+
+.. If you use neither the ``-m`` nor the ``-F`` option then bzr will open an
+.. editor for you to enter a message.  The editor to run is controlled by
+.. your ``$VISUAL`` or ``$EDITOR`` environment variable, which can be overridden
+.. by the ``editor`` setting in ``?/.bazaar/bazaar.conf``; ``$BZR_EDITOR`` will
+.. override either of the above mentioned editor options.  If you quit the
+.. editor without making any changes, the commit will be cancelled.
+
+``-m`` オプションも ``-F`` オプションも指定しなかった場合、 bzr はメッセージを\
+入力するためにエディタを立ち上げます。
+このエディタは ``$VISUAL`` か ``$EDITOR`` 環境変数で制御することができます。
+この環境変数を `` /.bazaar/bazaar.conf`` 内の ``editor`` を設定して上書き\
+することができ、さらに ``$BZR_EDITOR`` 環境変数がそれらすべてを上書きします。
+もし何も変更せずにエディタを閉じたなら、コミットはキャンセルされます。
+
+.. The file that is opened in the editor contains a horizontal line. The part
+.. of the file below this line is included for information only, and will not
+.. form part of the commit message. Below the separator is shown the list of
+.. files that are changed in the commit. You should write your message above
+.. the line, and then save the file and exit.
+
+エディタで開かれるファイルには水平線が含まれています。この線より下の部分は\
+参考用であり、コミットメッセージには含まれません。
+水平線の下にはコミットで変更されるファイルのリストが表示されます。
+メッセージは水平線の上に書く必要があります。そうしたら、ファイルを保存して\
+エディタを終了してください。
+
+.. If you would like to see the diff that will be committed as you edit the
+.. message you can use the ``--show-diff`` option to ``commit``. This will include
+.. the diff in the editor when it is opened, below the separator and the
+.. information about the files that will be committed. This means that you can
+.. read it as you write the message, but the diff itself wont be seen in the
+.. commit message when you have finished. If you would like parts to be
+.. included in the message you can copy and paste them above the separator.
+
+``commit`` コマンドに ``--show-diff`` オプションをつけると、コミットされる\
+変更の diff を見ることができます。この diff はエディタが開いたときに水平線\
+やコミットされるファイルの情報よりも下に含まれます。
+なので、コミットメッセージを書くときに diff を見ることができますが、\
+コミットメッセージ自体には diff が含まれません。
+コミットメッセージに diff を含めたい場合は、水平線より上にコピーペースト\
+してください。
+
+.. Selective commit
+
+選択コミット
+----------------
+
+.. If you give file or directory names on the commit command line then only
+.. the changes to those files will be committed.  For example::
+
+commit コマンドにファイル名やディレクトリ名を渡したとき、それらのファイルの\
+変更だけがコミットされます。 例 ::
+
+    % bzr commit -m "documentation fix" commit.py
+
+.. By default bzr always commits all changes to the tree, even if run from a
+.. subdirectory.  To commit from only the current directory down, use::
+
+デフォルトでは bzr は、サブディレクトリから実行される場合でもすべての変更を\
+コミットします。
+カレントディレクトリ以下だけをコミットする場合は、次のようにします ::
+
+    % bzr commit .
+
+
+.. Removing uncommitted changes
+
+コミットされていない変更を削除する
+===================================
+
+.. If you've made some changes and don't want to keep them, use the
+.. **revert** command to go back to the previous head version.  It's a good
+.. idea to use ``bzr diff`` first to see what will be removed. By default the
+.. revert command reverts the whole tree; if file or directory names are
+.. given then only those ones will be affected. ``bzr revert`` also clears the
+.. list of pending merges revisions.
+
+不要な変更がある場合、 **revert** コマンドで最後のリビジョンの状態に戻る\
+ことができます。
+revert するまえに ``bzr diff`` で何が削除されるのかを確認しておくと良いでしょう。
+デフォルトでは revert コマンドはツリー全体を revert します。ファイル名や\
+ディレクトリ名が指定されている場合は、そのファイルだけが revert されます。
+``bzr revert`` はマージ待ちリビジョンのリストも削除します。
+
+
+.. Ignoring files
+
+ファイルを無視する
+===================
+
+.. The .bzrignore file
+
+.bzrignore ファイル
+-------------------
+
+.. Many source trees contain some files that do not need to be versioned,
+.. such as editor backups, object or bytecode files, and built programs.  You
+.. can simply not add them, but then they'll always crop up as unknown files.
+.. You can also tell bzr to ignore these files by adding them to a file
+.. called ``.bzrignore`` at the top of the tree.
+
+多くのソースツリーはバージョン管理する必要のないファイルをたくさん含んでいます。
+たとえば、エディタのバックアップファイルや、オブジェクトファイル、バイトコード、
+ビルドされたプログラムなどです。
+こういったファイルを単に add しないこともできますが、そうすると毎回 unknown file
+としてたびたび出現することになります。
+ツリートップにある ``.bzrignore`` とよばれるファイルにそれらのファイルを追加する\
+ことで、bzrにそれらのファイルを無視させることができます。
+
+.. This file contains a list of file wildcards (or "globs"), one per line.
+.. Typical contents are like this::
+
+このファイルは行ごとにワイルドカード (もしくは"glob") のリストを含みます。
+典型的な内容の例です::
+
+    *.o
+    *?
+    *.tmp
+    *.py[co]
+
+.. If a glob contains a slash, it is matched against the whole path from the
+.. top of the tree; otherwise it is matched against only the filename.  So
+.. the previous example ignores files with extension ``.o`` in all
+.. subdirectories, but this example ignores only ``config.h`` at the top level
+.. and HTML files in ``doc/``::
+
+glob がスラッシュを含む場合、ツリーのトップからのパス全体にマッチします。
+そうでない場合は、単にファイル名にマッチします。
+なので、上の例はすべてのサブディレクトリの ``.o`` 拡張子を持つファイルを無視\
+しますが、次の例ではツリーのトップにある ``config.h`` ファイルと、 ``doc/``
+ディレクトリ以下のHTMLファイルだけを無視します::
+
+    ./config.h
+    doc/*.html
+
+.. To get a list of which files are ignored and what pattern they matched,
+.. use ``bzr ignored``::
+
+どのファイルがどのパターンにマッチして無視されているのかを、 ``bzr ignored``
+コマンドで表示することができます::
+
+    % bzr ignored
+    config.h                 ./config.h
+    configure.in?            *?
+
+.. It is OK to have either an ignore pattern match a versioned file, or to
+.. add an ignored file.  Ignore patterns have no effect on versioned files;
+.. they only determine whether unversioned files are reported as unknown or
+.. ignored.
+
+バージョン管理されているファイルが無視パターンにマッチしたり無視リストに\
+入っていても大丈夫です。無視パターンはバージョン管理されたファイルには\
+影響しません。バージョン管理されていないファイルを 'unknown' として扱うか\
+'ignored' として扱うかを決めるためだけに使われます。
+
+
+.. The ``.bzrignore`` file should normally be versioned, so that new copies
+.. of the branch see the same patterns::
+
+``.bzrignore`` ファイルは普通はバージョン管理されます。なのでそのブランチの\
+コピーでも同じパターンが無視されます。 ::
+
+    % bzr add .bzrignore
+    % bzr commit -m "Add ignore patterns"
+
+
+.. Global ignores
+
+グローバルの無視設定
+---------------------
+
+.. There are some ignored files which are not project specific, but more user
+.. specific. Things like editor temporary files, or personal temporary files.
+.. Rather than add these ignores to every project, bzr supports a global
+.. ignore file in ``?/.bazaar/ignore`` [1]_. It has the same syntax as the
+.. per-project ignore file.
+
+エディタの一時ファイルや個人の一時ファイルなど、\
+幾つかの無視ファイルはプロジェクト依存ではなくてユーザー依存です。
+こういったファイルを全プロジェクトで無視設定するかわりに、グローバルの\
+無視設定ファイル ``~/.bazaar/ignore`` を利用できます。
+これはプロジェクトの ignore ファイルと同じ文法で記述します。
+
+
+.. Examining history
+
+履歴を閲覧する
+===============
+
+bzr log
+-------
+
+.. The ``bzr log`` command shows a list of previous revisions. The ``bzr log
+.. --forward`` command does the same in chronological order to get most
+.. recent revisions printed at last.
+
+``bzr log`` コマンドは過去のリビジョンのリストを表示します。
+``bzr log --forward`` コマンドは同じ内容を、時系列順で最新のものが最後に\
+くるように出力します。
+
+.. As with ``bzr diff``, ``bzr log`` supports the ``-r`` argument::
+
+``bzr diff`` と同じように、 ``bzr log`` も ``-r`` 引数をサポートします::
+
+    % bzr log -r 1000..          # リビジョン r1000 とそれ以降すべて
+    % bzr log -r ..1000          # r1000 とそれ以前のすべて
+    % bzr log -r 1000..1100      # r1000 から r1100 まで
+    % bzr log -r 1000            # リビジョン r1000 だけ
+
+..    % bzr log -r 1000..          # Revision 1000 and everything after it
+..    % bzr log -r ..1000          # Everything up to and including r1000
+..    % bzr log -r 1000..1100      # changes from 1000 to 1100
+..    % bzr log -r 1000            # The changes in only revision 1000
+
+
+.. Branch statistics
+
+ブランチの情報
+=================
+
+.. The ``bzr info`` command shows some summary information about the working
+.. tree and the branch history.
+
+``bzr info`` コマンドは作業ツリーとブランチの履歴に関する情報の要約を表示します。
+
+
+.. Versioning directories
+
+ディレクトリをバージョン管理する
+================================
+
+.. bzr versions files and directories in a way that can keep track of renames
+.. and intelligently merge them::
+
+bzr はファイルとディレクトリを、名前の変更を追跡して賢くマージできるように\
+バージョン管理します::
+
+    % mkdir src
+    % echo 'int main() {}' > src/simple.c
+    % bzr add src
+    added src
+    added src/simple.c
+    % bzr status
+    added:
+      src/
+      src/simple.c
+
+
+.. Deleting and removing files
+
+ファイルを削除する
+===================
+
+.. You can delete files or directories by just deleting them from the working
+.. directory.  This is a bit different to CVS, which requires that you also
+.. do ``cvs remove``.
+
+ファイルを削除するのは、単純に作業ツリーからファイルを削除するだけでできます。
+これは、 ``cvs remove`` が必要な CVS とは少し異なります。
+
+.. ``bzr remove`` makes the file un-versioned, but may or may not delete the
+.. working copy [2]_.  This is useful when you add the wrong file, or decide that
+.. a file should actually not be versioned.
+
+``bzr remove`` はファイルをバージョン管理対象からはずしますが、作業ツリーから\
+削除することも削除しないこともできます。 [2]_
+これは間違ったファイルを追加してしまったり、あるファイルをバージョン管理するのを\
+やめる場合に便利です。
+
+::
+
+    % rm -r src
+    % bzr remove -v hello.txt
+    ?       hello.txt
+    % bzr status
+    removed:
+      hello.txt
+      src/
+      src/simple.c
+    unknown:
+      hello.txt
+
+.. If you remove the wrong file by accident, you can use ``bzr revert`` to
+.. restore it.
+
+もし間違ってファイルを削除してしまった場合、 ``bzr revert`` でリストアできます。
+
+
+.. Branching
+
+ブランチを作る
+==============
+
+.. Often rather than starting your own project, you will want to submit a
+.. change to an existing project.  To do this, you'll need to get a copy of
+.. the existing branch.  Because this new copy is potentially a new branch,
+.. the command is called **branch**::
+
+自分でプロジェクトを始めるのではなく、既存のプロジェクトに変更を加えたい場合があります。
+この場合、既存のブランチのコピーを取得する必要があります。
+このコピーは新しいブランチになるので、このコマンドは **branch** という名前になっています::
+
+    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev
+    % cd bzr.dev
+
+.. This copies down the complete history of this branch, so we can do all
+.. operations on it locally: log, annotate, making and merging branches.
+.. There will be an option to get only part of the history if you wish.
+
+.. XXX: There will be の訳これでいい？
+
+これでブランチの完全な履歴をコピーできたので、すべての操作 (log, annotate,
+branch の作成とマージなど) をローカルで実行できます。
+履歴の一部だけを取得するオプションも追加される予定です。
+
+.. You can also get a copy of an existing branch by copying its directory,
+.. expanding a tarball, or by a remote copy using something like rsync.
+
+既存のブランチをコピーするには、普通にディレクトリをコピーしたり、tarballを\
+展開したり、リモートから rsync のような方法でコピーすることもできます。
+
+.. Following upstream changes
+
+上流の変更を追いかける
+==========================
+
+.. You can stay up-to-date with the parent branch by "pulling" in their
+   changes::
+
+変更を "pull" することで手元のブランチを上流のブランチに対して最新に保つことが\
+できます。
+
+    % bzr pull
+
+.. After this change, the local directory will be a mirror of the source. This
+.. includes the ''revision-history'' - which is a list of the commits done in
+.. this branch, rather than merged from other branches.
+
+.. XXX This includes～がわからない.
+
+このコマンドを実行した後、ローカルディレクトリはpull元のミラーになります。
+ミラーするものには、 ''revision-history'' を含みます。つまり、別のブランチから\
+マージするのではなくて、このブランチに対してコミットした履歴になります。
+
+.. This command only works if your local (destination) branch is either an
+.. older copy of the parent branch with no new commits of its own, or if the
+.. most recent commit in your local branch has been merged into the parent
+.. branch.
+
+このコマンドはローカルの(pull先)ブランチが親ブランチの古いコピーで独自の\
+あたらしいリビジョンを一切含まないか、ローカルブランチへの最新のコミットが\
+親ブランチにマージされているときにのみ成功します。
+
+.. Merging from related branches
+
+関連ブランチからマージする
+=============================
+
+.. If two branches have diverged (both have unique changes) then ``bzr
+.. merge`` is the appropriate command to use. Merge will automatically
+.. calculate the changes that exist in the branch you're merging from that
+.. are not in your branch and attempt to apply them in your branch.
+
+二つのブランチが分岐している(互いに異なる変更を持っている)とき、
+``bzr merge`` コマンドの出番です。
+merge はマージ元ブランチにあって手元のブランチにない変更を自動で探して、\
+その変更を手元に適用しようと試みます。
+
+::
+
+  % bzr merge URL
+
+
+.. If there is a conflict during a merge, 3 files with the same basename
+.. are created. The filename of the common base is appended with ".BASE",
+.. the filename of the file containing your changes is appended with
+.. ".THIS" and the filename with the changes from the other tree is
+.. appended with ".OTHER".  Using a program such as kdiff3, you can now
+.. comfortably merge them into one file.  In order to commit you have to
+.. rename the merged file (".THIS") to the original file name.  To
+.. complete the conflict resolution you must use the resolve command,
+.. which will remove the ".OTHER" and ".BASE" files.  As long as there
+.. exist files with .BASE, .THIS or .OTHER the commit command will
+.. report an error.
+
+マージ中に衝突(conflict)が発生した場合、同じ基本名(basename)をもつ\
+3つのファイルが作成されます。
+共通の祖先になるファイルのファイル名には ".BASE" が、
+手元のブランチの変更を含むファイル名には ".THIS" が、
+マージ元の変更を含むファイル名には ".OTHER" が末尾に追加されます。
+kdiff3 のようなプログラムを利用してこれらのファイルをひとつに\
+マージすることができます。
+コミットするには、マージされた ".THIS" ファイルを元のファイル名に\
+リネームします。
+衝突の解決を完了するには、 resolve コマンドを使います。
+このコマンドは ".OTHER" と ".BASE" ファイルを削除します。
+.BASE, .THIS, .OTHER ファイルが残っている場合、 commit コマンドは\
+エラーを報告します。
+
+::
+
+  % kdiff3 file.BASE file.OTHER file.THIS
+  % mv file.THIS file
+  % bzr resolve file
+
+[**TODO**: explain conflict markers within files]
+
+
+ブランチを公開する
+======================
+
+.. You don't need a special server to publish a bzr branch, just a normal web
+.. server.  Just mirror the files to your server, including the .bzr
+.. directory.  One can push a branch (or the changes for a branch) by one of
+.. the following three methods:
+
+bzrのブランチを公開するには特別なサーバーは必要ありません、普通のWebサーバーが\
+使えます。
+.bzr ディレクトリを含めてファイルをサーバーにミラーしてください。
+ブランチをpush(やブランチに対する操作)するのに以下の3つの方法があります。
+
+.. * The best method is to use bzr itself to do it.
+
+* 最良の方法は bzr 自体を使うことです。
+
+  ::
+
+    % bzr push sftp://servername.com/path/to/directory
+
+..   (The destination directory must already exist unless the
+..   ``--create-prefix`` option is used.)
+
+  (push先ディレクトリがすでに存在するか、 ``--create-prefix`` オプションを\
+  利用する必要があります。)
+
+.. * Another option is the ``rspush`` plugin that comes with BzrTools, which
+..   uses rsync to push the changes to the revision history and the working
+..   tree.
+
+* 別の選択肢は bzrtools に含まれる ``rspush`` プラグインを利用することです。
+  これはリモートの履歴と作業ツリーに変更を push するのに rsync を利用します。
+
+.. * You can also copy the files around manually, by sending a tarball, or using
+..   rsync, or other related file transfer methods.  This is usually less safe
+..   than using ``push``, but may be faster or easier in some situations.
+
+* 手動で、 tarball を送ったり rsync を使ったりほかの転送方法を利用してファイルを\
+  送ることで
+
+
+.. Moving changes between trees
+
+変更をツリー間で移動する
+============================
+
+.. It happens to the best of us: sometimes you'll make changes in the wrong
+.. tree.  Maybe because you've accidentally started work in the wrong directory,
+.. maybe because as you're working, the change turns out to be bigger than you
+.. expected, so you start a new branch for it.
+
+どんな人にでもありえることですが、適切ではないツリー上で変更してしまうことがあります。
+単純に作業するディレクトリを間違えたり、変更がよそうよりも大きくなってしまったりして、
+その変更のために新しいブランチを作りなおすことがあります。
+
+.. To move your changes from one tree to another, use
+
+変更をあるツリーから別のツリーに移動するには
+
+::
+
+  % cd NEWDIR
+  % bzr merge --uncommitted OLDDIR
+
+.. This will apply all of the uncommitted changes you made in OLDDIR to NEWDIR.
+.. It will not apply committed changes, even if they could be applied to NEWDIR
+.. with a regular merge.  The changes will remain in OLDDIR, but you can use ``bzr
+.. revert OLDDIR`` to remove them, once you're satisfied with NEWDIR.
+
+これですべてのコミットされていないOLDDIR上の変更がNEWDIRに適用されます。
+コミットされていない変更は、通常のmergeでNEWDIRに適用することができる場合でも適用されません。
+OLDDIR上の変更はそのまま残りますが、NEWDIRの状態に満足したら ``bzr revert OLDDIR``
+で削除することができます。
+
+.. NEWDIR does not have to be a copy of OLDDIR, but they should be related.
+.. The more different they are, the greater the chance of conflicts.
+
+NEWDIRはOLDDIRのコピーである必要はありませんが、関連しているべきです。
+両者の違いが大きければそれだけ衝突が起こる可能性が大きくなります。

=== added file 'doc/ja/tutorials/using_bazaar_with_launchpad.txt'
--- doc/ja/tutorials/using_bazaar_with_launchpad.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/tutorials/using_bazaar_with_launchpad.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,552 @@
+===========================
+LaunchpadでBazaarを使う
+===========================
+
+
+動機付け
+==========
+
+コミュニティはチームとは違う
+----------------------------------
+
+ソフトウェアの初回リリースをしなければならない人々のチームというのは、\
+一人から数千人まで、その規模は多岐に渡ります。
+その要求に応じて、技術的な課題、経営上の課題、その両方が非常に大きなもの\
+になる可能性があります。
+Bazaarユーザガイドで説明したように、"ふさわしい"プロセスを選択し、\
+それに見合ったワークフローをサポートするBazaarのようなツールを使うことは、\
+大きな手助けになるでしょう。
+
+.. The team of people required to create the initial release
+   of a piece of software may vary in size from one person
+   to several thousand people. Depending on the requirements,
+   the challenges involved, both technical and managerial,
+   can be immense. As explained in the Bazaar User Guide, selecting
+   "just right" processes and using tools like Bazaar to support
+   matching workflows can greatly help.
+
+しかし、ソフトウェアによる成功のためには、すばらしいチーム以上のものが\
+必要です。 - それは、健全で活発な *コミュニティ* です。
+このグループは、通常はチームよりもはるかに大きく、なぜならそのソフトウェアに\
+関心のあるすべての人 - 開発チーム、ユーザ、トレーニングパートナー、\
+サポートパートナー、サードパーティの開発者など - を含むからです。
+
+.. Success with software though requires more than a great team - it
+   requires a healthy, active *community*. This group is typically
+   far larger than the team as it includes everyone interested in
+   the software: the team, users, training partners, support partners,
+   third-party developers and so on.
+
+すばらしいコミュニティというものはオープンソースの世界では良く理解されています。
+しかし、その適用はオープンソースの世界を越えて広がっています。: もっとも成功している\
+商業ソフトウェアのベンダーは、そのフラッグシッププロダクトと共に成長するコミュニティ\
+を作り上げ、運営することがたくみなのです。
+
+.. Great communities are well understood in the open source world.
+   Their applicability extends well beyond that though: most
+   successful commercial software vendors are well skilled at
+   building and managing the communities that grow up around
+   their flagship products.
+
+すばらしいチームと同じように、すばらしいコミュニティも偶然できるものではありません。
+良いポリシーとガイドラインが、参加者同士の健全なコミュニケーションと正しい振る舞い\
+を育てるために不可欠です。
+この話題についてもっと深く知りたければ、Karl Fogelのすばらしい著書 - \
+`Producing Open Source Software <http://www.producingoss.com/>`_ - を見てください。
+
+.. Like great teams, great communities don't just happen.
+   Good policies and guidelines are essential for
+   fostering the right sort of behaviour and healthy
+   relationships between participants. For a deeper look at
+   this topic, see Karl Fogel's landmark book:
+   `Producing Open Source Software <http://www.producingoss.com/>`_.
+
+
+協調開発に必要なもの
+---------------------------------------------------
+
+コミュニティの情報とワークフローを追跡し、管理するためには、賢いツールセットが重要です。
+そのようなツールを、協調開発環境(Collaborative Development Environments : CDEs)と呼びます。
+一般的には、WEBベースでアナウンスや案件、バグを管理します。
+`Launchpad <https://launchpad.net>`_ 、
+`SourceForge <http://sourceforge.net>`_ 、
+`java.net <http://java.net>`_ 、
+`SAP Community Network <https://www.sdn.sap.com/irj/sdn>`_ などに、CDEsの例があります。
+
+.. An intelligent toolset is also important for tracking and managing
+   community information and workflows. These tools are called
+   Collaborative Development Environments (CDEs). These toolsets are
+   typically web-based and manage things such as announcements,
+   issues/bugs, questions and answers, downloads, documents and
+   source code. Some examples of CDEs include
+   `Launchpad <https://launchpad.net>`_,
+   `SourceForge <http://sourceforge.net>`_,
+   `java.net <http://java.net>`_ and
+   `SAP Community Network <https://www.sdn.sap.com/irj/sdn>`_.
+
+
+関係するコミュニティとの協調を助ける
+-------------------------------------------------
+
+多くの成功しているプロダクトは、その下流にそれを使うたくさんのプロダクトがあります。
+言いかえると、他のコミュニティとやりとりをして、自分の変更が彼らにどんな影響を与えるかを\
+理解することで、新しい挑戦が成功するのです。
+これは、以下のようなプロダクトで特に明白です。:
+
+* プログラム言語、たとえばPyhon、PHP、Ruby、Java、Perlなど
+* コンパイラ、たとえばgcc、JDKなど
+* ライブラリ、たとえばzlib、opensslなど
+* フレームワーク、たとえばZope、Ruby on Rails、Springなど
+
+.. XXX downstream dependenciesは、直訳だとわかりづらい気がするのでやや意訳
+   In other wordからの一文の訳がよくわからない
+
+.. Many successful products have a huge number of downstream dependencies.
+   In other words, a new challenge arises with success: dealing with other
+   communities and understanding how your changes will impact them. This is
+   most obvious for projects like:
+
+.. * software languages, e.g. Python, PHP, Ruby, Java, Perl, etc.
+   * compilers, e.g. gcc, JDK, etc.
+   * libraries, e.g. zlib, openssl, etc.
+   * frameworks, e.g. Zope, Ruby on Rails, Spring, etc.
+
+しかし、アドオン機能を持つメジャーなアプリケーション、たとえばFirefox、Thundervird、\
+OpenOffice.org、Drupal、Wordpress、Joomlaなどにも、このことはあてはまります。
+
+.. However it applies equally for popular applications on which add-ons are
+   built, e.g. Firefox, Thunderbird, OpenOffice.org, Drupal, Wordpress, Joomla,
+   etc.
+
+コミュニティの境界をこえて案件や障害修正の追跡と管理をするための作業をサポートして\
+くれるツールが必要です。
+そのようなツールは、両極端にいるどちらのユーザも助けてくれます。:
+
+* 自分のことばで問題を報告することができるユーザ。
+  たとえば、「オペレーションシステムX上のアプリケーションYで、Zタイプのイメージの\
+  レンダリングがおかしい」など
+
+* 変更や障害修正が下流のプロダクトに与える影響をよりよく評価できる開発者。
+  たとえば、「グラフィックライブラリのバグを修正することにより、これらの10個のOS上の\
+  5つのアプリケーションに恩恵がある」など
+
+.. Tools that assist communities work together to track and manage
+   issues and fixes across community boundaries are required. These
+   tools help people at both ends of the spectrum:
+
+.. * users can report problems in their terms, e.g. rendering of image
+     type X is broken in application Y on operating system Z
+
+.. * developers can better appreciate the downstream impact of making a
+     change or fix, e.g. fixing this bug in a graphics library will
+     make the users of these 5 applications on these 10 operating
+     systems happy.
+
+その間にいる人々は、 *点線をつなぎ* 、上流と下流との間のコミュニケーションを担うという\
+重要な役割を果たします。
+多くの場合、彼らはエンドユーザのためにバグを修正したり、パッチをリリースしたり、上流の\
+開発チームに修正内容を提示したりします。
+それらすべてを持続可能な方法で常に追跡しつづけることは、簡単なことではありません。
+
+.. People in the middle play the essential role of *joining the dots* and
+   communicating up and down the line. In many cases, they may also fix the
+   problem for end users, releasing a patch and pushing a suggested fix
+   to the upstream development team. Keeping track of all that over time
+   in a sustainable way is no easy task.
+
+
+Launchpad: 開発をもっと効果的に、摩擦は少なく
+-------------------------------------------------
+
+`Ubuntu <http://www.ubuntu.com>`_ の開発に出資しているのと同じように、Canonicalは\
+オープンソースコミュニティ向けの無料のサービスとしてLaunchpad(https:launchpad.net)も\
+提供しています。
+Launchpadは、以下の注目すべき理由から、もっともエキサイティングなCDEsのひとつです。:
+
+* トラッキング対象のたくさんのもの同士の関係を具体化しています。
+  たとえば、ソースコードのブランチをバグ修正に関連づけることができます。
+
+* これまでの資産を管理するのと同じように、ロードマップ、マイルストーン、ブループリントの\
+  機能によってこれからの開発の計画や追跡もできます。
+
+* 翻訳ツールやパッケージングサービスを提供することで、翻訳者やテスターがコミュニティに参加し、\
+  貢献するときの抵抗を少なくしています。
+
+* 違うコミュニティ同士が、関連する案件やロードマップに対してともに作業するための結びつきを\
+  提供します。
+
+.. As well as sponsoring `Ubuntu <http://www.ubuntu.com>`_ and
+   `Bazaar <http://bazaar-vcs.org>`_ development, Canonical
+   provides Launchpad, https://launchpad.net, as a free service
+   for the open source community. Launchpad is one of the most
+   exciting CDEs around for several notable reasons:
+
+.. * it models relationships between many of things tracked, e.g.
+     source code branches can be associated with bug fixes
+
+.. * as well are managing historical knowledge,
+     it supports future development planning and tracking by providing
+     features such as roadmaps, milestones and blueprints
+
+.. * it provides translation tools and packaging services so that
+     barriers are reduced for translators and testers wishing to
+     join your community and help out
+
+.. * it provides a nexus for different communities to work
+     together on related issues and roadmaps.
+
+言いかえると、Launchpadは、あなたのコミュニティの成長を助け、 *コミュニティ内* と\
+*コミュニティ間* との両方でワークフローの摩擦を減らすようにデザインされています。
+究極的には、機械的なタスクにつかう時間をなくし、興味ぶかい開発により多くの時間を\
+さけるようにすることを意味しています。
+
+.. In other words, Launchpad has been designed to help your
+   community grow and to reduce the workflow friction both
+   *within* your community and *between* communities. Ultimately,
+   that means less time on mechanical tasks and more time for
+   interesting development.
+
+
+Bazaar: Launchpadのバージョン管理クライアント
+---------------------------------------------
+
+このチュートリアルは、BazaarとLaunchpadがどのようにして一緒に使うことができ、\
+どれだけお互いを引き立てあうのかを考えます。
+以下のことは覚えておいてください。:
+
+1. BazaarはLaunchpadなしで使うこともできます。
+2. LaunchpadはBazaarなしで使うこともできます。
+
+それでも、別々に使うよりも一緒に使った方がよりパワフルになるよう設計されています。
+
+.. This tutorial looks at how Bazaar and Launchpad can be used together
+   and how they complement each other. It is important to remember that:
+
+.. 1. Bazaar can be used without Launchpad
+.. 2. Launchpad can be used without Bazaar.
+
+.. By design though, their sum is greater than the individual
+   parts.
+
+
+Finding and browsing branches using Launchpad
+=============================================
+
+Finding available branches
+--------------------------
+
+While there are many advantages in adopting distributed version
+control, one of the things that disappears is the all-knowing
+central server with knowledge about all available branches. Indeed
+in a distributed environment, interesting branches can literally
+exist in 100s of locations across the Internet (or within an
+Intranet for that matter).
+
+Launchpad fills this gap by providing a registry of branches.
+
+
+Registering branches
+--------------------
+
+Branches can be uploaded to Launchpad or simply registered
+as being available in an external location. Branches can also
+be given a Status such as *New*, *Development*, *Mature* or
+*Abandoned*.
+
+Note: External branches can even be hosted in legacy version control
+tools, i.e. CVS and Subversion. Code in these systems will be
+scanned and converted to Bazaar branches on a periodic basis.
+For maximum fidelity of course, it is preferable for external
+branches to be hosted in Bazaar.
+
+
+Browsing branches
+-----------------
+
+Branches can be listed, filtered and sorted by numerous
+attributes including Name, Registrant, Author, Status, Age and
+time of last commit. Browsing of branches is also provided making
+it easy to see things such as:
+
+* where the branch can be downloaded from
+* how to upload changes
+* recent commits and the changes made by each
+* the source code of individual files for a given version.
+
+
+Accessing code in Launchpad using Bazaar
+========================================
+
+Getting the code for an open source project
+-------------------------------------------
+
+As Launchpad keeps track of thousands of open source projects
+and their latest code whether it be managed by Bazaar, CVS or Subversion,
+Bazaar users can grab that code as easily as this::
+
+  bzr branch lp:project-name
+
+where `project-name` is the Launchpad project ID. Here are some examples::
+
+  bzr branch lp:inkscape
+  bzr branch lp:amarok
+  bzr branch lp:python
+  bzr branch lp:rails
+  bzr branch lp:java-gnome
+
+You can then browse the code locally using your favorite editor or IDE and
+change the code if you wish.
+
+If a project has multiple series registered (e.g. a development series and a
+maintenance series), the latest code for a given series can be fetched using::
+
+  bzr branch lp:project-name/series
+
+Publishing your changes
+-----------------------
+
+Having fixed that annoying bug or added that cool feature you've always
+wanted, it's time to impress your friends and make the world a better
+place by making your code available to others. As explained earlier,
+Launchpad is a free Bazaar code hosting service so you can push your
+branch to it and others can access your code from there. For example,
+assuming you are a member of the relevant team, login to launchpad like this::
+
+  bzr launchpad-login userid
+
+where `userid` is your Launchpad user ID.
+You can then push your changes to a team branch like this::
+
+  bzr push lp:~team-name/project-name/branch-name
+
+Others can then download your code like this::
+
+  bzr branch lp:~team-name/project-name/branch-name
+
+
+Personal branches
+-----------------
+
+Even if you are not a member of a team, Launchpad can be used to publish
+your changes. In this case, simply create a personal branch like this::
+
+  bzr push lp:~userid/project-name/branch-name
+
+Others can then download your code like this::
+
+  bzr branch lp:~userid/project-name/branch-name
+
+Note: Even when publishing to a personal branch, it is polite to notify the
+upstream developers about your branch so they can pull your changes from
+it if they are generally applicable to all users and meet the project's
+quality standards.
+
+
+Linking branches using Launchpad
+================================
+
+Associating a branch with a bug
+-------------------------------
+
+After registering a branch, you can associate it to a bug so that
+people interested in that bug can track and download the fix as
+it becomes available.
+
+To do this, the steps are:
+
+1. Navigate to the bug in question.
+
+2. Select `Add branch` under `Actions`.
+
+3. Select the branch.
+
+4. Optionally set the State of the relationship. This is
+   *Fix In Progress* by default but you may wish to set it
+   to another state such as *Fix Available* if the branch already
+   addresses the issue.
+
+If you wish, you can also provide some arbitrary comments about
+the relationship between the bug and the branch.
+
+
+Changing the state in Launchpad while committing in Bazaar
+----------------------------------------------------------
+
+Bazaar and Launchpad can work together to reduce some of
+the status housekeeping for you. When you commit using Bazaar,
+use the --fixes option like this::
+
+  bzr commit --fixes lp:1234 -m "..."
+
+where 1234 is the bug ID. This will changes the State of the
+bug-branch relationship to *Fix Available*. If the one commit
+fixes multiple issues, the --fixes option can be specified multiple
+times.
+
+One of the cool things about this feature is that Launchpad does
+not need to be accessible when making the commit. The ``--fixes``
+option works by storing metadata which Launchpad will detect next
+time the branch is pushed to it or scanned once online again.
+
+Note: Launchpad will not implicitly close a bug just because a
+branch is available that fixes it. There are several reasons for this.
+Firstly, the branch usually needs to be merged into the trunk
+(main development branch) before most teams consider it fixed.
+Secondly, many teams have a separate process for confirming
+bugs are fixed over and above a developer saying so.
+
+As explained later, merge control features are currently under
+development in Launchpad and automatically changing the status of
+bugs to *Fix Committed* will be more appropriate once those features
+are in place.
+
+
+Associating a branch with a blueprint
+-------------------------------------
+
+After registering a branch, you can associate it to a blueprint so that
+people interested in that blueprint can track and test the feature as
+it develops.
+
+To do this, the steps are:
+
+1. Navigate to the blueprint in question.
+
+2. Select `Link branch` under `Actions`.
+
+3. Select the branch.
+
+If you wish, you can also provide some arbitrary comments about
+the relationship between the blueprint and the branch.
+
+
+Managing releases using Launchpad
+=================================
+
+Integrating changes
+-------------------
+
+Once a branch has been developed and published, communities
+typically go through a rigorous process before those changes
+are integrated into the core product and rolled out to end users.
+Some of the steps involved may include:
+
+* peer review of the changes
+
+* deciding which releases to include the changes in, e.g. the
+  next maintenance release, the next major release, or both
+
+* running functional regression tests
+
+* benchmarking to ensure performance remains acceptable
+
+* packaging into early access releases for end user testing
+
+* documentation updates, e.g. Release Notes for the targeted
+  releases
+
+* translation of the user interface and documentation into
+  multiple languages.
+
+This section briefly looks at some of the features in Launchpad that
+help get good quality code into production. Strong integration with
+Bazaar is core to making this happen smoothly.
+
+Note: Where indicated, some of the features below are still under
+development. If one or more of these features interest you, please
+consider joining the Launchpad beta test team at this link:
+https://help.launchpad.net/JoiningLaunchpadBetaTesters. You can
+then get early access to features and provide feedback to the
+developers before wider roll-out.
+
+
+Branch merge proposals
+----------------------
+
+After navigating to a branch in Launchpad, one of the available actions
+is *Propose for merging*. This lets you nominate which branch this code
+ought to be merged into.
+
+Tracking the knowledge about which branches are proposed to be merged
+into a codeline helps Release Managers keep on top of what still needs
+to be completed, or can be completed, before a ship date. Using this
+information, they can ensure branches are merged after completing any
+necessary reviews. In the simple case, the Release Manager may manually
+merge branches. In more advanced cases, the merging could be automatically
+done by a robot (like `PQM`_) when the branch reaches the right state
+(e.g. *Review completed*).
+
+.. _PQM: https://launchpad.net/pqm
+
+
+Code review tracking
+--------------------
+
+A number of features are under development in Launchpad to track the
+states, conversations and outcomes of code reviews. These features are
+expected to be integrated with branch merge proposals and branch
+browsing features.
+
+
+Personal Package Archives (PPAs)
+--------------------------------
+
+PPAs help developers and development teams get custom builds into the
+hands of users for early testing and feedback. In other words, a PPA
+allows a developer to form a community of testers who are interested
+in their changes. The testing community can install the packages,
+run them for the test period and then remove them cleanly from their
+system.
+
+See https://help.launchpad.net/PPAQuickStart for further details.
+
+
+Translations
+------------
+
+The Translations module in Launchpad is designed to make it easy for
+anyone to get involved translating applications to languages they know.
+Translators are shielded from the low level details.
+
+Launchpad keeps track of the translations for each major version of a
+project separately, allowing translators to continue to improve the
+translations of your stable releases while others start work on newer
+versions that are still in development. Translation speed in reduced
+by sharing resources across projects. Automatic suggestions, from a
+library of 750,000 translated strings, and a community of 19,000
+registered translators can radically cut the time required to
+localise your project into many languages.
+
+
+Summary
+=======
+
+The communities we join, whether off-line or on-line,
+say a lot about the sort of people we are. The flip-side
+to this is that the tools you choose for your community - particularly
+the CDE and version control tool - can have a large impact on who
+joins and how easily they can contribute.
+
+In their own right, Launchpad and Bazaar are highly useful tools.
+Together, they can:
+
+* help your community track major assets such as source code and knowledge
+* help it grow by reducing barriers to entry
+* help it interact with related communities.
+
+In particular, Launchpad is a free code hosting service for your Bazaar
+branches, branches can be browsed online, branches can be linked to bugs
+and blueprints, and the status of bug-branch relationships can be
+automatically managed by mentioning the bug while committing in Bazaar.
+Further integration is under development with the aim of streamlining
+the process from *great idea* to *running code in the hands of end users*.
+
+If you have any feedback on how you'd like to see Bazaar and Launchpad
+further integrated, please contact us on the Bazaar mailing list,
+bazaar@lists.canonical.com.
+
+While designed as a free service to support open source projects,
+Canonical may make Launchpad available to commercial software developers
+depending on their requirements. We would be happy to hear from you
+if you think Launchpad would be useful for managing your community,
+open source or otherwise.

=== added directory 'doc/ja/upgrade-guide'
=== added file 'doc/ja/upgrade-guide/data_migration.txt'
--- doc/ja/upgrade-guide/data_migration.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/upgrade-guide/data_migration.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,130 @@
+データ移行
+###############
+
+データ移行の準備
+-------------------
+
+移行を開始する前に、最初におこなうべきことがあります。
+
+1. 完全にバックアップをとってください。
+
+2. 古いブランチを消去(purge)する時間をとってください。
+
+完全なバックアップはなにか悪いことがおきたときのセーフティネットとなります。
+
+古いブランチの消去は移行対象となるデータを減らすことができます。これをおこなうためのいくつかのコツを
+`Finding obsolete branches`_　でご覧ください。
+
+移行に関連するコマンドの紹介
+----------------------------------
+
+データ移行時には注意すべき3つの重要なコマンドがあります。
+
+* **check** - リポジトリ、ブランチやツリーのデータ完全性に関するエラーのチェック。
+
+* **reconcile** - データ完全性に関するエラーの修復。
+
+* **upgrade** - 異なるデータフォーマットへの移行。
+
+**reconcile** はめったに必要ではありませんが  **check** を **upgrade** の前後で行うことは良い習慣です。
+
+これらのコマンドの詳細なヘルプは `Bazaarユーザーリファレンス`_ をごらんください。
+
+.. _Bazaarユーザーリファレンス: ../user-reference/index.html
+
+
+あなたのコミュニティとのコミュニケーション
+---------------------------------------------------------
+
+新しいフォーマットへのスムーズな移行を可能にするためには、以下が必須です:
+
+1. trunkの移行を行う責任者を1人きめること。
+
+2. trunkの移行試験が成功すること。
+
+3. trunkを移行する時間の予定をたてることと、前もってあなたのコミュニティに知らせておくこと。
+
+事前に警告をしておくことによりコミュニティに所属する人々が 移行日より前に Bazaarや必要なpluginを移行するのに十分な余裕を持つことができるでしょう。
+
+さらに大きなコミュニティにおいては、移行それ自身に要する時間に配慮しましょう。
+試験移行の後でどのくらい移行に時間がかかるのかに関する良い案を持っておくべきです。移行を週末か金曜日に行うことで問題が発生したときにあなた自身が一息つける時間をとることができることは道理にかなっているでしょう。
+
+trunkが移行したら、あなたはコミュニティに対して適切にお知らせし、彼らに彼ら自身のローカルブランチの移行説明書を示す必要があります。後ほど説明書の例を示します。
+
+
+スタンドアロンブランチの移行
+------------------------------------
+
+作業手順は以下のとおりです。:
+
+1. **bzr check** を起動します。
+
+2. もしエラーが発生したら、**bzr reconcile** を使ってエラーの修復をこころみてください。もしこれが失敗したら問題を解決してあなたのtrunkをクリーンにするために私たちがお手伝いできるようバグの報告ください。もし成功したならクリーンなtrunkなうちにバックアップをとってください。
+
+3. **bzr upgrade --format** を実行してください。**format** は 2a またはそれ以降のことです。
+
+4. **bzr check** を起動して最終結果が正しいかどうかを確認してください。
+
+
+共用リポジトリ中のブランチを移行
+-----------------------------------------
+
+移行は以下の手順で行ってください:
+
+1. 共用リポジトリの移行。
+
+2. ブランチの移行。
+
+3. 軽量チェックアウトの移行。
+
+スタンドアロンブランチの例のように **check** を移行の前後に行って問題が存在していないか、あるいは問題がひきおこされていないかを確認してください。
+
+
+Launchpad上のブランチを移行
+-------------------------------
+
+公開ブランチとプライベートブランチを独立させるために、Launchpadでは共用リポジトリではなく、スタックブランチをディスク容量の効率化の中心技術として使用しています。したがってLaunchpadをコードホスティングに使用しているプロジェクトでは新しいフォーマットへの移行は個人や社内でしようしているとはことなります。
+
+手順は次のようになります:
+
+1. 指名された人がtrunkのコピーを持ち移行作業を実施します。
+
+2. Launchpadにおいては 現在のtrunkを開発の中心(focus)からはずします。(これは *必ず* 実施してください、そうしないとこの後の手順が期待通りになりません。)
+
+3. 移行した trunk をLaunchpadに push します。
+
+4. 開発の中心(focus)に設定します。
+
+5. 古い trunk に登録しているユーザに対して新しい trunk へ登録するよう依頼します。
+
+つまり、これらの手順の意味は　古い trunk がいぜんとして有効でスタックされたブランチが存在し続けるということです。しかしながら開発の中心は移行後の trunk に切り替わっており、以後のLaunchpadにpushされるあなたのプロジェクトの新しいブランチは(移行後のtrunkに)スタックされます。
+
+この時点であなたはあなたのコミュニティに対して 新しいtrunkが有効になったことを知らせ、彼らに彼らのローカルブランチを移行する説明する準備ができました。
+
+
+中央の trunk が移行した後のローカルブランチ移行
+-----------------------------------------------------------
+
+スタンドアロンブランチの移行手順:
+
+1. 中央リポジトリの場所から最新のブランチを新しいディレクトリに取得します。
+
+2. 既存のブランチの中のあなたが行った修正を新しいブランチへpullあるいはmergeします。
+
+ブランチを共用リポジトリに移行する手順:
+
+1. 新しい共用リポジトリを新フォーマット(2aあるいはそれ以降)で作成します。
+
+2. 中央リポジトリから最新のブランチを作成した共用リポジトリへ格納します。
+
+3. あなたのローカルブランチで移行したいものを決定します。(もし決定していなければ、もちろんバックアップした後、  `Finding obsolete branches`_　してそのブランチを消去するのによい時間です。)
+
+4. 各ローカルブランチの移行に関して2つ選択肢があります。
+
+ * 新しいリポジトリで1つ空のブランチを **init** して古いリポジトリからリビジョンを **pull** する。
+
+ * 新リポジトリにおいて、 trunkから新しいブランチに **branch** した後古いリポジトリにおいてあなたが行った変更を **merge** する。
+
+前者の方法は(リビジョンの履歴という意味において)古いブランチと同一のブランチを得ることができる一方、parentブランチは古いブランチを指してしまい、新しいtrunkをさしません。もしあなたがこの方法をとった場合、おそらく branch.conf ファイルの parentブランチに関する設定をしなおしたくなるでしょう。
+
+それに比較して後者の方法は parentブランチは正確に設定されます。しかし、もしあなたがすべての最新のリビジョンをtrunkからそのブランチにincludeする用意ができていない限り理想的な方法にはなりません。

=== added file 'doc/ja/upgrade-guide/index.txt'
--- doc/ja/upgrade-guide/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/upgrade-guide/index.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,13 @@
+###########################
+Bazaar 2.0 移行ガイド
+###########################
+
+.. Please mark sections in included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+.. include:: overview.txt
+.. include:: data_migration.txt
+.. include:: tips_and_tricks.txt

=== added file 'doc/ja/upgrade-guide/overview.txt'
--- doc/ja/upgrade-guide/overview.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/upgrade-guide/overview.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,77 @@
+概要
+########
+
+移行手順の概要
+----------------
+
+Bazaar 2.xへのアップグレード作業は3段階あります:
+
+1. コアソフトウェアの移行
+
+2. 必要なプラグインの移行
+
+3. 新しいデフォルトフォーマットへのデータ移行
+
+Bazaar 2.xは以前のブランチのフォーマットをサポートしているので、厳密には3番目の手順は
+必要ありません。しかし、Bazaar 2.xの新しいデフォルトフォーマットはより効率よく領域を使用する、
+巨大なプロジェクトでより高速になる、さまざまな新しい特徴をそなえている、などの理由からほとんどのプロジェクトについて都合のよいときにでもアップグレードすることをおすすめします。
+
+ほとんどのユーザの方は2.xへのアップグレードと新しいフォーマットへの移行に苦労しません。
+しかしながら、大勢の開発者がいる(もしくは多くの開発者をようする)プロジェクトでは移行作業に手間がかかります。
+この場合、注意深く計画をたてることとよいコミュニケーションが必要不可欠となります。
+本文書はこの視点からの一般的なアドバイスを記載しています。
+不安な点がありましたら、メーリングリストやIRCチャンネルで私たちにおたずねください。
+
+
+コアソフトウェアの移行
+-----------------------
+
+コアソフトウェアの移行手順はオペレーティングシステムによって異なります。
+Bazaar 1.xからBazaar 1.yへの移行とBazaar 1.xからBazaar 2.0への移行には特に違いはありません。手順の概要は以下のようになります。
+
+Linuxでの移行手順:
+
+1. 必要なソフトウェアのソースに関してお使いのパッケージマネージャの設定をおこなう。
+       たとえばUbuntuの正式なリリースのPPAは https://launchpad.net/~bzr/+archive です。
+
+2. パッケージマネージャを使用して最新バージョンに移行する。
+
+Windowsでの移行手順:
+
+1. 「プログラムの追加と削除」で古いバージョンを削除する。
+
+2. 新しいバージョンのインストーラでインストールする。
+
+OS Xでの移行手順(インストーラを使用):
+
+1. 新しいバージョンのインストーラでインストールする。
+
+OS Xでの移行手順 (MacPortを使用):
+
+1. package metadataを更新する。 **sudo port selfupdate**
+
+2. 最新のバージョンに更新する。 **sudo port upgrade bzr**
+
+インストールや移行に関する詳しい情報については http://bazaar-vcs.org/Download
+をごらんください。	
+
+必要なプラグインの移行
+-----------------------
+
+多くのプラグインは特定のBazaarのバージョンに依存していないので、任意の作業です。
+他のプラグイン、特にbzrtoolsとbzr-svnはBazaarのAPIにかたく結びついているので、
+大体はコアソフトウェアとあわせて移行する必要があります。
+
+WindowsやOS Xをお使いのかたは、bzrtoolsとbzr-svnはインストーラに付属していますので
+移行にあたって特別な作業は必要ありません。LinuxやUNIXをお使いのかたは、bzrtools、bzr-svn
+や他の著名なプラグインをインストールしたり移行作業をお使いのプラットホームのパッケージマネージャ
+(たとえばUbuntuのSynaptic)でおこなうことができます。
+
+
+新しいデフォルトフォーマットへのデータ移行
+-------------------------------------------
+
+冒頭でも説明しましたように新しいフォーマットへの移行に伴う複雑さはいくつかの要因、特にプロジェクトの
+コミュニティの大きさに依存します。また、データがどのように保存されているかにも依存します。たとえば
+standaloneブランチとか、複数のブランチがshared repositoryに格納されているかとか、Launchpad上の
+stackedブランチかなどです。これらのシナリオについては次章で説明します。

=== added file 'doc/ja/upgrade-guide/tips_and_tricks.txt'
--- doc/ja/upgrade-guide/tips_and_tricks.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/upgrade-guide/tips_and_tricks.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,23 @@
+役立つヒントとコツ
+######################
+
+古いブランチを見つけるには
+-----------------------------
+
+もしあなたが開発における各変更や個々に行っている拡張のためにブランチの機能を使っている場合、いくつかのもう必要とされないブランチを持つことになるかもしれません。たいていの場合、関係のある変更は trunkにマージされているはずです。そのほかの場合ブランチは自分あるいは他人が行った別の変更の結果、古くなっているはずです。
+
+古いブランチをチェックするときには特に3つの点に注意があります。
+
+1. ワーキングツリーは変更の途中でないこと。
+
+2. ワーキングツリー内にはbzr shelveコマンドによって退避された変更をふくんでいないこと。
+
+3. どんなローカルでコミットされたリビジョンもparentブランチにマージされていること。
+
+ブランチのルートディレクトリに移動したあと、これらの点を個々にチェックするためのコマンドは以下です::
+
+  bzr status
+  bzr shelve --list
+  bzr missing --mine-only
+
+もしあなたのブランチがローカルの共用リポジトリに入っているならば、(revision 159またはそれ以降の)Bazaar Explorerのリポジトリビューの中の *Local Changed* タブがあなたが選択したブランチについて、いまのところはshelveコマンドによって退避された変更を除き、上記の情報の概要を表示するので有用です。

=== added directory 'doc/ja/user-guide'
=== added file 'doc/ja/user-guide/adv_merging.txt'
--- doc/ja/user-guide/adv_merging.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/adv_merging.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,105 @@
+疑似マージ
+===========
+
+チェリーピッキング
+------------------
+
+時々、ブランチの変更の全部ではなく一部だけを選んでマージすることが\
+便利であることがあります。
+これは一般的に *チェリーピッキング(cherrypicking)* として言及されます。
+
+チェリーピッキングが役に立ついくつかの事例:
+
+* メインの開発ブランチから修正の一部を取り出してリリースブランチに取り込む
+
+* 実験ブランチから改善内容を選別して機能ブランチに取り込む
+
+``foo`` ブランチのリビジョン Xによってなされた変更のみをマージするためには::
+
+  bzr merge -c X foo
+
+``foo`` ブランチのリビジョンXまでの変更のみをマージするためには::
+
+  bzr merge -r X foo
+
+``foo`` のリビジョンX以降の変更のみをマージするためには::
+
+  bzr merge -r X.. foo
+
+``foo`` ブランチのリビジョンXからリビジョンYまでの変更のみをマージするには::
+
+  bzr merge -r X..Y foo
+
+通常のマージと同じように、チェリーピックは明示的にコミットしなければなりません。
+これを行う前に、 ``bzr diff`` を利用した変更を見て何かあればテストスイートを\
+実行するとよいでしょう。
+
+通常のマージとは異なり、Bazaarは現在はチェリーピックを追跡しません。
+具体的に言うと、変更は通常のコミットと同じようになり、他のブランチから来た(内部の)変更履歴は失われます。
+上記のようなチェリーピックが役に立つ場面では、このことはたいてい重大な問題ではありません。
+フルマージが後で行われることはけっしてないと言える十分な理由があるからです。
+そうではない場面では、変更が再びマージされたときにまた衝突を解消する必要があります。
+
+.. _reverse-cherrypicking:
+
+リバースチェリーピッキング
+---------------------------
+
+チェリーピッキングは一連の変更を元に戻すことができます。この場合、リビジョン範囲の\
+上界(upper bound)が下界(lower bound)よりも *小さく* なります。
+たとえば、リビジョン10の変更を取り消すためのコマンドはこうなります::
+
+  bzr merge -r 10..9
+
+どこかから、すべてではない大半の変更を得たい場合通常のマージをした後に少しの\
+リバースチェリーピックを行うとよいでしょう。
+
+
+コミットされていない変更をマージする
+-------------------------------------
+
+複数のブランチを持っており、間違えて別のブランチを変更し始めた場合、訂正をとるステップは次のとおりです。
+ブランチ ``bar`` で作業したかったのに、ブランチ ``foo`` で作業を始めてしまったという場合を前提とします:
+
+1. ``bar`` ブランチに移動する
+2. ``bzr merge --uncommitted foo`` を実行する
+3. やってくる変更をチェックする (``bzr diff``)
+4. ``foo`` ブランチに変更する
+5. ``bzr revert`` を実行する
+
+.. TODO Selective file merging?
+
+
+リベースする
+--------------
+
+通常のマージの別のオプションは *リベース(rebase)* です。
+すなわち、現在のブランチが本来とは異なる地点をベースにするようにします。
+リベースは ``rebase`` プラグインによって提供される ``rebase`` コマンド\
+によってサポートされます。
+
+``rebase`` コマンドは現在の作業ディレクトリ内のリベースされるブランチ上で\
+別のブランチの位置をとります。
+ブランチが指定されないと親のブランチが使われ、通常これは望まれる結果です。
+
+最初のステップは現在のブランチのものであるが親のブランチではないリビジョンを\
+特定することです。
+現在のブランチはターゲットブランチと同じリビジョンに設定され、それぞれの\
+リビジョンはブランチのトップで再現されます。
+プロセスの終了時に現在のブランチがターゲットの最終リビジョンからブランチ\
+されたようになります。
+
+再現されるそれぞれのリビジョンがツリーの中で衝突を起こすことがあります。
+これが起きたらコマンドは停止してそれらを修正しなければなりません。
+``merge`` するためにコミットを解消し、それらが解消されたものとしてマークするために
+``bzr resolve`` を実行します。
+すべての衝突を解消したら、リベースオペレーションを続けるために ``bzr rebase-continue``
+を実行します。
+衝突に遭遇せず続けないことを決めたら、 ``bzr rebase-abort`` を実行できます。
+リプレイされるコミットの一覧を表示するために ``rebase-todo`` を利用することもできます。
+
+注: マージトラッキング機能が貧弱なVCSツールから来たユーザーの中にはリベースを好む人がいます。
+古いツールでの作業方法に似ている、もしくは"完璧にきれいな" 履歴が重要だからです。
+Bazaarでリベースする前に、通常のマージがベターな選択肢ではないのか考えてください。
+とりわけ、始める前にプライベートなブランチをリベースするのは大丈夫ですが、
+他の誰かとブランチを共有した後のリベースは **強く非推奨** です。

=== added file 'doc/ja/user-guide/annotating_changes.txt'
--- doc/ja/user-guide/annotating_changes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/annotating_changes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,34 @@
+変更に注釈を付ける
+===================
+
+内容の起源を探し出す
+--------------------
+
+複数の人がファイルに取り組むとき、
+誰が作ったのかもしくは最後に変更された内容を一度に見ることができるのは非常に便利です。
+これを行うためには、annotateコマンドを使います::
+
+  bzr annotate readme.txt
+
+悲観主義者もしくは楽観主義者のどちらかであるなら、
+``annotate`` の組み込みのエイリアスである ``blame`` もしくは ``praise``
+を使うことを好むかもしれません。
+どの方法であれ、次のような情報と一緒にファイルのそれぞれの行が表示されます:
+
+ * 最後に変更した人
+ * 最後に変更した時間
+ * コミットメッセージ
+
+GUIツール
+----------
+
+Bazaar用のさまざまなGUIは注釈の情報を閲覧するためのグラフィカルなツールを提供します。
+たとえば、bzr-gtkプラグインはこの機能を ``gannotate`` コマンドを使用して起動できる\
+GUIツールとして提供します::
+
+  bzr gannotate readme.txt
+
+GUIツールは関心のある情報をより豊かに表現するので
+(たとえばそれぞれのコミットのすべての変更内容)、\
+テキストベースよりも好ましいかもしれません。
+

=== added file 'doc/ja/user-guide/bazaar_workflows.txt'
--- doc/ja/user-guide/bazaar_workflows.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/bazaar_workflows.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,181 @@
+ワークフロー
+=============
+
+Bazaarはただのツール
+---------------------
+
+Bazaarは多くの異なる共同作業の方法を支援します。
+このことはあるワークフローで始めて状況が変われば別のワークフローを\
+採用できることを意味します。
+"唯一の正しい方法"は存在しませんし今後も現れることはりません。
+このセクションではBazaarによってサポートされる人気のあるいくつかの\
+ワークフローの手短な概要を提供します。
+
+これらのワークフローはBazaarの使い方の *一部* であることを念頭にお願いします。
+ここに記載されていないワークフローを利用したいのであれば、\
+下記に記載されているアイディアを足場にします。
+
+ソロ
+----
+
+ソフトウェアを開発する、ドキュメントを編集するもしくは設定ファイルを\
+変更するのであれ、簡単に使えるVCSは手助けになります。
+投稿者が1人であるプロジェクトを複数管理するために\
+単独のユーザーはこのワークフローを効率的に利用できます。
+
+.. image:: images/workflows_single.png
+
+まったくバージョン管理を使わない場合と比べたこのワークフローの利点は次のとおりです:
+
+ * 古いバージョンのバックアップ
+ * 前の状態へのロールバック
+ * 履歴の追跡
+
+このワークフローに適切なBazaarの主要な機能は管理作業が少ない\
+(サーバーのセットアップは不要)ことと簡単に利用できることです。
+
+
+パートナー
+-----------
+
+時に2人で変更を共有して共同作業をする必要があります。
+これは一般的に *ソロ* のワークフロー (上記を参照) もしくは\
+チーム指向のワークフロー(下記を参照)として始まります。
+ある時点で、2人目の人が最初の人が行った内容(履歴も含む)を含む\
+ブランチを作ります。
+適切なときにマージして変更内容を交換することで並行して作業できます。
+
+.. image:: images/workflows_peer.png
+
+*ソロ* を上回る利点は次のとおりです:
+
+ * 変更の共有が簡単
+ * それぞれのテキストファイルのそれぞれの行は変更した人、\
+   時間と理由を含む特定の変更と結びつけられています。
+
+このワークフローを採用する場合、BazaarはCVSとSubversionに対して
+次のような利点があります:
+
+ * サーバーのセットアップが不要
+ * インテリジェントなマージ機能により複数回のマージ作業が苦痛では
+   なくなります。
+
+
+集中型
+-------
+
+*lock-step* としても知られますが、これはCVSとSubversionによって\
+推奨/強制されるワークフローと本質的に同じです。
+すべての開発者が同じブランチに取り組みます。
+最新の内容をチェックアウトするために ``bzr update`` を実行し、\
+変更内容を中心位置にコミットするために ``bzr commit`` を実行します。
+
+.. image:: images/workflows_centralized.png
+
+このワークフローを導入するのであればSubversionとCVSも簡単なのでよい選択肢です。
+Bazaarはこのワークフローも直接サポートしていて、CVSとSubversionを上回る利点を\
+いくつかもちます:
+
+ * よりよいブランチとマージ
+ * よりよいリネームのサポート
+
+
+ローカルなコミットで集中型
+---------------------------
+
+このワークフローは、開発者が ``commit --local`` もしくはチェックアウトをunbind\
+して一連の変更を行うこと以外は、 *集中型* モデルと基本的に同じです。
+こういった一連の変更が完了するとき、開発者は作業内容を共用のメインラインに\
+コミットします。
+
+.. image:: images/workflows_localcommit.png
+
+*集中型* を越える利点:
+
+ * 旅行の間にネットに接続していないなどのオフラインで作業できます
+ * 誰かの作業を妨げる良くないコミットをする機会が少なくなります
+
+SubversionとCVSはこのモデルをサポートしません。
+他の分散型VCSツールはこれをサポートしますが、Bazaarよりも直接的ではありません。
+
+
+共用のメインラインで分散型
+-----------------------------
+
+このワークフローにおいて、それぞれの開発者は独自のブランチを持ち、\
+加えてメインブランチにコミットする権限があります。
+開発者は個人のブランチに取り組み、準備ができたらそれをメインラインに\
+マージします。
+
+.. image:: images/workflows_shared.png
+
+*ローカルコミットつきの集中型* を越える利点は次のとおりです:
+
+ * 作業内容の編成が簡単になる - それぞれのブランチで個別の変更を開発できます。
+ * 開発者は共同作業に取り組むときに別の人の個人ブランチをマージできます。
+
+SubversionとCVSはこのモデルをサポートしません。\
+他の分散型VCSツールはサポートします。
+Bazaarの多くの機能は、簡単な利用、共用レポジトリ、統合されたマージ機能と\
+リッチなメタデータ(ディレクトリのリネームの追跡を含む)を\
+含めてこのワークフローに有効です。
+
+人間のゲートキーパーで分散型
+-----------------------------
+
+このワークフローにおいて、それぞれの開発者は独自のブランチを持ち、\
+それに加えてメインのブランチに対してリードオンリーのアクセス権限を持ちます。
+1人の開発者(ゲートキーパー)はメインのブランチにコミットする権限を持ちます。
+1人の開発者が彼らの作業をマージしたい場合、ゲートキーパーに\
+マージしてくれるように頼みます。
+ゲートキーパーはコードのレビューを行い、必須の基準を満たすのであれば\
+作業内容をメインブランチにマージします。
+
+.. image:: images/workflows_gatekeeper.png
+
+*共用のメインラインによる分散型* に対する利点は次のとおりです:
+
+ * 常にコードはメインラインに入る前にレビューされます。
+ * 変更をメインラインに組み込むときに厳格なコントロールができます
+
+Bundle Buggyと呼ばれるBazaarのコンパニオンツールはどんな変更が\
+レビュー待ちになっているのか、その変更のステータスとレビューアの\
+コメントを追跡するのにとても便利です。
+
+
+自動的なゲートキーパーで分散型
+-------------------------------
+
+このワークフローにおいて、それぞれの開発者は独自のブランチを持つのに加えて、\
+メインストリームにリードオンリーのアクセス権限を持ちます。
+ソフトウエアのゲートキーパーはメインのブランチにコミットする権限を持ちます。
+開発者が作業内容をマージしたいとき、開発者は別の人にレビューを頼みます。
+レビューに合格したら、チームの方針によって、オリジナルの著者もしくは
+レビューワがゲートキーパーソフトウェアにマージするように頼み、
+ゲートキーパーソフトウェアはマージし、コンパイルし、テストスィートを実行します。コードがパスする場合のみ、メインラインにマージされます。
+
+注: 代替として、レビューのステップをスキップして著者は変更を自動化された\
+ゲートキーパーに投稿できます。
+(これはコードのレビューを別のステップとしてではなくジャストインタイムの\
+レビューを効果的に推進するペアプログラミングといった習慣を利用している\
+ときにとりわけ適切です。)
+
+.. image:: images/workflows_pqm.png
+
+*人間のゲートキーパーによる分散型* に対する利点は次のとおりです:
+
+ * コードはメインラインに入る前に常にテストされます
+   (メインラインの完全性が高まります)
+ * チームの規模の成長に対応できます
+
+BazaarのコンパニオンツールであるPatch Queue Manager (PQM)
+は自動化ゲートキーパーの機能を提供します。
+
+
+ワークフローを実施する
+-----------------------
+
+上記のそれぞれのワークフローを実施する方法を詳しく知りたいのであれば、\
+このマニュアルの3章から6章までを参照してください。最初に、2章で、\
+インストール方法、一般的な使い方の手引きと設定方法に関するティップス\
+が説明されています。

=== added file 'doc/ja/user-guide/branching_a_project.txt'
--- doc/ja/user-guide/branching_a_project.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/branching_a_project.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,100 @@
+プロジェクトをブランチする
+===========================
+
+ブランチのURL
+--------------
+
+誰かがあなたの作品のコピーを手に入れる前に、転送プロトコルを理解する必要があります。
+ブランチのトップレベルのディレクトリを、Windowsユーザーが慣れ親しんだ方法で、\
+ネットワーク上で共有することを決定するとします。
+LinuxとOS Xのユーザーは、大抵のSSHサーバーに組み込まれているセキュアなプロトコルである、\
+SFTPを通してアクセスする方が望ましいです。
+Bazaarは下記で一部が示されるたくさんのプロトコルのサポートに関して *とても* 柔軟です。
+
+  ===========   ==========================================================================
+  スキーム      説明
+  ===========   ==========================================================================
+  file://       標準ファイルシステムを利用してアクセスする (デフォルト)
+  sftp://       SFTPを利用してアクセスする (大抵のSSHサーバーはSFTPを提供する)
+  bzr://        Bazaarのスマートサーバーを利用した高速のアクセス
+  ftp://        パッシブFTPを利用してアクセスする
+  http://       ウェブサーバーによってエクスポートされたブランチへの読み込み限定のアクセス
+  ===========   ==========================================================================
+
+上記で示されるように、ブランチは転送プロトコルを示すスキームを伴うURLを使用して識別されます。
+スキームが無ければ、通常のファイルの名前が想定されます。
+サポートされるプロトコルの完全なリストに関しては、
+``urlspec`` のオンライントピックもしくはBazaarのユーザーリファレンスの
+`URLの識別子 <../user-reference/bzr_man.html#url-identifiers>`_
+のセクションを参照してください。
+
+.. _a-reminder-about-shared-repositories:
+
+共用レポジトリに関するリマインダ
+---------------------------------
+
+ブランチのコピーを手に入れる前に、ファイルシステム上に設置する場所を少し考えて\
+みましょう。
+最大限のストレージの効率性のために、共用リポジトリとしてセットアップされた\
+ディレクトリの元でブランチを作ることを推奨します。
+(よく使われるレイアウトについては、 `作業スペースを構成する
+<organizing_your_workspace.html>`_ の中の `ブランチの機能
+<organizing_your_workspace.html#feature-branches>`_
+を参照してください)
+たとえば::
+
+  bzr init-repo my-repo
+  cd my-repo
+
+誰からでもブランチを入手して好きなようにする準備ができました。
+
+ブランチのコマンド
+-------------------
+
+既存のブランチに基づいたブランチを手に入れるためには、 ``branch``
+コマンドを使用してください。構文は次のとおりです::
+
+  bzr branch URL [directory]
+
+ディレクトリの名前が渡されない場合、URLの最後の部分に基づいてディレクトリが作成されます。
+ドライブ名 (M:/) とSFTPのURLを示すそれぞれの例は次のとおりです::
+
+  bzr branch M:/cool-trunk
+  bzr branch sftp://bill@mary-laptop/cool-repo/cool-trunk
+
+新しいブランチを使うために明示的にディレクトリの名前を渡す例は次のとおりです::
+
+  bzr branch /home/mary/cool-repo/cool-trunk cool
+
+時間とスペースへの考慮
+-----------------------
+
+転送されるブランチのサイズと コンピュータとソースのブランチの間のネットワーク帯域と
+レイテンシによっては、この初期の転送は少し時間がかかります。
+その後の更新は変更のみが転送されるので遙かに速くなります。
+
+Bazaarは最新のスナップショットではなくブランチの完全な履歴を転送することを覚えておいてください。
+結果として、 ``branch`` を完了させた後でネットワークから離脱しても、
+ブランチの履歴に対して ``log`` と ``diff`` を好きなだけ行うことができます。
+さらに、履歴がローカルで保存されているのでこれらのオペレーションは速いです。
+
+Bazaarはバージョンの履歴を保存するために求められるディスクスペースの総量を\
+最小限にするスマートな圧縮技術を使うことに注意してください。
+多くの場合、プロジェクトの完全な履歴は最新バージョンの作業コピーよりも少ない\
+ディスクスペースを占めます。
+
+後の章で説明するように、Bazaarはブランチの軽量チェックアウト、
+すなわち履歴のローカルなストレージなしの作業ツリーもサポートします。
+もちろん、接続しない使い方は利用できませんが、ローカルディスクスペースが\
+本当に厳しいのであればそれはあなたが決めることができるトレードオフです。
+現在、制限された履歴の振り返りのためのサポート - *履歴の水平線(history horizon)* -
+は開発段階にあります。
+
+ブランチの情報を閲覧する
+-------------------------
+
+配布元も含むブランチの情報を見たいのであれば、 ``info`` コマンドを使います::
+
+  bzr info cool
+
+ブランチが引数として渡されなければ、現在のブランチの情報が表示されます。

=== added file 'doc/ja/user-guide/browsing_history.txt'
--- doc/ja/user-guide/browsing_history.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/browsing_history.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,93 @@
+履歴を閲覧する
+================
+
+bzr log
+-------
+
+``bzr log`` コマンドは以前のリビジョンの一覧を表示します。
+
+``bzr diff`` と同じように, ``bzr log`` は ``-r`` の引数をサポートします::
+
+    % bzr log -r 1000..          # リビジョン1000とその後のすべて
+    % bzr log -r ..1000          # r1000とそれまでのすべて
+    % bzr log -r 1000..1100      # 1000から1100までの変更
+    % bzr log -r 1000            # リビジョン1000のみの変更
+
+マージされたリビジョンを見る
+------------------------------
+
+Bazaarのような分散型のVCSは集中型のVCSツールよりもマージが非常に簡単なので、
+ブランチの履歴は、メインラインから分離してその後メインラインにマージされる\
+ようなラインを含むことがあります。
+技術的には、無数のリビジョンノード間の関係は無閉路有向グラフ(Directed Acyclic Graph: DAG)として知られます。
+
+多くの場合、まずはメインラインを見てそのあとに別のラインを見たいものです。
+そのため、log のデフォルトの動作はメインラインを表示して、マージされた\
+リビジョンがあるある場所を指示します。::
+
+  bzr log -n0 -rX
+
+全てのリビジョンと全てのマージされたリビジョンを見る場合は::
+
+  bzr log -n0
+
+-n オプションは表示するレベルを意味し、0の場合は全てを意味することに注意してください。
+もしそれがゴミゴミしているなら、値を変更して調整することが容易にできます。
+たとえば、もしあなたのプロジェクトがトップレベルのgatekeeperがチームレベルのgatekeeperからマージするように構成されている場合、\
+``bzr log`` はトップレベルgatekeeperの履歴だけを表示し、 ``bzr log -n2``
+はチームのgatekeeperの履歴を表示します。
+しかし、ほとんどの場合においては ``-n0`` で十分でしょう。
+
+
+出力をチューニングする
+-----------------------
+
+``log`` コマンドは出力を調整するために便利ないくつかのオプションを持ちます。次のものが含まれます:
+
+ * ``--forward`` はログを年代順で表します。
+    すなわち最新のリビジョンが最後に表示されます。
+
+ * ``--limit`` オプションは表示されるリビジョンの最大数を制御します。
+
+出力の調整方法の詳しい情報に関してはユーザーリファレンスのlogコマンドのオンラインヘルプを参照してください。
+
+ファイルの履歴を閲覧する
+-------------------------
+
+特定のファイルのみに適用されるように履歴をフィルタリングすることが便利であることがよくあります。
+これを行うためには、ファイルの名前を ``log`` コマンドに提供します::
+
+  bzr log foo.py
+
+古いバージョンのファイルを閲覧する
+-----------------------------------
+
+指定されたバージョンでファイルの内容を取得するには、次のように ``cat`` コマンドを使います::
+
+  bzr cat -r X file
+
+``X`` はリビジョンの識別子で ``file`` はファイルの名前です。
+これは出力を標準出力ストリームに送信しますので、次のように\
+閲覧ツール( ``less`` や ``more`` など)に出力をパイプで渡すか\
+リダイレクトするといいでしょう::
+
+  bzr cat -r -2 foo.py | less
+  bzr cat -r 1 foo.py > /tmp/foo-1st-version.py
+
+グラフィカルな履歴ビューワ
+----------------------------
+
+履歴のブラウジングはGUIツールが人生を本当に楽にしてくれる領域です。
+QBzrとbzr-gtkを含めてこの機能を提供するBazaarのプラグインがたくさんあります。
+これらがまだインストールされていなければ `プラグインを利用する <plugins.html>`_ で詳細なインストール方法をご覧ください。
+
+QBzrからグラフィカルビューワを使うには::
+
+  bzr qlog
+
+bzr-gtkからグラフィカルビューワを使うためには::
+
+  bzr viz
+
+``viz`` は実際には ``visualize`` の組み込みのエイリアスなので望むのであれば長い方のコマンド名を使います。
+

=== added file 'doc/ja/user-guide/bug_trackers.txt'
--- doc/ja/user-guide/bug_trackers.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/bug_trackers.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,49 @@
+バグトラッカー
+===============
+
+Bazaarにはコミットをプロジェクトのバグトラッカーのバグに関連づけできる機能があります。
+コミットとバグの間のハイパーリンクを生成する、もしくはコミットを含むブランチで閉じた\
+バグを自動的にマークするために、他のツール (もしくはフック) はこの情報を使うことができます。
+
+コミットとバグを関連付ける
+---------------------------
+
+コミットを行うとき、 ``commit`` の ``--fixes`` オプションを利用することでバグと関連付けることができます。例です::
+
+    $ bzr commit --fixes lp:12345 -m "Properly close the connection"
+
+このコマンドの実行によってコミットとLaunchpdのバグ12345とリンクするBazaarのメタデータが記録されます。
+異なるバグトラッカーを使う場合、( ``lp`` の代わりに) 独自のトラッカーコードを渡して代わりに使うことができます。
+Bugzilla、Trac、Roundupとその他のバグ/問題トラッカーに対してこれを設定する方法の詳細に関しては、
+Bazaarユーザーリファレンスの `バグトラッカーの設定`_ を参照してください。
+
+.. _バグトラッカーの設定: ../user-reference/bzr_man.html#bug-tracker-settings
+
+メタデータの記録 vs バグトラッカーの更新
+------------------------------------------
+
+コミット時に修正されたバグに関するメタデータの記録は完全なバグトラッカーの統合機能の中で唯一必要なものです。
+Bazaarは分散型VCSなので、ユーザーがオフラインでコミットしているためバグトラッカー自身へのアクセスが不可能な場合があります。
+代わりに、プロジェクトのワークフローに適切な中心位置に変更をpushするとき、\
+バグトラッカーを更新するためにフックをインストールすることが推奨されます。
+
+注: この2番目の処理段階はLaunchpadの外部もしくはホストされているブランチがスキャンされるときに
+Launchpadによって提供される統合機能の一部です。
+
+訂正をする
+-----------
+
+リビジョンとバグを関連付けるこの方法にはいくつかの制限があります。
+最初のものは関連づけはコミット時のみにしかできないことです。
+このことは、コミットするもしくは修正した後でバグが報告することを忘れた場合、
+一般的に後から差し戻してリンクを追加できないことを意味します。
+
+これに関連したことは関連づけは不変であるという事実です。
+バグがあるコミットによって修正されたものとしてマークされたが、リビジョンがバグを十分に解決しない、
+もしくは後で回帰がある場合、差し戻してリンクを削除できません。
+
+もちろん、正しいオプションで行うために最新コミットをアンドゥする ``bzr uncommit`` が常に使われます。
+これは正しくないコミットメッセージを訂正するためによく行われ、(たとえば ``--fixes`` を通した)最新コミットに
+記録されたメタデータを訂正するために等しく当てはまります。
+
+注: 正しくないリビジョンが公開される前に ``uncommit`` を行うのがベストです。

=== added file 'doc/ja/user-guide/bzrtools_plugin.txt'
--- doc/ja/user-guide/bzrtools_plugin.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/bzrtools_plugin.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,32 @@
+BzrTools
+========
+
+概要
+-----
+
+BzrToolsは便利なBazaar強化機能のコレクションです。
+インストールの手引きに関しては、BzrToolsのホームページを参照してください:
+http://bazaar-vcs.org/BzrTools.
+よく使われるコマンドのサンプルは下記のとおりです。
+
+
+shell
+-----
+
+``bzr shell`` はBazaarのコマンドを理解する以上のことを行うコマンドインタープリタを起動します。
+これはいくつかの利点を持ちます:
+
+ * すべてのコマンドの冒頭で ``bzr`` を入力する必要が無くなります。
+
+ * インテリジェントな自動入力補完が提供されます。
+
+ * Bazaarのライブラリを毎回ロードする必要がないのでコマンドは少し速く動作します。
+
+
+cdiff
+-----
+
+``bzr cdiff`` は GNU/Linux、UNIXとOS Xで ``bzr diff`` の出力の色つきバージョンを提供します。
+次のようによく使われます::
+
+  bzr cdiff | less -R

=== added file 'doc/ja/user-guide/central_intro.txt'
--- doc/ja/user-guide/central_intro.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/central_intro.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,32 @@
+集中型の開発
+=============
+
+動機
+-----
+
+並行して作業をして時折マージするよりも、ロックステップ、\
+すなわち複数の人が継続して変更を中心位置にコミットして\
+すべてのコミットの前に彼らの作業内容を最新の内容にマージすること、\
+で一度に作業をすることは有用であることがあります。
+
+このワークフローはSubversionとCVSのような集中型のVCSツールのユーザーには\
+とても慣れ親しまれています。
+単独の開発者が複数のマシンに取り組む場合にも応用できます。たとえば、\
+通常はデスクトップで作業をするが旅行の間はラップトップ、\
+もしくは(インターネットに接続した)ホームコンピュータで\
+勤務時間外に事務作業を完了させるといった具合です。
+
+あなたのチームがすでに集中型の開発でうまくいっているのであれば、それは\
+素晴らしいことです。
+多くのチームはこの方法でBazaarを使い始め、後で代替のワークフローを実験します。
+
+集中型のワークフロー
+---------------------
+
+下記のダイアグラムは *集中型のワークフロー* の概要を提供します。
+
+.. image:: images/workflows_centralized.png
+
+あなたのチームがより分散型のワークフローを利用することを計画しているとしても、
+この章でカバーされる多くのタスクは、とりわけブランチを公開する方法に関して\
+あなたにとって有用です。

=== added file 'doc/ja/user-guide/configuring_bazaar.txt'
--- doc/ja/user-guide/configuring_bazaar.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/configuring_bazaar.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,54 @@
+Bazaarを設定する
+==================
+
+Bazaarにあなたの名前を教える
+-----------------------------
+
+バージョン管理システムの機能の1つは誰が何を変更したのかを追跡することです。
+分散型のシステムでは、その機能を実現するためにグローバルにユニークな\
+それぞれの著者のための識別子が必要です。
+大抵の人はそれらの1つを持っています: Eメールアドレスです。
+Bazaarはあなたのユーザー名とホスト名を探し出してEメールアドレスを自動的に\
+生成します。
+Bazaarが行う推測を望まないのであれば、あなたが望む識別子を設定するために
+``whoami`` コマンドを使います::
+
+    % bzr whoami "Your Name <email@example.com>"
+
+``whoami`` は引数なしで使われると、現在の値が表示されます。
+
+設定ファイル
+-------------
+
+設定ファイルはLinux/Unixの場合 ``$HOME/.bazaar`` に、
+Windowsの場合 ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0`` にあります。
+この場所には3つの主要な設定ファイルがあります:
+
+* ``bazaar.conf`` はデフォルトの設定オプションを記述します。
+
+* ``locations.conf`` は特定のブランチの位置を記述しますd
+
+* ``authentication.conf`` はリモートサーバーのためのクレデンシャルな情報を記述します
+
+それぞれのブランチも特定の値をそのブランチに設定する設定ファイルを含みます。
+このファイルはブランチの中の ``.bzr/branch/branch.conf`` で見つかります。
+このファイルは **ブランチのすべてのユーザー** に見えます。
+あなたに固有の設定を持つブランチのための値の1つを上書きしたいのであれば、
+``locations.conf`` でそれを行うことができます。
+
+``whoami`` コマンドを使用してEメールアドレスを設定した後の ``bazaar.conf`` の内容のサンプルは次のとおりです::
+
+  [DEFAULT]
+  email = Your Name <email@example.com>
+
+サポートされる構文と構成設定の詳細については、
+Bazaarのユーザーリファレンスの `構成設定 <../user-reference/bzr_man.html#configuration-settings>`_ の項目を参照してください。
+
+
+ルールベースのプリファレンス
+-----------------------------
+
+いくつかのコマンドとプラグインは特定のパターンにマッチするファイルのカスタムの処理機能を提供します。
+ユーザーごとにルールベースのプリファレンスが ``BZR_HOME/rules`` で定義されます。
+ルールが検索される検索方法と関連ファイルの詳細な構文に関する詳細については、
+Bazaarのユーザープリファレンスの `ルール <../user-reference/bzr_man.html#rules>`_ の項目を参照してください。

=== added file 'doc/ja/user-guide/controlling_registration.txt'
--- doc/ja/user-guide/controlling_registration.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/controlling_registration.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,91 @@
+ファイルの登録を制御する
+=========================
+
+Bazaarは何を追跡するのか？
+--------------------------
+
+前に説明したように、 ``bzr add`` は現在のディレクトリの元でBazaarがバージョン管理すべきだと考える
+すべてのものを見つけ登録します。登録するものは次のようなものになります:
+
+ * ファイル
+ * ディレクトリ
+ * シンボリックリンク
+
+Bazaarは興味を持つファイルと興味を持たないファイルに関してデフォルトのルールを持ちます。
+後で説明される `ファイルを無視する`_ のようにこれらのルールを調整できます。
+
+他の多くのVCSツールとは異なり、Bazaarはディレクトリを第一級の項目として扱います。
+結果として、空のディレクトリは正しくサポートされます -
+ディレクトリが追跡されプロジェクトのエクスポートに含まれることを保証するために
+ディレクトリ内部にダミーファイルを作る必要はありません。
+
+シンボリックリンクに関しては、シンボリックリンクの値は追跡され、
+シンボリックリンクが指し示すものの内容は追跡されません。
+
+注: プロジェクトの中のプロジェクトを追跡するサポート機能 ("入れ子ツリー") は現在開発中です。
+この機能の開発を手伝うもしくはテストすることにご興味がありましたらBazaarの開発者に連絡して下さるようお願いします。
+
+登録を選ぶ
+-----------
+
+いくつかの事例において、登録したいものをBazaarに発見を任せるよりも明示的に指名したいことがあります。
+これを行うためには、パスを引数として ``add`` コマンドに提供します::
+
+  bzr add fileX dirY/
+
+ディレクトリを追加すると暗黙的にそのディレクトリの中の関心のあるすべてのものが追加されます。
+
+ファイルを無視する
+-------------------
+
+エディタのバックアップ、オブジェクト、バイトコードのファイル、ビルドされたプログラムなど、
+多くのソースツリーはバージョン管理する必要のないファイルを含みます。
+単純にこれらを追加しないでおくと、これらは常に未知のファイルとして現れます。
+ツリーのトップでこれらを ``.bzrignore`` と呼ばれるファイルに追加することでBazaarにこれらのファイルを無視するように指示することもできます。
+
+このファイルは一行ごとにファイルのワイルドカード(もしくは "globs")の一覧を含みます。典型的な内容は次のとおりです::
+
+    *.o
+    *~
+    *.tmp
+    *.py[co]
+
+globがスラッシュを含む場合、ツリーのトップからのパス全体がマッチします;
+さもなければファイルの名前だけにマッチします。以前の例では
+すべてのサブディレクトリ内の ``.`` の拡張子を持つファイルが無視されますが、
+次の例ではトップレベルでは ``config.h`` だけと ``doc/`` の中のHTMLが無視されます::
+
+    ./config.h
+    doc/*.html
+
+どのファイルが無視され何のパターンにマッチするのかについての一覧表を得るためには、 ``bzr ignored`` を使います::
+
+    % bzr ignored
+    config.h                 ./config.h
+    configure.in~            *~
+
+無視するパターンがバージョン管理されていないファイルのみにマッチし、それらが"unknown"もしくは"ignored"として扱われるのかを制御します。
+ファイルが明示的に追加されると、無視するパターンにマッチするかに関わらずバージョン管理されたままです。
+
+``.bzrignore`` ファイルは通常はバージョン管理されるので、ブランチの新しいコピーは同じパターンを見ます::
+
+    % bzr add .bzrignore
+    % bzr commit -m "Add ignore patterns"
+
+``bzr ignore PATTERN`` コマンドはPATTERNを ``.bzrignore`` ファイルに手軽に追加するために使われます
+(必要でBazaarによって追跡するために登録する場合、作られます)。
+``.bzrignore`` ファイルを直接編集することでパターンの除去と修正が行われます。
+
+グローバルで無視する
+---------------------
+
+プロジェクト固有のものではないが、ユーザー固有の無視されるファイルがいくつかあります。
+編集者用の一時ファイルもしくは個人の一時ファイルのようなものです。
+これらを無視するようにすべてのプロジェクトに追加するよりも、
+bzrは ``~/.bazaar/ignore`` の中でグローバルで無視するファイルをサポートします [#]_ 。
+これはプロジェクト単位で無視するファイルと同じ構文を持ちます。
+
+.. [#] Windowsにおいて、ユーザーの設定ファイルはアプリケーションデータディレクトリで見つかります。
+   ``~/.bazaar/branch.conf`` の代わりに、設定ファイルは次のように見つかります:
+   ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\branch.conf``
+   同じことが ``locations.conf`` 、 ``ignore`` 、と ``plugins`` ディレクトリにも当てはまります。

=== added file 'doc/ja/user-guide/core_concepts.txt'
--- doc/ja/user-guide/core_concepts.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/core_concepts.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,121 @@
+コアの概念
+===========
+
+単純なユーザーモデル
+---------------------
+
+Bazaarを使うために理解する必要のある概念は4つあります:
+
+* **リビジョン(Revision)** - 取り組むファイルのスナップショット
+
+* **作業ツリー(Working tree)** - バージョン管理されたファイルとサブディレクトリを含むディレクトリ
+
+* **ブランチ(Branch)** - ファイルの履歴を記述する、順序づけされたリビジョンの集合
+
+* **リポジトリ(Repository)**  - リビジョンの貯蔵場所
+
+それぞれを詳しく見てみましょう。
+
+リビジョン
+-----------
+
+リビジョンはファイルとディレクトリの内容と形を含むそれらのツリーの状態の **スナップショット** です。
+リビジョンはそれ自身に関連づけされたメタデータをいくつか含みます。メタデータには次のようなものが含まれます:
+
+* コミットした人
+* コミットした時間
+* コミットメッセージ
+* そのリビジョンの元になった親のリビジョン
+
+リビジョンは不変で、グローバルかつユニークに **リビジョンid (revision-id)** で識別できます。
+リビジョンidの例は次のとおりです::
+
+ pqm@pqm.ubuntu.com-20071129184101-u9506rihe4zbzyyz
+
+リビジョンidはコミットする、もしくは他のシステムからインポートする時点で生成されます。
+リビジョンidは内部で利用するときや外部ツールとの統合に必要ですが、
+ブランチ固有の **リビジョン番号** (*revision numbers*)の方が人間に好まれるインタフェースに\
+なります。
+
+リビジョン番号は 1 や 42 や 2977.1.59 のようにドットで区切られた10進法の識別子で\
+ブランチに対するリビジョン番号のグラフを通してパスを追跡します。
+リビジョン番号は一般的にリビジョンidよりも短く、単独のブランチの範囲では
+それらの関係を理解するためにそれぞれを比較できます。
+たとえば、リビジョン10はリビジョン9の直後のメインライン(下記を参照)のリビジョンです。
+リビジョン番号はコマンドが実行されているときに生成されます。
+これらはブランチ内でどのリビジョンがチップ(すなわち最新のリビジョン)であるかに依存するからです。
+
+Bazaarで指定できるリビジョンとリビジョンの範囲のいくつかの方法に関しては、付録の
+`リビジョンを指定する <specifying_revisions.html>`_ を参照してください。
+リビジョンの番号付けの詳細に関しては `リビジョン番号を理解する <zen.html#understanding-revision-numbers>`_
+を参照してください。
+
+.. *TODO: add diagram*
+
+作業ツリー
+------------
+
+作業ツリー(working tree)は ユーザーが編集できるファイルを保持する
+*バージョン管理されたディレクトリ* です。
+作業ツリーは *ブランチ* に関連付けされます。
+
+多くのコマンドは作業ツリーをそれぞれの文脈で使います。
+たとえば、 ``commit`` コマンドは作業ツリーの中のファイルの\
+現在の内容を利用して新しいリビジョン番号を作ります。
+
+.. *TODO: add diagram*
+
+ブランチ
+---------
+
+最もシンプルな場合、ブランチは *順序づけされた一連のリビジョン* です。
+最終リビジョンは *チップ(tip)* として知られます。
+
+ブランチは分かれたりその後再結合(*marged* back)されたりして、\
+グラフの形をとります。
+技術的にいえば、グラフは(親と子のリビジョンの間)の有行な関係を表し、\
+ループが存在しないので、 *directed acyclic graph* (DAG) として\
+言及されるかもしれません。
+
+この名前にギョッとするかもしれませんが、ご心配なく。
+覚えておくべき重要なことは次のとおりです:
+
+* DAGの範囲内での開発の主要なラインは *メインライン(mineline)*,
+  *トランク(trunk)*, もしくは単に *左側(left hand side: LHS)* と呼ばれます。
+
+* ブランチはメインラインではない開発ラインを持つことがあります。
+  そのとき、別のラインはある時点で始まり別の時点で終わります。
+
+.. *TODO: add diagram*
+
+レポジトリ
+-----------
+
+レポジトリはシンプルにいえば *リビジョンの保管場所* です。
+最もシンプルな事例では、それぞれのブランチが独自のレポジトリを持ちます。\
+別の事例では、ディスクの使用量を最適化するためにブランチに対してレポジトリを\
+共用しています。
+
+.. *TODO: add diagram*
+
+概念をまとめる
+---------------
+
+上記の概念を把握したら、Bazaarのさまざまな使い方が理解しやすくなります。
+Bazaarの最もシンプルな使い方は *スタンドアロンツリー(standalone tree)* で、\
+これは1つの位置に作業ツリー、ブランチとレポジトリのすべてが含まれます。
+他のよくあるシナリオには次のようなものがあります:
+
+* `共用リポジトリ(shared branch) <branching_a_project.html#a-reminder-about-shared-repositories>`_
+  - 作業ツリーとブランチは同じディレクトリにありますが、リポジトリは高い階層の\
+  ディレクトリに存在します。
+
+* `スタックブランチ(stacked branch) <stacked.html>`_
+  - 親のリポジトリと共通なリビジョンは親のリポジトリのものを利用することで、
+  ブランチはユニークなリビジョンだけを保存します。
+
+* `軽量チェックアウト(lightweight checkout) <using_checkouts.html#getting-a-lightweight-checkout>`_
+  - 作業ツリーとは別の場所にブランチが保存されます。
+
+Bazaarを使う最良の方法は、あなたのニーズ次第です。
+次に共通のワークフローを見てみましょう。

=== added file 'doc/ja/user-guide/distributed_intro.txt'
--- doc/ja/user-guide/distributed_intro.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/distributed_intro.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,24 @@
+分散型の開発
+=============
+
+動機
+----
+
+分散型のVCSツールは共同作業の新しい方法を提供します。
+これは私達が生きる現代の世界をより反映したものでより高い品質の\
+成果を可能にします。
+
+分散型の共用のメインラインのワークフロー
+-----------------------------------------
+
+このワークフローにおいて、それぞれの開発者は1つもしくは複数の\
+独自のブランチに加えて、メインブランチのチェックアウトを持ちます。
+開発者は個人のブランチに取り組み、準備ができたら、それをメインラインに\
+マージします。
+
+.. image:: images/workflows_shared.png
+
+他の分散型のワークフローはこの章の後ろの方で検討します。
+
+..
+   vim: tw=74 ft=rst

=== added file 'doc/ja/user-guide/entering_commands.txt'
--- doc/ja/user-guide/entering_commands.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/entering_commands.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,36 @@
+コマンドを入力する
+===================
+
+ユーザーインターフェイス
+-------------------------
+
+Bazaarに対して利用可能な数多くのユーザーインターフェイスが存在します。
+コアパッケージは **bzr** と呼ばれるコマンドラインツールを提供し
+グラフィカルユーザーインターフェイス(GUI)はプラグインとして利用できます。
+
+bzrを使う
+---------
+
+構文は次のとおりです::
+
+  bzr [グローバルオプション] command [オプションと引数]
+
+グローバルオプションはBazaarの動作方法に影響を与え ``command`` の前後に現れます。コマンド特有のオプションはコマンドの後で指定しなければなりませんが、コマンド固有の引数の前後と間で指定することができます。
+
+共通のオプション
+-----------------
+
+下記で示されるいくつかのオプションはすべてのコマンドに対して有効です。
+
+  ==========  =========  =================
+  短い形式    長い形式   説明
+  ==========  =========  =================
+  -h          --help     get help
+  -v          --verbose  be more verbose
+  -q          --quiet    be more quiet
+  ==========  =========  =================
+
+Quietモードはエラーと警告のみを表示します。これはスクリプトで使う際に便利です。
+
+注: 大抵のコマンドは1つのレベルの冗長性だけをサポートします。今後これは変更されるかもしれません。
+高度な冗長性を求めるためには、-vオプションを複数回指定するだけです。

=== added file 'doc/ja/user-guide/filtered_views.txt'
--- doc/ja/user-guide/filtered_views.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/filtered_views.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,165 @@
+Filtered views
+==============
+
+Filtered view の紹介
+--------------------------
+
+Viewはtreeに対するマスクを提供し、ユーザーはtreeの一部分に集中できる\
+ようになります。
+このマスキングが役に立ついくつかの場面があります。たとえば、大きな\
+プロジェクトの技術ライターやテスターはプロジェクトのうち一部のディレクトリ\
+やファイルだけを扱います。
+
+開発者は大規模な変更をviewを使っていくつかのコミットに分解したいと思う\
+かもしれません。 ``shelve`` ``unshelve`` がいくつかの変更を後のコミットまで\
+とっておくのに対して、viewは次のコミットに(何を含めないかではなく)何を\
+含めるかを指定します。
+
+viewを作った後は、ファイルリストをサポートするコマンド - status,
+diff, commit, etc - に暗黙的に毎回そのファイルリストが渡されます。
+それらのコマンドに明示的にファイルリストを渡すことも可能ですが、\
+指名するファイルは現在のviewの中にないといけません。
+対照的に、ツリーを対象とするコマンド - pull, merge, update, etc -
+はviewが作られた後もツリー全体に対して操作しますが、現在のviewに\
+関係するもののみを報告します。
+どちらのケースでも、Bazaarはユーザーに毎回viewが使われていることを\
+報告するので、操作や出力がマスクされていることが判ります。
+
+.. 2aになったらこのnoteは要らない
+.. Note: Bazaar's default format does not yet support filtered views. That
+   is likely to change in the near future. To use filtered views in the
+   meantime, you currently need to upgrade to ``development-wt6`` (or
+   ``development-wt6-rich-root``) format first.
+
+
+view を作る
+---------------
+
+次のように, ``view`` コマンドにファイルやディレクトリを指定することで\
+viewを作ります::
+
+  bzr view file1 file2 dir1 ...
+
+出力は::
+
+  Using 'my' view: file1, file2, dir1
+
+
+現在のviewをリストする
+------------------------
+
+現在のviewを見るには、 ``view`` コマンドに引数をつけないで実行します::
+
+  bzr view
+
+もしviewが無ければ、 ``No current view.`` というメッセージが出力されるでしょう。
+そうでなければ、現在のviewの名前と内容が次のように表示されます::
+
+  'my' view is: a, b, c
+
+
+viewを切り替える
+-----------------------
+
+ほとんどの場合、viewは「変更を選択するために作られて、\
+変更がコミットされると削除される」という具合に短い期間で使われます。
+それ以外の場合では、viewに名前をつけてそれを切り替えたい場合がある\
+かもしれません。
+
+名前つきviewを宣言してそれに切り替えるには::
+
+    bzr view --name view-name file1 dir1 ...
+
+たとえば::
+
+  bzr view --name doc NEWS doc/
+  Using doc view: NEWS, doc/
+
+名前つきviewを見るには::
+
+  bzr view --name view-name
+
+名前つきviewに切り替えるには::
+
+  bzr view --switch view-name
+
+全ての名前つきviewの一覧を得るには::
+
+  bzr view --all
+
+
+一時的にviewを無効にする
+----------------------------
+
+現在のviewを削除せずに無効にしたい場合、 ``off`` という名前の仮想viewに\
+切り替えることができます。これは、ツリー全体を一つか二つのコマンドで操作する\
+必要があり(例: merge)、しかしその後に元のviewに戻りたい場合に便利です。
+
+現在のviewを削除せずに無効にするには::
+
+  bzr view --switch off
+
+ツリー全体に対する操作が終わったら、元のviewの名前を指定して戻ることが\
+できます。たとえば、デフォルトの名前が使われて他のであれば::
+
+  bzr view --switch my
+
+
+viewを削除する
+--------------
+
+現在のviewを削除するには::
+
+  bzr view --delete
+
+名前つきviewを削除するには::
+
+  bzr view --name view-name --delete
+
+全てのviewを削除するには::
+
+  bzr view --delete --all
+
+
+注意点
+---------------------
+
+view を定義しても作業ツリー内のほかのファイルを削除するわけでは\
+ありません。単に作業ツリーに対する "レンズ" を提供するだけです。
+
+view は作業ツリーのメタデータとして保存されます。pull, push, update
+といったブランチコマンドを使っても他の作業ツリーに伝播しません。
+
+view はファイルパスの形で定義されます。もしview内のファイルをview外に
+移動したのであれば、view はそのファイルを追跡しません。
+たとえば、viewが ``doc/`` と定義されていて ``doc/NEWS`` を ``NEWS``
+に移動しても view は ``doc/`` に定義されたままで、 ``doc/`` と ``NEWS``
+のように変更されたりはしません。同じように、view内のファイルを削除しても\
+viewからはそのファイルパスは削除されません。
+
+
+現在のviewを利用するコマンドは:
+
+* status
+* diff
+* commit
+* add
+* remove
+* revert
+* mv
+* ls
+
+ツリー全体に対する操作だけれども現在のviewの中だけを報告するコマンドは:
+
+* pull
+* update
+* merge.
+
+現在のところ、多くのコマンドがviewを無視します。ニーズがある\
+コマンドから徐々に上の対応リストに追加されていくでしょう。
+いくつかのコマンドは全体図を見るのがより適しているために、\
+viewを無視したままになるでしょう。このタイプのコマンドには\
+次のものがあります:
+
+* log
+* info

=== added file 'doc/ja/user-guide/getting_help.txt'
--- doc/ja/user-guide/getting_help.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/getting_help.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,19 @@
+helpを表示する
+==============
+
+Bazaarは組み込みのオンラインヘルプシステムを搭載しています。
+トピックの一覧を見るためには::
+
+  bzr help topics
+
+コマンドの一覧を見るためには::
+
+  bzr help commands
+
+トピックのxxxもしくはコマンドのxxxのヘルプを表示するためには::
+
+  bzr help xxx
+
+ヘルプを検索するもしくは大きなドキュメントとして読みたい場合、
+情報はBazaarのユーザーリファレンスでも手に入ります。
+

=== added file 'doc/ja/user-guide/hooks.txt'
--- doc/ja/user-guide/hooks.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/hooks.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,59 @@
+フックを利用する
+================
+
+フックとは？
+------------
+
+Bazaarのふるまいをカスタマイズする1つの方法は *フック(hook)* です。
+フックによって特定のBazaarの特定のオペレーションの前後でアクションを実行できます。
+オペレーションは ``commit`` 、 ``push`` 、 ``pull`` 、と ``uncommit`` を含みます。
+フックとパラメータの完全なリストに関しては、ユーザーリファレンスの
+`フック <../user-reference/bzr_man.html#hooks>`_ を参照してください。
+
+大抵のフックはクライアントで実行されますが、サーバーで実行されるものもわずかにあります。
+(サーバーサイドのオペレーションの特殊なケースを扱うものは `bzr-push-and-update`_ プラグインも参照。)
+
+.. _bzr-push-and-update: https://launchpad.net/bzr-push-and-update/
+
+
+フックを使用する
+-----------------
+
+フックを使用するには、 `プラグインを書きます <#writing-a-plugin>`_ 。
+新しいコマンドを作成する代わりに、このプラグインはフックを定義してインストールします。例です::
+
+    from bzrlib import branch
+
+
+    def post_push_hook(push_result):
+        print "The new revno is %d" % push_result.new_revno
+
+
+    branch.Branch.hooks.install_named_hook('post_push', post_push_hook,
+                                     'My post_push hook')
+
+この例を使用するには、 ``push_hook.py`` という名前のファイルを作り
+``plugins`` サブディレクトリに設置します。
+(プラグインをインストールしていなければ、 ``plugins`` ディレクトリを作る必要があります)。
+
+以上です！次回にpushすると、"The new revno is..."が表示されます。
+もちろん、Pythonのフルパワーを思いとおりにできるので、フックはこれよりもはるかに手が込んでいます。
+これでフックの使い方を理解したので、それらで何をするかはあなたしだいです。
+
+プラグインのコードは2つのことを行います。
+最初に、これは ``push`` が完了した後に実行する関数を定義します。
+(代わりにインスタンスメソッドもしくは呼び出し可能なオブジェクトを使用することもできます。)
+すべてのpushフックは単独の引数 ``push_result`` をとります。
+
+2番目に、プラグインはフックをインストールします。
+最初の引数 ``'post_push'`` はフックがインストールされている場所を特定します。
+2番目の引数はフック自身です。3番目の引数は ``'My post_push hook'`` という名前で、
+これは進行メッセージとエラーメッセージで使用されます。
+
+
+フックをデバッグする
+---------------------
+
+インストールされたフックの一覧を表示するには、 ``hooks`` コマンドを使います::
+
+    bzr hooks

=== added file 'doc/ja/user-guide/http_smart_server.txt'
--- doc/ja/user-guide/http_smart_server.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/http_smart_server.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,221 @@
+FastCGIでBazaarを提供する
+==========================
+
+このドキュメントでは、Apache 2.0とFastCGIもしくはmod_pythonを利用して
+Bazaar HTTPスマートサーバーをセットアップする1つの方法を説明します。
+
+スマートサーバーに関する詳細な情報とそれを設定する他の方法に関しては、
+メインのスマートサーバーのドキュメントを参照してください。
+
+例
+---
+
+プレーンなHTTPで `/srv/example.com/www/code` を `http://example.com/code/...` として
+すでに公開しているとします。これはbzrのブランチと `/srv/example.com/www/code/branch-one`
+と `/srv/example.com/www/code/my-repo/branch-two` のようなディレクトリを含みます。
+既存のHTTP形式のアクセス権限に加えてリードオンリーのスマートサーバーのアクセス権限を
+これらのディレクトリに提供したい場合を考えます。
+
+Apache 2.0を設定する
+--------------------
+
+FastCGI
+~~~~~~~
+
+最初に、mod_fastcgiを設定します。たとえば次の行をhttpd.confに追加します::
+
+    LoadModule fastcgi_module /usr/lib/apache2/modules/mod_fastcgi.so
+    FastCgiIpcDir /var/lib/apache2/fastcgi
+
+我々の例では、`http://example.com/code` で `/srv/example.com/www/code` をすでに提供しているので
+既存のApacheの設定は次のようになります::
+
+    Alias /code /srv/example.com/www/code
+    <Directory /srv/example.com/www/code>
+        Options Indexes
+        # ...
+    </Directory>
+
+.bzr/smartの形式で終わるURLに対するすべてのリクエストを扱うために
+次のように変更する必要があります::
+
+    Alias /code /srv/example.com/www/code
+    <Directory /srv/example.com/www/code>
+        Options Indexes FollowSymLinks
+        RewriteEngine On
+        RewriteBase /code
+        RewriteRule ^(.*/|)\.bzr/smart$ /srv/example.com/scripts/bzr-smart.fcgi
+    </Directory>
+
+    # bzr-smart.fcgiはDocumentRootの元に存在しないので、実行されるように
+    # AliasはこれをURLの名前空間のエイリアスにする。
+    Alias /srv/example.com/scripts/bzr-smart.fcgi /srv/example.com/scripts/bzr-smart.fcgi
+    <Directory /srv/example.com/scripts>
+        Options ExecCGI
+        <Files bzr-smart.fcgi>
+            SetHandler fastcgi-script
+        </Files>
+    </Directory>
+
+この設定はFastCGIを通して `/code` 内部の `/.bzr/smart` で終わるURLに対する
+Bazaarのスマートサーバーへのリクエストを扱うようにApacheに指示します。
+
+詳細な情報は mod_rewrite_ と mod_fastcgi_ のドキュメントを参照してください。
+
+.. _mod_rewrite: http://httpd.apache.org/docs/2.0/mod/mod_rewrite.html
+.. _mod_fastcgi: http://www.fastcgi.com/mod_fastcgi/docs/mod_fastcgi.html
+
+mod_python
+~~~~~~~~~~
+
+最初に、次のようなコードをhttpd.confに追加してmod_pythonを設定します::
+
+    LoadModule python_module /usr/lib/apache2/modules/mod_python.so
+
+FastCGIと同じ方法でmod_rewriteを用いて書き換えルールを定義します::
+
+    RewriteRule ^(.*/|)\.bzr/smart$ /srv/example.com/scripts/bzr-smart.fcgi
+
+変更は次のようになります::
+
+    RewriteRule ^(.*/|)\.bzr/smart$ /srv/example.com/scripts/bzr-smart.py
+
+mod_fastcgiのように、スクリプトがどのように扱われるのかも定義します::
+
+    Alias /srv/example.com/scripts/bzr-smart.py /srv/example.com/scripts/bzr-smart.py
+    <Directory /srv/example.com/scripts>
+        <Files bzr-smart.py>
+            PythonPath "sys.path+['/srv/example.com/scripts']"
+            AddHandler python-program .py
+            PythonHandler bzr-smart::handler
+        </Files>
+    </Directory>
+
+この設定はmod_pythonを通して `/code` 内部の `/.bzr/smart` で終わるURLに対するリクエストを
+Bazaarのスマートサーバーに渡すように指示します。
+
+注: bzrlibがPATHの中に存在しない場合、次の行を変更する必要があります::
+
+            PythonPath "sys.path+['/srv/example.com/scripts']"
+
+変更後は次のようになります::
+
+            PythonPath "['/path/to/bzr']+sys.path+['/srv/example.com/scripts']"
+
+
+詳細な情報は mod_python_ のドキュメントを参照してください。
+
+.. _mod_python: http://www.modpython.org/
+
+
+Bazaarを設定する
+-----------------
+
+FastCGI
+~~~~~~~
+
+`/srv/example.com/scripts/bzr-smart.fcgi` でスマートサーバーを実行するためにApacheを設定しました。
+これはスマートサーバーを設定するために書く必要のある単なるシンプルなスクリプトで
+サーバーをFastCGIのゲートウェイに結びつけます。次のようになります::
+
+    import fcgi
+    from bzrlib.transport.http import wsgi
+
+    smart_server_app = wsgi.make_app(
+        root='/srv/example.com/www/code',
+        prefix='/code/',
+        path_var='REQUEST_URI',
+        readonly=True,
+        load_plugins=True,
+        enable_logging=True)
+
+    fcgi.WSGIServer(smart_server_app).run()
+
+　`fcgi`のモジュールはhttp://svn.saddi.com/py-lib/trunk/fcgi.pyで見つかります。
+これは flup_ の一部です。
+
+.. _flup: http://www.saddi.com/software/flup/
+
+mod_python
+~~~~~~~~~~
+
+`/srv/example.com/scripts/bzr-smart.py` でスマートサーバーを実行するためにApacheを設定しました。
+これはスマートサーバーを設定するために書く必要のあるシンプルなスクリプトでサーバーをmod_pythonの
+ゲートウェイに結びつけます。次のようになります::
+
+    import modpywsgi
+    from bzrlib.transport.http import wsgi
+
+    smart_server_app = wsgi.make_app(
+        root='/srv/example.com/www/code',
+        prefix='/code/',
+        path_var='REQUEST_URI',
+        readonly=True,
+        load_plugins=True,
+        enable_logging=True)
+
+    def handler(request):
+        """Handle a single request."""
+        wsgi_server = modpywsgi.WSGIServer(smart_server_app)
+        return wsgi_server.run(request)
+
+`modpywsgi` モジュールは
+`http://dev.pocoo.org/projects/pocoo/browser/pocoo/wrappers/modpy.py` で見つかります。
+これは pocoo_ の一部です。modpywsgi.pyをbzr-smart.pyと同じディレクトリ
+(すなわち/srv/example.com/scripts/)に設置していることを確認してください。
+
+.. _pocoo: http://dev.pocoo.org/projects/pocoo/
+
+クライアント
+------------
+
+これで `bzr+http://` 形式のURLを利用できます::
+
+    bzr log bzr+http://example.com/code/my-branch
+
+プレーンなHTTP形式のアクセスも持続します::
+
+    bzr log http://example.com/code/my-branch
+
+
+高度な設定
+-----------
+
+BazaarのHTTPスマートサーバーはWSGIアプリケーションなので、
+WSGI標準に準拠するサードパーティのWSGIのミドルウェアもしくはサーバーで利用できます。
+唯一の要件は以下のとおりです:
+
+  * 　`SmartWSGIApp` をコンストラクトするためには、それが提供する **root transport** を指定する必要があります。
+  * それぞれのリクエストの `environ` dict は **'bzrlib.relpath'** 変数の設定を持たなければなりません。
+
+この例で使われている `make_app` ヘルパーは それに渡される `root` パスに基づいたトランスポートを伴う
+`SmartWSGIApp` をコンストラクトし、引数 `prefix` と`path_var` に基づくそれぞれのリクエストに対する
+　`bzrlib.relpath` を算出します。
+上記の例において、これは (Apacheによって設定される)'REQUEST_URI' を取り、接頭辞の '/code/' と接尾辞の '/.bzr/smart'
+をはぎ取り、それを 'bzrlib.relpath' として設定するので、 '/code/foo/bar/.bzr/smart' に対するリクエストは
+'foo/bzr' の 'bzrlib.relpath' になります。
+
+`SmartWSGIApp` を直接コンストラクトすることで、ローカルではないトランスポートに対して
+スマートサーバーを設定するもしくは任意任意のパスの変換を行うことは可能です。
+詳細な情報に関しては `bzrlib.transport.http.wsgi` のdocstringsと `WSGI標準`_ を参照してください。
+
+.. _WSGI標準: http://www.python.org/dev/peps/pep-0333/
+
+
+``bzr+http://`` を通してpushする
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+httpスマートサーバーを通してデータをプッシュすることは可能です。
+これを行うための最も簡単な方法は、 ``wsgi.make_app()`` コールに ``readonly=False`` を
+提供するだけです。ただし、スマートプロトコルは認証機能が含まれないので注意してください。
+書き込みのサポートを有効にする場合、
+実際にシステム上のデータを書き込みできる人を制限するために、 ``.bzr/smart`` URLへの権限を制限するとよいでしょう。
+
+現時点では、同じURLに対して読み込み限定の人と読み込みと書き込みの人を分けることはできません。
+(認証を行う)HTTPレイヤーにおいて、すべては単なるPOSTリクエストだからです。
+しかしながら、HTTPSアクセスの場合に認証が必要な書き込みサーバーを使い、
+プレーンなHTTPは読み込み限定のアクセスを許可することは確実にできます。
+
+
+..
+   vim: ft=rst tw=74 et

=== added directory 'doc/ja/user-guide/images'
=== added file 'doc/ja/user-guide/images/workflows_centralized.png'
Binary files doc/ja/user-guide/images/workflows_centralized.png and doc/ja/user-guide/images/workflows_centralized.png differ
=== added file 'doc/ja/user-guide/images/workflows_centralized.svg'
--- doc/ja/user-guide/images/workflows_centralized.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_centralized.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,1542 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_centralized.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_centralized.png"
+   inkscape:export-xdpi="90"
+   inkscape:export-ydpi="90">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient5536"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5540"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5542"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5544"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5546"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5548"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient5550"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5552"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5554"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient5556"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5558"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5562"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5566"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient5568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5570"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient5572"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5574"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="39.648127"
+       inkscape:collect="always"
+       id="radialGradient2797"
+       fy="101.92288"
+       fx="50.092871"
+       cy="102.70191"
+       cx="49.760482"
+       gradientTransform="scale(1.1222336,0.8910801)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="35.284406"
+       inkscape:collect="always"
+       id="radialGradient2791"
+       fy="32.061308"
+       fx="81.553592"
+       cy="33.402904"
+       cx="80.599566"
+       gradientTransform="scale(0.8352269,1.1972794)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="67.164412"
+       y1="53.505203"
+       xlink:href="#linearGradient4376"
+       x2="63.804663"
+       x1="64.786456"
+       inkscape:collect="always"
+       id="linearGradient2789"
+       gradientTransform="scale(1.1424512,0.8753109)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient9648"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient9646"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient9640">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop9642" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop9644" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.4142136"
+     inkscape:cx="536.99132"
+     inkscape:cy="369.73871"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1024"
+     inkscape:window-height="712"
+     inkscape:window-x="-4"
+     inkscape:window-y="-4" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <g
+       inkscape:label="Layer 1"
+       id="g4996"
+       transform="matrix(0.331077,0,0,0.2676656,75.992157,230.68349)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <g
+         transform="matrix(2.674162,0,0,2.674162,-826.248,-323.8239)"
+         id="g6052">
+        <path
+           style="fill:#c7c7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:6.11299896;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="czcczzz"
+           id="path1306"
+           d="M 362.77592,187.283 C 360.50343,190.98677 361.20593,367.68763 364.14011,374.65173 C 366.46268,380.1642 441.02381,442.12988 444.93699,443.78694 C 495.35017,443.444 529.34176,425.0858 534.99109,415.38735 C 537.14042,403.1889 535.31621,215.19709 533.25552,211.25359 C 531.47859,207.85312 436.04893,173.6386 432.71615,172.86054 C 429.71763,172.16052 365.30189,183.1661 362.77592,187.283 z " />
+        <path
+           style="fill:#ffffff;fill-opacity:0.54385968;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path2066"
+           d="M 366.42857,190.93361 C 391.19048,201.4098 418.60601,218.30739 446.22506,231.64072 C 472.394,225.42153 510.2022,217.10972 529.24981,213.77639 C 504.726,221.39543 472.52022,228.51448 447.99641,236.13353 C 446.56784,293.51448 447.257,380.45861 445.82843,437.83956 C 445.11414,379.98242 443.14285,291.6479 442.42856,233.79075 C 415.99999,219.50504 390,206.64789 366.42857,190.93361 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path4356"
+           d="M 519.99794,379.97737 C 510.93834,392.99882 482.41849,399.43361 468.8726,394.16864 C 471.21835,393.5424 516.96143,380.96883 519.99794,379.97737 z " />
+        <g
+           transform="translate(2.035534,15.20712)"
+           id="g4374">
+          <path
+             style="fill:#ffffff;fill-opacity:0.39473685;fill-rule:evenodd;stroke:none;stroke-width:1.01199996;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="cccccc"
+             id="path4362"
+             d="M 471.29127,340.59039 L 513.55921,324.30516 C 517.9002,325.84805 517.04588,332.27818 517.04588,332.27818 L 510.46155,334.58088 C 510.46155,334.58088 501.26764,349.01224 484.93096,343.36795 C 484.93096,343.36795 472.7787,345.52605 471.29127,340.59039 z " />
+          <path
+             style="fill:#606060;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.11199999;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="ccccccc"
+             id="path2826"
+             d="M 471.66824,335.10501 C 485.70133,331.45482 499.73443,327.80464 513.76752,324.15445 C 514.30594,326.13864 514.34437,328.99782 513.50779,330.48201 C 511.36566,331.50652 507.10221,332.35425 504.96008,333.37876 C 498.80357,339.27354 493.45917,339.80363 483.65919,338.95243 C 479.87505,339.74603 476.0909,340.36284 472.30676,341.15644 C 471.15285,338.85897 470.82215,337.90248 471.66824,335.10501 z " />
+        </g>
+        <path
+           style="fill:#ffffff;fill-opacity:0.40350874;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccc"
+           id="path4423"
+           d="M 364.8671,189.69191 L 446.71991,235.61832 L 446.39149,441.00771 L 366.28132,373.53968 L 364.8671,189.69191 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5957"
+           d="M 515.24794,392.97737 C 505.81506,405.42036 486.94113,407.56087 476.3726,403.76831 C 478.1563,403.29212 512.93901,393.73127 515.24794,392.97737 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5959"
+           d="M 508.24794,405.72737 C 502.79158,413.09279 492.2492,415.37141 483.8726,412.49343 C 484.991,412.19485 506.80021,406.20008 508.24794,405.72737 z " />
+        <path
+           style="fill:#fcfcfc;fill-opacity:0.44298245;fill-rule:evenodd;stroke:none;stroke-width:0.31200001;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path5973"
+           d="M 522.875,227.86218 L 527.04289,228.4302 L 527.79289,326.56929 L 463.46862,344.54896 L 461.88388,339.34073 L 523.68934,322.86218 L 522.875,227.86218 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6026"
+           d="M 462.21967,264.23013 L 462.31434,266.99086 L 522.7929,249.54632 L 462.21967,264.23013 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6036"
+           d="M 461.33579,284.2059 L 461.43046,286.96663 L 521.90902,269.52209 L 461.33579,284.2059 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6038"
+           d="M 462.21967,302.64613 L 462.31434,305.40686 L 522.7929,287.96232 L 462.21967,302.64613 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6040"
+           d="M 462.21967,320.79868 L 462.31434,323.55941 L 522.7929,306.11487 L 462.21967,320.79868 z " />
+        <path
+           style="opacity:1;color:#000000;fill:none;fill-opacity:0.75;fill-rule:evenodd;stroke:#9e9e9e;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="ccc"
+           id="path5988"
+           d="M 522.55191,229.64344 L 462.03362,244.76045 L 462.53549,344.35813" />
+      </g>
+    </g>
+    <g
+       id="g5256"
+       transform="translate(601.5744,207.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(633.63525,501.49239)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <g
+       id="g5488"
+       transform="translate(601.5744,407.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient5536);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path5490"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient5538);fill-opacity:1"
+         id="g5492">
+        <path
+           style="fill:url(#linearGradient5540);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5494"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5542);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5496"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5544);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path5498"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient5546);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5548);stroke-width:1.44734821pt"
+         id="rect5500"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient5550);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path5502"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient5552);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5504"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient5554);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect5506"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient5556);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5558);stroke-width:1.4649456pt"
+         id="rect5508"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient5560);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path5510"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g5512">
+        <path
+           style="fill:url(#linearGradient5562);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5514"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient5564);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5516"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient5566);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path5518"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient5568);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path5520"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient5570);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path5522"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient5572);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path5524"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient5574);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5526"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5528"><tspan
+           id="tspan5530">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5532"><tspan
+           id="tspan5534">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g6024"
+       transform="matrix(-1,0,0,1,900.16045,422.61731)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path6027"
+         d="M 60.545133,72.847539 C 65.294534,78.031101 68.316881,87.318315 75.00922,87.318316 C 81.485677,85.518467 82.349205,70.11177 83.212732,66.800051 C 75.872748,71.839624 68.316882,74.71938 60.545133,72.847539 z " />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#d20000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path6029"
+         d="M 31.546762,99.654209 C 31.156121,124.85047 95.78552,127.73183 95.62922,99.654209 C 97.174007,77.325462 86.068776,64.629762 83.309105,66.788232 C 81.907864,67.884209 81.387229,92.223995 71.919297,86.625353 C 67.316417,83.903554 62.167959,73.44849 59.915352,73.101625 C 56.516277,72.578221 50.007529,69.826123 44.029815,64.675414 C 42.461522,63.324094 32.076211,77.214403 31.546762,99.654209 z " />
+      <path
+         style="fill:url(#radialGradient2797);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2796"
+         d="M 43.53125,77.3125 C 40.353026,86.016409 37.202011,96.366079 40.377303,105.23542 C 48.984655,117.18204 66.049398,117.25223 79.222417,115.04972 C 88.094278,113.47345 96.636121,105.87972 94.744454,96.188658 C 94.751182,88.561019 93.319573,80.643142 89.09375,74.1875 C 87.954705,81.120157 85.706152,92.347929 76.686643,91.786583 C 66.841974,89.84774 65.058803,76.33878 54.747596,75.105769 C 49.945701,71.530053 45.566465,69.110698 43.783935,76.852875 L 43.53125,77.3125 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,0.997459,16.38124)"
+         style="fill:#efd7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path6032"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccccc"
+         id="path3720"
+         d="M 56.980881,5.8426527 C 39.420698,8.0166254 30.552872,16.206245 24.211446,49.532095 C 14.512196,98.076517 21.871677,115.5525 32.990311,115.56714 C 17.54932,102.40769 63.877625,86.740105 56.295103,44.070713 C 68.4508,48.712358 94.51097,54.349644 95.164349,41.718703 C 97.176702,29.219492 88.64173,4.4775042 56.980881,5.8426527 z " />
+      <path
+         style="fill:url(#linearGradient2789);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2164"
+         d="M 60.687242,45.028999 C 62.530882,55.403773 61.180052,64.151015 58.312242,71.685249 C 61.630122,73.07804 65.296862,73.904 69.155992,73.903999 C 83.975322,73.903999 95.981712,62.468019 95.999742,48.403999 C 88.357632,52.885439 70.244092,48.678277 60.687242,45.028999 z " />
+      <path
+         style="fill:url(#radialGradient2791);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2790"
+         d="M 52.174948,8.1325312 C 35.846775,12.141346 31.110158,30.475875 28.060647,44.840387 C 24.465246,64.767005 19.485139,85.90438 25.518698,105.82003 C 29.863591,114.87216 28.026452,106.52571 31.049538,102.11795 C 41.311249,87.323083 56.256862,73.307418 55.936774,53.886064 C 56.647391,49.398848 52.34734,38.640985 60.701717,42.254379 C 70.683443,45.202557 82.078811,49.011247 92.143698,44.632531 C 96.945103,37.45042 93.288237,27.137344 88.876323,20.399742 C 81.135092,8.5919962 65.300885,5.0194752 52.174948,8.1325312 z " />
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path699"
+       d="M 319.16674,325.66524 L 432.27399,313.12251 L 422.57906,332.08242 L 484.9028,325.95688 C 484.9028,325.95688 494.59773,306.41369 495.05931,306.41369 C 495.52148,306.41369 517.68079,331.79078 517.68079,331.79078 C 517.68079,331.79078 465.51355,358.33479 465.05197,358.33479 C 465.51355,358.91808 474.74689,339.66616 474.74689,339.37453 L 402.72705,345.79207 L 412.42255,326.24852 L 309.01023,338.4996 L 319.16674,325.66524 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:48px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont;font-stretch:normal;font-variant:normal;text-anchor:start;text-align:start;writing-mode:lr;line-height:125%"
+       x="140"
+       y="521.23737"
+       id="text7612"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan7614"
+         x="140"
+         y="521.23737">Server</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="359.5625"
+       y="261.21948"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan7879"
+         x="359.5625"
+         y="261.21948">bzr checkout</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9548"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(42.857147,67.142853)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="325.71429"
+       y="259.52307"
+       id="text9550"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9552"
+         x="325.71429"
+         y="259.52307">1</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9554"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(492.85715,-2.8571472)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="777.71429"
+       y="191.52307"
+       id="text9556"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9558"
+         x="777.71429"
+         y="191.52307">2</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="819.5625"
+       y="191.21948"
+       id="text9566"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9568"
+         x="819.5625"
+         y="191.21948">bzr update</tspan></text>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.29065037;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path9650"
+       d="M 539.95542,466.93556 L 415.85387,476.71718 L 426.49116,461.93102 L 358.1094,466.70812 C 358.1094,466.70812 347.47211,481.94916 346.96566,481.94916 C 346.45858,481.94916 322.14533,462.15846 322.14533,462.15846 C 322.14533,462.15846 379.38334,441.45772 379.88978,441.45772 C 379.38334,441.00284 369.25249,456.01673 369.25249,456.24417 L 448.27282,451.23935 L 437.63489,466.48068 L 551.09912,456.92649 L 539.95542,466.93556 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9652"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(51.511043,348.5966)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="334.36819"
+       y="540.97681"
+       id="text9654"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9656"
+         x="334.36819"
+         y="540.97681">3</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="369.5625"
+       y="544.09448"
+       id="text9658"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9660"
+         x="369.5625"
+         y="544.09448">bzr commit</tspan></text>
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/images/workflows_gatekeeper.png'
Binary files doc/ja/user-guide/images/workflows_gatekeeper.png and doc/ja/user-guide/images/workflows_gatekeeper.png differ
=== added file 'doc/ja/user-guide/images/workflows_gatekeeper.svg'
--- doc/ja/user-guide/images/workflows_gatekeeper.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_gatekeeper.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,2137 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_gatekeeper.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_manualpqm.png"
+   inkscape:export-xdpi="90"
+   inkscape:export-ydpi="90">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient5536"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5540"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5542"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5544"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5546"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5548"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient5550"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5552"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5554"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient5556"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5558"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5562"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5566"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient5568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5570"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient5572"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5574"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="39.648127"
+       inkscape:collect="always"
+       id="radialGradient2797"
+       fy="101.92288"
+       fx="50.092871"
+       cy="102.70191"
+       cx="49.760482"
+       gradientTransform="scale(1.1222336,0.8910801)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="35.284406"
+       inkscape:collect="always"
+       id="radialGradient2791"
+       fy="32.061308"
+       fx="81.553592"
+       cy="33.402904"
+       cx="80.599566"
+       gradientTransform="scale(0.8352269,1.1972794)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="67.164412"
+       y1="53.505203"
+       xlink:href="#linearGradient4376"
+       x2="63.804663"
+       x1="64.786456"
+       inkscape:collect="always"
+       id="linearGradient2789"
+       gradientTransform="scale(1.1424512,0.8753109)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient9648"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient9646"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient9640">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop9642" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop9644" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient7932"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient7934"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient7936"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient7938"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient7940"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient7942"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient7944"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient7946"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient7948"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient7950"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient7952"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient7954"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient7956"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient7958"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient7960"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient7962"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient7964"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient7966"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient7968"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient7990"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <radialGradient
+       xlink:href="#linearGradient1861"
+       r="26.285225"
+       inkscape:collect="always"
+       id="radialGradient1887"
+       fy="44.906904"
+       fx="34.609807"
+       cy="45.317611"
+       cx="33.865884"
+       gradientTransform="scale(1.3025634,0.767717)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1861"
+       r="27.313507"
+       inkscape:collect="always"
+       id="radialGradient1885"
+       fy="96.522109"
+       fx="44.745902"
+       cy="96.948882"
+       cx="45.838441"
+       gradientTransform="scale(1.0963096,0.9121511)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="69.990188"
+       y1="60.176033"
+       xlink:href="#linearGradient1864"
+       x2="54.084046"
+       x1="51.210938"
+       inkscape:collect="always"
+       id="linearGradient1883"
+       gradientTransform="scale(1.2343409,0.8101489)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1858">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop1859" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop1860" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1861">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop1862" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1863" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1864">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop1865" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1866" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1867">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop1868" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1869" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11180">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop11182" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop11184" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11174">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop11176" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop11178" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11168">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop11170" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop11172" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11162">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop11164" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop11166" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1"
+     inkscape:cx="559.94128"
+     inkscape:cy="472.46874"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1416"
+     inkscape:window-height="825"
+     inkscape:window-x="0"
+     inkscape:window-y="25" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <g
+       inkscape:label="Layer 1"
+       id="g4996"
+       transform="matrix(0.331077,0,0,0.2676656,39.992157,230.68349)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <g
+         transform="matrix(2.674162,0,0,2.674162,-826.248,-323.8239)"
+         id="g6052">
+        <path
+           style="fill:#c7c7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:6.11299896;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="czcczzz"
+           id="path1306"
+           d="M 362.77592,187.283 C 360.50343,190.98677 361.20593,367.68763 364.14011,374.65173 C 366.46268,380.1642 441.02381,442.12988 444.93699,443.78694 C 495.35017,443.444 529.34176,425.0858 534.99109,415.38735 C 537.14042,403.1889 535.31621,215.19709 533.25552,211.25359 C 531.47859,207.85312 436.04893,173.6386 432.71615,172.86054 C 429.71763,172.16052 365.30189,183.1661 362.77592,187.283 z " />
+        <path
+           style="fill:#ffffff;fill-opacity:0.54385968;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path2066"
+           d="M 366.42857,190.93361 C 391.19048,201.4098 418.60601,218.30739 446.22506,231.64072 C 472.394,225.42153 510.2022,217.10972 529.24981,213.77639 C 504.726,221.39543 472.52022,228.51448 447.99641,236.13353 C 446.56784,293.51448 447.257,380.45861 445.82843,437.83956 C 445.11414,379.98242 443.14285,291.6479 442.42856,233.79075 C 415.99999,219.50504 390,206.64789 366.42857,190.93361 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path4356"
+           d="M 519.99794,379.97737 C 510.93834,392.99882 482.41849,399.43361 468.8726,394.16864 C 471.21835,393.5424 516.96143,380.96883 519.99794,379.97737 z " />
+        <g
+           transform="translate(2.035534,15.20712)"
+           id="g4374">
+          <path
+             style="fill:#ffffff;fill-opacity:0.39473685;fill-rule:evenodd;stroke:none;stroke-width:1.01199996;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="cccccc"
+             id="path4362"
+             d="M 471.29127,340.59039 L 513.55921,324.30516 C 517.9002,325.84805 517.04588,332.27818 517.04588,332.27818 L 510.46155,334.58088 C 510.46155,334.58088 501.26764,349.01224 484.93096,343.36795 C 484.93096,343.36795 472.7787,345.52605 471.29127,340.59039 z " />
+          <path
+             style="fill:#606060;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.11199999;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="ccccccc"
+             id="path2826"
+             d="M 471.66824,335.10501 C 485.70133,331.45482 499.73443,327.80464 513.76752,324.15445 C 514.30594,326.13864 514.34437,328.99782 513.50779,330.48201 C 511.36566,331.50652 507.10221,332.35425 504.96008,333.37876 C 498.80357,339.27354 493.45917,339.80363 483.65919,338.95243 C 479.87505,339.74603 476.0909,340.36284 472.30676,341.15644 C 471.15285,338.85897 470.82215,337.90248 471.66824,335.10501 z " />
+        </g>
+        <path
+           style="fill:#ffffff;fill-opacity:0.40350874;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccc"
+           id="path4423"
+           d="M 364.8671,189.69191 L 446.71991,235.61832 L 446.39149,441.00771 L 366.28132,373.53968 L 364.8671,189.69191 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5957"
+           d="M 515.24794,392.97737 C 505.81506,405.42036 486.94113,407.56087 476.3726,403.76831 C 478.1563,403.29212 512.93901,393.73127 515.24794,392.97737 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5959"
+           d="M 508.24794,405.72737 C 502.79158,413.09279 492.2492,415.37141 483.8726,412.49343 C 484.991,412.19485 506.80021,406.20008 508.24794,405.72737 z " />
+        <path
+           style="fill:#fcfcfc;fill-opacity:0.44298245;fill-rule:evenodd;stroke:none;stroke-width:0.31200001;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path5973"
+           d="M 522.875,227.86218 L 527.04289,228.4302 L 527.79289,326.56929 L 463.46862,344.54896 L 461.88388,339.34073 L 523.68934,322.86218 L 522.875,227.86218 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6026"
+           d="M 462.21967,264.23013 L 462.31434,266.99086 L 522.7929,249.54632 L 462.21967,264.23013 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6036"
+           d="M 461.33579,284.2059 L 461.43046,286.96663 L 521.90902,269.52209 L 461.33579,284.2059 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6038"
+           d="M 462.21967,302.64613 L 462.31434,305.40686 L 522.7929,287.96232 L 462.21967,302.64613 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6040"
+           d="M 462.21967,320.79868 L 462.31434,323.55941 L 522.7929,306.11487 L 462.21967,320.79868 z " />
+        <path
+           style="opacity:1;color:#000000;fill:none;fill-opacity:0.75;fill-rule:evenodd;stroke:#9e9e9e;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="ccc"
+           id="path5988"
+           d="M 522.55191,229.64344 L 462.03362,244.76045 L 462.53549,344.35813" />
+      </g>
+    </g>
+    <g
+       id="g5256"
+       transform="translate(601.5744,227.66157)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(635.63525,491.49239)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <g
+       id="g5488"
+       transform="translate(601.5744,407.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient5536);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path5490"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient5538);fill-opacity:1"
+         id="g5492">
+        <path
+           style="fill:url(#linearGradient5540);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5494"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5542);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5496"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5544);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path5498"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient5546);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5548);stroke-width:1.44734821pt"
+         id="rect5500"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient5550);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path5502"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient5552);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5504"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient5554);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect5506"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient5556);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5558);stroke-width:1.4649456pt"
+         id="rect5508"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient5560);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path5510"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g5512">
+        <path
+           style="fill:url(#linearGradient5562);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5514"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient5564);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5516"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient5566);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path5518"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient5568);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path5520"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient5570);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path5522"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient5572);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path5524"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient5574);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5526"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5528"><tspan
+           id="tspan5530">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5532"><tspan
+           id="tspan5534">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g6024"
+       transform="matrix(-1,0,0,1,900.16045,422.61731)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path6027"
+         d="M 60.545133,72.847539 C 65.294534,78.031101 68.316881,87.318315 75.00922,87.318316 C 81.485677,85.518467 82.349205,70.11177 83.212732,66.800051 C 75.872748,71.839624 68.316882,74.71938 60.545133,72.847539 z " />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#d20000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path6029"
+         d="M 31.546762,99.654209 C 31.156121,124.85047 95.78552,127.73183 95.62922,99.654209 C 97.174007,77.325462 86.068776,64.629762 83.309105,66.788232 C 81.907864,67.884209 81.387229,92.223995 71.919297,86.625353 C 67.316417,83.903554 62.167959,73.44849 59.915352,73.101625 C 56.516277,72.578221 50.007529,69.826123 44.029815,64.675414 C 42.461522,63.324094 32.076211,77.214403 31.546762,99.654209 z " />
+      <path
+         style="fill:url(#radialGradient2797);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2796"
+         d="M 43.53125,77.3125 C 40.353026,86.016409 37.202011,96.366079 40.377303,105.23542 C 48.984655,117.18204 66.049398,117.25223 79.222417,115.04972 C 88.094278,113.47345 96.636121,105.87972 94.744454,96.188658 C 94.751182,88.561019 93.319573,80.643142 89.09375,74.1875 C 87.954705,81.120157 85.706152,92.347929 76.686643,91.786583 C 66.841974,89.84774 65.058803,76.33878 54.747596,75.105769 C 49.945701,71.530053 45.566465,69.110698 43.783935,76.852875 L 43.53125,77.3125 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,0.997459,16.38124)"
+         style="fill:#efd7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path6032"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccccc"
+         id="path3720"
+         d="M 56.980881,5.8426527 C 39.420698,8.0166254 30.552872,16.206245 24.211446,49.532095 C 14.512196,98.076517 21.871677,115.5525 32.990311,115.56714 C 17.54932,102.40769 63.877625,86.740105 56.295103,44.070713 C 68.4508,48.712358 94.51097,54.349644 95.164349,41.718703 C 97.176702,29.219492 88.64173,4.4775042 56.980881,5.8426527 z " />
+      <path
+         style="fill:url(#linearGradient2789);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2164"
+         d="M 60.687242,45.028999 C 62.530882,55.403773 61.180052,64.151015 58.312242,71.685249 C 61.630122,73.07804 65.296862,73.904 69.155992,73.903999 C 83.975322,73.903999 95.981712,62.468019 95.999742,48.403999 C 88.357632,52.885439 70.244092,48.678277 60.687242,45.028999 z " />
+      <path
+         style="fill:url(#radialGradient2791);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2790"
+         d="M 52.174948,8.1325312 C 35.846775,12.141346 31.110158,30.475875 28.060647,44.840387 C 24.465246,64.767005 19.485139,85.90438 25.518698,105.82003 C 29.863591,114.87216 28.026452,106.52571 31.049538,102.11795 C 41.311249,87.323083 56.256862,73.307418 55.936774,53.886064 C 56.647391,49.398848 52.34734,38.640985 60.701717,42.254379 C 70.683443,45.202557 82.078811,49.011247 92.143698,44.632531 C 96.945103,37.45042 93.288237,27.137344 88.876323,20.399742 C 81.135092,8.5919962 65.300885,5.0194752 52.174948,8.1325312 z " />
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path699"
+       d="M 319.16674,325.66524 L 432.27399,313.12251 L 422.57906,332.08242 L 484.9028,325.95688 C 484.9028,325.95688 494.59773,306.41369 495.05931,306.41369 C 495.52148,306.41369 517.68079,331.79078 517.68079,331.79078 C 517.68079,331.79078 465.51355,358.33479 465.05197,358.33479 C 465.51355,358.91808 474.74689,339.66616 474.74689,339.37453 L 402.72705,345.79207 L 412.42255,326.24852 L 309.01023,338.4996 L 319.16674,325.66524 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:48px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="73.4375"
+       y="510.12573"
+       id="text7612"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan7614"
+         x="73.4375"
+         y="510.12573">Server</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="359.5625"
+       y="261.21948"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan7879"
+         x="359.5625"
+         y="261.21948">bzr branch</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9548"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(42.857147,67.142853)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="325.71429"
+       y="259.52307"
+       id="text9550"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9552"
+         x="325.71429"
+         y="259.52307">1</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9554"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(466.18527,201.5491)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="751.04242"
+       y="395.37573"
+       id="text9556"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9558"
+         x="751.04242"
+         y="395.37573">2</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="778.89062"
+       y="392.32886"
+       id="text9566"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         x="778.89062"
+         y="392.32886"
+         id="tspan2963">make changes</tspan></text>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:2.52894235;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path9650"
+       d="M 578.13978,492.35651 L 518.11306,536.64644 L 515.93459,528.2361 L 482.53728,552.4378 C 482.53728,552.4378 484.9546,560.99862 484.68867,561.16617 C 484.42242,561.33391 461.26447,562.83001 461.26447,562.83001 C 461.26447,562.83001 480.44933,537.04707 480.71524,536.87954 C 480.21048,536.89659 482.77445,545.21473 482.89387,545.28997 L 521.75768,517.49359 L 524.17482,526.05472 L 578.73553,485.35896 L 578.13978,492.35651 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9652"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(449.56027,418.37723)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="732.41742"
+       y="611.97729"
+       id="text9654"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9656"
+         x="732.41742"
+         y="611.97729">3</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="768.26562"
+       y="608.23511"
+       id="text9658"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9660"
+         x="768.26562"
+         y="608.23511">request merge</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="75.5625"
+       y="228.09448"
+       id="text2965"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2967"
+         x="75.5625"
+         y="228.09448">main branch</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="556.98438"
+       y="165.64139"
+       id="text2969"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2971"
+         x="556.98438"
+         y="165.64139">local branches</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:none;fill-opacity:1;stroke:#0000ff;stroke-width:5.00006151;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path4930"
+       sodipodi:cx="342"
+       sodipodi:cy="171.0945"
+       sodipodi:rx="66"
+       sodipodi:ry="35"
+       d="M 408 171.0945 A 66 35 0 1 1  276,171.0945 A 66 35 0 1 1  408 171.0945 z"
+       transform="matrix(1.9161749,0,0,1.0419298,-477.33182,37.826027)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <path
+       sodipodi:type="arc"
+       style="fill:none;fill-opacity:1;stroke:#0000ff;stroke-width:5.00006151;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path7839"
+       sodipodi:cx="342"
+       sodipodi:cy="171.0945"
+       sodipodi:rx="66"
+       sodipodi:ry="35"
+       d="M 408 171.0945 A 66 35 0 1 1  276,171.0945 A 66 35 0 1 1  408 171.0945 z"
+       transform="matrix(2.0657387,0,0,1.0382501,-36.482679,-19.544354)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:2.27460909;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path7875"
+       d="M 313.49127,554.98551 L 266.8349,508.88833 L 275.69462,507.21539 L 250.19978,481.56811 C 250.19978,481.56811 241.18156,483.42447 241.00507,483.22026 C 240.82835,483.0158 239.25232,465.23179 239.25232,465.23179 C 239.25232,465.23179 266.41286,479.96469 266.58935,480.16889 C 266.57138,479.78127 257.8088,481.75026 257.72954,481.84196 L 287.01109,511.6872 L 277.99254,513.54344 L 320.8627,555.44302 L 313.49127,554.98551 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <g
+       id="g7884"
+       transform="translate(322.22009,479.97324)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient7932);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path7886"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient7934);fill-opacity:1"
+         id="g7888">
+        <path
+           style="fill:url(#linearGradient7936);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path7890"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient7938);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path7892"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient7940);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path7894"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient7942);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient7944);stroke-width:1.44734821pt"
+         id="rect7896"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient7946);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path7898"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient7948);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path7900"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient7950);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect7902"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient7952);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient7954);stroke-width:1.4649456pt"
+         id="rect7904"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient7956);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path7906"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g7908">
+        <path
+           style="fill:url(#linearGradient7958);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path7910"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient7960);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path7912"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient7962);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path7914"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient7964);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path7916"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient7966);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path7918"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient7968);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path7920"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient7990);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path7922"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text7924"><tspan
+           id="tspan7926">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text7928"><tspan
+           id="tspan7930">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g11201"
+       transform="translate(224.98935,560.87966)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11204"
+         d="M 61.208646,74.540863 C 65.958047,79.724425 68.980394,89.011639 75.672733,89.01164 C 82.14919,87.211791 83.012718,71.805094 83.876245,68.493375 C 76.536261,73.532948 68.980395,76.412704 61.208646,74.540863 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,-0.8485902,18.11889)"
+         style="fill:#ebd5bb;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path11206"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#354b63;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path11208"
+         d="M 32.210275,101.34753 C 31.819634,126.54379 96.449036,129.42515 96.292736,101.34753 C 97.837516,79.018786 86.732289,66.323086 83.972618,68.481556 C 82.571377,69.577533 82.050742,93.917319 72.58281,88.318677 C 67.97993,85.596878 62.831472,75.141814 60.578865,74.794949 C 57.17979,74.271545 50.671042,71.519447 44.693328,66.368738 C 43.125035,65.017418 32.739724,78.907727 32.210275,101.34753 z " />
+      <path
+         style="fill:#7e5429;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccscc"
+         id="path14564"
+         d="M 67.304802,16.686453 C 54.985668,-4.2976037 31.742548,13.847204 34.832083,38.13111 C 28.606909,39.936495 13.38594,55.735942 54.610465,51.217079 C 72.973357,49.204214 127.11969,28.718598 84.679736,22.863615 C 78.797006,1.2972292 67.040662,6.1031815 67.304802,16.686453 z " />
+      <path
+         style="fill:url(#linearGradient1883);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1879"
+         d="M 89.582928,41.074792 C 78.886738,46.748497 62.561318,51.815798 53.926678,52.762292 C 47.018518,53.519536 42.160188,53.578455 38.114178,53.356042 C 39.550848,66.152312 50.849068,76.168541 64.707928,76.168542 C 79.538378,76.168542 91.582928,64.747093 91.582928,50.668542 C 91.582928,47.276803 90.850878,44.035951 89.582928,41.074792 z " />
+      <path
+         style="fill:url(#radialGradient1885);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1884"
+         d="M 43.031249,70.1875 C 35.995246,80.448202 32.902215,93.581638 34.156249,105.875 C 40.334493,118.62839 56.831543,120.43683 69.499999,119.875 C 80.494576,119.32475 94.949065,113.14258 93.695531,100.00002 C 93.939855,90.023763 92.261916,78.780004 84.874999,71.5 C 82.650684,78.396104 83.536195,89.443626 74.999999,91.84375 C 65.062996,91.017122 64.05284,76.914438 54.283675,75.750529 C 50.352102,75.051855 46.009593,69.547093 43.031249,70.1875 z " />
+      <path
+         style="fill:url(#radialGradient1887);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1886"
+         d="M 51.968749,10.15625 C 40.703741,13.843837 36.038494,27.433868 37.531249,38.375 C 35.900906,41.584912 25.71302,45.254989 31.843749,49.03125 C 53.068339,53.154256 75.12687,46.221276 93.715523,36.077723 C 100.42684,33.740896 99.810666,26.846559 92.384918,26.66513 C 86.324151,26.558371 81.674394,23.81643 81.165374,17.307044 C 79.826948,13.582045 74.107596,6.6890987 71.01108,12.623276 C 71.073069,19.511996 65.891703,20.102559 63.230392,14.042893 C 60.468574,10.851605 56.135557,9.1882781 51.968749,10.15625 z " />
+    </g>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2488"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(82.857147,474.9866)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="365.71429"
+       y="668.60229"
+       id="text2490"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2492"
+         x="365.71429"
+         y="668.60229">4</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="401.5625"
+       y="665.76636"
+       id="text2494"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2496"
+         x="401.5625"
+         y="665.76636">accept or reject</tspan></text>
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/images/workflows_localcommit.png'
Binary files doc/ja/user-guide/images/workflows_localcommit.png and doc/ja/user-guide/images/workflows_localcommit.png differ
=== added file 'doc/ja/user-guide/images/workflows_localcommit.svg'
--- doc/ja/user-guide/images/workflows_localcommit.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_localcommit.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,1575 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_localcommit.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_localcommit.png"
+   inkscape:export-xdpi="90"
+   inkscape:export-ydpi="90">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient5536"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5540"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5542"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5544"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5546"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5548"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient5550"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5552"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5554"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient5556"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5558"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5562"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5566"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient5568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5570"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient5572"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5574"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="39.648127"
+       inkscape:collect="always"
+       id="radialGradient2797"
+       fy="101.92288"
+       fx="50.092871"
+       cy="102.70191"
+       cx="49.760482"
+       gradientTransform="scale(1.1222336,0.8910801)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="35.284406"
+       inkscape:collect="always"
+       id="radialGradient2791"
+       fy="32.061308"
+       fx="81.553592"
+       cy="33.402904"
+       cx="80.599566"
+       gradientTransform="scale(0.8352269,1.1972794)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="67.164412"
+       y1="53.505203"
+       xlink:href="#linearGradient4376"
+       x2="63.804663"
+       x1="64.786456"
+       inkscape:collect="always"
+       id="linearGradient2789"
+       gradientTransform="scale(1.1424512,0.8753109)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient8493"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient8491"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient8485">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop8487" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop8489" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="0.70710678"
+     inkscape:cx="503.09779"
+     inkscape:cy="201.79714"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1024"
+     inkscape:window-height="712"
+     inkscape:window-x="-4"
+     inkscape:window-y="-4" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <g
+       inkscape:label="Layer 1"
+       id="g4996"
+       transform="matrix(0.331077,0,0,0.2676656,75.992157,230.68349)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999">
+      <g
+         transform="matrix(2.674162,0,0,2.674162,-826.248,-323.8239)"
+         id="g6052">
+        <path
+           style="fill:#c7c7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:6.11299896;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="czcczzz"
+           id="path1306"
+           d="M 362.77592,187.283 C 360.50343,190.98677 361.20593,367.68763 364.14011,374.65173 C 366.46268,380.1642 441.02381,442.12988 444.93699,443.78694 C 495.35017,443.444 529.34176,425.0858 534.99109,415.38735 C 537.14042,403.1889 535.31621,215.19709 533.25552,211.25359 C 531.47859,207.85312 436.04893,173.6386 432.71615,172.86054 C 429.71763,172.16052 365.30189,183.1661 362.77592,187.283 z " />
+        <path
+           style="fill:#ffffff;fill-opacity:0.54385968;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path2066"
+           d="M 366.42857,190.93361 C 391.19048,201.4098 418.60601,218.30739 446.22506,231.64072 C 472.394,225.42153 510.2022,217.10972 529.24981,213.77639 C 504.726,221.39543 472.52022,228.51448 447.99641,236.13353 C 446.56784,293.51448 447.257,380.45861 445.82843,437.83956 C 445.11414,379.98242 443.14285,291.6479 442.42856,233.79075 C 415.99999,219.50504 390,206.64789 366.42857,190.93361 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path4356"
+           d="M 519.99794,379.97737 C 510.93834,392.99882 482.41849,399.43361 468.8726,394.16864 C 471.21835,393.5424 516.96143,380.96883 519.99794,379.97737 z " />
+        <g
+           transform="translate(2.035534,15.20712)"
+           id="g4374">
+          <path
+             style="fill:#ffffff;fill-opacity:0.39473685;fill-rule:evenodd;stroke:none;stroke-width:1.01199996;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="cccccc"
+             id="path4362"
+             d="M 471.29127,340.59039 L 513.55921,324.30516 C 517.9002,325.84805 517.04588,332.27818 517.04588,332.27818 L 510.46155,334.58088 C 510.46155,334.58088 501.26764,349.01224 484.93096,343.36795 C 484.93096,343.36795 472.7787,345.52605 471.29127,340.59039 z " />
+          <path
+             style="fill:#606060;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.11199999;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="ccccccc"
+             id="path2826"
+             d="M 471.66824,335.10501 C 485.70133,331.45482 499.73443,327.80464 513.76752,324.15445 C 514.30594,326.13864 514.34437,328.99782 513.50779,330.48201 C 511.36566,331.50652 507.10221,332.35425 504.96008,333.37876 C 498.80357,339.27354 493.45917,339.80363 483.65919,338.95243 C 479.87505,339.74603 476.0909,340.36284 472.30676,341.15644 C 471.15285,338.85897 470.82215,337.90248 471.66824,335.10501 z " />
+        </g>
+        <path
+           style="fill:#ffffff;fill-opacity:0.40350874;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccc"
+           id="path4423"
+           d="M 364.8671,189.69191 L 446.71991,235.61832 L 446.39149,441.00771 L 366.28132,373.53968 L 364.8671,189.69191 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5957"
+           d="M 515.24794,392.97737 C 505.81506,405.42036 486.94113,407.56087 476.3726,403.76831 C 478.1563,403.29212 512.93901,393.73127 515.24794,392.97737 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5959"
+           d="M 508.24794,405.72737 C 502.79158,413.09279 492.2492,415.37141 483.8726,412.49343 C 484.991,412.19485 506.80021,406.20008 508.24794,405.72737 z " />
+        <path
+           style="fill:#fcfcfc;fill-opacity:0.44298245;fill-rule:evenodd;stroke:none;stroke-width:0.31200001;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path5973"
+           d="M 522.875,227.86218 L 527.04289,228.4302 L 527.79289,326.56929 L 463.46862,344.54896 L 461.88388,339.34073 L 523.68934,322.86218 L 522.875,227.86218 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6026"
+           d="M 462.21967,264.23013 L 462.31434,266.99086 L 522.7929,249.54632 L 462.21967,264.23013 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6036"
+           d="M 461.33579,284.2059 L 461.43046,286.96663 L 521.90902,269.52209 L 461.33579,284.2059 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6038"
+           d="M 462.21967,302.64613 L 462.31434,305.40686 L 522.7929,287.96232 L 462.21967,302.64613 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6040"
+           d="M 462.21967,320.79868 L 462.31434,323.55941 L 522.7929,306.11487 L 462.21967,320.79868 z " />
+        <path
+           style="opacity:1;color:#000000;fill:none;fill-opacity:0.75;fill-rule:evenodd;stroke:#9e9e9e;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="ccc"
+           id="path5988"
+           d="M 522.55191,229.64344 L 462.03362,244.76045 L 462.53549,344.35813" />
+      </g>
+    </g>
+    <g
+       id="g5256"
+       transform="translate(601.5744,207.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(633.63525,501.49239)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <g
+       id="g5488"
+       transform="translate(601.5744,407.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient5536);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path5490"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient5538);fill-opacity:1"
+         id="g5492">
+        <path
+           style="fill:url(#linearGradient5540);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5494"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5542);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5496"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5544);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path5498"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient5546);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5548);stroke-width:1.44734821pt"
+         id="rect5500"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient5550);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path5502"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient5552);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5504"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient5554);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect5506"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient5556);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5558);stroke-width:1.4649456pt"
+         id="rect5508"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient5560);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path5510"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g5512">
+        <path
+           style="fill:url(#linearGradient5562);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5514"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient5564);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5516"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient5566);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path5518"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient5568);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path5520"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient5570);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path5522"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient5572);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path5524"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient5574);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5526"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5528"><tspan
+           id="tspan5530">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5532"><tspan
+           id="tspan5534">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g6024"
+       transform="matrix(-1,0,0,1,900.16045,422.61731)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999">
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path6027"
+         d="M 60.545133,72.847539 C 65.294534,78.031101 68.316881,87.318315 75.00922,87.318316 C 81.485677,85.518467 82.349205,70.11177 83.212732,66.800051 C 75.872748,71.839624 68.316882,74.71938 60.545133,72.847539 z " />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#d20000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path6029"
+         d="M 31.546762,99.654209 C 31.156121,124.85047 95.78552,127.73183 95.62922,99.654209 C 97.174007,77.325462 86.068776,64.629762 83.309105,66.788232 C 81.907864,67.884209 81.387229,92.223995 71.919297,86.625353 C 67.316417,83.903554 62.167959,73.44849 59.915352,73.101625 C 56.516277,72.578221 50.007529,69.826123 44.029815,64.675414 C 42.461522,63.324094 32.076211,77.214403 31.546762,99.654209 z " />
+      <path
+         style="fill:url(#radialGradient2797);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2796"
+         d="M 43.53125,77.3125 C 40.353026,86.016409 37.202011,96.366079 40.377303,105.23542 C 48.984655,117.18204 66.049398,117.25223 79.222417,115.04972 C 88.094278,113.47345 96.636121,105.87972 94.744454,96.188658 C 94.751182,88.561019 93.319573,80.643142 89.09375,74.1875 C 87.954705,81.120157 85.706152,92.347929 76.686643,91.786583 C 66.841974,89.84774 65.058803,76.33878 54.747596,75.105769 C 49.945701,71.530053 45.566465,69.110698 43.783935,76.852875 L 43.53125,77.3125 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,0.997459,16.38124)"
+         style="fill:#efd7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path6032"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccccc"
+         id="path3720"
+         d="M 56.980881,5.8426527 C 39.420698,8.0166254 30.552872,16.206245 24.211446,49.532095 C 14.512196,98.076517 21.871677,115.5525 32.990311,115.56714 C 17.54932,102.40769 63.877625,86.740105 56.295103,44.070713 C 68.4508,48.712358 94.51097,54.349644 95.164349,41.718703 C 97.176702,29.219492 88.64173,4.4775042 56.980881,5.8426527 z " />
+      <path
+         style="fill:url(#linearGradient2789);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2164"
+         d="M 60.687242,45.028999 C 62.530882,55.403773 61.180052,64.151015 58.312242,71.685249 C 61.630122,73.07804 65.296862,73.904 69.155992,73.903999 C 83.975322,73.903999 95.981712,62.468019 95.999742,48.403999 C 88.357632,52.885439 70.244092,48.678277 60.687242,45.028999 z " />
+      <path
+         style="fill:url(#radialGradient2791);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2790"
+         d="M 52.174948,8.1325312 C 35.846775,12.141346 31.110158,30.475875 28.060647,44.840387 C 24.465246,64.767005 19.485139,85.90438 25.518698,105.82003 C 29.863591,114.87216 28.026452,106.52571 31.049538,102.11795 C 41.311249,87.323083 56.256862,73.307418 55.936774,53.886064 C 56.647391,49.398848 52.34734,38.640985 60.701717,42.254379 C 70.683443,45.202557 82.078811,49.011247 92.143698,44.632531 C 96.945103,37.45042 93.288237,27.137344 88.876323,20.399742 C 81.135092,8.5919962 65.300885,5.0194752 52.174948,8.1325312 z " />
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path699"
+       d="M 319.16674,325.66524 L 432.27399,313.12251 L 422.57906,332.08242 L 484.9028,325.95688 C 484.9028,325.95688 494.59773,306.41369 495.05931,306.41369 C 495.52148,306.41369 517.68079,331.79078 517.68079,331.79078 C 517.68079,331.79078 465.51355,358.33479 465.05197,358.33479 C 465.51355,358.91808 474.74689,339.66616 474.74689,339.37453 L 402.72705,345.79207 L 412.42255,326.24852 L 309.01023,338.4996 L 319.16674,325.66524 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999" />
+    <text
+       xml:space="preserve"
+       style="font-size:48px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont;font-stretch:normal;font-variant:normal;text-anchor:start;text-align:start;writing-mode:lr;line-height:125%"
+       x="140"
+       y="521.23737"
+       id="text7612"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999"><tspan
+         sodipodi:role="line"
+         id="tspan7614"
+         x="140"
+         y="521.23737">Server</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="763.75"
+       y="188.09448"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="35.529999"
+       inkscape:export-ydpi="35.529999"><tspan
+         sodipodi:role="line"
+         id="tspan7879"
+         x="763.75"
+         y="188.09448">bzr commit --local</tspan><tspan
+         sodipodi:role="line"
+         x="763.75"
+         y="228.09448"
+         id="tspan7922" /></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="801.4375"
+       y="609.46948"
+       id="text7881"
+       sodipodi:linespacing="100%"><tspan
+         sodipodi:role="line"
+         id="tspan7883"
+         x="801.4375"
+         y="609.46948">bzr unbind</tspan><tspan
+         sodipodi:role="line"
+         x="801.4375"
+         y="641.46948"
+         id="tspan8507">bzr commit</tspan><tspan
+         sodipodi:role="line"
+         x="801.4375"
+         y="673.46948"
+         id="tspan8511">bzr bind</tspan></text>
+    <g
+       id="g7903"
+       transform="translate(21.8125,50.285718)">
+      <path
+         transform="matrix(0.5652174,0,0,0.5909091,121.25465,81.649039)"
+         d="M 340 221.23734 A 32.857143 31.428572 0 1 1  274.28571,221.23734 A 32.857143 31.428572 0 1 1  340 221.23734 z"
+         sodipodi:ry="31.428572"
+         sodipodi:rx="32.857143"
+         sodipodi:cy="221.23734"
+         sodipodi:cx="307.14285"
+         id="path7897"
+         style="fill:#000000"
+         sodipodi:type="arc" />
+      <text
+         sodipodi:linespacing="125%"
+         id="text7899"
+         y="225.53198"
+         x="286.3125"
+         style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+         xml:space="preserve"><tspan
+           y="225.53198"
+           x="286.3125"
+           id="tspan7901"
+           sodipodi:role="line">1</tspan></text>
+    </g>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="351.375"
+       y="272.69269"
+       id="text7908"
+       sodipodi:linespacing="100%"><tspan
+         sodipodi:role="line"
+         id="tspan7910"
+         x="351.375"
+         y="272.69269">bzr checkout</tspan></text>
+    <g
+       id="g7912"
+       transform="translate(438.71429,-31.85714)">
+      <path
+         transform="matrix(0.5652174,0,0,0.5909091,121.25465,81.649039)"
+         d="M 340 221.23734 A 32.857143 31.428572 0 1 1  274.28571,221.23734 A 32.857143 31.428572 0 1 1  340 221.23734 z"
+         sodipodi:ry="31.428572"
+         sodipodi:rx="32.857143"
+         sodipodi:cy="221.23734"
+         sodipodi:cx="307.14285"
+         id="path7914"
+         style="fill:#000000"
+         sodipodi:type="arc" />
+      <text
+         sodipodi:linespacing="125%"
+         id="text7916"
+         y="225.53198"
+         x="286.3125"
+         style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+         xml:space="preserve"><tspan
+           y="225.53198"
+           x="286.3125"
+           id="tspan7918"
+           sodipodi:role="line">2</tspan></text>
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.58159733;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path8495"
+       d="M 530.64409,443.90791 L 411.93077,455.56731 L 422.10621,437.94266 L 356.69344,443.63682 C 356.69344,443.63682 346.51796,461.80368 346.0335,461.80368 C 345.54844,461.80368 322.2908,438.21377 322.2908,438.21377 C 322.2908,438.21377 377.0437,413.53911 377.52817,413.53911 C 377.0437,412.99691 367.35272,430.89301 367.35272,431.16411 L 442.94217,425.19852 L 432.76613,443.36572 L 541.30393,431.97742 L 530.64409,443.90791 z " />
+    <g
+       id="g8497"
+       transform="translate(446.57144,390.28572)">
+      <path
+         transform="matrix(0.5652174,0,0,0.5909091,121.25465,81.649039)"
+         d="M 340 221.23734 A 32.857143 31.428572 0 1 1  274.28571,221.23734 A 32.857143 31.428572 0 1 1  340 221.23734 z"
+         sodipodi:ry="31.428572"
+         sodipodi:rx="32.857143"
+         sodipodi:cy="221.23734"
+         sodipodi:cx="307.14285"
+         id="path8499"
+         style="fill:#000000"
+         sodipodi:type="arc" />
+      <text
+         sodipodi:linespacing="125%"
+         id="text8501"
+         y="225.53198"
+         x="286.3125"
+         style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+         xml:space="preserve"><tspan
+           y="225.53198"
+           x="286.3125"
+           id="tspan8503"
+           sodipodi:role="line">2</tspan></text>
+    </g>
+    <g
+       id="g8513"
+       transform="translate(59.142865,311.71429)">
+      <path
+         transform="matrix(0.5652174,0,0,0.5909091,121.25465,81.649039)"
+         d="M 340 221.23734 A 32.857143 31.428572 0 1 1  274.28571,221.23734 A 32.857143 31.428572 0 1 1  340 221.23734 z"
+         sodipodi:ry="31.428572"
+         sodipodi:rx="32.857143"
+         sodipodi:cy="221.23734"
+         sodipodi:cx="307.14285"
+         id="path8515"
+         style="fill:#000000"
+         sodipodi:type="arc" />
+      <text
+         sodipodi:linespacing="125%"
+         id="text8517"
+         y="225.53198"
+         x="286.3125"
+         style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+         xml:space="preserve"><tspan
+           y="225.53198"
+           x="286.3125"
+           id="tspan8519"
+           sodipodi:role="line">3</tspan></text>
+    </g>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="389.375"
+       y="534.40698"
+       id="text8525"
+       sodipodi:linespacing="100%"><tspan
+         sodipodi:role="line"
+         id="tspan8527"
+         x="389.375"
+         y="534.40698">bzr commit</tspan></text>
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/images/workflows_peer.png'
Binary files doc/ja/user-guide/images/workflows_peer.png and doc/ja/user-guide/images/workflows_peer.png differ
=== added file 'doc/ja/user-guide/images/workflows_peer.svg'
--- doc/ja/user-guide/images/workflows_peer.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_peer.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,1589 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_peer.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_peer.png"
+   inkscape:export-xdpi="90"
+   inkscape:export-ydpi="90">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient5536"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5540"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5542"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5544"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5546"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5548"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient5550"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5552"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5554"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient5556"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5558"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5562"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5566"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient5568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5570"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient5572"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5574"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="39.648127"
+       inkscape:collect="always"
+       id="radialGradient2797"
+       fy="101.92288"
+       fx="50.092871"
+       cy="102.70191"
+       cx="49.760482"
+       gradientTransform="scale(1.1222336,0.8910801)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="35.284406"
+       inkscape:collect="always"
+       id="radialGradient2791"
+       fy="32.061308"
+       fx="81.553592"
+       cy="33.402904"
+       cx="80.599566"
+       gradientTransform="scale(0.8352269,1.1972794)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="67.164412"
+       y1="53.505203"
+       xlink:href="#linearGradient4376"
+       x2="63.804663"
+       x1="64.786456"
+       inkscape:collect="always"
+       id="linearGradient2789"
+       gradientTransform="scale(1.1424512,0.8753109)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient9648"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient9646"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient9640">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop9642" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop9644" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1"
+     inkscape:cx="536.99132"
+     inkscape:cy="369.73871"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1759"
+     inkscape:window-height="875"
+     inkscape:window-x="0"
+     inkscape:window-y="25" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <g
+       id="g5256"
+       transform="translate(601.5744,309.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(541.63525,501.49239)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <g
+       id="g5488"
+       transform="translate(111.5744,317.66157)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient5536);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path5490"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient5538);fill-opacity:1"
+         id="g5492">
+        <path
+           style="fill:url(#linearGradient5540);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5494"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5542);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5496"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5544);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path5498"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient5546);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5548);stroke-width:1.44734821pt"
+         id="rect5500"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient5550);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path5502"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient5552);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5504"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient5554);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect5506"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient5556);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5558);stroke-width:1.4649456pt"
+         id="rect5508"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient5560);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path5510"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g5512">
+        <path
+           style="fill:url(#linearGradient5562);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5514"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient5564);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5516"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient5566);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path5518"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient5568);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path5520"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient5570);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path5522"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient5572);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path5524"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient5574);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5526"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5528"><tspan
+           id="tspan5530">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5532"><tspan
+           id="tspan5534">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g6024"
+       transform="matrix(-1,0,0,1,300.80614,215.0989)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path6027"
+         d="M 60.545133,72.847539 C 65.294534,78.031101 68.316881,87.318315 75.00922,87.318316 C 81.485677,85.518467 82.349205,70.11177 83.212732,66.800051 C 75.872748,71.839624 68.316882,74.71938 60.545133,72.847539 z " />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#d20000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path6029"
+         d="M 31.546762,99.654209 C 31.156121,124.85047 95.78552,127.73183 95.62922,99.654209 C 97.174007,77.325462 86.068776,64.629762 83.309105,66.788232 C 81.907864,67.884209 81.387229,92.223995 71.919297,86.625353 C 67.316417,83.903554 62.167959,73.44849 59.915352,73.101625 C 56.516277,72.578221 50.007529,69.826123 44.029815,64.675414 C 42.461522,63.324094 32.076211,77.214403 31.546762,99.654209 z " />
+      <path
+         style="fill:url(#radialGradient2797);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2796"
+         d="M 43.53125,77.3125 C 40.353026,86.016409 37.202011,96.366079 40.377303,105.23542 C 48.984655,117.18204 66.049398,117.25223 79.222417,115.04972 C 88.094278,113.47345 96.636121,105.87972 94.744454,96.188658 C 94.751182,88.561019 93.319573,80.643142 89.09375,74.1875 C 87.954705,81.120157 85.706152,92.347929 76.686643,91.786583 C 66.841974,89.84774 65.058803,76.33878 54.747596,75.105769 C 49.945701,71.530053 45.566465,69.110698 43.783935,76.852875 L 43.53125,77.3125 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,0.997459,16.38124)"
+         style="fill:#efd7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path6032"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccccc"
+         id="path3720"
+         d="M 56.980881,5.8426527 C 39.420698,8.0166254 30.552872,16.206245 24.211446,49.532095 C 14.512196,98.076517 21.871677,115.5525 32.990311,115.56714 C 17.54932,102.40769 63.877625,86.740105 56.295103,44.070713 C 68.4508,48.712358 94.51097,54.349644 95.164349,41.718703 C 97.176702,29.219492 88.64173,4.4775042 56.980881,5.8426527 z " />
+      <path
+         style="fill:url(#linearGradient2789);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2164"
+         d="M 60.687242,45.028999 C 62.530882,55.403773 61.180052,64.151015 58.312242,71.685249 C 61.630122,73.07804 65.296862,73.904 69.155992,73.903999 C 83.975322,73.903999 95.981712,62.468019 95.999742,48.403999 C 88.357632,52.885439 70.244092,48.678277 60.687242,45.028999 z " />
+      <path
+         style="fill:url(#radialGradient2791);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2790"
+         d="M 52.174948,8.1325312 C 35.846775,12.141346 31.110158,30.475875 28.060647,44.840387 C 24.465246,64.767005 19.485139,85.90438 25.518698,105.82003 C 29.863591,114.87216 28.026452,106.52571 31.049538,102.11795 C 41.311249,87.323083 56.256862,73.307418 55.936774,53.886064 C 56.647391,49.398848 52.34734,38.640985 60.701717,42.254379 C 70.683443,45.202557 82.078811,49.011247 92.143698,44.632531 C 96.945103,37.45042 93.288237,27.137344 88.876323,20.399742 C 81.135092,8.5919962 65.300885,5.0194752 52.174948,8.1325312 z " />
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path699"
+       d="M 357.16674,263.66524 L 470.27399,251.12251 L 460.57906,270.08242 L 522.9028,263.95688 C 522.9028,263.95688 532.59773,244.41369 533.05931,244.41369 C 533.52148,244.41369 555.68079,269.79078 555.68079,269.79078 C 555.68079,269.79078 503.51355,296.33479 503.05197,296.33479 C 503.51355,296.91808 512.74689,277.66616 512.74689,277.37453 L 440.72705,283.79207 L 450.42255,264.24852 L 347.01023,276.4996 L 357.16674,263.66524 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="635.5625"
+       y="201.21948"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan7879"
+         x="635.5625"
+         y="201.21948">bzr branch</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9548"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(318.85715,7.142853)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="601.71429"
+       y="199.52307"
+       id="text9550"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9552"
+         x="601.71429"
+         y="199.52307">2</tspan></text>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:2.49513507;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path9650"
+       d="M 426.28539,558.28183 L 482.38891,565.59894 L 477.58003,554.5382 L 508.49388,558.1117 C 508.49388,558.1117 513.30276,569.51271 513.53172,569.51271 C 513.76096,569.51271 524.75243,554.70834 524.75243,554.70834 C 524.75243,554.70834 498.87641,539.22321 498.64746,539.22321 C 498.87641,538.88294 503.45634,550.11403 503.45634,550.28417 L 467.73303,546.54033 L 472.54219,557.94156 L 421.24757,550.79458 L 426.28539,558.28183 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9652"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(-194.48896,372.41254)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="87.591393"
+       y="566.02826"
+       id="text9654"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9656"
+         x="87.591393"
+         y="566.02826">4</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="119.03906"
+       y="543.19232"
+       id="text9658"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9660"
+         x="119.03906"
+         y="543.19232">merge changes</tspan><tspan
+         sodipodi:role="line"
+         x="119.03906"
+         y="583.19232"
+         id="tspan2716">from peer</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2670"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(-187.14285,5.361605)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="94.539062"
+       y="198.97729"
+       id="text2672"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2674"
+         x="94.539062"
+         y="198.97729">1</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="129.5625"
+       y="195.43823"
+       id="text2676"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2678"
+         x="129.5625"
+         y="195.43823">start project</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2680"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(-20.189728,217.62723)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="261.83594"
+       y="411.22729"
+       id="text2682"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2684"
+         x="261.83594"
+         y="411.22729">3</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="294.51562"
+       y="388.40698"
+       id="text2686"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2688"
+         x="294.51562"
+         y="388.40698">record</tspan><tspan
+         sodipodi:role="line"
+         x="294.51562"
+         y="428.40698"
+         id="tspan2712">changes</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2690"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(321.8001,372.41254)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="603.88049"
+       y="566.02826"
+       id="text2692"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2694"
+         x="603.88049"
+         y="566.02826">4</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="635.32812"
+       y="543.19232"
+       id="text2696"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2698"
+         x="635.32812"
+         y="543.19232">merge changes</tspan><tspan
+         sodipodi:role="line"
+         x="635.32812"
+         y="583.19232"
+         id="tspan2718">from peer</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2700"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(462.85715,216.65848)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="744.88281"
+       y="410.25854"
+       id="text2702"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2704"
+         x="744.88281"
+         y="410.25854">3</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="777.5625"
+       y="387.43823"
+       id="text2706"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2708"
+         x="777.5625"
+         y="387.43823">record</tspan><tspan
+         sodipodi:role="line"
+         x="777.5625"
+         y="427.43823"
+         id="tspan2714">changes</tspan></text>
+    <path
+       inkscape:export-ydpi="41.964157"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_centralized.png"
+       d="M 515.71461,505.61603 L 459.61109,512.93314 L 464.41997,501.8724 L 433.50612,505.4459 C 433.50612,505.4459 428.69724,516.84691 428.46828,516.84691 C 428.23904,516.84691 417.24757,502.04254 417.24757,502.04254 C 417.24757,502.04254 443.12359,486.55741 443.35254,486.55741 C 443.12359,486.21714 438.54366,497.44823 438.54366,497.61837 L 474.26697,493.87453 L 469.45781,505.27576 L 520.75243,498.12878 L 515.71461,505.61603 z "
+       id="path2710"
+       sodipodi:nodetypes="cccccccccccc"
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:2.49513507;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1" />
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/images/workflows_pqm.png'
Binary files doc/ja/user-guide/images/workflows_pqm.png and doc/ja/user-guide/images/workflows_pqm.png differ
=== added file 'doc/ja/user-guide/images/workflows_pqm.svg'
--- doc/ja/user-guide/images/workflows_pqm.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_pqm.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,1794 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_pqm.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_pqm.png"
+   inkscape:export-xdpi="90"
+   inkscape:export-ydpi="90">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient5536"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5540"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5542"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5544"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5546"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5548"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient5550"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5552"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5554"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient5556"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5558"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5562"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5566"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient5568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5570"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient5572"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5574"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="39.648127"
+       inkscape:collect="always"
+       id="radialGradient2797"
+       fy="101.92288"
+       fx="50.092871"
+       cy="102.70191"
+       cx="49.760482"
+       gradientTransform="scale(1.1222336,0.8910801)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="35.284406"
+       inkscape:collect="always"
+       id="radialGradient2791"
+       fy="32.061308"
+       fx="81.553592"
+       cy="33.402904"
+       cx="80.599566"
+       gradientTransform="scale(0.8352269,1.1972794)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="67.164412"
+       y1="53.505203"
+       xlink:href="#linearGradient4376"
+       x2="63.804663"
+       x1="64.786456"
+       inkscape:collect="always"
+       id="linearGradient2789"
+       gradientTransform="scale(1.1424512,0.8753109)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient9648"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient9646"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient9640">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop9642" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop9644" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient7934"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       id="linearGradient1858">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop1859" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop1860" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1861">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop1862" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1863" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1864">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop1865" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1866" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1867">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop1868" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1869" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11180">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop11182" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop11184" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11174">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop11176" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop11178" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11168">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop11170" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop11172" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient11162">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop11164" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop11166" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1"
+     inkscape:cx="559.94128"
+     inkscape:cy="392.13154"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1416"
+     inkscape:window-height="825"
+     inkscape:window-x="0"
+     inkscape:window-y="25" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2791"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(562.85715,227.14285)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="844.88281"
+       y="420.74292"
+       id="text2793"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2795"
+         x="844.88281"
+         y="420.74292">3</tspan></text>
+    <g
+       inkscape:label="Layer 1"
+       id="g4996"
+       transform="matrix(0.331077,0,0,0.2676656,39.992157,230.68349)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <g
+         transform="matrix(2.674162,0,0,2.674162,-826.248,-323.8239)"
+         id="g6052">
+        <path
+           style="fill:#c7c7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:6.11299896;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="czcczzz"
+           id="path1306"
+           d="M 362.77592,187.283 C 360.50343,190.98677 361.20593,367.68763 364.14011,374.65173 C 366.46268,380.1642 441.02381,442.12988 444.93699,443.78694 C 495.35017,443.444 529.34176,425.0858 534.99109,415.38735 C 537.14042,403.1889 535.31621,215.19709 533.25552,211.25359 C 531.47859,207.85312 436.04893,173.6386 432.71615,172.86054 C 429.71763,172.16052 365.30189,183.1661 362.77592,187.283 z " />
+        <path
+           style="fill:#ffffff;fill-opacity:0.54385968;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path2066"
+           d="M 366.42857,190.93361 C 391.19048,201.4098 418.60601,218.30739 446.22506,231.64072 C 472.394,225.42153 510.2022,217.10972 529.24981,213.77639 C 504.726,221.39543 472.52022,228.51448 447.99641,236.13353 C 446.56784,293.51448 447.257,380.45861 445.82843,437.83956 C 445.11414,379.98242 443.14285,291.6479 442.42856,233.79075 C 415.99999,219.50504 390,206.64789 366.42857,190.93361 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path4356"
+           d="M 519.99794,379.97737 C 510.93834,392.99882 482.41849,399.43361 468.8726,394.16864 C 471.21835,393.5424 516.96143,380.96883 519.99794,379.97737 z " />
+        <g
+           transform="translate(2.035534,15.20712)"
+           id="g4374">
+          <path
+             style="fill:#ffffff;fill-opacity:0.39473685;fill-rule:evenodd;stroke:none;stroke-width:1.01199996;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="cccccc"
+             id="path4362"
+             d="M 471.29127,340.59039 L 513.55921,324.30516 C 517.9002,325.84805 517.04588,332.27818 517.04588,332.27818 L 510.46155,334.58088 C 510.46155,334.58088 501.26764,349.01224 484.93096,343.36795 C 484.93096,343.36795 472.7787,345.52605 471.29127,340.59039 z " />
+          <path
+             style="fill:#606060;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.11199999;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="ccccccc"
+             id="path2826"
+             d="M 471.66824,335.10501 C 485.70133,331.45482 499.73443,327.80464 513.76752,324.15445 C 514.30594,326.13864 514.34437,328.99782 513.50779,330.48201 C 511.36566,331.50652 507.10221,332.35425 504.96008,333.37876 C 498.80357,339.27354 493.45917,339.80363 483.65919,338.95243 C 479.87505,339.74603 476.0909,340.36284 472.30676,341.15644 C 471.15285,338.85897 470.82215,337.90248 471.66824,335.10501 z " />
+        </g>
+        <path
+           style="fill:#ffffff;fill-opacity:0.40350874;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccc"
+           id="path4423"
+           d="M 364.8671,189.69191 L 446.71991,235.61832 L 446.39149,441.00771 L 366.28132,373.53968 L 364.8671,189.69191 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5957"
+           d="M 515.24794,392.97737 C 505.81506,405.42036 486.94113,407.56087 476.3726,403.76831 C 478.1563,403.29212 512.93901,393.73127 515.24794,392.97737 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5959"
+           d="M 508.24794,405.72737 C 502.79158,413.09279 492.2492,415.37141 483.8726,412.49343 C 484.991,412.19485 506.80021,406.20008 508.24794,405.72737 z " />
+        <path
+           style="fill:#fcfcfc;fill-opacity:0.44298245;fill-rule:evenodd;stroke:none;stroke-width:0.31200001;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path5973"
+           d="M 522.875,227.86218 L 527.04289,228.4302 L 527.79289,326.56929 L 463.46862,344.54896 L 461.88388,339.34073 L 523.68934,322.86218 L 522.875,227.86218 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6026"
+           d="M 462.21967,264.23013 L 462.31434,266.99086 L 522.7929,249.54632 L 462.21967,264.23013 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6036"
+           d="M 461.33579,284.2059 L 461.43046,286.96663 L 521.90902,269.52209 L 461.33579,284.2059 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6038"
+           d="M 462.21967,302.64613 L 462.31434,305.40686 L 522.7929,287.96232 L 462.21967,302.64613 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6040"
+           d="M 462.21967,320.79868 L 462.31434,323.55941 L 522.7929,306.11487 L 462.21967,320.79868 z " />
+        <path
+           style="opacity:1;color:#000000;fill:none;fill-opacity:0.75;fill-rule:evenodd;stroke:#9e9e9e;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="ccc"
+           id="path5988"
+           d="M 522.55191,229.64344 L 462.03362,244.76045 L 462.53549,344.35813" />
+      </g>
+    </g>
+    <g
+       id="g5256"
+       transform="translate(601.5744,227.66157)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(593.63525,509.49239)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <g
+       id="g5488"
+       transform="translate(601.5744,417.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient5536);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path5490"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient5538);fill-opacity:1"
+         id="g5492">
+        <path
+           style="fill:url(#linearGradient5540);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5494"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5542);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5496"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5544);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path5498"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient5546);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5548);stroke-width:1.44734821pt"
+         id="rect5500"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient5550);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path5502"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient5552);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5504"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient5554);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect5506"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient5556);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5558);stroke-width:1.4649456pt"
+         id="rect5508"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient5560);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path5510"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g5512">
+        <path
+           style="fill:url(#linearGradient5562);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5514"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient5564);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5516"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient5566);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path5518"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient5568);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path5520"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient5570);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path5522"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient5572);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path5524"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient5574);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5526"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5528"><tspan
+           id="tspan5530">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5532"><tspan
+           id="tspan5534">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g6024"
+       transform="matrix(-1,0,0,1,874.16045,452.61731)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644">
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path6027"
+         d="M 60.545133,72.847539 C 65.294534,78.031101 68.316881,87.318315 75.00922,87.318316 C 81.485677,85.518467 82.349205,70.11177 83.212732,66.800051 C 75.872748,71.839624 68.316882,74.71938 60.545133,72.847539 z " />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#d20000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path6029"
+         d="M 31.546762,99.654209 C 31.156121,124.85047 95.78552,127.73183 95.62922,99.654209 C 97.174007,77.325462 86.068776,64.629762 83.309105,66.788232 C 81.907864,67.884209 81.387229,92.223995 71.919297,86.625353 C 67.316417,83.903554 62.167959,73.44849 59.915352,73.101625 C 56.516277,72.578221 50.007529,69.826123 44.029815,64.675414 C 42.461522,63.324094 32.076211,77.214403 31.546762,99.654209 z " />
+      <path
+         style="fill:url(#radialGradient2797);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2796"
+         d="M 43.53125,77.3125 C 40.353026,86.016409 37.202011,96.366079 40.377303,105.23542 C 48.984655,117.18204 66.049398,117.25223 79.222417,115.04972 C 88.094278,113.47345 96.636121,105.87972 94.744454,96.188658 C 94.751182,88.561019 93.319573,80.643142 89.09375,74.1875 C 87.954705,81.120157 85.706152,92.347929 76.686643,91.786583 C 66.841974,89.84774 65.058803,76.33878 54.747596,75.105769 C 49.945701,71.530053 45.566465,69.110698 43.783935,76.852875 L 43.53125,77.3125 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,0.997459,16.38124)"
+         style="fill:#efd7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path6032"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccccc"
+         id="path3720"
+         d="M 56.980881,5.8426527 C 39.420698,8.0166254 30.552872,16.206245 24.211446,49.532095 C 14.512196,98.076517 21.871677,115.5525 32.990311,115.56714 C 17.54932,102.40769 63.877625,86.740105 56.295103,44.070713 C 68.4508,48.712358 94.51097,54.349644 95.164349,41.718703 C 97.176702,29.219492 88.64173,4.4775042 56.980881,5.8426527 z " />
+      <path
+         style="fill:url(#linearGradient2789);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2164"
+         d="M 60.687242,45.028999 C 62.530882,55.403773 61.180052,64.151015 58.312242,71.685249 C 61.630122,73.07804 65.296862,73.904 69.155992,73.903999 C 83.975322,73.903999 95.981712,62.468019 95.999742,48.403999 C 88.357632,52.885439 70.244092,48.678277 60.687242,45.028999 z " />
+      <path
+         style="fill:url(#radialGradient2791);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2790"
+         d="M 52.174948,8.1325312 C 35.846775,12.141346 31.110158,30.475875 28.060647,44.840387 C 24.465246,64.767005 19.485139,85.90438 25.518698,105.82003 C 29.863591,114.87216 28.026452,106.52571 31.049538,102.11795 C 41.311249,87.323083 56.256862,73.307418 55.936774,53.886064 C 56.647391,49.398848 52.34734,38.640985 60.701717,42.254379 C 70.683443,45.202557 82.078811,49.011247 92.143698,44.632531 C 96.945103,37.45042 93.288237,27.137344 88.876323,20.399742 C 81.135092,8.5919962 65.300885,5.0194752 52.174948,8.1325312 z " />
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path699"
+       d="M 319.16674,325.66524 L 432.27399,313.12251 L 422.57906,332.08242 L 484.9028,325.95688 C 484.9028,325.95688 494.59773,306.41369 495.05931,306.41369 C 495.52148,306.41369 517.68079,331.79078 517.68079,331.79078 C 517.68079,331.79078 465.51355,358.33479 465.05197,358.33479 C 465.51355,358.91808 474.74689,339.66616 474.74689,339.37453 L 402.72705,345.79207 L 412.42255,326.24852 L 309.01023,338.4996 L 319.16674,325.66524 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:48px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="92.546875"
+       y="509.71948"
+       id="text7612"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan7614"
+         x="92.546875"
+         y="509.71948">Server</tspan><tspan
+         sodipodi:role="line"
+         x="92.546875"
+         y="569.71948"
+         id="tspan2803">(PQM)</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="359.5625"
+       y="261.21948"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan7879"
+         x="359.5625"
+         y="261.21948">bzr branch</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9548"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(42.857147,67.142853)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="325.71429"
+       y="259.52307"
+       id="text9550"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9552"
+         x="325.71429"
+         y="259.52307">1</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9554"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(558.85715,89.5491)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="841.25"
+       y="283.37573"
+       id="text9556"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9558"
+         x="841.25"
+         y="283.37573">2</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="874.89062"
+       y="264.32886"
+       id="text9566"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         x="874.89062"
+         y="264.32886"
+         id="tspan2788">make</tspan><tspan
+         sodipodi:role="line"
+         x="874.89062"
+         y="304.32886"
+         id="tspan2815">changes</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9652"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(449.56027,432.37723)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="732.41742"
+       y="625.97729"
+       id="text9654"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9656"
+         x="732.41742"
+         y="625.97729">4</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="768.26562"
+       y="622.23511"
+       id="text9658"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan9660"
+         x="768.26562"
+         y="622.23511">accept or reject</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="75.5625"
+       y="228.09448"
+       id="text2965"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2967"
+         x="75.5625"
+         y="228.09448">main branch</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="556.98438"
+       y="165.64139"
+       id="text2969"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2971"
+         x="556.98438"
+         y="165.64139">local branches</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:none;fill-opacity:1;stroke:#0000ff;stroke-width:5.00006151;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path4930"
+       sodipodi:cx="342"
+       sodipodi:cy="171.0945"
+       sodipodi:rx="66"
+       sodipodi:ry="35"
+       d="M 408 171.0945 A 66 35 0 1 1  276,171.0945 A 66 35 0 1 1  408 171.0945 z"
+       transform="matrix(1.9161749,0,0,1.0419298,-477.33182,37.826027)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <path
+       sodipodi:type="arc"
+       style="fill:none;fill-opacity:1;stroke:#0000ff;stroke-width:5.00006151;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path7839"
+       sodipodi:cx="342"
+       sodipodi:cy="171.0945"
+       sodipodi:rx="66"
+       sodipodi:ry="35"
+       d="M 408 171.0945 A 66 35 0 1 1  276,171.0945 A 66 35 0 1 1  408 171.0945 z"
+       transform="matrix(2.0657387,0,0,1.0382501,-36.482679,-19.544354)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <g
+       id="g11201"
+       transform="translate(224.98935,560.87966)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2488"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(44.857147,386.9866)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="327.71429"
+       y="580.60229"
+       id="text2490"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2492"
+         x="327.71429"
+         y="580.60229">5</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="363.5625"
+       y="577.76636"
+       id="text2494"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         id="tspan2496"
+         x="363.5625"
+         y="577.76636">request merge</tspan></text>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path2801"
+       d="M 530.83326,472.52373 L 417.72601,485.06646 L 427.42094,466.10655 L 365.0972,472.23209 C 365.0972,472.23209 355.40227,491.77528 354.94069,491.77528 C 354.47852,491.77528 332.31921,466.39819 332.31921,466.39819 C 332.31921,466.39819 384.48645,439.85418 384.94803,439.85418 C 384.48645,439.27089 375.25311,458.52281 375.25311,458.81444 L 447.27295,452.3969 L 437.57745,471.94045 L 540.98977,459.68937 L 530.83326,472.52373 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="878.89062"
+       y="396.40698"
+       id="text2811"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_manualpqm.png"
+       inkscape:export-xdpi="38.384644"
+       inkscape:export-ydpi="38.384644"><tspan
+         sodipodi:role="line"
+         x="878.89062"
+         y="396.40698"
+         id="tspan2813">request</tspan><tspan
+         sodipodi:role="line"
+         x="878.89062"
+         y="436.40698"
+         id="tspan2817">review</tspan></text>
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/images/workflows_shared.png'
Binary files doc/ja/user-guide/images/workflows_shared.png and doc/ja/user-guide/images/workflows_shared.png differ
=== added file 'doc/ja/user-guide/images/workflows_shared.svg'
--- doc/ja/user-guide/images/workflows_shared.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_shared.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,1594 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_shared.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_shared.png"
+   inkscape:export-xdpi="49.419998"
+   inkscape:export-ydpi="49.419998">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="radialGradient5536"
+       gradientUnits="userSpaceOnUse"
+       cx="42.007257"
+       cy="39.007645"
+       fx="42.280806"
+       fy="39.410465"
+       r="11.574221" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5540"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5542"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5544"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5546"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="25.220815"
+       y1="178.48862"
+       x2="25.220815"
+       y2="234.26866" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5548"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       x1="51.460928"
+       y1="269.85831"
+       x2="-16.224496"
+       y2="176.28694" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient893"
+       id="linearGradient5550"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1870691,0.842411)"
+       x1="146.69923"
+       y1="224.57898"
+       x2="74.533693"
+       y2="81.477602" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5552"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       x1="45.685757"
+       y1="110.4447"
+       x2="41.967061"
+       y2="232.24952" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5554"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       x1="-77.726178"
+       y1="208.43991"
+       x2="95.644441"
+       y2="11.699047" />
+    <radialGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1133"
+       id="radialGradient5556"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       cx="60.004654"
+       cy="56.485935"
+       fx="72.107883"
+       fy="39.288476"
+       r="68.589222" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5558"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       x1="92.437968"
+       y1="-3.9104078"
+       x2="27.674331"
+       y2="91.07699" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5560"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       x1="39.810948"
+       y1="90.197025"
+       x2="17.876529"
+       y2="113.71949" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5562"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.329144,0.7523639)"
+       x1="39.690614"
+       y1="49.507656"
+       x2="70.224305"
+       y2="20.481863" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5564"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       x1="35.190362"
+       y1="76.277559"
+       x2="8.346058"
+       y2="105.42543" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient888"
+       id="linearGradient5566"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       x1="141.60217"
+       y1="228.39311"
+       x2="88.447016"
+       y2="133.54711" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient902"
+       id="linearGradient5568"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       x1="101.10657"
+       y1="177.77768"
+       x2="95.100155"
+       y2="173.03153" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5570"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       x1="88.755695"
+       y1="169.09755"
+       x2="88.996957"
+       y2="182.99154" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1317"
+       id="linearGradient5572"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.223869,0.8170809)"
+       x1="111.49758"
+       y1="131.25248"
+       x2="107.04918"
+       y2="148.78619" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient892"
+       id="linearGradient5574"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       x1="31.449743"
+       y1="203.499"
+       x2="31.617281"
+       y2="251.21892" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="39.648127"
+       inkscape:collect="always"
+       id="radialGradient2797"
+       fy="101.92288"
+       fx="50.092871"
+       cy="102.70191"
+       cx="49.760482"
+       gradientTransform="scale(1.1222336,0.8910801)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="35.284406"
+       inkscape:collect="always"
+       id="radialGradient2791"
+       fy="32.061308"
+       fx="81.553592"
+       cy="33.402904"
+       cx="80.599566"
+       gradientTransform="scale(0.8352269,1.1972794)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="67.164412"
+       y1="53.505203"
+       xlink:href="#linearGradient4376"
+       x2="63.804663"
+       x1="64.786456"
+       inkscape:collect="always"
+       id="linearGradient2789"
+       gradientTransform="scale(1.1424512,0.8753109)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient9648"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient9646"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient9640">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop9642" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop9644" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="0.8"
+     inkscape:cx="578.40513"
+     inkscape:cy="404.22798"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1405"
+     inkscape:window-height="869"
+     inkscape:window-x="0"
+     inkscape:window-y="25" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <g
+       inkscape:label="Layer 1"
+       id="g4996"
+       transform="matrix(0.331077,0,0,0.2676656,75.992157,230.68349)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192">
+      <g
+         transform="matrix(2.674162,0,0,2.674162,-826.248,-323.8239)"
+         id="g6052">
+        <path
+           style="fill:#c7c7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:6.11299896;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="czcczzz"
+           id="path1306"
+           d="M 362.77592,187.283 C 360.50343,190.98677 361.20593,367.68763 364.14011,374.65173 C 366.46268,380.1642 441.02381,442.12988 444.93699,443.78694 C 495.35017,443.444 529.34176,425.0858 534.99109,415.38735 C 537.14042,403.1889 535.31621,215.19709 533.25552,211.25359 C 531.47859,207.85312 436.04893,173.6386 432.71615,172.86054 C 429.71763,172.16052 365.30189,183.1661 362.77592,187.283 z " />
+        <path
+           style="fill:#ffffff;fill-opacity:0.54385968;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path2066"
+           d="M 366.42857,190.93361 C 391.19048,201.4098 418.60601,218.30739 446.22506,231.64072 C 472.394,225.42153 510.2022,217.10972 529.24981,213.77639 C 504.726,221.39543 472.52022,228.51448 447.99641,236.13353 C 446.56784,293.51448 447.257,380.45861 445.82843,437.83956 C 445.11414,379.98242 443.14285,291.6479 442.42856,233.79075 C 415.99999,219.50504 390,206.64789 366.42857,190.93361 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path4356"
+           d="M 519.99794,379.97737 C 510.93834,392.99882 482.41849,399.43361 468.8726,394.16864 C 471.21835,393.5424 516.96143,380.96883 519.99794,379.97737 z " />
+        <g
+           transform="translate(2.035534,15.20712)"
+           id="g4374">
+          <path
+             style="fill:#ffffff;fill-opacity:0.39473685;fill-rule:evenodd;stroke:none;stroke-width:1.01199996;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="cccccc"
+             id="path4362"
+             d="M 471.29127,340.59039 L 513.55921,324.30516 C 517.9002,325.84805 517.04588,332.27818 517.04588,332.27818 L 510.46155,334.58088 C 510.46155,334.58088 501.26764,349.01224 484.93096,343.36795 C 484.93096,343.36795 472.7787,345.52605 471.29127,340.59039 z " />
+          <path
+             style="fill:#606060;fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:1.11199999;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+             sodipodi:nodetypes="ccccccc"
+             id="path2826"
+             d="M 471.66824,335.10501 C 485.70133,331.45482 499.73443,327.80464 513.76752,324.15445 C 514.30594,326.13864 514.34437,328.99782 513.50779,330.48201 C 511.36566,331.50652 507.10221,332.35425 504.96008,333.37876 C 498.80357,339.27354 493.45917,339.80363 483.65919,338.95243 C 479.87505,339.74603 476.0909,340.36284 472.30676,341.15644 C 471.15285,338.85897 470.82215,337.90248 471.66824,335.10501 z " />
+        </g>
+        <path
+           style="fill:#ffffff;fill-opacity:0.40350874;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccccc"
+           id="path4423"
+           d="M 364.8671,189.69191 L 446.71991,235.61832 L 446.39149,441.00771 L 366.28132,373.53968 L 364.8671,189.69191 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5957"
+           d="M 515.24794,392.97737 C 505.81506,405.42036 486.94113,407.56087 476.3726,403.76831 C 478.1563,403.29212 512.93901,393.73127 515.24794,392.97737 z " />
+        <path
+           style="fill:#000000;fill-opacity:0.16228069;fill-rule:evenodd;stroke:none;stroke-width:0.25pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
+           sodipodi:nodetypes="ccc"
+           id="path5959"
+           d="M 508.24794,405.72737 C 502.79158,413.09279 492.2492,415.37141 483.8726,412.49343 C 484.991,412.19485 506.80021,406.20008 508.24794,405.72737 z " />
+        <path
+           style="fill:#fcfcfc;fill-opacity:0.44298245;fill-rule:evenodd;stroke:none;stroke-width:0.31200001;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+           sodipodi:nodetypes="ccccccc"
+           id="path5973"
+           d="M 522.875,227.86218 L 527.04289,228.4302 L 527.79289,326.56929 L 463.46862,344.54896 L 461.88388,339.34073 L 523.68934,322.86218 L 522.875,227.86218 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6026"
+           d="M 462.21967,264.23013 L 462.31434,266.99086 L 522.7929,249.54632 L 462.21967,264.23013 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6036"
+           d="M 461.33579,284.2059 L 461.43046,286.96663 L 521.90902,269.52209 L 461.33579,284.2059 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6038"
+           d="M 462.21967,302.64613 L 462.31434,305.40686 L 522.7929,287.96232 L 462.21967,302.64613 z " />
+        <path
+           style="opacity:1;color:#000000;fill:#000000;fill-opacity:0.22745098;fill-rule:evenodd;stroke:none;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:0.22807013;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="cccc"
+           id="path6040"
+           d="M 462.21967,320.79868 L 462.31434,323.55941 L 522.7929,306.11487 L 462.21967,320.79868 z " />
+        <path
+           style="opacity:1;color:#000000;fill:none;fill-opacity:0.75;fill-rule:evenodd;stroke:#9e9e9e;stroke-width:2.61199999;stroke-linecap:butt;stroke-linejoin:miter;marker:none;marker-start:none;marker-mid:none;marker-end:none;stroke-miterlimit:4;stroke-dasharray:none;stroke-dashoffset:0;stroke-opacity:1;visibility:visible;display:inline;overflow:visible;font-family:Bitstream Vera Sans"
+           sodipodi:nodetypes="ccc"
+           id="path5988"
+           d="M 522.55191,229.64344 L 462.03362,244.76045 L 462.53549,344.35813" />
+      </g>
+    </g>
+    <g
+       id="g5256"
+       transform="translate(601.5744,207.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(633.63525,501.49239)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <g
+       id="g5488"
+       transform="translate(601.5744,407.49165)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient5536);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path5490"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient5538);fill-opacity:1"
+         id="g5492">
+        <path
+           style="fill:url(#linearGradient5540);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5494"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5542);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path5496"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5544);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path5498"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient5546);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5548);stroke-width:1.44734821pt"
+         id="rect5500"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient5550);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path5502"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient5552);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5504"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient5554);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect5506"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient5556);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient5558);stroke-width:1.4649456pt"
+         id="rect5508"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient5560);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path5510"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g5512">
+        <path
+           style="fill:url(#linearGradient5562);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5514"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient5564);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path5516"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient5566);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path5518"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient5568);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path5520"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient5570);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path5522"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient5572);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path5524"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient5574);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path5526"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5528"><tspan
+           id="tspan5530">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text5532"><tspan
+           id="tspan5534">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g6024"
+       transform="matrix(-1,0,0,1,900.16045,422.61731)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192">
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path6027"
+         d="M 60.545133,72.847539 C 65.294534,78.031101 68.316881,87.318315 75.00922,87.318316 C 81.485677,85.518467 82.349205,70.11177 83.212732,66.800051 C 75.872748,71.839624 68.316882,74.71938 60.545133,72.847539 z " />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#d20000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path6029"
+         d="M 31.546762,99.654209 C 31.156121,124.85047 95.78552,127.73183 95.62922,99.654209 C 97.174007,77.325462 86.068776,64.629762 83.309105,66.788232 C 81.907864,67.884209 81.387229,92.223995 71.919297,86.625353 C 67.316417,83.903554 62.167959,73.44849 59.915352,73.101625 C 56.516277,72.578221 50.007529,69.826123 44.029815,64.675414 C 42.461522,63.324094 32.076211,77.214403 31.546762,99.654209 z " />
+      <path
+         style="fill:url(#radialGradient2797);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2796"
+         d="M 43.53125,77.3125 C 40.353026,86.016409 37.202011,96.366079 40.377303,105.23542 C 48.984655,117.18204 66.049398,117.25223 79.222417,115.04972 C 88.094278,113.47345 96.636121,105.87972 94.744454,96.188658 C 94.751182,88.561019 93.319573,80.643142 89.09375,74.1875 C 87.954705,81.120157 85.706152,92.347929 76.686643,91.786583 C 66.841974,89.84774 65.058803,76.33878 54.747596,75.105769 C 49.945701,71.530053 45.566465,69.110698 43.783935,76.852875 L 43.53125,77.3125 z " />
+      <path
+         transform="matrix(0.440859,0,0,0.441062,0.997459,16.38124)"
+         style="fill:#efd7c7;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path6032"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         transform="translate(2.509562,-4.432856e-2)"
+         style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccccc"
+         id="path3720"
+         d="M 56.980881,5.8426527 C 39.420698,8.0166254 30.552872,16.206245 24.211446,49.532095 C 14.512196,98.076517 21.871677,115.5525 32.990311,115.56714 C 17.54932,102.40769 63.877625,86.740105 56.295103,44.070713 C 68.4508,48.712358 94.51097,54.349644 95.164349,41.718703 C 97.176702,29.219492 88.64173,4.4775042 56.980881,5.8426527 z " />
+      <path
+         style="fill:url(#linearGradient2789);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2164"
+         d="M 60.687242,45.028999 C 62.530882,55.403773 61.180052,64.151015 58.312242,71.685249 C 61.630122,73.07804 65.296862,73.904 69.155992,73.903999 C 83.975322,73.903999 95.981712,62.468019 95.999742,48.403999 C 88.357632,52.885439 70.244092,48.678277 60.687242,45.028999 z " />
+      <path
+         style="fill:url(#radialGradient2791);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path2790"
+         d="M 52.174948,8.1325312 C 35.846775,12.141346 31.110158,30.475875 28.060647,44.840387 C 24.465246,64.767005 19.485139,85.90438 25.518698,105.82003 C 29.863591,114.87216 28.026452,106.52571 31.049538,102.11795 C 41.311249,87.323083 56.256862,73.307418 55.936774,53.886064 C 56.647391,49.398848 52.34734,38.640985 60.701717,42.254379 C 70.683443,45.202557 82.078811,49.011247 92.143698,44.632531 C 96.945103,37.45042 93.288237,27.137344 88.876323,20.399742 C 81.135092,8.5919962 65.300885,5.0194752 52.174948,8.1325312 z " />
+    </g>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.63842154;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path699"
+       d="M 319.16674,325.66524 L 432.27399,313.12251 L 422.57906,332.08242 L 484.9028,325.95688 C 484.9028,325.95688 494.59773,306.41369 495.05931,306.41369 C 495.52148,306.41369 517.68079,331.79078 517.68079,331.79078 C 517.68079,331.79078 465.51355,358.33479 465.05197,358.33479 C 465.51355,358.91808 474.74689,339.66616 474.74689,339.37453 L 402.72705,345.79207 L 412.42255,326.24852 L 309.01023,338.4996 L 319.16674,325.66524 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192" />
+    <text
+       xml:space="preserve"
+       style="font-size:48px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont;font-stretch:normal;font-variant:normal;text-anchor:start;text-align:start;writing-mode:lr;line-height:125%"
+       x="140"
+       y="521.23737"
+       id="text7612"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan7614"
+         x="140"
+         y="521.23737">Server</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="359.5625"
+       y="261.21948"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan7879"
+         x="359.5625"
+         y="261.21948">bzr branch</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9548"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(42.857147,67.142853)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="325.71429"
+       y="259.52307"
+       id="text9550"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan9552"
+         x="325.71429"
+         y="259.52307">1</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9554"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(492.85715,-2.8571472)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="777.71429"
+       y="191.52307"
+       id="text9556"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan9558"
+         x="777.71429"
+         y="191.52307">2</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="819.5625"
+       y="179.59448"
+       id="text9566"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan9568"
+         x="819.5625"
+         y="179.59448">bzr pull</tspan><tspan
+         sodipodi:role="line"
+         x="819.5625"
+         y="219.59448"
+         id="tspan2963">bzr merge</tspan></text>
+    <path
+       style="fill:none;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:4.29065037;stroke-linecap:butt;stroke-linejoin:round;stroke-dasharray:none;stroke-opacity:1"
+       sodipodi:nodetypes="cccccccccccc"
+       id="path9650"
+       d="M 539.95542,466.93556 L 415.85387,476.71718 L 426.49116,461.93102 L 358.1094,466.70812 C 358.1094,466.70812 347.47211,481.94916 346.96566,481.94916 C 346.45858,481.94916 322.14533,462.15846 322.14533,462.15846 C 322.14533,462.15846 379.38334,441.45772 379.88978,441.45772 C 379.38334,441.00284 369.25249,456.01673 369.25249,456.24417 L 448.27282,451.23935 L 437.63489,466.48068 L 551.09912,456.92649 L 539.95542,466.93556 z "
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192" />
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9652"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(51.511043,348.5966)"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="334.36819"
+       y="540.97681"
+       id="text9654"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan9656"
+         x="334.36819"
+         y="540.97681">3</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="369.5625"
+       y="544.09448"
+       id="text9658"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan9660"
+         x="369.5625"
+         y="544.09448">bzr commit</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="61.5625"
+       y="240.09448"
+       id="text2965"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan2967"
+         x="61.5625"
+         y="240.09448">main branch</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="563.43756"
+       y="582.09442"
+       id="text2969"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="C:\devel\public_html\gigo-ice.org\scm\bazaar\wiki\workflows_shared.png"
+       inkscape:export-xdpi="42.227192"
+       inkscape:export-ydpi="42.227192"><tspan
+         sodipodi:role="line"
+         id="tspan2971"
+         x="563.43756"
+         y="582.09442">local branches</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:none;fill-opacity:1;stroke:#0000ff;stroke-width:5.00006169;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path4930"
+       sodipodi:cx="342"
+       sodipodi:cy="171.0945"
+       sodipodi:rx="66"
+       sodipodi:ry="35"
+       d="M 408 171.0945 A 66 35 0 1 1  276,171.0945 A 66 35 0 1 1  408 171.0945 z"
+       transform="matrix(1.9161749,0,0,1.0419298,-501.33182,49.826027)" />
+    <path
+       sodipodi:type="arc"
+       style="fill:none;fill-opacity:1;stroke:#0000ff;stroke-width:5.00006151;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+       id="path7839"
+       sodipodi:cx="342"
+       sodipodi:cy="171.0945"
+       sodipodi:rx="66"
+       sodipodi:ry="35"
+       d="M 408 171.0945 A 66 35 0 1 1  276,171.0945 A 66 35 0 1 1  408 171.0945 z"
+       transform="matrix(2.1405493,0,0,1.0364644,-57.067817,396.76108)" />
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/images/workflows_single.png'
Binary files doc/ja/user-guide/images/workflows_single.png and doc/ja/user-guide/images/workflows_single.png differ
=== added file 'doc/ja/user-guide/images/workflows_single.svg'
--- doc/ja/user-guide/images/workflows_single.svg	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/images/workflows_single.svg	2009-10-29 10:01:19 +0000
@@ -0,0 +1,1079 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<!-- Created with Inkscape (http://www.inkscape.org/) -->
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://web.resource.org/cc/"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:xlink="http://www.w3.org/1999/xlink"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="1052.3622"
+   height="744.09448"
+   id="svg2"
+   sodipodi:version="0.32"
+   inkscape:version="0.45.1"
+   version="1.0"
+   sodipodi:docbase="/home/ian/Desktop/talk/workflows"
+   sodipodi:docname="workflows_single.svg"
+   inkscape:output_extension="org.inkscape.output.svg.inkscape"
+   inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+   inkscape:export-xdpi="90"
+   inkscape:export-ydpi="90">
+  <defs
+     id="defs4">
+    <radialGradient
+       xlink:href="#linearGradient5992"
+       r="33.156250"
+       inkscape:collect="always"
+       id="radialGradient6000"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="matrix(1.000000,0.000000,0.000000,1.693685,0.000000,-197.9515)"
+       fy="285.36218"
+       fx="495.50000"
+       cy="285.36218"
+       cx="495.50000" />
+    <linearGradient
+       y2="187.57059"
+       y1="225.40080"
+       xlink:href="#linearGradient5963"
+       x2="458.91232"
+       x1="383.95898"
+       inkscape:collect="always"
+       id="linearGradient5969"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient3586">
+      <stop
+         style="stop-color:#000000;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop3588" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop3590" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5963">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5965" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5967" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       id="linearGradient5992">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1;"
+         offset="0"
+         id="stop5994" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0;"
+         offset="1"
+         id="stop5996" />
+    </linearGradient>
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient893"
+       x2="0.92957747"
+       x1="-2.3960868e-17"
+       id="linearGradient4284" />
+    <linearGradient
+       y2="-0.033519555"
+       y1="2.0837989"
+       xlink:href="#linearGradient893"
+       x2="0.99074072"
+       x1="-0.77314812"
+       id="linearGradient4283" />
+    <linearGradient
+       y2="1.8771822"
+       y1="-0.033741195"
+       xlink:href="#linearGradient902"
+       x2="0.48453596"
+       x1="0.47041038"
+       id="linearGradient2740"
+       gradientTransform="scale(0.997153,1.002855)" />
+    <linearGradient
+       y2="1.9025002"
+       y1="-0.043652620"
+       xlink:href="#linearGradient902"
+       x2="0.48481107"
+       x1="0.47042510"
+       id="linearGradient1506"
+       gradientTransform="scale(0.995847,1.004170)" />
+    <linearGradient
+       y2="1.8570156"
+       y1="-0.024853170"
+       xlink:href="#linearGradient902"
+       x2="0.48548824"
+       x1="0.47157744"
+       id="linearGradient1505"
+       gradientTransform="scale(0.997825,1.002180)" />
+    <linearGradient
+       y2="182.99154"
+       y1="169.09755"
+       xlink:href="#linearGradient892"
+       x2="88.996957"
+       x1="88.755695"
+       id="linearGradient1404"
+       gradientTransform="scale(1.3695887,0.7301462)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.34964636"
+       id="radialGradient1316"
+       fy="0.18269235"
+       fx="0.50352114"
+       cy="0.50000006"
+       cx="0.50000000" />
+    <radialGradient
+       xlink:href="#linearGradient1317"
+       r="0.41197181"
+       id="radialGradient1315"
+       fy="0.26666668"
+       fx="0.47535211"
+       cy="0.53333336"
+       cx="0.47887325" />
+    <linearGradient
+       y2="173.03153"
+       y1="177.77768"
+       xlink:href="#linearGradient902"
+       x2="95.100155"
+       x1="101.10657"
+       id="linearGradient1171"
+       gradientTransform="scale(1.3601783,0.7351977)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="1.8378206"
+       y1="-0.016295359"
+       xlink:href="#linearGradient902"
+       x2="0.48655096"
+       x1="0.47284532"
+       id="linearGradient1170"
+       gradientTransform="scale(0.998371,1.001632)" />
+    <linearGradient
+       y2="81.477602"
+       y1="224.57898"
+       xlink:href="#linearGradient893"
+       x2="74.533693"
+       x1="146.69923"
+       id="linearGradient1169"
+       gradientTransform="scale(1.1870691,0.842411)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="133.54711"
+       y1="228.39311"
+       xlink:href="#linearGradient888"
+       x2="88.447016"
+       x1="141.60217"
+       id="linearGradient1167"
+       gradientTransform="scale(1.1838753,0.8446836)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="148.78619"
+       y1="131.25248"
+       xlink:href="#linearGradient1317"
+       x2="107.04918"
+       x1="111.49758"
+       id="linearGradient1166"
+       gradientTransform="scale(1.223869,0.8170809)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="176.28694"
+       y1="269.85831"
+       xlink:href="#linearGradient888"
+       x2="-16.224496"
+       x1="51.460928"
+       id="linearGradient1157"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="234.26866"
+       y1="178.48862"
+       xlink:href="#linearGradient888"
+       x2="25.220815"
+       x1="25.220815"
+       id="linearGradient1156"
+       gradientTransform="scale(2.4217071,0.4129318)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="105.42543"
+       y1="76.277559"
+       xlink:href="#linearGradient892"
+       x2="8.346058"
+       x1="35.190362"
+       id="linearGradient1150"
+       gradientTransform="scale(1.3283861,0.7527932)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="20.481863"
+       y1="49.507656"
+       xlink:href="#linearGradient892"
+       x2="70.224305"
+       x1="39.690614"
+       id="linearGradient1148"
+       gradientTransform="scale(1.329144,0.7523639)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="113.71949"
+       y1="90.197025"
+       xlink:href="#linearGradient892"
+       x2="17.876529"
+       x1="39.810948"
+       id="linearGradient1146"
+       gradientTransform="scale(1.3207392,0.7571517)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="251.21892"
+       y1="203.499"
+       xlink:href="#linearGradient892"
+       x2="31.617281"
+       x1="31.449743"
+       id="linearGradient1144"
+       gradientTransform="scale(2.1051174,0.4750329)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="-0.45783132"
+       y1="3.3012049"
+       xlink:href="#linearGradient888"
+       x2="0.92957747"
+       x1="0.00000000"
+       id="linearGradient1141" />
+    <linearGradient
+       y2="232.24952"
+       y1="110.4447"
+       xlink:href="#linearGradient888"
+       x2="41.967061"
+       x1="45.685757"
+       id="linearGradient1140"
+       gradientTransform="scale(1.9102155,0.5235012)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="75.912531"
+       y1="375.92199"
+       xlink:href="#linearGradient1806"
+       x2="-268.25407"
+       x1="-249.72067"
+       id="linearGradient1138"
+       gradientTransform="scale(1.087146,0.9198397)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient1133"
+       r="68.589222"
+       id="radialGradient1132"
+       fy="39.288476"
+       fx="72.107883"
+       cy="56.485935"
+       cx="60.004654"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="11.699047"
+       y1="208.43991"
+       xlink:href="#linearGradient888"
+       x2="95.644441"
+       x1="-77.726178"
+       id="linearGradient905"
+       gradientTransform="scale(1.0964158,0.9120627)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       xlink:href="#linearGradient1806"
+       id="linearGradient901" />
+    <linearGradient
+       y2="91.07699"
+       y1="-3.9104078"
+       xlink:href="#linearGradient888"
+       x2="27.674331"
+       x1="92.437968"
+       id="linearGradient891"
+       gradientTransform="scale(1.2267534,0.8151598)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient888">
+      <stop
+         style="stop-color:#626262;stop-opacity:1.0000000;"
+         offset="0.0000000"
+         id="stop889" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop890" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient892">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop893" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop894" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient902">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="0.00000000"
+         id="stop903" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.22000000;"
+         offset="1.0000000"
+         id="stop904" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1098">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1099" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.22314049;"
+         offset="0.50000000"
+         id="stop1101" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.00000000;"
+         offset="0.59930235"
+         id="stop1102" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.60330576;"
+         offset="1.0000000"
+         id="stop1100" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1133">
+      <stop
+         style="stop-color:#8bb7df;stop-opacity:1.0000000;"
+         offset="0.00000000"
+         id="stop1134" />
+      <stop
+         style="stop-color:#2a6092;stop-opacity:1.0000000;"
+         offset="0.76209301"
+         id="stop1136" />
+      <stop
+         style="stop-color:#375e82;stop-opacity:1.0000000;"
+         offset="1.0000000"
+         id="stop1135" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient1317">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52892560;"
+         offset="0.00000000"
+         id="stop1318" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.17355372;"
+         offset="0.50000000"
+         id="stop1320" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.00000000;"
+         offset="1.0000000"
+         id="stop1319" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient893">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop895" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop896" />
+    </linearGradient>
+    <radialGradient
+       xlink:href="#linearGradient1806"
+       r="11.574221"
+       id="radialGradient1977"
+       fy="39.410465"
+       fx="42.280806"
+       cy="39.007645"
+       cx="42.007257"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient1806">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.35051546;"
+         offset="0.0000000"
+         id="stop1807" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.13402061;"
+         offset="0.64999998"
+         id="stop3276" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop1808" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5281"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5283"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5285"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="5.5130484"
+       inkscape:collect="always"
+       id="radialGradient1828"
+       fy="61.38567"
+       fx="86.542037"
+       cy="61.38567"
+       cx="86.542037"
+       gradientTransform="matrix(-0.8164966,0,0,1.2247449,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="11.123441"
+       inkscape:collect="always"
+       id="radialGradient1824"
+       fy="58.887858"
+       fx="118.06427"
+       cy="58.54025"
+       cx="117.17439"
+       gradientTransform="matrix(-0.6229142,0,0,1.6053575,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="22.00904"
+       inkscape:collect="always"
+       id="radialGradient1822"
+       fy="87.892895"
+       fx="45.50637"
+       cy="88.322677"
+       cx="45.139623"
+       gradientTransform="matrix(-1.0914815,0,0,0.9161859,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <radialGradient
+       xlink:href="#linearGradient4362"
+       r="18.836343"
+       inkscape:collect="always"
+       id="radialGradient1818"
+       fy="33.351633"
+       fx="48.40165"
+       cy="32.467054"
+       cx="48.40165"
+       gradientTransform="matrix(-1.1146027,0,0,0.8971807,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       y2="74.834393"
+       y1="57.093738"
+       xlink:href="#linearGradient4376"
+       x2="50.203204"
+       x1="50.52668"
+       inkscape:collect="always"
+       id="linearGradient1815"
+       gradientTransform="matrix(-1.3516689,0,0,0.7398261,262.80373,-280)"
+       gradientUnits="userSpaceOnUse" />
+    <linearGradient
+       id="linearGradient4384">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop4385" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4386" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4376">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop4377" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4378" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4362">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop4363" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop4364" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient4358">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop4359" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop4360" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5538"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient5714"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       id="linearGradient6015">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.77513230;"
+         offset="0.0000000"
+         id="stop6017" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6019" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6009">
+      <stop
+         style="stop-color:#000000;stop-opacity:0.52645504;"
+         offset="0.0000000"
+         id="stop6011" />
+      <stop
+         style="stop-color:#000000;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6013" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient6003">
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.66666669;"
+         offset="0.0000000"
+         id="stop6005" />
+      <stop
+         style="stop-color:#ffffff;stop-opacity:0.0000000;"
+         offset="1.0000000"
+         id="stop6007" />
+    </linearGradient>
+    <linearGradient
+       id="linearGradient5997">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop5999" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop6001" />
+    </linearGradient>
+    <linearGradient
+       inkscape:collect="always"
+       xlink:href="#linearGradient1806"
+       id="linearGradient6037"
+       gradientUnits="userSpaceOnUse"
+       gradientTransform="scale(1.087146,0.9198397)"
+       x1="-249.72067"
+       y1="375.92199"
+       x2="-268.25407"
+       y2="75.912531" />
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient654"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient653"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient650">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop651" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop652" />
+    </linearGradient>
+    <linearGradient
+       y2="0.46093750"
+       y1="0.46093750"
+       xlink:href="#linearGradient650"
+       x2="1.16666818"
+       x1="1.22222710"
+       spreadMethod="repeat"
+       id="linearGradient9648"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       y2="0.53906250"
+       y1="0.53125000"
+       xlink:href="#linearGradient650"
+       x2="1.16666901"
+       x1="1.00000548"
+       spreadMethod="repeat"
+       id="linearGradient9646"
+       gradientUnits="objectBoundingBox" />
+    <linearGradient
+       id="linearGradient9640">
+      <stop
+         style="stop-color:#000;stop-opacity:1;"
+         offset="0"
+         id="stop9642" />
+      <stop
+         style="stop-color:#fff;stop-opacity:1;"
+         offset="1"
+         id="stop9644" />
+    </linearGradient>
+  </defs>
+  <sodipodi:namedview
+     id="base"
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1.0"
+     gridtolerance="10000"
+     guidetolerance="10"
+     objecttolerance="10"
+     inkscape:pageopacity="0.0"
+     inkscape:pageshadow="2"
+     inkscape:zoom="1.4142136"
+     inkscape:cx="536.99132"
+     inkscape:cy="529.01021"
+     inkscape:document-units="px"
+     inkscape:current-layer="layer1"
+     width="1052.3622px"
+     height="744.09448px"
+     showgrid="true"
+     inkscape:window-width="1465"
+     inkscape:window-height="896"
+     inkscape:window-x="0"
+     inkscape:window-y="25" />
+  <metadata
+     id="metadata7">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <g
+     inkscape:label="Layer 1"
+     inkscape:groupmode="layer"
+     id="layer1">
+    <g
+       id="g5256"
+       transform="translate(631.5744,227.66157)"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         transform="matrix(6.392368,0.545409,-0.130014,2.864752,-184.6606,-38.15109)"
+         style="fill:url(#radialGradient1977);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:type="arc"
+         sodipodi:ry="12.562782"
+         sodipodi:rx="12.562782"
+         sodipodi:cy="37.865574"
+         sodipodi:cx="41.875938"
+         id="path1976"
+         d="M 54.438721 37.865574 A 12.562782 12.562782 0 1 1  29.313156,37.865574 A 12.562782 12.562782 0 1 1  54.438721 37.865574 z" />
+      <g
+         transform="matrix(1,0,0,1.036969,356.8306,-11.4294)"
+         style="fill:url(#linearGradient6037);fill-opacity:1"
+         id="g4293">
+        <path
+           style="fill:url(#linearGradient5281);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2720"
+           d="M -270.85787,33.814995 C -289.35564,33.925992 -307.93321,33.592782 -326.38104,33.981747 C -331.43469,35.696391 -331.02221,41.899652 -330.68524,46.15332 C -330.75782,60.227303 -330.53537,74.298225 -330.21167,88.36826 C -328.21297,91.039611 -323.21766,90.618387 -322.68469,94.539015 C -320.78054,96.259426 -317.05071,94.88215 -314.4389,95.333237 C -298.54999,95.360274 -282.66107,95.387302 -266.77215,95.414339 C -266.35587,90.465192 -260.12609,88.824447 -255.81783,89.540255 C -256.01688,89.058389 -261.69557,87.939375 -259.61591,84.491525 C -259.45681,68.72727 -259.19734,52.882199 -259.82064,37.168229 C -261.19394,32.980583 -267.34179,33.83368 -270.85787,33.814995 z M -236.65184,97.260473 C -234.79025,100.12642 -237.08724,103.09386 -239.92892,104.16357 C -242.6311,105.91539 -245.59105,107.62992 -248.52894,108.76804 C -253.1773,108.19079 -251.42424,101.88475 -255.01281,99.896645 C -260.33594,96.447012 -267.21045,98.43943 -273.23329,97.939231 C -291.8249,97.94887 -310.41651,97.958519 -329.00813,97.968158 C -335.45898,103.56578 -339.16595,111.40269 -341.55034,119.32178 C -337.25147,124.2061 -329.89606,122.27575 -324.10438,122.40002 C -298.64553,122.23171 -273.11679,122.61546 -247.69897,122.24542 C -243.40174,121.14669 -247.44685,114.84894 -243.58488,113.04441 C -242.73865,112.73374 -247.81245,114.4382 -247.26205,111.62955 C -245.49117,106.66028 -239.14113,105.99595 -235.92338,102.36811 C -234.39131,99.755669 -236.26958,96.922488 -238.33047,95.260495 C -237.77093,95.927151 -237.21138,96.593817 -236.65184,97.260473 z M -240.64255,111.75263 C -243.64086,113.13223 -237.02792,110.69536 -235.55512,111.97369 C -229.71113,112.74417 -224.16461,117.19625 -218.12358,115.22951 C -225.97639,116.31604 -232.799,109.03014 -240.64255,111.75263 z M -212.01083,112.33724 C -215.98173,113.85021 -208.21543,112.17765 -210.07883,115.87566 C -212.50961,119.93855 -206.99008,113.8662 -209.61436,112.54677 C -210.16198,111.94632 -211.27989,112.47663 -212.01083,112.33724 z M -213.97451,120.82946 C -220.13871,124.32615 -228.37873,119.08124 -233.85995,124.39439 C -238.36465,128.00055 -244.57099,130.35185 -247.0433,135.75122 C -247.65922,139.60202 -243.25109,141.90251 -240.44565,143.71808 C -235.60127,146.54512 -228.8227,145.75388 -225.20082,141.42836 C -220.62679,137.96117 -216.44182,134.08489 -212.48592,129.96782 C -212.82701,126.95048 -214.43694,123.63971 -213.97451,120.82946 z " />
+        <path
+           style="fill:url(#linearGradient5283);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           id="path2723"
+           d="M -269.68453,32.256957 C -288.76965,32.351184 -307.87514,32.249603 -326.94796,32.349264 C -332.63884,33.663474 -333.90446,40.291305 -333.21597,45.149113 C -333.11996,59.896901 -333.07471,74.659754 -332.61729,89.39481 C -331.88583,93.310348 -324.86009,92.098674 -325.11097,96.44089 C -328.07184,96.184706 -331.5534,96.317135 -333.07248,99.246492 C -338.92562,104.98392 -341.99312,112.66465 -344.27268,120.28679 C -340.22572,125.96631 -332.26467,125.31453 -326.02946,124.71751 C -300.16629,124.7277 -274.28316,124.82043 -248.43245,124.77905 C -244.42424,124.78686 -243.30672,120.35609 -243.96666,117.2099 C -242.88598,112.93536 -237.04086,113.94554 -233.80717,114.98513 C -228.01851,116.64297 -221.26418,120.43074 -215.57982,116.37592 C -211.36091,113.71809 -213.05678,118.4029 -215.77936,119.43344 C -220.82539,122.25797 -227.09125,118.98178 -232.39677,121.20855 C -236.53238,123.88957 -240.74707,126.85249 -244.76678,129.74666 C -248.34219,132.01467 -251.90947,137.38626 -248.13747,140.97315 C -243.79274,146.02948 -236.37425,149.4527 -229.68248,147.08651 C -225.09383,144.85973 -221.79206,140.75401 -217.61535,137.88661 C -215.10454,135.69469 -212.49235,133.26839 -210.83749,130.50207 C -210.86477,126.92195 -214.68529,121.91303 -210.252,119.57013 C -207.25619,117.95208 -205.81053,112.12098 -209.75314,110.87946 C -214.16982,109.44692 -216.95156,115.09837 -221.43751,113.68608 C -228.47365,112.76758 -235.5565,107.20489 -242.69931,110.72434 C -246.89551,113.06547 -243.47174,109.4356 -241.45524,108.56544 C -237.85613,106.84628 -232.73147,104.36798 -233.94637,99.617708 C -234.27189,95.083838 -239.22223,93.197522 -242.95318,91.723135 C -247.61613,89.074942 -253.27003,89.345117 -258.06082,86.933298 C -257.89248,70.385101 -257.58805,53.76423 -258.26571,37.261116 C -259.2092,32.393288 -265.59824,31.96057 -269.68453,32.256957 z M -258.66259,91.764016 C -251.5059,92.239344 -243.21163,93.474137 -238.58238,99.271629 C -238.96251,103.06003 -244.00295,103.80224 -246.52821,106.14082 C -248.92267,108.48087 -251.12372,105.80503 -251.02958,103.27159 C -252.70852,98.336432 -258.20582,95.710815 -263.31841,96.533197 C -267.00561,96.7255 -263.71935,91.937514 -261.395,92.380192 C -260.48382,92.178338 -259.57521,91.953759 -258.66259,91.764016 z " />
+        <path
+           style="fill:url(#linearGradient5285);fill-opacity:1;stroke-width:1pt;font-family:helvetica"
+           sodipodi:nodetypes="ccccczccccccccccccccccccczccccc"
+           id="path2737"
+           d="M -324.0398,30.70877 C -336.3492,30.820231 -335.15663,39.652507 -334.79476,45.313268 C -334.5469,60.436643 -334.38614,75.599009 -334.01234,90.698281 C -333.20516,93.057424 -330.71249,93.985661 -328.75475,95.252079 C -334.4553,96.476239 -336.96996,102.43195 -340.11175,106.59303 C -342.33294,111.36531 -347.84019,115.92868 -345.92111,121.43642 C -344.00204,126.94416 -332.21757,127.68181 -324.95408,127.12866 C -299.06901,127.09789 -273.17022,127.14905 -247.29372,127.06713 C -243.29961,126.16956 -240.99668,122.03601 -241.4977,118.23645 C -238.30082,114.95371 -233.32521,118.03039 -229.53292,118.63002 C -225.71641,119.31313 -232.5646,119.27527 -233.19362,120.54849 C -238.23604,122.95799 -242.6166,126.65447 -246.90973,130.10509 C -250.44674,132.97354 -252.4229,138.10741 -249.57412,142.08235 C -246.21315,145.92284 -241.41489,148.84284 -236.30395,149.79628 C -230.65487,150.83779 -225.57101,147.82678 -221.6157,144.24077 C -216.87391,140.59839 -212.0873,136.78287 -208.84361,131.80554 C -207.76302,128.26399 -211.47449,123.86671 -208.08348,121.09796 C -204.93438,118.46115 -204.06893,113.02076 -207.41836,110.2673 C -212.81988,106.81278 -218.36682,114.55112 -223.89705,111.29128 C -227.94209,110.1659 -231.91311,108.52596 -236.17676,108.45194 C -231.52711,105.88023 -229.62903,98.782331 -234.08944,95.153402 C -239.61551,89.404431 -248.455,88.793917 -255.40182,85.744487 C -255.86992,78.940296 -255.53665,71.972758 -255.70928,65.098797 C -255.80747,55.730822 -255.73864,46.312632 -255.94025,36.975777 C -258.03631,31.236293 -265.34014,30.439522 -270.76286,30.729689 C -289.40725,30.770714 -311.88665,30.597309 -324.0398,30.70877 z M -255.46516,94.482857 C -250.34561,95.62106 -244.69322,96.21649 -240.83258,100.05203 C -242.37635,102.55028 -245.27573,103.64481 -247.80048,104.97505 C -249.71506,99.684643 -254.39847,94.970039 -260.51378,95.138259 C -260.66903,94.131274 -256.73261,94.551178 -255.46516,94.482857 z " />
+      </g>
+      <rect
+         y="78.658051"
+         x="33.326111"
+         width="57.567924"
+         style="fill:url(#linearGradient1156);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient1157);stroke-width:1.44734821pt"
+         id="rect1155"
+         height="8.3153667" />
+      <path
+         style="fill:url(#linearGradient1169);fill-rule:evenodd;stroke-width:0.90459263;stroke-opacity:0.07438019"
+         sodipodi:nodetypes="czzczczzzzzzzc"
+         id="path2676"
+         d="M 98.723806,78.927818 C 95.18666,77.759681 93.50122,82.555591 98.766686,81.004087 C 104.03217,79.452583 120.13123,85.906451 120.37383,89.795491 C 120.61643,93.905503 101.5003,98.581154 106.74108,104.42426 C 111.62816,110.70149 115.35468,100.13868 123.54696,104.21261 C 131.73923,108.17607 136.26048,109.72394 142.25488,104.94185 C 149.10027,101.9342 145.04599,107.07658 139.57918,113.60451 C 134.11237,120.13244 144.00251,115.08156 147.91225,105.31962 C 151.93248,95.557673 139.13128,107.33503 133.66268,105.40571 C 128.19408,103.47639 119.73678,97.849788 113.27625,102.55563 C 106.81572,107.26147 109.62894,99.493003 114.85637,97.90307 C 120.0838,96.092166 122.81363,93.045722 122.85597,90.161522 C 122.89831,87.498293 117.92629,84.811803 112.94229,82.402852 C 107.73732,79.993901 100.49788,78.588966 98.723806,78.927818 z " />
+      <path
+         style="fill:url(#linearGradient1140);fill-opacity:1;fill-rule:evenodd;stroke-width:1.44734821pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1139"
+         d="M 15.102732,106.80712 C 13.80355,109.23224 17.148847,113.52338 19.900059,113.52338 L 107.85106,113.52338 C 110.18914,113.52338 113.70766,110.4906 112.64839,108.40622 L 102.7339,88.897093 C 101.97024,87.394398 100.26184,86.65834 98.576216,86.65834 L 28.215425,86.658339 C 26.825434,86.658339 25.353768,87.671846 24.697385,88.897093 L 15.102732,106.80712 z " />
+      <rect
+         y="22.413721"
+         x="26.015469"
+         width="72.279724"
+         style="fill:url(#linearGradient905);fill-opacity:1;fill-rule:evenodd;stroke-width:1.62826681"
+         ry="5.4369707"
+         rx="5.4369707"
+         id="rect1137"
+         height="60.126495" />
+      <rect
+         y="31.695871"
+         x="33.386066"
+         width="58.178177"
+         style="fill:url(#radialGradient1132);fill-opacity:1;fill-rule:evenodd;stroke:url(#linearGradient891);stroke-width:1.4649456pt"
+         id="rect1131"
+         height="38.044163" />
+      <path
+         style="fill:url(#linearGradient1146);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzccccc"
+         id="path1145"
+         d="M 27.690431,52.841444 L 27.370609,74.749236 C 27.319624,78.241665 29.310209,80.477938 32.807578,80.506029 L 72.625393,80.825852 L 76.463254,71.87084 L 32.008024,71.55102 L 31.688202,52.681533 L 27.690431,52.841444 z " />
+      <g
+         transform="matrix(-1,0,0,1,125.4301,0)"
+         id="g1791">
+        <path
+           style="fill:url(#linearGradient1148);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1147"
+           d="M 42.062098,33.460351 L 77.341205,33.008055 C 82.787126,32.938235 89.553204,38.416797 89.553204,43.863165 L 89.553204,60.14583 L 41.609801,59.693534 L 42.062098,33.460351 z " />
+        <path
+           style="fill:url(#linearGradient1150);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+           sodipodi:nodetypes="czzccc"
+           id="path1149"
+           d="M 78.337784,67.629235 L 46.723745,67.724544 C 41.843589,67.739257 35.829319,62.771024 35.877168,57.891081 L 36.020221,43.301821 L 78.973514,44.128288 L 78.337784,67.629235 z " />
+      </g>
+      <path
+         style="fill:url(#linearGradient1167);fill-opacity:1;fill-rule:evenodd;stroke-width:0.72367412;stroke-opacity:0.34710741"
+         sodipodi:nodetypes="cczzzzzzc"
+         id="path1159"
+         d="M 137.39107,112.02341 C 137.39107,112.02341 129.0757,110.26438 123.63872,113.62251 C 118.20176,116.98064 109.96635,123.21719 108.76702,124.81628 C 107.40777,126.57531 107.42036,130.22796 109.24674,131.53253 L 114.84364,135.53031 C 118.31797,138.01198 124.86218,139.25396 128.11624,136.48978 L 142.98795,123.85681 C 144.79792,122.3193 145.72732,118.27921 144.10733,116.82073 C 142.95609,115.04975 140.4892,112.91939 137.39107,112.02341 z " />
+      <path
+         style="fill:url(#linearGradient1171);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzc"
+         id="path1160"
+         d="M 142.3483,121.13833 L 125.91043,133.59673 C 122.97154,135.82414 118.65484,134.11775 116.28283,133.77129 C 113.9108,133.42481 111.88528,131.87901 112.12516,132.33209 C 112.36503,132.78517 115.08349,135.71687 117.72203,136.48978 C 120.36055,137.26267 124.9543,138.89307 127.50953,136.15531 C 130.06477,133.41755 145.2267,123.53699 142.3483,121.13833 z " />
+      <path
+         style="fill:url(#linearGradient1404);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="cczc"
+         id="path1403"
+         d="M 132.11225,127.51984 C 135.31047,122.88242 120.11893,113.12786 109.08509,127.0401 C 110.20446,130.71805 116.80662,132.5992 121.82304,132.33547 C 126.68363,132.07993 129.50037,129.97181 132.11225,127.51984 z " />
+      <path
+         style="fill:url(#linearGradient1166);fill-opacity:1;fill-rule:evenodd;stroke-width:1.08551121"
+         sodipodi:nodetypes="cccccccc"
+         id="path1519"
+         d="M 138.63464,112.68306 C 135.9958,113.22749 132.31739,114.43079 129.87534,116.38362 C 128.77009,115.68011 125.32759,114.5677 123.66767,113.84494 L 123.24572,114.10517 C 129.67287,117.23476 136.43512,117.91249 135.88192,122.87668 C 136.33675,122.98575 137.05589,123.09702 136.73191,122.38863 C 136.41775,118.90392 132.50587,117.23351 131.02697,116.81532 C 133.17224,114.26602 136.255,113.70892 138.63464,112.68306 z " />
+      <path
+         style="fill:url(#linearGradient1144);fill-opacity:1;fill-rule:evenodd;stroke-width:1pt"
+         sodipodi:nodetypes="czzzzzzzz"
+         id="path1143"
+         d="M 18.891612,106.48414 C 17.978451,108.31614 19.173914,111.55774 22.263529,111.55774 L 105.0195,111.55774 C 106.66288,111.55774 109.13595,109.26672 108.39142,107.69215 L 101.42279,92.954575 C 100.88602,91.819403 99.685232,91.263378 98.500462,91.263378 L 28.108183,91.263369 C 27.131195,91.263369 26.0968,92.028994 25.635445,92.954575 L 18.891612,106.48414 z " />
+      <text
+         y="-14.660837"
+         xml:space="preserve"
+         x="6.147172"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1232"><tspan
+           id="tspan1233">Computer</tspan></text>
+      <text
+         y="-34.951134"
+         xml:space="preserve"
+         x="84.564949"
+         transform="scale(0.246729,0.246729)"
+         style="font-size:12px;font-style:normal;font-weight:normal;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1pt;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:helvetica"
+         id="text1235"><tspan
+           id="tspan1236">Created by Andrew Fitzsimon</tspan></text>
+    </g>
+    <g
+       id="g5474"
+       transform="translate(633.63525,501.49239)"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157">
+      <path
+         style="fill:#ffffff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path9383"
+         d="M 203.47051,-209.74941 C 198.72111,-204.56585 195.69876,-195.27863 189.00642,-195.27863 C 182.52997,-197.07848 181.66644,-212.48518 180.80291,-215.7969 C 188.1429,-210.75732 195.69876,-207.87757 203.47051,-209.74941 z " />
+      <path
+         transform="matrix(-0.440859,0,0,0.441062,265.52775,-266.17138)"
+         style="fill:#f1bb96;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:type="arc"
+         sodipodi:ry="57.825485"
+         sodipodi:rx="60.94183"
+         sodipodi:cy="70.290855"
+         sodipodi:cx="150.27701"
+         id="path3713"
+         d="M 211.21884 70.290855 A 60.94183 57.825485 0 1 1  89.335178,70.290855 A 60.94183 57.825485 0 1 1  211.21884 70.290855 z" />
+      <path
+         style="fill:#233e6a;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccssssc"
+         id="path4369"
+         d="M 232.46888,-182.94274 C 232.85952,-157.74648 168.23012,-154.86512 168.38642,-182.94274 C 166.84164,-205.27149 177.94687,-217.96719 180.70654,-215.80872 C 182.10778,-214.71274 182.62841,-190.37295 192.09635,-195.9716 C 196.69923,-198.69339 201.84768,-209.14846 204.10029,-209.49532 C 207.49937,-210.01873 214.00811,-212.77083 219.98583,-217.92153 C 221.55412,-219.27285 231.93943,-205.38255 232.46888,-182.94274 z " />
+      <path
+         style="fill:#513624;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path11309"
+         d="M 204.55432,-273.85152 C 222.46413,-271.53047 237.32676,-259.28175 231.38357,-231.42099 C 229.66954,-221.67743 222.12426,-217.60887 219.35537,-236.36962 C 211.4578,-233.88387 177.25785,-223.92576 170.54948,-241.26677 C 166.55631,-248.43407 174.86257,-276.23329 204.55432,-273.85152 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path11942"
+         d="M 191.92173,-167.75448 C 192.06919,-184.44566 194.18855,-193.73288 188.47558,-194.95709 C 182.9785,-195.85052 179.91138,-176.52634 179.04785,-173.21462 C 175.85958,-157.19769 189.53653,-154.44605 191.92173,-167.75448 z " />
+      <path
+         style="fill:url(#linearGradient1815);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:8.50416374;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1811"
+         d="M 172.67812,-237.76056 C 182.56217,-225.58826 212.09549,-234.15979 219.36562,-236.44806 C 220.33459,-229.88278 221.90014,-226.25074 223.58437,-224.54181 C 219.31219,-215.8234 210.06249,-209.76056 199.27187,-209.76056 C 184.44142,-209.76056 172.42812,-221.18201 172.42812,-235.26056 C 172.42812,-236.11869 172.59078,-236.92413 172.67812,-237.76056 z " />
+      <path
+         style="fill:url(#radialGradient1818);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1817"
+         d="M 203.17522,-273.74212 C 221.08504,-271.42107 235.94766,-259.17235 230.00448,-231.31159 C 228.29044,-221.56803 220.74517,-217.49946 217.97627,-236.26022 C 210.0787,-233.77447 175.87876,-223.81635 169.17039,-241.15737 C 165.17722,-248.32467 173.48348,-276.12389 203.17522,-273.74212 z " />
+      <path
+         style="fill:url(#radialGradient1822);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         id="path1819"
+         d="M 220.74123,-214.1875 C 227.87764,-203.73841 231.28831,-190.18836 229.45998,-177.71875 C 222.3997,-165.39834 205.93726,-163.52328 193.05373,-164.75 C 194.11526,-173.29796 194.69425,-182.39807 193.51876,-190.98978 C 191.02311,-195.41909 199.33209,-197.29913 200.39748,-201.6875 C 203.70655,-208.92744 212.80427,-208.10966 218.04988,-213.3696 C 218.9201,-213.57294 220.00051,-215.94141 220.74123,-214.1875 z M 179.55373,-210.28125 C 180.69974,-204.97453 181.23339,-199.24919 184.58498,-194.75 C 179.40159,-187.81847 178.05976,-178.63643 176.67873,-170.28125 C 167.10271,-177.01707 169.81568,-190.62142 172.02963,-200.39411 C 173.03008,-204.26346 176.36728,-212.34166 179.19382,-211.77772 C 179.27177,-211.45363 179.5117,-210.45598 179.55373,-210.28125 z " />
+      <path
+         style="fill:url(#radialGradient1824);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="cccc"
+         id="path1823"
+         d="M 192.35803,-167.43887 C 192.50549,-184.13006 194.62485,-193.41727 188.91188,-194.64149 C 183.4148,-195.53491 180.34768,-176.21073 179.48415,-172.89901 C 176.29589,-156.88208 189.97283,-154.13044 192.35803,-167.43887 z " />
+      <path
+         style="fill:#1f4eb3;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1825"
+         d="M 185.2414,-200.53324 C 185.2414,-197.95291 187.25802,-195.85872 189.74278,-195.85872 C 192.22755,-195.85872 194.24417,-197.95291 194.24417,-200.53324 C 194.24417,-203.11357 193.61259,-209.36288 191.12783,-209.36288 C 188.64306,-209.36288 185.2414,-203.11357 185.2414,-200.53324 z " />
+      <path
+         style="fill:url(#radialGradient1828);fill-opacity:1;fill-rule:evenodd;stroke:none;stroke-width:3.75;stroke-linecap:round;stroke-linejoin:round;stroke-miterlimit:4;stroke-opacity:1"
+         sodipodi:nodetypes="ccccc"
+         id="path1827"
+         d="M 186.28018,-201.05263 C 186.28018,-198.4723 188.2968,-196.37811 190.78156,-196.37811 C 193.26633,-196.37811 195.28295,-198.4723 195.28295,-201.05263 C 195.28295,-203.63296 194.65137,-209.88227 192.16661,-209.88227 C 189.68184,-209.88227 186.28018,-203.63296 186.28018,-201.05263 z " />
+    </g>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="345.5625"
+       y="218.05542"
+       id="text7877"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         x="345.5625"
+         y="218.05542"
+         id="tspan2399">create project</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9548"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(32.857147,24.174103)"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="314.53906"
+       y="217.78979"
+       id="text9550"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9552"
+         x="314.53906"
+         y="217.78979">1</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9554"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(33.388397,76.658478)"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="315.78125"
+       y="270.48511"
+       id="text9556"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9558"
+         x="315.78125"
+         y="270.48511">2</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="344.92188"
+       y="267.43823"
+       id="text9566"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9568"
+         x="344.92188"
+         y="267.43823">record changes</tspan></text>
+    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path9652"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(32.857147,128.5416)"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="314.88281"
+       y="322.14166"
+       id="text9654"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9656"
+         x="314.88281"
+         y="322.14166">3</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="346.9086"
+       y="319.32135"
+       id="text9658"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan9660"
+         x="346.9086"
+         y="319.32135">browse history</tspan></text>
+    <flowRoot
+       xml:space="preserve"
+       id="flowRoot2405"><flowRegion
+         id="flowRegion2407"><rect
+           id="rect2409"
+           width="274.35742"
+           height="94.045197"
+           x="293.44931"
+           y="485.2934" /></flowRegion><flowPara
+         id="flowPara2411"></flowPara></flowRoot>    <path
+       sodipodi:type="arc"
+       style="fill:#000000"
+       id="path2427"
+       sodipodi:cx="292.14285"
+       sodipodi:cy="181.95163"
+       sodipodi:rx="15"
+       sodipodi:ry="15"
+       d="M 307.14285 181.95163 A 15 15 0 1 1  277.14285,181.95163 A 15 15 0 1 1  307.14285 181.95163 z"
+       transform="translate(32.857147,180.5416)"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157" />
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffffff;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="314.9375"
+       y="374.15729"
+       id="text2429"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2431"
+         x="314.9375"
+         y="374.15729">4</tspan></text>
+    <text
+       xml:space="preserve"
+       style="font-size:32px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;font-family:aquafont"
+       x="346.9086"
+       y="371.32135"
+       id="text2433"
+       sodipodi:linespacing="125%"
+       inkscape:export-filename="/home/ian/Desktop/talk/workflows/workflows_single.png"
+       inkscape:export-xdpi="41.964157"
+       inkscape:export-ydpi="41.964157"><tspan
+         sodipodi:role="line"
+         id="tspan2435"
+         x="346.9086"
+         y="371.32135">package release</tspan></text>
+  </g>
+</svg>

=== added file 'doc/ja/user-guide/index.txt'
--- doc/ja/user-guide/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/index.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,140 @@
+####################
+Bazaarユーザーガイド
+####################
+
+.. Please mark sections in included files as following:
+..   level 1 ========
+..   level 2 --------
+..   level 3 ~~~~~~~~
+..   level 4 ^^^^^^^^ (it is better not to use nesting deeper than 3 levels)
+
+紹介
+#####
+
+.. toctree::
+   :maxdepth: 1
+
+   introducing_bazaar
+   core_concepts
+   bazaar_workflows
+
+
+始める
+#######
+
+.. toctree::
+   :maxdepth: 1
+
+   installing_bazaar
+   entering_commands
+   getting_help
+   configuring_bazaar
+   using_aliases
+   plugins
+   zen
+
+
+個人用途のバージョン管理
+#########################
+
+.. toctree::
+   :maxdepth: 1
+
+   solo_intro
+   starting_a_project
+   controlling_registration
+   reviewing_changes
+   recording_changes
+   browsing_history
+   releasing_a_project
+   undoing_mistakes
+
+
+同僚と共有する
+##############
+
+.. toctree::
+   :maxdepth: 1
+
+   partner_intro
+   branching_a_project
+   merging_changes
+   resolving_conflicts
+   annotating_changes
+
+
+集中スタイルの、チームコラボレーション
+#######################################
+
+.. toctree::
+   :maxdepth: 1
+
+   central_intro
+   publishing_a_branch
+   using_checkouts
+   working_offline_central
+   reusing_a_checkout
+
+
+分散スタイルの、チームコラボレーション
+#######################################
+
+.. toctree::
+   :maxdepth: 1
+
+   distributed_intro
+   organizing_branches
+   using_gatekeepers
+   sending_changes
+
+
+その他のトピック
+#################
+
+.. toctree::
+   :maxdepth: 1
+
+   part2_intro
+   adv_merging
+   shelving_changes
+   filtered_views
+   stacked
+   server
+   hooks
+   version_info
+
+
+人気のあるプラグインの手短なツアー
+####################################
+
+.. toctree::
+   :maxdepth: 1
+
+   bzrtools_plugin
+   svn_plugin
+
+
+Bazaarを環境に統合する
+#######################
+
+.. toctree::
+   :maxdepth: 1
+
+   web_browsing
+   bug_trackers
+
+
+付録
+#####
+
+.. toctree::
+   :maxdepth: 1
+
+   specifying_revisions
+   organizing_your_workspace
+   shared_repository_layouts
+   setting_up_email
+   http_smart_server
+   writing_a_plugin
+
+.. |--| unicode:: U+2014

=== added file 'doc/ja/user-guide/installing_bazaar.txt'
--- doc/ja/user-guide/installing_bazaar.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/installing_bazaar.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,101 @@
+Bazaarをインストールする
+=========================
+
+Linux
+-----
+
+BazaarのパッケージはUbuntu/Debian、Red HatとGentooを含む人気のある
+大抵のLinuxディストリビューションで利用できます。
+最新の手引きは http://bazaar-vcs.org/Download を参照してください。
+
+Windows
+-------
+
+Windowsユーザーは、Bazaarのコアパッケージと一緒に必要な前提要件と
+いくつかの便利なプラグインを含むインストーラが利用できます。
+最新の手引きは http://bazaar-vcs.org/Download を参照してください。
+
+注: Windows上でCygwinを動かしている場合、Cygwin用のBazaarパッケージを\
+Windows版の代わりに使わなければなりません。
+
+他のオペレーティングシステム
+-----------------------------
+
+BazaarのパッケージはLinuxとWindowsだけでなく、Mac OS X, FreeBSD, Solaris\
+を含む広い範囲のオペレーティングシステムで利用可能です。
+最新の手引きに関しては http://bazaar-vcs.org/Download を参照してください。
+
+
+ゼロからインストールする
+-------------------------
+
+予めビルドされたパッケージよりもソースからBazaarをビルドしたい場合、\
+手順は次のとおりです:
+
+  1. まだインストールしていなければ、バージョン2.4以降のPythonをインストールします。
+
+  2. http://bazaar-vcs.org/Download もしくはLaunchpad (https://launchpad.net/~bzr/)から
+     ``bazaar-xxx.tar.gz`` ファイル(xxxはバージョン番号)をダウンロードします。
+
+  3. tar、WinZipもしくは同等のコマンドを用いてアーカイブを解凍します。
+
+  4. 作成されたディレクトリをPATHに登録します。
+
+インストールが成功したことを確認するために、次のように **bzr** コマンドを試します::
+
+  bzr version
+
+このコマンドによってインストールされているBazaarのバージョンが表示されます。
+このコマンドが動作しない場合、開発者が正常な動作の手助けをできるように
+EメールかIRCを通して開発者に連絡をして頂くようお願いします。
+
+
+site-wide な場所にインストールする
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+ディレクトリにPATHを設定する代わりに、次のコマンドでにbzrを\
+インストールすることができます。::
+
+  python setup.py install
+
+もしあなたがコンパイラやPythonの開発ツールを持っていない場合、
+bzrは全ての拡張モジュールに対して(遅い)pure-pythonの実装を提供します。
+次のコマンドを使って拡張モジュールのコンパイルなしにインストールできます::
+
+  python setup.py install build_ext --allow-python-fallback
+
+
+開発バージョンを稼働させる
+---------------------------
+
+Bazaarの最新の開発バージョンを常に利用したい場合があります。
+バグの危険性が増すので大半のユーザーにはお勧めできないことに注意してください。
+一方で、開発バージョンは(開発プロセスのおかげで)非常に安定しているので、
+これを動かすことで、バグと改善内容のための変更内容を開発者に送ることが楽になります。
+より多くの人が最新のソフトウェアをテストすることで開発者の手助けにもなります。
+
+従うべき手順は次のとおりです:
+
+  1. 上記の方法の1つを利用してBazaarをインストールする。
+
+  2. 次のように開発バージョンのコピーを入手します::
+
+       bzr branch http://bazaar-vcs.org/bzr/bzr.dev
+
+  3. 作成されたディレクトリ(bzr.dev)をPATHに登録します
+
+上級ユーザーはより早く動かすためにC言語の拡張機能をビルドもしたいことでしょう。
+これは ``make`` と ``pyrex`` とCコンパイラを利用することで実現できます。
+このことに関して手助けが必要であればEメールかIRCを通して連絡をして\
+下さるようお願いします。
+
+
+複数のバージョンを稼働させる
+-----------------------------
+
+Bazaarの複数のバージョンをインストールしてそれらを切り替えることは簡単です。
+これを行うためには、実行したい **bzr** のフルパス名を入力するだけです。
+関連ライブラリは自動的に検出されます。もちろん、パス名を提供しない場合、
+通常のシステムパスで見つかる **bzr** のコマンドが使われます。
+
+この機能は最新バージョンと開発バージョンの両方を走らせたい(テストしたい)場合にとりわけ役立ちます。

=== added file 'doc/ja/user-guide/introducing_bazaar.txt'
--- doc/ja/user-guide/introducing_bazaar.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/introducing_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,117 @@
+Bazaarの紹介
+=============
+
+Bazaarとは？
+-------------
+
+Bazaarはみんなのコラボレーションを手助けするツールです。
+これは(たとえばソフトウェアのソースコードなどの)ファイルのグループの変化の\
+段階のスナップショットを提供するためにファイルの変更を追跡します。
+この情報を利用することで、Bazaarはあなたの作業と他の人の作業の成果を簡単にマージします。
+
+Bazaarのようなツールはバージョン管理ツール(version control systems: VCS)と呼ばれ\
+長い間ソフトウェアの開発者の間で人気がありました。
+Bazaarは使いやすく、柔軟で簡単にセットアップできるので、ソフトウェアの開発者だけでなく、\
+テクニカルライター、ウェブデザイナー、翻訳者のようなファイルとドキュメントに取り組む\
+人達にも理想的なツールです。
+
+このガイドは、個人で使うのかチームで使うのかに関わらずBazaarのインストールと使い方の手引きをします。
+すでに分散型のバージョン管理システムに慣れ親しんでおりすぐとりかかりたいのであれば、\
+このセクションを流し読みして `さらに学ぶ`_ のセクションに移動するとよいでしょう。
+
+バージョン管理システムの小史
+-----------------------------
+
+バージョン管理ツールは数十年の間に進化してきました。
+簡単に説明すると、ツールは4世代に渡ります:
+
+ 1. ファイルのバージョン管理ツール、たとえばSCCS、RCS
+ 2. ファイルのバージョン管理ツール - 集中型、たとえばCVS
+ 3. ファイルのバージョン管理ツール - 第二世代集中型、たとえばSubversion
+ 4. ファイルのバージョン管理ツール - 分散型、たとえばBazaar
+
+Bazaarの設計と実装は前世代のすべてのツールから学んだことに基づいています。
+とりわけ、Bazaarは集中型と分散型の両方のバージョン管理モデルをサポートするので\
+ツールを変更せずに複数のモデルに対応できます。
+
+集中型 vs 分散型
+-----------------
+
+従来の多くのVCSツールはファイルのツリーに対する履歴(**リポジトリ**, *repository*)
+を提供する中央サーバーが必要です。
+ファイルに対する作業に取り組むために、ユーザーはサーバーに接続してファイルを\
+**チェックアウト** (*checkout*) する必要があります。
+チェックアウトにより、ユーザーが修正できるツリー(**作業ツリー**, *working tree*)ができます。
+これらの変更を記録(**コミット**, *commit*)するためには、集中型のサーバーにアクセスする権限が必要で、\
+コミットをする前に作業内容を最新バージョンとマージしなければなりません。
+このアプローチは集中型モデルとして知られます。
+
+集中型モデルは長期にわたって有用であることを示してきましたが顕著な欠点がいくつかあります。
+先ず第一に、集中型のVCSはバージョン管理機能を利用するためにはサーバーに接続できることを要求します。
+二番目に、集中型のモデルは変更の **スナップショットの記録** のふるまいと変更の **公開**
+のふるまいと密接にリンクさせます。
+これは状況によってはよいこともありますが別の状況では品質にわるい影響を与えることがあります。
+
+分散型のVCSツールは単独の集中型のレポジトリではなく複数のレポジトリをユーザーとチームに持たせます。
+Bazaarでは通常、履歴はバージョン管理されているコードと同じ場所に保存されます。
+これによってユーザーは、オフラインであってもコミットするべきタイミングで変更をコミットできます。
+ネットワークのアクセスは変更を公開するもしくは別の場所の変更にアクセスするときのみ求められます。
+
+実際、分散型VCSツールを賢く使うことでオフライン作業を超えたいくつかの開発者にとっての利点があります。
+
+ * 開発者が実験用のブランチを作るのが簡単になります
+ * 仲間とのアドホックなコラボレーションが簡単になります
+ * ルーチンタスクの時間が減ります - より創造的な活動に時間を割けます
+ * "feature-wide" コミットの利用を通してリリース管理の柔軟性が増します
+ * トランクの質と安定性を高い水準で維持でき、それによって作業者のストレスが少なくなります
+ * オープンソースのコミュニティにおいて:
+
+   * コア開発者ではない人が作成と変更の維持をしやすくなります
+   * コア開発者が外部の開発者と共同作業をしてコアのチームに組み込むことが楽になります
+
+ * 会社において、分散されたチームや外部のチームと連携するのが簡単になります
+
+分散型VCSツールの集中型より優れた点の詳細な一覧に関しては、 http://bazaar-vcs.org/BzrWhy を参照してください。
+
+
+Bazaarの主要な機能
+-------------------
+
+Bazaarは現存する唯一のVCSツールではありませんが、多くのチームとコミュニティにとって\
+よい選択肢になる優れた機能をいくつか持ちます。
+別のVCSツールとの比較の要約はBazaarのWiki、 http://bazaar-vcs.org/ で見つかります。
+
+多くの機能の中で、とりわけ強調するものがあります:
+BazaarはPythonで書かれた完全にフリーなソフトウェアです。
+結果として、改善に貢献することは簡単です。
+手を貸して頂けるのであれば、 http://bazaar-vcs.org/BzrSupport を参照して頂くようお願いします。
+
+
+さらに学ぶ
+-----------
+
+このマニュアルではBazaarの簡単な紹介と効果的な使い方を提供します。
+すべてのユーザーは、少なくとも次の点について書かれたこの章の残りを読むことが推奨されます:
+
+ * ユーザーが知る必要のある中心的な概念を説明します
+ * Bazaarを利用した人気のある方法をいくつか紹介します
+
+2-6章ではさまざまなタスクを実現するためにBazaarを使う方法を詳しく説明します。
+Bazaarを使い始めた後で最初から最後まで読むことをほとんどの方にお勧めします。
+7章とそれ以降はコアの機能を理解した上でBazaarを利用する際に手助けになる追加情報を提供します。
+この教材は必要なときに任意の順番で読むことができます。
+
+すでに他のバージョン管理ツールに慣れ親しんでいるのであれば、次のドキュメントを読んですぐに始めるとよいでしょう:
+
+ * 5分でBazaar_ - ミニチュートリアル
+ * Bazaarクィックスタートカード_ - よく使われるコマンドを1ページにまとめた要約。
+
+加えて、オンラインのヘルプと `Bazaarユーザーリファレンス`_
+は利用可能なコマンドとオプションのすべての詳細を提供します。
+
+.. _5分でBazaar: ../mini-tutorial/index.html
+.. _Bazaarクィックスタートカード: ../quick-reference/quick-start-summary.svg
+.. _Bazaarユーザーリファレンス: ../user-reference/bzr_man.html
+
+このマニュアルがお役に立てることを願っております。Bazaarの残りのドキュメントの改善を提案したいのであれば、
+メーリングリスト(bazaar@lists.canonical.com)に連絡して頂けるようお願いします。

=== added file 'doc/ja/user-guide/merging_changes.txt'
--- doc/ja/user-guide/merging_changes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/merging_changes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,93 @@
+変更をマージする
+=================
+
+並行開発
+---------
+
+誰かがプロジェクトの独自ブランチを持ったら、 並行して変更を行い、\
+オリジナルのブランチを続ける開発にコミットできます。
+まもなくですが、開発の独立したラインを結合することが必要にあります。
+このプロセスは *マージ (merging)* として知られます。
+
+mergeコマンド
+-------------
+
+別のブランチから変更を受け入れるためには、 ``merge`` コマンドを使います。
+構文は次のとおりです::
+
+  bzr merge [URL]
+
+URLが渡されない場合、オリジナルのものから由来する初期のブランチがデフォルト\
+として使われます。
+たとえば、BillがMaryの作業内容からブランチを作る場合、
+下記のようにコマンドを入力すれば彼女の次の変更をマージできます::
+
+  bzr merge
+
+一方で、MaryはBillのブランチで行われた作業内容を彼女のブランチにマージ\
+したいかもしれません。
+この場合、彼女は最初に明示的にURLを渡す必要があります::
+
+  bzr merge sftp://mary@bill-laptop/cool-repo/cool-trunk
+
+マージブランチがまだ設定されていなければ、これによってデフォルトの\
+マージブランチが設定されます。
+設定した後でデフォルトを変更するためには、 ``--remember`` オプション\
+を使います。
+
+マージの動作方法は？
+--------------------
+
+マージのためのいくつかのアルゴリズムがあります。
+Bazaarのデフォルトのアルゴリズムは次のように動作する
+*3方向マージ (3-way merging)* の一種です。
+Aが祖先でBとCの2つがブランチであると仮定すると、次のテーブルは使われるルールを\
+提示します。
+
+  === === === ====== =================
+   A   B   C  結果   コメント
+  === === === ====== =================
+   x   x   x  x      unchanged
+   x   x   y  y      line from C
+   x   y   x  y      line from B
+   x   y   z  ?      conflict
+  === === === ====== =================
+
+マージの中には人間の手助けによってのみ完了するものがあることに留意してください。
+これらを解決する方法の詳細は `衝突を解消する <resolving_conflicts.html>`_ を参照してください。
+
+マージを記録する
+-----------------
+
+衝突が解決した後で、マージをコミットする必要があります。例です::
+
+  bzr commit -m "Merged Mary's changes"
+
+衝突が無くても、明確なコミットがまだ必要です。
+他のツールとは異なり、これはBazaarの機能と考えられています。
+クリーンなマージは必ずしもよいマージとは限らないので、個別の明確なステップ\
+としてコミットすることで、すべてがよい状態にあることを検証するための最初の\
+テストスィートを実行できます。
+
+問題が見つかったら、マージをコミットする前にそれらを訂正する\
+もしくは ``revert`` を使用してマージを廃棄すべきです。
+
+マージの追跡
+------------
+
+Bazaarの機能の中で最も重要な機能の1つは、分散型で高品質の\
+*マージトラッキング* です。
+言い換えると、Bazaarは何がすでにマージされていることを覚えており、\
+マージのための最良の祖先を賢く選ぶためにその情報を使い、\
+衝突の回数と規模を最小にします。
+
+あなたが他の多くのVCSツールの難民であるなら、
+*何が何でもマージは避けさせてください* という習慣から抜け出すのは\
+本当に難しいかもしれません。
+Bazaarによっていつでも安全に他の人とのマージを行うことができます。
+peer-to-peerの方法でうまくゆくときに、高い品質を保つために、
+"統合のたまり場"として集中型のブランチを使うことも避けられます。
+コラボレーションしている変更を本当に広く共有する準備ができたら、\
+変更を中心のブランチにマージしてコミットする機会です。
+
+このようにマージ機能がうまくゆけば開発者の共同作業の方法を変えることができます。

=== added file 'doc/ja/user-guide/organizing_branches.txt'
--- doc/ja/user-guide/organizing_branches.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/organizing_branches.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,95 @@
+ブランチを編成する
+===================
+
+ミラーブランチ
+----------------
+
+開発をするために分散型のワークフローを利用する際の主要な違いは\
+メインのローカルブランチは変更を行う場所ではないことです。
+代わりに、中心ブランチのそのままのコピーとして保存されます。
+すなわち、これは *ミラーブランチ* です。
+
+ミラーブランチを作るためには、共用リポジトリ(まだなければ)を作り\
+ミラーを作るために ``branch`` コマンド(もしくは ``checkout``)を使います。
+例です::
+
+  bzr init-repo PROJECT
+  cd PROJECT
+  bzr branch sftp://centralhost/srv/bzr/PROJECT/trunk
+
+タスクのブランチ
+-----------------
+
+それぞれの新しい機能もしくは修正は独自のブランチの中で開発されます。
+これらのブランチは *機能ブランチ* もしくは *タスクブランチ* として言及されます -
+用語はお互いに置き換えて使うことができます。
+
+タスクブランチを作るためには、ミラーブランチに対して  ``branch`` コマンドを使います。
+例です::
+
+  bzr branch trunk fix-123
+  cd fix-123
+  (hack, hack, hack)
+
+この方法には数多くの利点があります:
+
+ 1. 並行して複数の変更に取り組むことができます
+ 2. 変更の間の交換が減ります
+ 3. 複数の人々は準備ができるまでpeer-to-peerモードでブランチに取り組むことができます
+
+とりわけ、変更が他のものより料理するのに時間がかかるのであれば、レビューを求めたり、
+フィードバックを適用することができます。
+中心ブランチにマージする前に個別のブランチで十分な品質の作業を完了させることで、
+中心ブランチの品質と安定性は以前よりも高い水準を維持します。
+
+ミラーブランチをリフレッシュする
+---------------------------------
+
+これを行うためには ``pull`` コマンドを使います::
+
+  cd trunk
+  bzr pull
+
+最新のトランクを機能ブランチにマージする
+-----------------------------------------
+
+これを行うためには ``merge`` コマンドを使います::
+
+  cd fix-123
+  bzr merge
+  (resolve any conflicts)
+  bzr commit -m "merged trunk"
+
+機能をトランクにマージする
+---------------------------
+
+異なる分散型のワークフローの方針は変わります、
+すべての開発者がメイントランクにコミットする権限を持つ最もシンプルな\
+事例は下記のとおりです。
+
+ミラーがチェックアウトなら::
+
+  cd trunk
+  bzr update
+  bzr merge ../fix-123
+  (resolve any conflicts)
+  bzr commit -m "Fixed bug #123"
+
+ミラーがブランチの場合::
+
+  cd trunk
+  bzr pull
+  bzr merge ../fix-123
+  (resolve any conflicts)
+  bzr commit -m "Fixed bug #123"
+  bzr push
+
+タスクブランチをバックアップする
+--------------------------------
+
+集中型ワークフローの副作用の1つは変更がITオペレーションの一部として\
+バックアップされる中心位置にしょっちゅうコミットされることです。
+タスクブランチを開発するとき、作業内容を中心位置に公開することは\
+バックアップになるのでよい考えです(しかし共用位置であることは必須ではありません)。
+この目的のためだけにローカルのタスクブランチをバックアップサーバー上で\
+確立されたリモートブランチにバインドするとよいかもしれません。

=== added file 'doc/ja/user-guide/organizing_your_workspace.txt'
--- doc/ja/user-guide/organizing_your_workspace.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/organizing_your_workspace.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,177 @@
+.. _organizing-your-workspace:
+
+作業スペースを構成する
+=========================
+
+.. _common-workspace-layouts:
+
+一般的なレイアウト
+---------------------
+
+Bazaarのユーザーがプロジェクトのための作業スペースを構成するベストな方法は、\
+次のような要素に依存します:
+
+* ユーザーの役割: プロジェクトオーナー vs コア開発者 vs カジュアルな貢献者
+
+* ワークフロー: プロジェクトが推奨/強制している、貢献のためのワークフロー
+
+* サイズ: 大きいプロジェクトは小さいプロジェクトよりもリソースを要求します。
+
+少なくとも4つの一般的なワークスペースの構成方法があります。
+
+* lightweight checkout
+* standalone tree
+* feature branches
+* switchable sandbox.
+
+各レイアウトの簡単な説明を以下に記します。
+
+
+軽量チェックアウト
+--------------------
+
+このレイアウトでは、作業ツリーはローカルですがブランチはリモートにあります。
+これはCVSやSVNで一般的に利用されるレイアウトで、シンプルで簡単に理解できます。
+
+セットアップするには::
+
+  bzr checkout --lightweight URL project
+  cd project
+
+作業するには::
+
+  (make changes)
+  bzr commit
+  (make changes)
+  bzr commit
+
+各コミットが暗黙的に変更を同じブランチを利用している他の人に公開していることに\
+注意してください。ただし、コミットが成功するには作業ツリーがリモートのブランチの\
+最新の状態になっている必要があります。最新のコードを取得してマージするには、::
+
+  bzr update
+
+
+スタンドアロンツリー
+----------------------
+
+このレイアウトでは、作業ツリーとブランチは一つの場所にあります。
+共有リポジトリが上位のディレクトリに無い限り、リポジトリも同じ場所に\
+格納されます。これはBazaarのデフォルトレイアウトで、小規模から中規模の\
+大きさのプロジェクトに適しています。
+
+セットアップ::
+
+  bzr branch URL project
+  cd project
+
+作業::
+
+  (make changes)
+  bzr commit
+  (make changes)
+  bzr commit
+
+変更を中央の場所に公開する::
+
+  bzr push [URL]
+
+pushするURLは最初の一回だけ要求されます。
+
+もし中央の場所が、pushするまでの間に他のユーザーからの変更を受け取っていた\
+場合、pushする前にそれらの変更をローカルブランチにmergeする必要があります::
+
+  bzr merge
+  (resolve conflicts)
+  bzr commit
+
+代替手段として、チェックアウトを使うこともできます。ブランチと同じように\
+チェックアウトも履歴全体をローカルにコピーしますが、ローカルブランチが\
+リモートの場所に束縛されているので、両方のブランチに一度にコミットされます。
+
+注意: チェックアウトはローカルコミット+pushに比べてスマートです。
+チェックアウトはまずリモートにコミットして、それが成功したときにだけ\
+ローカルにもコミットします。
+
+.. _feature-branches:
+
+機能ブランチ
+--------------
+
+このレイアウトでは、いくつかのブランチとツリーがあって、一般的にリポジトリを共有します。
+一つのブランチは "trunk" のミラーを保存していて、それ以外の作業単位(例:バグ修正や
+機能追加)にはそれぞれの "機能ブランチ" を作ります。
+このレイアウトはほとんどのプロジェクト、特に中規模のものにとって理想的です。
+
+セットアップ::
+
+  bzr init-repo project
+  cd project
+  bzr branch URL trunk
+
+機能ブランチを開始する::
+
+  bzr branch trunk featureX
+  cd featureX
+
+作業する::
+
+  (make changes)
+  bzr commit
+  (make changes)
+  bzr commit
+
+変更をメーリングリストに公開してレビュー&承認してもらう::
+
+  bzr send
+
+変更を公開ブランチで公開する(たとえばLaunchpad上でmerge要求を出すために)::
+
+  bzr push [URL]
+
+変化形として、trunkをチェックアウトとして作ることもできます。
+もしtrunkへのコミット権限を持っているのであれば、trunkへマージして\
+コミットするとその変更は暗黙的に公開されます。
+他には、trunkのURLが読み込み専用だった場合(例: httpアドレス)、チェックアウトを\
+利用することはローカルのtrunkミラーに間違えて変更を登録してしまうことを\
+防止します。これはプロジェクトがPQMなどのゲートキーパー型のワークフロー\
+を利用していたときに有用です。
+
+
+.. _local-sandbox:
+
+ローカルのsandbox
+------------------
+
+このレイアウトは機能ブランチのレイアウトとほぼ同じですが、機能ブランチが\
+それぞれ作業ツリーを持つ代わりに一つの作業ツリーを共用する点が違います。
+これはgitのデフォルトレイアウトに似ていて、大きなツリー(10000ファイル以上\
+とか)を持つプロジェクトや、ビルドによる加工物(.oや.classファイルといった)\
+を大量に作るプロジェクトに適しています。
+
+セットアップ::
+
+  bzr init-repo --no-trees project
+  cd project
+  bzr branch URL trunk
+  bzr checkout --lightweight trunk sandbox
+  cd sandbox
+
+これでsandboxで作業を開始できますが、sandboxがtrunkを参照したままコミット\
+してしまうと、(trunkがcheckoutで無い限り)trunkが元のtrunkのミラーでは\
+なくなってしまいます。
+なので、まず機能branchを作ってsandboxをそちらに紐づけましょう::
+
+  bzr branch ../trunk ../featureX
+  bzr switch ../featureX
+
+この後の、変更を行ったりその変更を公開して適用してもらうまでの\
+プロセスは機能ブランチレイアウトの時と同じです。
+
+
+進んだレイアウト
+----------------
+
+お望みとあれば、あなたのお好みの構成に合わせてレイアウトを決めることができます。
+例やアイデアについては `共有リポジトリのレイアウト <shared_repository_layouts.html>`_
+を参照してください。

=== added file 'doc/ja/user-guide/part2_intro.txt'
--- doc/ja/user-guide/part2_intro.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/part2_intro.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,11 @@
+これからの長い旅
+=================
+
+前の章でBazaarがあなた自身と他の人との共同作業を生産的にすることを手助け\
+してくれる方法について確固として理解して頂けることを筆者達は願っております。
+初めてBazaarを学んでいるのであれば、一度習得したら、このマニュアルに戻るために\
+すでにカバーされた手順を試すとよいかもしれません。
+
+残りの章ではBazaarをより適切に使うためのさまざまなトピックをカバーしています。
+明言されない限り、この章と残りの章はそれぞれ独立しているので好きな順序で
+読むことができます。

=== added file 'doc/ja/user-guide/partner_intro.txt'
--- doc/ja/user-guide/partner_intro.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/partner_intro.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,33 @@
+他の人と連携する
+=================
+
+Peer-to-peerをうまくやる
+-------------------------
+
+多くの場合、1人よりも2人で考える方がベターです。
+1人でプロジェクトを始め、誰かがあなたを手伝いたい、もしくはあなたが別の人に助けを求めたいことがあります。
+ペアプログラマとしてタスクを割り当てられたより大きなチームのメンバーであることでしょう。
+どちらにしても、効率よく共同作業を行うために、2人の人間がプロセス、ガイドラインとツールセットの一式に同意する必要があります。
+
+誰かに電話で直接呼び出すことが許可されていなくて、彼らに話しかける唯一の方法は最初に電話会議を予約することである場合を想像してください。
+集中型のVCSのリポジトリを通してのみコードを共有する企業とコミュニティは毎日\
+そのような拘束に耐えています。
+中央管理がうまくいくときもあれば、peer-to-peerがうまくいくときもあります。
+Bazaarはどちらの場合でも手助けになるように設計されました。
+
+パートナーのワークフロー
+-------------------------
+
+これは唯一の方法ではありませんが、下記の *パートナーのワークフロー* はBazaarを利用してペアで共同作業をしたい人々のためのよいスタート地点です。
+
+.. image:: images/workflows_peer.png
+
+以前の章でカバーしたタスクに加えて、この章では2つの必要不可欠なコラボレーション活動を紹介します:
+
+ * ブランチのコピーを手に入れる
+ * 複数のブランチの間の変更をマージする
+
+コードベースに取り組むだけのときでも、たとえば異なるリリースのために\
+複数のブランチを手元に置き必要に応じてそれらの変更をマージすることは\
+とても実用的です。
+あなたの "パートナー" が本当にあなた自身かもしれませんから。

=== added file 'doc/ja/user-guide/plugins.txt'
--- doc/ja/user-guide/plugins.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/plugins.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,101 @@
+プラグインを利用する
+=====================
+
+.. Information on how to use plugins in Bazaar.
+
+プラグインとは？
+-----------------
+
+プラグインは主にサードパーティによって作られたBazaarのための外部コンポーネントです。
+プラグインは新しい機能を追加することでBazaarを補強する能力があります。
+プラグインは現在の機能を置き換えることでBazaarのふるまいを変更することもできます。
+プラグインのサンプルのアプリケーションは次のとおりです:
+
+* コマンドをオーバーライドする
+* 新しいコマンドを追加する
+* 追加のネットワーク転送機能を提供する
+* ログの出力をカスタマイズする
+
+プラグインを通してできるカスタマイズの可能性は際限がありません。
+実際、開発者が新しい機能を公式のコードベースに含める前にテストするための方法としてプラグインは機能します。
+プラグインは機能の引退時でも同様に役立ちます。たとえば廃止されたファイルのフォーマットがある日Bazaarのコアから除外されるかもしれませんが\
+代わりにプラグインとして利用できます。
+
+プラグインはユーザーにとって、外部の開発者にとっても、Bazaar自身にもよいものです。
+
+プラグインが見つかる場所
+-------------------------
+
+http://bazaar-vcs.org/BzrPlugins ページでプラグインのリストが見つかります。
+
+プラグインをインストールする方法
+---------------------------------
+
+プラグインのインストール作業はとても簡単です！　まだ作られていなければ、
+Bazaarの設定ディレクトリの元で ``plugins`` ディレクトリを作ります。
+Linuxの場合は ``~/.bazaar/`` でWindowsの場合は
+``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\`` です。
+このディレクトリの範囲内では(下記では$BZR_HOMEとして言及される) それぞれのプラグインは独自のサブディレクトリに設置されます。
+
+プラグインはとりわけBazaarのブランチとよく連携します。
+たとえば、Linuxのメインのユーザーアカウント用にbzrtoolsプラグインをインストールするためには、次のコマンドを実行します::
+
+    bzr branch http://panoramicfeedback.com/opensource/bzr/bzrtools
+    ~/.bazaar/plugins/bzrtools
+
+プラグインをインストールするディレクトリの名前はPythonの有効な識別子でなければなりません。
+このことはディレクトリは特定の文字だけを含まなければならないことを意味します。とりわけハイフン (``-``) を含んではなりません。
+``bzr-gtk`` を ``$BZR_HOME/plugins/bzr-gtk`` にインストールするよりも、 ``$BZR_HOME/plugins/gtk`` にインストールします。
+
+プラグインの代替用の場所
+-------------------------
+
+必要なパーミッションがあれば、プラグインをシステム全体のベースにインストールすることもできます。
+現在2つの場所がプラグインのためにチェックされます:
+
+ 1. システムの場所 - bzrlib/plugins
+ 2. 個人の場所 - $BZR_HOME/plugins.
+
+Linuxにおいて、これらの典型的な場所は
+``/usr/lib/python2.4/site-packages/bzrlib/plugins/`` と
+``$HOME/.bazaar/plugins/`` です。
+Windowsにおいて、システムの場所は
+``C:\\Program Files\\Bazaar\\plugins`` になり、
+個人の場所は ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0\plugins`` です。
+
+環境変数 ``BZR_PLUGIN_PATH`` をプラグインが含まれるディレクトリに設定することで\個人のプラグインの場所を上書きできます。
+
+
+インストールされたプラグインの一覧を表示する
+---------------------------------------------
+
+これを行うためには、次のようにpluginsコマンドを使います::
+
+    bzr plugins
+
+それぞれのプラグインの名前、場所とバージョンが表示されます。
+
+プラグインによって追加された新しいコマンドは ``bzr help commands`` を実行することで見ることができます。
+プラグインによって提供されたコマンドはブラケットの中のプラグインの名前に従って表示されます。
+
+人気のあるプラグイン
+--------------------
+
+次の表は人気のあるプラグインのサンプルです。
+
+  ================ ================= ==================================
+  カテゴリ         名前              説明
+  ================ ================= ==================================
+  GUI              QBzr              QtベースのGUIツール
+  GUI              bzr-gtk           GTKベースのGUIツール
+  GUI              bzr-eclipse       Eclipseとの統合
+  General          bzrtools          その他。shelfを含めた機能の強化
+  General          difftools         外部の差分ツールヘルパー
+  General          extmerge          外部のマージツールヘルパー
+  Integration      bzr-svn           Subversionをリポジトリとして利用する
+  Migration        cvsps             CVSパッチセットを移行させる
+  ================ ================= ==================================
+
+あなた独自のプラグインを書きたい場合、難しいことではありません。
+始めるためには付録の `プラグインを書く <writing_a_plugin.html>`_
+の項目をご覧ください。

=== added file 'doc/ja/user-guide/publishing_a_branch.txt'
--- doc/ja/user-guide/publishing_a_branch.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/publishing_a_branch.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,68 @@
+ブランチを公開する
+===================
+
+集中型リポジトリをセットアップする
+-------------------------------------
+
+集中型のワークフローはコンピュータ上のブランチを中心型のブランチ\
+として指名することで使うことができます。
+実際大抵のチームは集中型のブランチをホストするために専用サーバーを\
+持ちます。
+
+共用リポジトリをローカルで使うことが最良の習慣であるように、\
+中心型のブランチを共用リポジトリを設置することもお勧めです。
+通常は、中心型の共用ブランチはファイルの作業コピーではなく\
+履歴のみを保存することに注意してください。
+なので、そのような共有リポジトリを作るときには通常 ``no-trees``
+オプションを使います::
+
+  bzr init-repo --no-trees sftp://centralhost/srv/bzr/PROJECT
+
+この手順をcvsrootもしくはSubversionのリポジトリのセットアップとして\
+似たようなものとして考えることができます。
+しかしながら、Bazaarはリポジトリ内のブランチの編成方法をより柔軟にします。
+ガイドラインと例に関しては付録の
+`共用レポジトリのレイアウト <shared_repository_layouts.html>`_ を参照してください。
+
+
+集中型ブランチを始める
+-------------------------
+
+集中型ブランチに初期の内容を投入する方法は2つあります:
+
+ 1. ローカルのブランチを作り中央にプッシュする
+ 2. 空の中央ブランチを作り内容をコミットする
+
+最初のやり方の例です::
+
+  bzr init-repo PROJECT  (ローカルリポジトリを準備する)
+  bzr init PROJECT/trunk
+  cd PROJECT/trunk
+			 (開発ファイルをコピーする)
+  cp -ar ~/PROJECT .     (OS固有のツールを使用してファイルをコピーする)
+  bzr add                (リポジトリを投入する; バージョン管理を始める)
+  bzr commit -m "Initial import"
+                         (中心リポジトリに公開する)
+  bzr push sftp://centralhost/srv/bzr/PROJECT/trunk
+
+2番目のやり方の例です::
+
+  bzr init-repo PROJECT  (ローカルリポジトリを準備する)
+  cd PROJECT
+  bzr init sftp://centralhost/srv/bzr/PROJECT/trunk
+  bzr checkout sftp://centralhost/srv/bzr/PROJECT/trunk
+  cd trunk
+  cp -ar ~/PROJECT .     (OS固有のツールを使用してファイルをコピーする)
+  bzr add                (リポジトリを投入する; バージョン管理を始める)
+  bzr commit -m "Initial import"
+                         (中心リポジトリに公開する)
+  bzr push sftp://centralhost/srv/bzr/project/trunk
+
+``checkout`` コミットを使って作られた作業ツリー内部でコミットすると\
+ローカルと同様に内容は暗黙の内に中心位置にコミットされることに注意してください。
+``checkout`` の代わりに ``branch`` コマンドを使ったので、\
+内容はローカルにのみコミットされます。
+
+このように中心位置に密接に連動した作業ツリーは *チェックアウト(checkouts)*
+と呼ばれます。
+この章の残りでは数多くの機能を詳しく説明します。

=== added file 'doc/ja/user-guide/recording_changes.txt'
--- doc/ja/user-guide/recording_changes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/recording_changes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,76 @@
+変更を記録する
+===============
+
+bzr commit
+----------
+
+作業ツリーの状態が満足のゆくものであるとき、これをブランチに **コミット** できます。
+そしてその状態のスナップショットを保持する新しいリビジョンが作られます。
+
+**commit** コマンドはリビジョンの変更を記述するメッセージをとります。
+コミットはあなたのユーザーID、現在の時間とタイムゾーン、一覧表とツリーの内容も記録します。
+コミットメッセージは ``-m`` もしくは ``--message`` オプションによって指定されます。
+複数行のコミットメッセージを入力できます;
+大抵のシェルでは行の終わりで引用符を開いたままにするだけで入力できます。
+
+::
+
+    % bzr commit -m "added my first file"
+
+ファイルからメッセージを得るために ``-F`` オプションを使うことができます。
+中には、作業している間にコミットメッセージ用のノートを作り、自分が何を行い何を発言したのか
+確認するために差分をレビューしたい人がいます。
+(このファイルは一休みしてから作業を取り出すのにも役立ちます)
+
+エディタからのメッセージ
+-------------------------
+
+``-m`` もしくは ``-F`` オプションを使わないのであれば、
+bzrはメッセージを入力するためにエディタを開きます。
+起動させるエディタは ``$VISUAL`` もしくは ``$EDITOR`` 環境変数によって制御され、
+``~/.bazaar/bazaar.conf`` の中の ``editor`` 設定によって上書きできます;
+``$BZR_EDITOR`` は上記で言及したエディタのオプションを上書きします。
+変更なしでエディタを閉じると、コミットはキャンセルされます。
+
+エディタの中で開かれるファイルは境界線を含みます。
+この行の下のファイルの部分は情報用のみのために含まれ、コミットメッセージには\
+含まれません。
+セパレータの下側はコミットで変更されるファイルの一覧が表示されます。
+上記の行の上側でメッセージを書き、ファイルを保存して閉じます。
+
+編集メッセージとしてコミットする差分を見たければ ``--show-diff`` オプションを使うことができます。
+これはエディタが開くときにエディタの差分を含みます。セパレータの下とファイルに関する情報はコミットされます。
+これは書いたメッセージを読むことができることを意味しますが、
+差分自身は終了したときにコミットメッセージに表示されません。
+一部をメッセージに含めたいのであれば、それらをセパレータの上側にコピー＆ペーストできます。
+
+選択可能なコミット
+------------------
+
+コミットのコマンドラインでファイルもしくはディレクトリの名前を渡すと
+それらのファイルへの変更のみがコミットされます。たとえば::
+
+    % bzr commit -m "documentation fix" commit.py
+
+デフォルトではサブディレクトリから実行されたとしても
+bzrは常にツリーへのすべての変更をコミットします。
+現在のディレクトリのみからコミットするには、ドットを引数として使います::
+
+    % bzr commit .
+
+変更に署名をつける
+-------------------
+
+たとえば誰かのパッチを適用するときなど、コミットしようとしている変更があなたのものでないなら、 ``--author`` という commit のオプションを使って変更に署名をつけられます。 ::
+
+    % bzr commit --author "Jane Rey <jrey@example.com>"
+
+ここで指定された人はそのリビジョンの "author" として記録され、\
+あなたはそのリビジョンの "committer" として記録されます。
+
+もしリビジョンの変更がペアプログラミングなどにより複数の人に作られたもの\
+ならば、 ``--author`` を複数回指定して記録することができます。 ::
+
+    % bzr commit --author "Jane Rey <jrey@example.com>" \
+        --author "John Doe <jdoe@example.com>"
+

=== added file 'doc/ja/user-guide/releasing_a_project.txt'
--- doc/ja/user-guide/releasing_a_project.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/releasing_a_project.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,43 @@
+プロジェクトをリリースする
+==========================
+
+リリースをパッケージ化する
+--------------------------
+
+``export`` コマンドはリリースのパッケージを作成するために使われます。
+すなわち、ブランチの中のファイルとディレクトリをコピーしてそれらを真新しいディレクトリもしくはアーカイブファイルのパッケージを作成します。
+たとえば、このコマンドは最後にコミットされたバージョンを ``tar.gz`` アーカイブファイルにパッケージ化します::
+
+  bzr export ../releases/my-stuff-1.5.tar.gz
+
+``export`` コマンドは下記に示されるアーカイブのタイプを作るためにアーカイブファイルの接尾辞を使います。
+
+      ==========================       ===================
+      サポートされるフォーマット       拡張子で自動検出
+      ==========================       ===================
+         dir                                (none)
+         tar                                 .tar
+         tbz2                           .tar.bz2, .tbz2
+         tgz                             .tar.gz, .tgz
+         zip                                 .zip
+      ==========================       ===================
+
+最新のリビジョン以外のリビジョンをパッケージにすることを望むのであれば、 ``-r`` オプションを使います。
+アーカイブ内部のrootディレクトリを調整したいのであれば、 ``--root``
+オプションを使います。
+``export`` によってサポートされるオプションの詳細については
+オンラインヘルプもしくはユーザーリファレンスを参照してください。
+
+リリースをタギングする
+-----------------------
+
+リリースのパッケージを作成するために使われたバージョンを覚えるよりも、
+``tag`` コマンドを使ってバージョンのためのシンボルを定義する方が便利です::
+
+  bzr tag version-1-5
+
+リビジョンの識別子が必要なときはいつでもそのタグを使うことができます::
+
+  bzr diff -r tag:version-1-5
+
+ブランチの中で定義したタグの一覧を見たい場合、 ``tags`` コマンドを使います。

=== added file 'doc/ja/user-guide/resolving_conflicts.txt'
--- doc/ja/user-guide/resolving_conflicts.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/resolving_conflicts.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,75 @@
+衝突の解消
+===========
+
+ワークフロー
+-------------
+
+マージプロセスの間にそれぞれの衝突を解消することを強制する他のいくつかのツール\
+とは異なり、Bazaarはできる限りマージしてから衝突を報告します。
+これによって衝突の解消をより扱いやすくします。
+解消すべき方法を決めることを手助けするためにポストマージツリー全体の内容が\
+利用可能だからです。
+それぞれの解消もしくはグループがよい状態であることを確認するためにテストを\
+いくつか選んで実行することもよいでしょう。
+
+衝突の一覧を表示する
+---------------------
+
+``merge`` コマンドで報告されるのと同様に、\
+突出した衝突の一覧は ``conflicts`` コマンドを使用することでいつでも表示されます。
+これは ``status`` コマンドから出力の一部として含めることも可能です。
+
+衝突を解消する
+--------------
+
+衝突に遭遇したら、 ``merge`` コマンドは解決されていない領域を表示する\
+埋め込みマーカーをそれぞれのファイルに追加します。
+1つの衝突を持つそれぞれのファイルに対して3つのファイルも作ります:
+
+ * foo.BASE
+ * foo.THIS
+ * foo.OTHER
+
+``foo`` は衝突したファイルの名前です。
+多くの場合、問題になっているそれぞれのファイルを手作業で編集し、\
+関連領域を修正し衝突マーカーを除去することで衝突を解消できます。
+
+衝突の中のすべてのファイルを修正し、マーカーを削除した後で、
+``resolve`` コマンドを使用してBazaarにそれらを解決したものとしてマークするように頼みます::
+
+  bzr resolve
+
+代わりに、それぞれのファイルを修正した後で、これを解消したものとしてマークできます::
+
+  bzr resolve foo
+
+``resolve`` コマンドは作業ツリーからBASE, THIS, OTHERファイルをクリーンナップします。
+
+remergeコマンドを使う
+---------------------
+
+いくつかの場合、任意のファイルに対して異なるマージアルゴリズムを試したいことがあります。
+これを行うためには、ファイルを次のように指定して ``remerge`` コマンドを使います::
+
+  bzr remerge --weave foo
+
+``foo`` はファイルで ``weave`` オプションは利用可能なマージアルゴリズムです。
+いわゆる ``criss-cross`` (十字遺伝)マージが検出されたときに、
+たとえば、2つのブランチが同じものをマージしてからお互いをマージするときに、\
+このアルゴリズムはとりわけ便利です。
+詳細については ``criss-cross`` と ``remerge`` のオンラインヘルプを参照してください。
+
+衝突を解消するために外部ツールを利用する
+-----------------------------------------
+
+衝突を解消するためにGUIツールを利用したいのであれば、
+*extmerge* プラグインをインストールしてください。次のようにインストールできます::
+
+  bzr extmerge foo
+
+``foo`` は衝突したファイルです。
+解消するファイルの一覧を提供するよりも、すべての衝突ファイルを暗黙の内に指定するために ``--all`` オプションを利用できます。
+
+``extmerge`` コマンドは ``bazaar.conf`` ファイルの中の ``external_merge`` 設定によって指定されるツールを使います。
+設定されていなければ、 ``kdiff3`` もしくは ``opendiff`` のような人気のあるマージツールが設定されます。
+後者はOS XのFileMergeのコマンドラインインターフェイスです。

=== added file 'doc/ja/user-guide/reusing_a_checkout.txt'
--- doc/ja/user-guide/reusing_a_checkout.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/reusing_a_checkout.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,83 @@
+チェックアウトを再利用する
+===========================
+
+動機
+-----
+
+時々、複数のブランチに取り組むために単独のチェックアウトを\
+サンドボックスとして持つことは便利です。
+挙げられる理由のいくつかは次の内容を含みます:
+
+ * 作業ツリーが大きいときディスクスペースを節約する
+ * 固定された位置で開発する
+
+多くの場合、作業ツリーのディスクの利用量は ``.bzr`` ディレクトリよりも
+大きくなります。
+複数のブランチに取り組みたいが、それぞれの作業ツリーすべてのオーバーヘッドを\
+許容できない場合、複数のブランチをまたがってチェックアウトを再利用することが\
+うまくゆく方法です。
+
+他の機会において、サンドボックスの位置は数多くの開発とテストツールに設定されます。
+繰り返しますが、複数のブランチをまたがったチェックアウトの再利用は役に立ちます。
+
+
+ブランチが結びつけられた場所を変更する
+---------------------------------------
+
+チェックアウトが結びつけられている場所を変更するためには、次の手順に従います:
+
+ 1. 作業内容が失われないようにローカルの変更が中央ブランチにコミット
+    されたことを確認します
+
+ 2. 取り組みたい新しいリモートブランチのURLを渡して ``bind`` コマンドを使います
+
+ 3. ``revert`` コマンドの後に続いて ``update`` コマンドを使用して望むブランチの
+    コピーをチェックアウトします
+
+新しいブランチに bind して update するだけだと、コミットしたもの、していないもの\
+両方のローカルの変更がマージされることに注意してください。
+``revert`` か ``commit`` を使って、それらを維持するか破棄するかを決めなければ\
+いけません。
+
+bind+update レシピの代わりは ``switch`` コマンドを使うことです。これは基本的に、\
+ツリーの中のコミットされていない変更がマージされること以外は、既存のブランチを\
+除去して新しい位置で ``checkout`` を再び実行することと同じです。
+
+注: 場合によってバインドされた異なるブランチの適切なキャッシュをチェックアウトするために
+``switch`` はコミットされた変更を廃棄するので、ローカルにコミットされているが最も最近\
+バインドされたブランチにまだコミットされていない変更が存在する場合意図的に失敗します。
+これらの変更を本当に廃棄したいのであれば、 ``--force`` オプションを使います。
+
+
+軽量型チェックアウトを切り替える
+----------------------------------
+
+軽量型チェックアウトでは、ローカルのコミットは存在せず、 ``switch`` は\
+作業ツリーが関連づけられたブランチを効率よく選びます。
+1つの可能なセットアップ方法は、ローカルツリーなしのリポジトリと軽量\
+チェックアウトを組み合わせて使うことです。
+これによって取り組むものを簡単に切り替えることができます。例です::
+
+  bzr init-repo --no-trees PROJECT
+  cd PROJECT
+  bzr branch sftp://centralhost/srv/bzr/PROJECT/trunk
+  bzr checkout --lightweight trunk my-sandbox
+  cd my-sandbox
+  (hack away)
+
+この例のこの範囲でtrunk ``.bzr`` ディレクトリを持ちますがそこでの\
+ブランチとしての作業ツリーはツリーなしのリポジトリで作られたことに\
+注意してください。必要な数だけブランチを入手もしくは作成して必要に\
+応じてそれらの間で切り替えることができます。例です::
+
+  (my-sandboxの中にいることを前提とする)
+  bzr branch sftp://centralhost/srv/bzr/PROJECT/PROJECT-1.0 ../PROJECT-1.0
+  bzr switch ../PROJECT-1.0
+  (fix bug in 1.0)
+  bzr commit -m "blah, blah blah"
+  bzr switch ../trunk
+  (go back to working on the trunk)
+
+注: ブランチはローカルのみのものでも、(``checkout`` で作るか ``branch``
+でそれらを作った後で ``bind`` を使うことで)リモートのブランチにバインド\
+されたものでも可能です。

=== added file 'doc/ja/user-guide/reviewing_changes.txt'
--- doc/ja/user-guide/reviewing_changes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/reviewing_changes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,50 @@
+変更をレビューする
+==================
+
+リープする前にロックする
+-------------------------
+
+作業が完了したら、恒久的に記録することに先駆けて変更をレビューするのはよい考えです。
+この方法で、何を意図しているのかをコミットすることを確認できます。
+
+2つのbzrコマンド: **status** と **diff** はとりわけ便利です。
+
+bzr status
+----------
+
+ **status** コマンドは最後のリビジョン以降に作業ディレクトリに行われた変更内容を伝えます::
+
+    % bzr status
+    modified:
+       foo
+
+``bzr status`` は 変更されないもしくは無視される "つまらない" ファイルを隠します。
+statusコマンドはチェックするためにオプションとしてファイルもしくはディレクトリの名前を渡すことができます。
+
+bzr diff
+--------
+
+The **diff** コマンドはすべてのファイルへの変更の全文を標準のunified diffとして表示します。
+これは ''patch''、 ''diffstat''、 ''filterdiff'' と ''colordiff''といった多くのプログラムを通してパイプで引き渡すことができます::
+
+    % bzr diff
+    === added file 'hello.txt'
+    --- hello.txt   1970-01-01 00:00:00 +0000
+    +++ hello.txt   2005-10-18 14:23:29 +0000
+    @@ -0,0 +1,1 @@
+    +hello world
+
+
+``-r`` オプションによって、ツリーは前のリビジョン、もしくは示された2つのリビジョンの違いを表示します::
+
+    % bzr diff -r 1000..          # everything since r1000
+    % bzr diff -r 1000..1100      # changes from 1000 to 1100
+
+``--diff-options`` オプションによってbzrは外部のdiffプログラムにオプションを渡して実行します。例です::
+
+    % bzr diff --diff-options --side-by-side foo
+
+プロジェクトの中には新旧のファイルのためのパスの始めで接頭辞を表示するためにパッチを好むところもあります。
+``--prefix`` オプションはそのような接頭辞を提供するために使われます。
+ショートカットとして、 ``bzr diff -p1`` は ``patch -p1`` コマンドで機能する形式を生み出します。
+

=== added file 'doc/ja/user-guide/sending_changes.txt'
--- doc/ja/user-guide/sending_changes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/sending_changes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,65 @@
+変更を送信する
+===============
+
+動機
+-----
+
+多くの分散型のシナリオでは、開発者にとってURLを公開することでタスクブランチを\
+共有することが常に現実的であるとは限りません。
+たとえば、開発者が在宅で一晩中作業をする場合、ゲートキーパーが別のタイムゾーンで\
+レビューしてマージしたいときに開発者はタスクブランチに十分にアクセスできません。
+
+Bazaarは手助けする巧妙な機能: *マージディレクティブ* を提供します。
+
+マージのディレクティブを理解する
+---------------------------------
+
+マージディレクティブを"ミニブランチ" - ブランチが作成された後の成長部分 -
+として考えることができます。
+これは変更点を記したソフトウェアパッチですが、追加情報として中間コミット、\
+リネームとデジタル署名のようなメタデータがつきます。
+
+別の実用的なメタファはパケットケーキ: レシピと必要な材料を持った\
+マージディレクティブです。
+具体的にいえば、材料とはブランチ上で加えられた全ての変更のメタデータで、\
+レシピとはそれらの変更点をどうやってマージするかで、 ``merge`` コマンドが\
+共通の祖先を選ぶのに利用する情報です。
+
+それらをどのように考えるのであれ、マージディレクティブはよいものです。
+これらは簡単に作れて、メールに添付して送信するのに最適で、受け取った後で\
+ブランチと同じように処理できます。
+
+マージディレクティブを作る
+-----------------------------
+
+マージディレクトリを作りオプションとして送信するためには、 ``send`` コマンドを使います。
+
+デフォルトでは、 ``send`` はマージディレクティブを ブランチのための "投稿アドレス" 、
+通常はリード開発者もしくは開発メーリングリストにEメールを送信します。
+オプションなしの ``send`` はマージディレクティブを作り、Eメールツールを作動させて添付し、\
+少しの説明文を追加するための準備をします。
+(この設定方法の詳細に関してはオンラインヘルプの ``send`` と
+リファレンスマニュアルの `構成設定 <../user-reference/bzr_man.html#configuration-settings>`_
+を参照)
+
+大抵のプロジェクトではパッチ付きのメールに説明文を追加し、パッチの理由と内容を説明します。
+これによってレビューワは行単位の差分に入る前にいくらかの事情を理解できます。
+
+代わりに、 ``--output`` (or ``-o``) オプションが渡されると、 ``send``
+はマージディレクティブをファイルに書くので、あなた自身にメールを送り、
+それを検査し、後の使用のために保存できます。
+``-`` の出力ファイルが渡されると、ディレクティブはstdoutに書き込まれます。例です::
+
+  cd X-fix-123
+  bzr send -o ../fix-123.patch
+
+
+マージのディレクティブを適用する
+---------------------------------
+
+``merge`` と ``pull`` コマンドを使うことでマージディレクティブはブランチと同じ方法で\
+適用できます
+
+これらはBazaarを使わない上流のプロジェクトとコミュニケーションをするときにも便利です。
+とりわけ、マージディレクティブ内の変更全体のプレビューは無地のソフトウェアパッチの\
+ようになるので、たとえば彼らは ``patch -p0`` を使用してそれらを適用できます。

=== added file 'doc/ja/user-guide/server.txt'
--- doc/ja/user-guide/server.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/server.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,94 @@
+スマートサーバーを稼働させる
+============================
+
+BazaarはHTTP、FTPもしくはSFTPを通して動作するので特化したサーバーは\
+必須ではありません。
+SSH、inetd、もしくは専用モードで起動できるスマートサーバー(smart server)\
+の選択肢があります。
+
+ダムサーバー
+-------------
+
+HTTP、FTP、SFTPとHTTP-WebDAVを"ダム(dumb)"サーバーとして記述します。
+これらはBazaarに支援を提供しないからです。
+これらのプロトコルのどれかを通してBazaarリポジトリを利用できるようにする場合、
+Bazaarはリモートからの読み込みを許可します。
+実行しているBazaarコマンドの中でブランチへのURLを入力するだけです。::
+
+    bzr log http://bazaar-vcs.org/bzr/bzr.dev
+
+BazaarはFTP、SFTPと(プラグインを通した)HTTP-WebDAVを通した書き込みをサポートします。
+
+ハイパフォーマンスなスマートサーバー
+-------------------------------------
+
+ハイパフォーマンスなスマートサーバー(hpss - high-performance smart server)は\
+いくつかのオペレーションをダムサーバーよりも遙かに高速に実行します。
+開発者がパフォーマンスのチューニングを継続するので、将来のリリースでは\
+スマートサーバーを利用することで改善されるオペレーションの範囲は増えます。
+
+高度なセキュリティの維持を可能にするために、
+デフォルトでは現在のスマートサーバーはリードオンリーになります。
+読み込みと書き込み権限を有効にするには、 ``--allow-writes`` で動かします。
+SSHアクセスメソッドを利用するとき、bzrは ``--allow-writes`` オプションで\
+自動的に実行します。
+
+次はスマートサーバーの代替の設定方法を説明します。
+
+SSH
+~~~
+
+SSHを通してBazaarを利用する際にサーバー上の特別な設定は必要ありません::
+
+    BZR_REMOTE_PATH=~/bin/bzr bzr log bzr+ssh://host/path/to/branch
+
+``BZR_REMOTE_PATH`` 環境変数はリモートシステムで `bzr` が起動する方法を調整します。
+デフォルトでは単に `bzr` として起動するので、 `bzr` 実行ファイルはデフォルトの\
+検索パス上にあることが要求されます。
+
+``bzr+ssh://`` URLスキームはファイルシステムのrootからの絶対パスだけをサポートします。
+将来のバージョンでは ``sftp://`` URL (https://bugs.launchpad.net/bzr/+bug/109143) と同じように
+``~`` もサポートされる予定です。
+
+inetd
+~~~~~
+
+この例では ``/srv/bzr/repo/branchname`` にブランチがある ``/srv/bzr/repo`` 内の
+共用リポジトリ用に専用ユーザーの `bzruser` で `bzr` を実行する方法を示しています。
+
+inetdからBazaarサーバーを動かすにはinetd.confエントリが必要です::
+
+    4155  stream  tcp  nowait  bzruser  /usr/bin/bzr /usr/bin/bzr serve --inet --directory=/srv/bzr/repo
+
+クライアントコマンドを実行するとき、提供するURLは
+inetd.confに渡される ``--directory`` オプションに相対的な `bzr://` です::
+
+    bzr log bzr://host/branchname
+
+専用サーバー
+~~~~~~~~~~~~~
+
+このモードはinetdモードと同じパスとURLのふるまいを持ちます。
+特定のユーザーとして実行するには、 ``su`` を使うもしくはそのユーザーとしてログインします。
+
+この例では公式のポート番号の `4155` 上でbzrを稼働しすべてのインターフェイス上でリスンします。
+これによってポート `4155` 上のマシンに到達できる世界のどこからでも接続できます。
+
+サーバー::
+
+    bzr serve --directory=/srv/bzr/repo
+
+クライアント::
+
+    bzr log bzr://host/branchname
+
+この例では `localhost` のポート `1234` で ``bzr serve`` が実行されます。
+
+サーバー::
+
+    bzr serve --port=localhost:1234 --directory=/srv/bzr/repo
+
+クライアント::
+
+    bzr log bzr://localhost:1234/branchname
+

=== added file 'doc/ja/user-guide/setting_up_email.txt'
--- doc/ja/user-guide/setting_up_email.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/setting_up_email.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,93 @@
+Eメールを設定する
+=================
+
+.. Bazaarでコミット用のEメールを指定するさまざまな方法の説明です。
+
+なぜBazaarでEメールアドレスをセットアップするのか？
+---------------------------------------------------
+
+リビジョンが作成されたとき誰がどのリビジョンをコミットしたのかわかるように
+Bazaarは指定されたEメールアドレスをリビジョンに保存します。
+Eメールアドレスは検証されないので、それゆえ 偽造できるので、プロジェクトに関わる人々を信用しなければなりません。
+
+加えて、リビジョンのEメールアドレスはクレジットかつ/もしくは注釈に関してリビジョンの筆者とコンタクトをとる別の方法を提供します。
+
+Eメールアドレスをセットアップする方法
+--------------------------------------
+
+Eメールアドレスが設定されていない場合、Bazaarはユーザー名とホスト名に基づいて推測を試みます。
+これは望む状況ではないかもしれないので、Bazaarに使うメールを伝える方法は3つ存在します:
+
+いくつかの設定ファイルの1つにEメールを設定できます。
+他の設定値のように、 ``bazaar.conf`` で一般的な設定として設定できます。
+特定のブランチ、もしくは複数のブランチの一式用に値を上書きしたい場合、 ``locations.conf`` を利用できます。
+``.bzr/branch/branch.conf`` も動作しますが、
+他の人であってもそのブランチへのすべてのコミットで同じEメールアドレスが使われます。
+
+優先順位は
+
+ 1. ``BZR_EMAIL`` 環境変数が設定されている場合
+ #. Eメールが現在のブランチの ``locations.conf`` ファイルに対して設定されている場合。
+ #. Eメールが現在のブランチの ``.bzr/branch/branch.conf`` ファイルに設定されている場合。
+ #. Eメールがデフォルトの ``bazaar.conf`` 設定ファイルで設定されている場合。
+ #. `EMAIL` 環境変数が設定されている場合
+ #. Bazaarはユーザー名とホスト名から推測しようとします。
+
+Bazaarが現在のEメールと考えるものを確認するには、 ``whoami`` ("who am i?") コマンドを使います::
+
+    % bzr whoami
+    Joe Cool <joe@example.com>
+
+'whoami'コマンドでEメールを設定する
+------------------------------------
+
+Eメールをグローバルに設定するにはwhoamiコマンドを使用します::
+
+    % bzr whoami "Joe Cool <joe@example.com>"
+
+もしくは現在のブランチのみの場合::
+
+    % bzr whoami --branch "Joe Cool <joe@example.com>"
+
+これらのコマンドによってグローバルな ``bazaar.conf`` もしくはブランチの ``branch.conf`` ファイルがそれぞれ修正されます。
+
+デフォルトの設定ファイルでEメールを設定する
+--------------------------------------------
+
+デフォルトのiniファイルを使うには、 ``bazaar.conf`` ファイル
+(Linuxでは ``~/.bazaar/`` 、Windowsでは ``%APPDATA%\bazaar\2.0\`` )を作成し編集して下記で示すようにEメールアドレスを設定します。
+DEFAULTは大文字と個別を区別して、大文字でなければならないことに注意をお願いします。
+::
+
+    [DEFAULT]
+    email=Your Name <name@isp.com>
+
+
+iniファイルのフォーマットの詳細情報に関しては、Bazaarユーザーリファレンスの `構成設定 <../user-reference/bzr_man.html#id21>`_ を参照してください。
+
+ブランチ単位でEメールを設定する
+--------------------------------
+
+2番目のアプローチは ``locations.conf`` 設定ファイルを使用してブランチごとにEメールを設定する方法です::
+
+    [/some/branch/location]
+    email=Your Name <name@other-isp.com>
+
+これによってブランチのEメールアドレスは ``/some/branch/location`` に設定され、
+上記の ``bazaar.conf`` で指定されたデフォルトの値を上書きします。
+
+環境変数を通してEメールを設定する
+---------------------------------
+
+Bazaarが利用する最後の方法は ``BZR_EMAIL`` と ``EMAIL`` 環境変数 に対するチェックです。
+一般的に、スクリプトのコンテキストでEメールを上書きするためにこの方法を利用できます。
+一般的なデフォルトの値に設定したい場合、上記のiniの方法を参照して下さるようお願いします。
+
+スパムに関する懸念事項
+-----------------------
+
+スパムの標的にされないようにEメールアドレスを共有したくない人達がいます。
+公開された場所で自分でブランチもしくはチェンジセットを公開しない限り、BazaarはけっしてEメールアドレスを露出しません。
+他の人があなたに作業内容に関して連絡できるように実際のアドレスを使うことを *強く* お勧めしますが、必須ではありません。
+メールアドレスは難読にしたり、宛先がわからず戻ってくるようにする、もしくは `spamgourmet.cm` のような
+アンチスパムサービスの検査をうけさせたりします。

=== added file 'doc/ja/user-guide/shared_repository_layouts.txt'
--- doc/ja/user-guide/shared_repository_layouts.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/shared_repository_layouts.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,363 @@
+共用レポジトリのレイアウト
+===========================
+
+Bazaarは共用ブランチ内部のブランチのレイアウトを柔軟に決められるように設計されました。
+この柔軟性によってユーザーはBazaarを自分のワークフローに合わせることができますが、\
+"よい"レイアウトとは何かということを疑問に持つようになります。
+ここでは代わりになるものをいくつか説明しそれぞれの利点を検討します。
+
+言及すべき重要な点はよいレイアウトは"一般的な"ユーザーが理解できるように
+ブランチの内容を何らかの形でハイライトします。
+SVNにおいて これは "``trunk/``" ブランチであると考えられ、
+大抵のレイアウトではこの命名規約が守られています。
+これを "``mainline``" もしくは "``dev``" と呼ぶ人もいれば、
+CVSから来た人々はしばし "``HEAD``" と言及します。
+
+
+"SVN形式" (``trunk/``, ``branches/``)
+---------------------------------------
+
+SVNからやってきた人々は次のような"標準的な"プロジェクトのレイアウトに慣れています::
+
+  repository/       # リポジトリ全体
+   +- trunk/        # 開発のメインライン
+   +- branches/     # コンテナディレクトリ
+   |   +- foo/      # 開発中のfoo機能用ブランチ
+   |     ...
+   +- tags/         # コンテナディレクトリ
+       +- release-X # 特定のリリースバージョンをマークするために専用ブランチ
+          ...
+
+Bazaarでは、これは完全に適切なレイアウトです。
+SVNからやって来た人が慣れ親しめることが利点で\
+開発の焦点を当てる場所が明確になります。
+
+同じリポジトリで複数のプロジェクトを持つとき、\
+SVNのレイアウトは何を行うのか少し不透明です。
+
+
+``project/trunk``
+~~~~~~~~~~~~~~~~~
+
+SVN用の望ましい方法はプロジェクトごとにレイアウト用のトップレベルのディレクトリを用意することです::
+
+  repository/            # リポジトリ全体
+   +- project1/          # コンテナディレクトリ
+   |   +- trunk/         # project1の開発のメインライン
+   |   +- branches/      # コンテナディレクトリ
+   |       +- foo/       # project1のfoo機能の開発用ブランチ
+   |         ...
+   |
+   +- project2/          # project2用のコンテナ
+       +- trunk/         # project2用のメインライン
+       +- branches/      # project2のブランチ用のコンテナ
+
+
+これはBazaarでも機能します。
+しかしながら、Bazaarでリポジトリを作るのは簡単で( ``bzr init-repo`` )、
+それらの主要な恩恵を受けられるのは複数のブランチが共通の祖先を共有するときです。
+
+ですのでBazaarに対して望ましい方法は次のとおりです::
+
+    project1/          # project1用のリポジトリ
+     +- trunk/         # project1の開発のメインライン
+     +- branches/      # コンテナディレクトリ
+         +- foo/       # project1のfoo機能の開発用ブランチ
+           ...
+
+    project2/          # project2用のリポジトリ
+     +- trunk/         # project2用のメインライン
+     +- branches/      # project2のブランチ用のコンテナ
+
+
+``trunk/project``
+~~~~~~~~~~~~~~~~~
+
+SVNで次のようなレイアウトを利用するプロジェクトもたまにあります::
+
+  repository/             # リポジトリ全体
+    +- trunk/             # コンテナディレクトリ
+    |   +- project1       # project1用のメインライン
+    |   +- project2       # project2用のメインライン
+    |         ...
+    |
+    +- branches/          # コンテナ
+        +- project1/      # コンテナ (?)
+        |   +- foo        # project1の'foo'ブランチ
+        +- project2/
+            +- bar        # project2の'bar'ブランチ
+
+
+次のレイアウトはちょっと変形させたものです::
+
+  repository/             # リポジトリ全体
+    +- trunk/             # コンテナディレクトリ
+    |   +- project1       # project1用のメインライン
+    |   +- project2       # project2用のメインライン
+    |         ...
+    |
+    +- branches/          # コンテナ
+        +- project1-foo/  # project1の'foo'ブランチ
+        +- project2-bar/  # project2の'bar'ブランチ
+
+"``trunk/``" 全体をチェックアウトすることで、すべてのプロジェクト用の\
+メインラインを入手できるようにすることが、このレイアウトが採用されている理由だと\
+筆者は考えます。
+
+このレイアウトはBazaarでも使えますが、一般的にお勧めできません。
+
+ 1) 一回の ``bzr branch/checkout/get`` は一つのブランチを作ります。
+    単独のコマンドですべてのメインラインを入手する利点が得られません。 [1]_
+
+ 2) ``repository/trunk/foo`` が ``foo`` プロジェクトの ``trunk`` か
+    ``trunk`` ブランチの単なる ``foo`` ディレクトリなのか明らかではありません。
+    この混乱の一部はSVNによるものです。
+    SVNはプロジェクトのブランチ用に使う1つのプロジェクトのファイルに対して同じ"名前空間"を使うからです。
+    Bazaarにおいて、プロジェクトを構成するファイルの明確な定義、もしくはブランチの位置の対立軸があります
+    (ブランチごとに唯一の ``.bzr/`` ディレクトリか、チェックアウトの中にたくさんの
+    ``.svn/`` ディレクトリかという対立軸です)
+
+.. [1] 注: `NestedTreeSupport`_ は"メタプロジェクト"を作成する方法を提供します。
+    メタプロジェクトはリポジトリのレイアウトにかかわらず複数のプロジェクトを集約します。
+    1つのプロジェクトを ``bzr checkout`` すれば、必要なサブプロジェクトがすべて手に入ります。
+
+.. _NestedTreeSupport: http://bazaar-vcs.org/NestedTrees
+
+
+入れ子形式 (``project/branch/sub-branch/``)
+---------------------------------------------
+
+SVNではできない、Bazaarによる別のスタイルは、ブランチ同士を\
+入れ子にすることです。
+Bazaarは作業ツリーなしのリポジトリ作成(``--no-trees``)をサポート\
+(と推奨)しているのでこのスタイルが可能になります。
+作業ファイルはブランチの設置場所に混ぜられていないので、 好きな名前空間にブランチを設置できます。
+
+1つの可能性は次のとおりです::
+
+  project/             # リポジトリ全体、*と* プロジェクトのメインラインのブランチ
+   + joe/              # 開発者Joeの開発のプライマリブランチ
+   |  +- feature1/     # 開発者Joeのfeature1開発ブランチ
+   |  |   +- broken/   # feature1を開発するためのステージングブランチ
+   |  +- feature2/     # Joeのfeature2開発ブランチ
+   |    ...
+   + barry/            # Barryの開発ブランチ
+   |  ...
+   + releases/
+      +- 1.0/
+          +- 1.1.1/
+
+このレイアウトのアイディアはブランチ用の階層的なレイアウトを作ることです。
+変更はたいていより上位の名前空間のブランチへと流れていきます。
+また、このレイアウトではユーザーに独自の作業をするための場所も提供します。
+このレイアウトの素晴らしい点の1つは、グローバルな ``branches`` 名前空間を\
+散らかさずにミニブランチを置けるので、ブランチ作成が"手軽"になることです。
+
+このレイアウトのもう一つの利点は、ブランチの名前の中で詳細な内容を指定する際に\
+繰り返しが減ることです。
+
+例です::
+
+  bzr branch http://host/repository/project/branches/joe-feature-foo-bugfix-10/
+
+上と下を比較します::
+
+  bzr branch http://host/project/joe/foo/bugfix-10
+
+
+また、 ``repository/project/branches/`` ディレクトリの中のリストがあれが何かわかるかもしれません::
+
+  barry-feature-bar/
+  barry-bugfix-10/
+  barry-bugfix-12/
+  joe-bugfix-10/
+  joe-bugfix-13/
+  joe-frizban/
+
+Versus こういったブランチが開発者のディレクトリに分散している。
+ブランチの数が少なければ、 ``branches/`` は一見するだけですべての\
+ブランチが見えるという素晴らしい利点があります。
+ブランチの数が多ければ、 ``branches/`` はすべてのブランチが\
+見えてしまうというはっきりした欠点があります。
+(調べるブランチが100あるとき、興味のあるブランチを見つけるのが難しくなります)。
+
+入れ子ブランチはたくさんのブランチよりもスケーラブルのようです。
+しかしながら、それぞれの個別のブランチは見つけにくいです。
+(たとえば"Joeはfoo機能ブランチでバグ修正10に取り組んでいるのか、\
+それともbarの機能ブランチを取り組んでいるのか？")
+
+他の小さな利点は次のようなものです::
+
+   bzr branch http://host/project/release/1/1/1
+  もしくは
+   bzr branch http://host/project/release/1/1/2
+
+1.1.1と1.1.2のリリースを示します。
+これはリリースする数と一度に見られる能力よりも分割する方がゲインが多いかによります。
+
+
+ステータスによる種類分け (``dev/``, ``merged/``, ``experimental/``)
+---------------------------------------------------------------------
+
+ブランチをbreak upする他の方法はこれらを現在のステータス順でソートすることです。
+そうするとレイアウトは次のようになります::
+
+  project/               # レイアウト全体
+   +- trunk/             # 開発に焦点を当てたブランチ
+   +- dev/               # 進行中の作業用コンテナディレクトリ
+   |   +- joe-feature1   # Joeの現在のfeature-1ブランチ
+   |   +- barry-bugfix10 # bugfix 10に対するBarryの作業内容
+   |    ...
+   +- merged/            # これらのブランチがマージされたことを示すコンテナ
+   |   +- bugfix-12      # すでにマージされたバグ修正
+   +- abandonded/        # 'dead-end'と見なされているブランチ
+
+
+これはたくさんの利点と欠点があります。
+あまり多くない数のアクティブに開発されているブランチを見ることができるか、\
+今までに作られた全てのブランチが見えるかという違いがあります。
+古いブランチは削除しない限り失われませんが、別ディレクトリへと整理されるので\
+たいていの場合お目当てのブランチを見つけやすくなります。
+(反対に、古いブランチは見つけにくくなります)。
+
+このレイアウトで最大の欠点、ブランチが移動することです。
+誰かが ``project/dev/new-feature`` ブランチをフォローしているとき、
+そのブランチが  ``trunk/`` にマージされると ``project/merged/new-feature``
+に移動するので ``bzr pull`` が突然機能しなくなります。
+この回避策はいくつかあります。
+1つは利用者を導くために古いブランチから新しいブランチにリクエストする\
+HTTPリダイレクトを使うことです。
+``bzr`` >= 0.15 ではユーザーに ``http://old/path が http://new/path``
+にリダイレクトされることを教えてくれます。
+しかしながら、HTTP以外の方法(SFTP、ローカルファイルシステム、など)を\
+通してブランチにアクセスしている場合は役に立ちません。
+
+一時的なリダイレクト用にシンボリックリンクを利用することも可能です
+(シンボリックリンクがリポジトリ内にある限りトラブルはほんのわずかしかありません)。
+しかし、シンボリックリンクを結局削除したくなったり、散乱の削減の恩恵を得られません。
+シンボリックリンクの代わりの別の可能性は ``BranchReference`` を使うことです。
+``bzr`` コマンドを通してこれらを作るのは現時点では難しいですが、便利だと思う人がいれば変わるかもしれません。
+これは実際には `Launchpad`_ が ``bzr checkout https://launchpad.net/bzr`` をできるようにしている方法です。
+``BranchReference`` は機能的にはシンボリックリンクですが、他のURLの参照ができます。
+相対パスによる参照ができるように拡張されれば、http、sftp、ローカルパスを通しても\
+動作するでしょう。
+
+.. _Launchpad: https://launchpad.net
+
+
+日付/リリース/その他で種類分け (``2006-06/``, ``2006-07/``, ``0.8/``, ``0.9``)
+------------------------------------------------------------------------------
+
+スケーラビリティを可能にする別の方法は"現在の"ブランチのブラウジングを許可することです。
+基本的に、活発に開発されるブランチは新しく作られ古いブランチはマージもしくは\
+廃棄されることを前提とします。
+
+基本的に日付レイアウトは次のようになります::
+
+  project/                # projectリポジトリ全体
+   +- trunk/              # 一般的なメインライン
+   +- 2006-06/            # この月に作成されたブランチ用のディレクトリのコンテナ
+   |   +- feature1/       # "project"の"feature1"用ブランチ
+   |   +- feature2/       # "project"の"feature2"用ブランチ
+   +- 2005-05/            # 異なる月に作成されるブランチ用のコンテナディレクトリ
+       +- feature3/
+       ...
+
+これは "私の新しいブランチをどこに設置すればいいの？" という質問に素早く答えてくれます。
+機能が長期間開発されるのであれば、ブランチを最新の日付にコピーして、\
+そこで作業を続けることも道理にかなっています。
+最新の日付と、そこからのさかのぼっていくことで活発なブランチを見つけることができます。
+(小さな欠点は 大抵のディレクトリリストは古い順にソートされているので、\
+多くの場合新しいブランチにたどり着くために余計なスクロールが必要になることです)。
+古いブランチを新しい位置にコピーしたくない場合、ブランチを探すのが面倒になるのも欠点です。
+
+別の候補は、リリースをターゲットにしたものです::
+
+  project/          # リポジトリ概要
+   +- trunk/        # メインラインの開発ブランチ
+   +- releases/     # リリースブランチ用のコンテナ
+   |   +- 0.8/      # リリース0.8のブランチ
+   |   +- 0.9/      # リリース0.9のブランチ
+   +- 0.8/          # リリース0.8をターゲットとするブランチ用のコンテナ
+   |   +- feature1/ # 0.8にマージする予定の"feature1"用のブランチ
+   |   +- feature2/ # "リリース0.8をターゲットとしたfeature2"用のブランチ
+   +- 0.9/
+       +- feature3/ # リリース0.9をターゲットとした"feature3"用のブランチ
+
+
+その派生として、ブランチが ``0.9`` ディレクトリに入っていることが 0.9に *向けた*
+ブランチであることではなく 0.9 *から* 派生したブランチであることを意味するように\
+することや、 ``0.8/release`` が0.8ブランチの公式リリースであることを意味するように\
+することが考えられます。
+
+一般的なアイディアはリリースをターゲットにすることで、何のブランチがマージ\
+されるのを待っているのか調べることができます。
+このレイアウトはブランチの状態(開発中なのか、終了してレビューを待っているのか)\
+に関する情報を提供しません。
+これは履歴を隠す効果もあり、日付ベースの種類分けと同じような利点と欠点を持っています。
+
+シンプルな開発者名 (``project/joe/foo``, ``project/barry/bar``)
+----------------------------------------------------------------
+
+別の利用できるレイアウトは、開発者ごとにディレクトリを割り当てて、\
+その下にブランチのためのサブディレクトリを作ることです。次のようになります::
+
+  project/      # リポジトリ全体
+   +- trunk/    # メインラインのブランチ
+   +- joe/      # Joeのブランチ用のコンテナ
+   |   +- foo/  # Joeの"project"の"foo"ブランチ
+   +- barry/
+       +- bar/  # Barryの"project"の"bar"ブランチ
+
+このアイデアでは、branchは入れ子になっておらず、branchは開発者によってのみ\
+グループ化されます。
+
+`Launchpad`_ で使われている派生系はこのようになっています::
+
+  repository/
+   +- joe/             # Joeのブランチ
+   |   +- project1/    # Joeのブランチである"project1"用のコンテナ
+   |   |   +- foo/     # Joeの"project1"の"foo"ブランチ
+   |   +- project2/    # Joeの"project2"ブランチ用のコンテナ
+   |       +- bar/     # Joeの"project2"の"bar"ブランチ
+   |        ...
+   |
+   +- barry/
+   |   +- project1/    # Barryの"project1"のブランチ用のコンテナ
+   |       +- bug-10/  # Barryの"project1"の"bug-10"ブランチ
+   |   ...
+   +- group/
+       +- project1/
+           +- trunk/   # "project1"に焦点をあてたメイン開発
+
+
+このレイアウトではそれぞれの開発者が取り組んでいるものを簡単に見ることができます。
+焦点のブランチは"group" ディレクトリに保存されます。
+これによって"グループ"が取り組んでいるブランチを見分けられます。
+
+これによって異なる人々の作業内容をそれぞれ分離できますが、\
+"プロジェクトX用のすべてのブランチ"を見つけるのが難しくなります。
+`Launchpad`_ はデータベースバックエンドを伴う素晴らしいウェブインターフェイス\
+を提供していて、"view"をこのレイアウトのトップに追加することでこの欠点を補っています。
+これはそれぞれの個人が "``~/public_html``" ディレクトリを持ち、そこで独自の\
+ウェブページを公開する個人用ホームページのモデルに近いです。
+一般的に、集中型のプロジェクト用に共用リポジトリを作成するとき、\
+個人単位で分割してからプロジェクト単位に分割することを望まないでしょう。
+通常はプロジェクト単位で分割してから個人単位で分割するとよいでしょう。
+
+要約
+-----
+
+最後に、誰にとってもうまくいく唯一の命名規則はありません。
+開発者の人数、新しいブランチが作成される頻度、ブランチのライフサイクルなどに\
+よって異なります。
+自身に問いかける質問は次のとおりです:
+
+  1) 寿命の長い少数のブランチを作るか、もしくはたくさんの"ミニ"機能ブランチを作るか
+     (加えて:  ミニ機能ブランチをたくさん *作りたい* が現在のVCSでは苦痛なのでできないのではないか？)
+
+  2) 1人で開発しているのか、大きなチームか？
+
+  3) チームであれば、一般的に全員が同時に同じブランチに取り組むことを計画しているか？
+     もしくは人々が追跡することを想定した"安定"ブランチを持つか。
+

=== added file 'doc/ja/user-guide/shelving_changes.txt'
--- doc/ja/user-guide/shelving_changes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/shelving_changes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,109 @@
+Shelving Changes
+================
+
+ときどき、作業ツリーから一時的に変更点を取り除いて、あとで元に戻したいことが\
+あるかもしれません。
+たとえば何か作業中に小さいバグフィックスを見つけてコミットする場合などです。
+Bazaarは変更を ``shelf`` (書棚)に保存する機能を持っています。
+後で変更を元に戻したくなったときは、 ``unshelve`` を使って作業ツリーに戻す\
+ことができます。
+
+たとえば、一つか複数の変更がされた作業ツリーを考えて見ます...::
+
+  $ bzr diff
+  === modified file 'description.txt'
+  --- description.txt
+  +++ description.txt
+  @@ -2,7 +2,7 @@
+   ===============
+
+   These plugins
+  -by Michael Ellerman
+  +written by Michael Ellerman
+   provide a very
+   fine-grained 'undo'
+   facility
+  @@ -11,6 +11,6 @@
+   This allows you to
+   undo some of
+   your changes,
+  -commit, and get
+  +perform a commit, and get
+   back to where you
+   were before.
+
+``shelve`` コマンドはインタラクティブにどの変更を作業ツリーに保留して\
+おきたいのかを質問します。::
+
+  $ bzr shelve
+  --- description.txt
+  +++ description.txt
+  @@ -2,7 +2,7 @@
+   ===============
+
+   These plugins
+  -by Michael Ellerman
+  +written by Michael Ellerman
+   provide a very
+   fine-grained 'undo'
+   facility
+
+  Shelve? [yNfrq?]: y
+  --- description.txt
+  +++ description.txt
+  @@ -11,6 +11,6 @@
+   This allows you to
+   undo some of
+   your changes,
+  -commit, and get
+  +perform a commit, and get
+   back to where you
+   were before.
+
+  Shelve? [yNfrq?]: n
+  Shelve 2 change(s)? [yNfrq?]', 'y'
+  Selected changes:
+   M  description.txt
+  Changes shelved with id "1".
+
+もしたくさんの変更が作業ツリーにあるのであれば、 ``shelve`` コマンド\
+にファイルのリストを渡して、それらのファイルの変更だけについて質問\
+されるようにすることができます。
+変更を shelve した後に ``diff`` コマンドで作業ツリーに期待する変更だけが\
+残っていることを確認するとよいでしょう。::
+
+  $ bzr diff
+  === modified file 'description.txt'
+  --- description.txt
+  +++ description.txt
+  @@ -2,7 +2,7 @@
+   ===============
+
+   These plugins
+  -by Michael Ellerman
+  +written by Michael Ellerman
+   provide a very
+   fine-grained 'undo'
+   facility
+
+よし! - コミットする準備ができました::
+
+  $ bzr commit -m "improve first sentence"
+
+後になって、shelveした変更を作業ツリーに ``unshelve`` コマンドで\
+戻します::
+
+  $ bzr unshelve
+  Unshelving changes with id "1".
+   M  description.txt
+  All changes applied successfully.
+
+もし望むのであれば、複数のアイテムをshelfに置くことができます。
+通常 ``unshelve`` が実行されるたびに最も最近 shelve された変更が\
+元に戻されます。
+明示的にどの変更を戻すのかを指定することで別の順序で unshelve する\
+こともできます。
+
+Bazaarはshelveされた後に変更があっても、shelfの変更を作業ツリーに\
+マージするので、衝突が発生するかもしれません。
+その場合は通常のマージ後と同じように衝突を解決しなければなりません。

=== added file 'doc/ja/user-guide/solo_intro.txt'
--- doc/ja/user-guide/solo_intro.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/solo_intro.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,23 @@
+単独で始める
+=============
+
+個人の生産性を向上させるツール
+--------------------------------
+
+ツールの中には個人を生産的にする(たとえばエディタ)ためや
+チームもしくは会社全体を生産的にする(たとえばバックエンドサービス)ために設計されたものがあります。
+バージョン管理ツールは伝統的に後者の陣営にありました。
+
+Bazaarがクールであることの1つはセットアップが簡単なのでバージョン管理ツールを個人の生産性を上げるツールとして扱うことができることです。
+既知のよい状態であるかチェックする、もしくは履歴を追跡するために変更を保存したい場合、簡単に行うことができます。
+この章では方法を説明します。
+
+単独用途のワークフロー
+-----------------------
+
+あなた独自の名作を作っているのであれば、ソフトウェア、プロジェクトもしくは\
+ドキュメントの一式であれ、典型的なワークフローは次のようになります:
+
+.. image:: images/workflows_single.png
+
+チームの一員として常に作業をするとしても、この章でカバーされるタスクはあなたが行うことの基本になるので、よいスタート地点です。

=== added file 'doc/ja/user-guide/specifying_revisions.txt'
--- doc/ja/user-guide/specifying_revisions.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/specifying_revisions.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,151 @@
+.. _specifying-revisions:
+
+リビジョンを指定する
+====================
+
+.. _revision-identifiers-and-ranges:
+
+リビジョンの識別子と範囲
+-------------------------
+
+Bazaarは1つのリビジョンもしくはリビジョンの範囲を指定するための豊富な表現方法を持ちます。
+リビジョンの範囲を指定するには、上限と下限を ``..`` のシンボルで区切ります。例です::
+
+    $ bzr log -r 1..4
+
+境界値の片方を省略できます::
+
+    $ bzr log -r 1..
+    $ bzr log -r ..4
+
+コマンドの中には範囲ではなく1つのリビジョンだけをとるものがあります。例です::
+
+    $ bzr cat -r 42 foo.c
+
+他の場合、範囲は必要ですが、範囲の長さを1つにします。
+これに関連したコマンドについて、 ``-c`` オプションは次のように使われます::
+
+    $ bzr diff -c 42
+
+.. _available-revision-identifiers:
+
+利用可能なリビジョンの識別子
+------------------------------
+
+リビジョン、もしくは範囲の境界、は
+下記に示される異なるフォーマットを利用して渡すことができます。
+
+ +----------------------+--------------------------------------------+
+ |  引数の型            | 説明                                       |
+ +----------------------+--------------------------------------------+
+ | *number*             | リビジョン番号                             |
+ +----------------------+--------------------------------------------+
+ | **revno**:*number*   | 正のリビジョン番号                         |
+ +----------------------+--------------------------------------------+
+ | **last**:*number*    | 負のリビジョン番号                         |
+ +----------------------+--------------------------------------------+
+ | **revid**:*guid*     | グローバルでユニークなリビジョンID         |
+ +----------------------+--------------------------------------------+
+ | **before**:*rev*     | ''rev''の左端の親                          |
+ +----------------------+--------------------------------------------+
+ | **date**:*value*     | 渡された日付の後の最初のエントリ           |
+ +----------------------+--------------------------------------------+
+ | **tag**:*value*      | 渡されたタグにマッチするリビジョン         |
+ +----------------------+--------------------------------------------+
+ | **ancestor**:*path*  | ブランチからのマージされた最新のリビジョン |
+ +----------------------+--------------------------------------------+
+ | **branch**:*path*    | 別のブランチの最新リビジョン               |
+ +----------------------+--------------------------------------------+
+ | **submit**:*path*    | 投稿ブランチの共通の祖先                   |
+ +----------------------+--------------------------------------------+
+
+これらのフォーマットの手短な紹介は下記のとおりです。
+完全な詳細内容に関しては、 Bazaarユーザーリファレンスの `リビジョンの識別子`_ を参照してください。
+
+.. _リビジョンの識別子: ../user-reference/bzr_man.html#revision-identifiers
+
+番号
+~~~~~
+
+正の数は現在のブランチにおけるリビジョン番号を表します。
+リビジョン番号は ``bzr log`` の出力の中で "revno"とラベルされます。
+最初の10のリビジョンのログを表示するには::
+
+    $ bzr log -r ..10
+
+負の数は最新リビジョンから数えます。-1は最後にコミットされたリビジョンです。
+
+最新の10のリビジョンのログを表示するには::
+
+    $ bzr log -r -10..
+
+revid
+~~~~~
+
+**revid** は ``bzr log`` と他のコマンドによって示される内部のリビジョンIDの指定を可能にします。
+
+例です::
+
+    $ bzr log -r revid:Matthieu.Moy@imag.fr-20051026185030-93c7cad63ee570df
+
+before
+~~~~~~
+
+**before**
+    ''rev''は''rev'' の左端の親を指定します。
+    これはリビジョンの履歴で ''rev'' の前に現れるリビジョン、
+    もしくは ''rev'' がコミットされたときに最新であったリビジョンです。
+
+''rev'' はリビジョンの識別子であり連結できます。
+
+例です::
+
+    $ bzr log -r before:before:4
+    ...
+    revno: 2
+    ...
+
+date
+~~~~
+
+**date**
+    ''value'' は真夜中もしくは指定された時刻での与えられた日付の、
+    深夜12時か指定された時刻の後の最初の履歴エントリにマッチします。
+
+正式な値は次のとおりです:
+
+ * **yesterday**
+ * **today**
+ * **tomorrow**
+ * **YYYY-MM-DD** 書式の日付
+ * **YYYY-MM-DD,HH:MM:SS** 書式の日付/時間、2番目はオプションです (コンマに注意)
+
+"今日のログエントリすべてをください"ということを伝える適切な方法は次のとおりです::
+
+    $ bzr log -r date:yesterday..date:today
+
+Ancestor
+~~~~~~~~
+
+**ancestor**:*path*
+    現在のブランチと異なるブランチ間の共通の祖先を指定します。
+    これはマージの目的に使われる同じ祖先です。
+
+*path* はリモートブランチのURLもしくはローカルブランチへのファイルパスになります。
+
+たとえば、 ``../parent`` からフォークされた以降のブランチで行われた変更を見るには::
+
+    $ bzr diff -r ancestor:../parent
+
+Branch
+~~~~~~
+
+branch
+   ``path`` は別のブランチの最新リビジョンを指定します。
+
+``path`` はリモートブランチのURLもしくはローカルブランチへのファイルパスです。
+
+たとえば、手元のブランチと別のブランチの間の違いを取得するには::
+
+    $ bzr diff -r branch:http://example.com/bzr/foo.dev
+

=== added file 'doc/ja/user-guide/stacked.txt'
--- doc/ja/user-guide/stacked.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/stacked.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,92 @@
+スタックブランチを利用する
+==========================
+
+スタックブランチとは？
+-------------------------
+
+スタックブランチ(stacked branch)は別のブランチのリビジョンを見つける方法を知っています。
+スタックブランチはユニークなリビジョンのみを保存することで、速く作れたり\
+効率的に保存したりします。
+これらの観点から、スタックブランチは共用リポジトリと似ています。
+しかしながら、スタックブランチは追加の利点があります:
+
+* 新しいブランチはスタックされたブランチとは完全に異なる位置に設置できます。
+
+* スタックブランチを削除すれば(共用リポジトリだと残ってしまう)
+  本当のリビジョンも削除されます
+
+* セキュリティは共用リポジトリよりも向上しています。
+  スタックドオンリポジトリはスタックブランチにコミットする開発者に対して物理的にリードオンリーだからです。
+
+これらの恩恵によって実験ブランチとコードホスティングサイトを含めたさまざまな\
+シナリオに対してスタックブランチは理想的なものになります。
+
+スタックブランチを作成する
+-------------------------
+
+スタックブランチを作成するには、branchコマンドの ``stacked`` オプションを使用します。
+例です::
+
+  bzr branch --stacked source-url my-dir
+
+このコマンドによって ``my-dir`` がローカルリビジョンなしのスタックブランチ\
+として作成されます。
+定義されると、 ``source-url`` に関連づけされた公開ブランチは
+*スタックドオン(stacked on)* の位置として使われます。
+さもなければ、 ``source-url`` は *スタックドオン* の位置になります。
+
+
+スタックチェックアウトを作成する
+-----------------------------------
+
+スタックチェックアウトを直接作成する機能はまもなくサポートされる予定です。
+それまでの間、2段階の処理が必要です:
+
+1. 上記で示されたようにスタックブランチを作成する。
+
+2. ``reconfigure`` もしくは ``bind`` コマンドのどちらかを利用して
+   ブランチをチェックアウトに変換する。
+
+
+スタックブランチをプッシュする
+---------------------------------
+
+多くのプロジェクトの大部分の変更は
+*開発トランク* or *現在の安定* ブランチといった既存のブランチを基礎としています。
+これらの1つにスタックされた新しいブランチの作成は ``push`` コマンドを利用して
+次のように簡単にできます::
+
+  bzr push --stacked-on reference-url my-url
+
+このコマンドによって ``reference-url`` にスタックされた ``my-url`` で新しいブランチが作成され
+``reference-url`` でまだブランチにない現在のブランチのリビジョンのみを格納します。
+
+ローカルブランチがスタックブランチとして作成された場合、
+``push`` するには ``--stacked`` オプションを使うことが可能で
+*stacked-on* な位置が明確になります。例です::
+
+  bzr branch --stacked source-url my-dir
+  cd my-dir
+  (hack, hack, hack)
+  bzr commit -m "fix bug"
+  bzr push --stacked
+
+
+スタックブランチの制限
+----------------------
+
+スタックブランチに関して覚えておくべき大事なことは、ほとんど全ての\
+オペレーションでスタックドオンブランチが必要になることです。
+これは両方のブランチがローカルもしくは同じサーバーにあるときは\
+問題にはなりません。
+
+スタックするブランチを変更する
+-------------------------------
+
+``bzr reconfigure`` コマンドを使ってスタックドオンブランチを変更したり\
+スタックするのをやめたりすることができます。
+``bzr reconfigure --unstacked`` を実行した場合、bzrは全ての参照されているデータを\
+スタックドオンブランチからスタックされていたブランチにコピーしてくることに\
+注意してください。
+大きなレポジトリにおいては、これは時間がかかったりリポジトリサイズを増大\
+させたりします。

=== added file 'doc/ja/user-guide/starting_a_project.txt'
--- doc/ja/user-guide/starting_a_project.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/starting_a_project.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,48 @@
+プロジェクトを始める
+=====================
+
+既存のプロジェクトをバージョン管理する
+---------------------------------------
+
+バージョン管理下に置きたいソースコードのツリー(ドキュメントのディレクトリ)をすでにお持ちなら、
+使うコマンドは以下のとおりです::
+
+  cd my-stuff
+  bzr init
+  bzr add
+  bzr commit -m "Initial import"
+
+``bzr init`` はトップレベルのディレクトリで ``.bzr`` ディレクトリを作ります(上記の例では ``my-stuff`` )。
+次のことに注意してください:
+
+ * Bazaarは必要なすべてのものをそのディレクトリに置きます -
+   データベース、ウェブサーバー、特別なサービスをセットアップする **必要はありません**
+
+ * Bazaarは ``.bzr`` を1つのディレクトリだけに作り、他のすべてのサブディレクトリの中には作らないぐらい礼儀正しいです。
+
+``bzr add`` はバージョン管理化におくべきと考えられるすべてのファイルとディレクトリを見つけ内部で登録します。
+``bzr commit`` はこれらの内容のスナップショットとその情報をコミットメッセージと一緒に記録します。
+
+``init`` 、 ``add`` と ``commit`` に関する詳細な情報は後で提供します。
+現時点で、覚えておくべき大事なことは上記のレシピです。
+
+新しいプロジェクトを始める
+---------------------------
+
+プロジェクトをゼロから始める場合、最初の段階で空のディレクトリを作った後で上述のレシピを使うこともできます。
+後の章で詳しく探求する効率の理由から、プロジェクトのためにトップレベルでレポジトリを作り
+その中で *メイン* のブランチを入れ子にすることはよいアイディアです。次のようになります::
+
+  bzr init-repo my.repo
+  cd my.repo
+  bzr init my.main
+  cd my.main
+  hack, hack, hack
+  bzr add
+  bzr commit -m "Initial import"
+
+*main* の代わりに *trunk* もしくは *dev* のような名前を好む人もいます。
+何であれあなたにとって最も有用な意味のある名前を選んでください。
+
+``init-repo`` と ``init`` コマンドの両方はパスを引数としてとり、すでに存在していなければそのパスを作ることに留意してください。
+

=== added file 'doc/ja/user-guide/svn_plugin.txt'
--- doc/ja/user-guide/svn_plugin.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/svn_plugin.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,112 @@
+bzr-svn
+=======
+
+概要
+-----
+
+bzr-svnによって集中型のSubversionリポジトリをまだ利用しているプロジェクトで\
+BazaarをVCSクライアントとして使うことができます。
+Subversionリポジトリへのアクセスは大部分は透明、\
+すなわちネイティブのBazaarブランチで ``bzr`` を使用するようにSubversion\
+リポジトリで大部分の ``bzr`` コマンドを直接利用できます。
+
+多くのbzr-svnユーザーは集中型のSubversionトランクのローカルミラーを作成し、\
+機能ブランチに取り組み、準備ができたときに変更をすべててSubversionに戻します。
+これによって既存のチーム規模のプロセスとSubversionの上に現在組み込まれている\
+ツール統合フックを妨げずに分散型VCSツールの多くの利点を得られます。
+本当に、これはBazaarを採用しようとしているがタイミングもしくは非技術的な\
+利用からまだ採用していないチームのための共通の暫定ステップです
+
+インストールの手引きに関しては、bzr-svnのホームページをご覧ください:
+http://bazaar-vcs.org/BzrForeignBranches/Subversion.
+
+
+シンプルな例
+-------------
+
+GNOMEプロジェクトの **beagle** でのシンプルな使い方です。
+最初に、ブランチの保存用のローカルな共用リポジトリをセットアップして\
+トランクをチェックアウトします::
+
+  bzr init-repo --rich-root-pack beagle-repo
+  cd beagle-repo
+  bzr checkout svn+ssh://svn.gnome.org/svn/beagle/trunk beagle-trunk
+
+
+``init-repo`` に対して ``rich-root-pack`` オプションを使うことが重要です。
+bzr-svnは追加のメタデータがいくつか必要ですが、Bazaarのデフォルトのリポジトリフォーマットではまだサポートされないからです。
+(訳注: Bazaar 2.0以降を使っているのであれば、 --rich-root-pack オプションは不要です。)
+次に、フィーチャブランチを作成してハックします::
+
+  bzr branch beagle-trunk beagle-feature1
+  cd beagle-feature1
+  (hack, hack, hack)
+  bzr commit -m "blah blah blah"
+  (hack, hack, hack)
+  bzr commit -m "blah blah blah"
+
+機能がクックされたとき、トランクをリフレッシュして変更をマージします::
+
+  cd ../beagle-trunk
+  bzr update
+  bzr merge ../beagle-feature1
+  bzr commit -m "Complete comment for SVN commit"
+
+トランクミラーはチェックアウトなので、それにコミットすれば実際のSubversionトランクにコミットされます。
+以上です！
+
+
+集中型のミラーを利用する
+-------------------------
+
+大きなプロジェクトに関しては、上記のレシピを調整すれば役立つことがしばしあります。
+とりわけ、初期のチェックアウトはとても遅い可能性があるので\
+プロジェクトに関するすべてのSubversionリポジトリをBazaarリポジトリに一旦インポートして、
+そのネイティブのBazaarリポジトリからブランチを作成します。
+bzr-svnはリポジトリからリポジトリへの変換を行うために ``svn-import`` コマンドを提供します。
+使い方の例です::
+
+  bzr svn-import svn+ssh://svn.gnome.org/svn/beagle
+
+中央のBazaarミラーを利用するために更新された上記からのレシピです::
+
+  bzr init-repo --rich-root-pack beagle-repo
+  cd beagle-repo
+  bzr branch bzr+ssh://bzr.gnome.org/beagle.bzr/trunk beagle-trunk
+  bzr branch beagle-trunk beagle-feature1
+  cd beagle-feature1
+  (hack, hack, hack)
+  bzr commit -m "blah blah blah"
+  (hack, hack, hack)
+  bzr commit -m "blah blah blah"
+  cd ../beagle-trunk
+  bzr pull
+  bzr merge ../beagle-feature1
+  bzr commit -m "Complete comment for SVN commit"
+  bzr push
+
+この場合、トランクへのコミットをしてもローカルでマージをコミットするだけです。
+マスターのSubversionトランクにコミットを戻すには、追加コマンド(``bzr push``)が必要です。
+
+注:  トランクブランチで ``pull`` と ``push`` のコマンドを最初に使う際に
+これらのコマンドに関連URLを渡す必要があります。
+その後で、bzrはそれらを記憶します。
+
+このセットアップの最後のピースはSubversionのものと同期される中心のBazaarミラーを\
+Subversionのリポジトリと同期し続けるためにスクリプトを適切な場所に設置することです。
+これはcronジョブを追加したり、Subversionフックを利用するなどによって行われます。
+
+
+bzr-svnの制限
+--------------
+
+BazaarとはSubversionは異なる機能を持つ異なるツールなので\
+何らかの相互運用問題が常に存在します。
+bzr-svn 0.5.4 に関するいくつかの例です:
+
+ * Bazaarはversioned propertiesをサポートしません
+
+ * Bazaarはファイルのコピーのトラッキングをサポートしません
+
+現在の制約の一覧に関しては、bzr-svnのウェブページ、\
+http://bazaar-vcs.org/BzrForeignBranches/Subversion を参照してください。

=== added file 'doc/ja/user-guide/undoing_mistakes.txt'
--- doc/ja/user-guide/undoing_mistakes.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/undoing_mistakes.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,152 @@
+間違いを取り消す
+================
+
+間違いは起きる
+---------------
+
+Bazaarは下記で説明されるような間違いから簡単にリカバーできるように\
+設計されています。
+
+プロジェクトのリビジョンの履歴をドロップする
+---------------------------------------------
+
+思いがけず間違ったツリーをバージョン管理下に置いたとしても、 ``.bzr`` ディレクトリを削除するだけで済みます。
+
+ファイルもしくはディレクトリの登録を解除する
+---------------------------------------------
+
+バージョン管理下に置きたくないファイルを思いがけず ``add`` コマンドで登録しても、
+それを忘れるようにBazaarにそれを忘れさせるために ``remove`` コマンドを使用できます。
+
+``remove`` は修正されたファイルが削除されないよに *安全に物事を行う* ために設計されています。たとえば::
+
+  bzr add foo.html
+  (oops - didn't mean that)
+  bzr remove foo.html
+
+このコマンドは修正されたもしくは未知のファイルについてはエラーを出力します。
+ファイルを維持したいのであれば、 ``--keep`` オプションを使います。
+代わりに、ファイルを削除したいのであれば、 ``--force`` オプションを使います::
+
+  bzr add foo.html
+  (oops - didn't mean that)
+  bzr remove --keep foo.html
+  (foo.html はディスクには残るけれども、bzrには登録されない)
+
+一方で、未変更の ``TODO`` ファイルは登録が解除されエラー出力なしでディスクから削除されます::
+
+  bzr add TODO
+  bzr commit -m "added TODO"
+  (hack, hack, hack - but don't change TODO)
+  bzr remove TODO
+  (TODO ファイルは削除される)
+
+注: IDEもしくはオペレーティングシステムのファイルマネージャーを\
+利用してファイルを削除する場合、 ``commit`` コマンドはそれを削除\
+されるものとして暗黙のうちに扱います。
+
+最後のコミット以降の変更を取り消す
+----------------------------------
+
+バージョン管理ツールを使う理由の1つは作業をしている間にツリーのステータスを楽に調べられることです。
+最新の ``commit`` 以降の変更を廃棄することを決心したら、使うコマンドは ``revert`` です::
+
+  bzr revert
+
+事前の警告として、 実際にすべてが本当に廃棄されたことを確認するために
+``bzr status`` と ``bzr diff`` を最初に使うことはよい習慣です。
+
+最後のコミット以降のファイルへの変更を取り消す
+-----------------------------------------------
+
+最後のコミット以降の特定のファイルの変更を取り消したいが、ツリーの他のすべての変更を維持したい場合、
+ファイルの名前を引数として ``revert`` に渡します::
+
+  bzr revert foo.py
+
+最後のコミットを取り消す
+-------------------------
+
+意図しないコミットをしてしまったら、取り消すために ``uncommit`` コマンドを使います::
+
+  bzr uncommit
+
+``revert`` とは異なり、 ``uncommit`` は作業のツリーの内容をそのままにします。
+意図せずに間違ったエラーメッセージをコミットしてしまった場合、これは本当に重宝します::
+
+  bzr commit -m "Fix bug #11"
+  (damn - wrong bug number)
+  bzr uncommit
+  bzr commit -m "Fix bug #1"
+
+コミットを取り消す別の理由は1つもしくは複数のファイルの追加を忘れたからというものです 。
+これを避けるために、未知のファイルがツリーの中で見つかるとコミットがエラーになるように
+``commit`` を ``commit --strict`` のエイリアスにする人もいます。
+
+注: ``merge`` コマンドは次の章まで紹介しませんが、
+``uncommit`` で追加するマージをリストアすることは無意味です。
+(``uncommit`` の後で ``bzr status`` を実行するとこれらが表示されます)
+``merge`` は履歴の前の方の指定したコミットだけを効率良く取り消すためにも使われます。
+``merge`` に関する詳細な情報は
+次の章の `変更をマージする <merging_changes.html>`_
+とBazaarのユーザーリファレンスを参照してください。
+
+複数のコミットを取り消す
+------------------------
+
+複数のコミットを取り消すためには -r オプションを使います::
+
+  bzr uncommit -r -3
+
+これを行うための理由が本当にいくつかの変更を破棄したいのであるなら、
+``uncommit`` は作業ツリーを変更しないことを覚えておいてください:
+タスクを完了させることと同じようにおそらく ``revert`` コマンドを実行する必要があります。
+しかし多くの場合、履歴をそのままにしておき、最新のよい状態の内容を反映する
+新しいリビジョンを追加する方が間違いなくベターです。
+
+過去のバージョンの状態に戻す
+-----------------------------
+
+望まない変更を行ったが、コードがユーザーに公開されているのでコミットの取り消しが合理的ではない場合、
+作業ツリーを望む状態に戻すために ``revert`` を利用できます::
+
+  % bzr commit "Fix bug #5"
+  Committed revision 20.
+  (release the code)
+  (hmm - bad fix)
+  bzr revert -r 19
+  bzr commit -m "Backout fix for bug #5"
+
+この作業によってツリー全体をリビジョン19の状態に変更します。
+それ以降は新しいコミットをしていなければおそらくこれがあなたのしたい唯一のことです。
+そうであれば、 ``revert`` はこれらをきれいに消去します。
+この場合、わるい修正を取り消す代わりに
+`リバースチェリーピッキング <advanced_merging.html#reverse-cherrypicking>`_
+を使う方がよいでしょう。
+
+注: 19のような絶対的なリビジョン番号の代わりに、
+負の数を使ってチップ(-1)と相対的なリビジョンを指定できます::
+
+  bzr revert -r -2
+
+タグを訂正する
+----------------
+
+早まってタグを定義したのなら、
+``tag`` コマンドの ``--force`` オプションを使って再定義します::
+
+  bzr tag 2.0-beta-1
+  (oops, we're not yet ready for that)
+  (make more commits to include more fixes)
+  bzr tag 2.0-beta-1 --force
+
+タグをクリアする
+-----------------
+
+タグを定義したが使いたくないのであれば、削除するために、
+``tag`` コマンドの ``--delete`` オプションを使うことができます::
+
+  bzr tag 2.0-beta-4
+  (oops, we're not releasing a 4th beta)
+  bzr tag 2.0-beta-4 --delete
+

=== added file 'doc/ja/user-guide/using_aliases.txt'
--- doc/ja/user-guide/using_aliases.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/using_aliases.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,55 @@
+エイリアスを利用する
+====================
+
+エイリアスとは？
+-----------------
+
+エイリアスは良く入力するコマンド用のショートカットを作る
+もしくはコマンド用のデフォルトを設定するための手軽な方法です。
+
+エイリアスを定義する
+---------------------
+
+コマンドのエイリアスは ``bazaar.conf`` ファイルの ``[ALIASES]`` セクションで定義されます。
+エイリアスはエイリアスの名前で始まり、等号(=)、コマンド列が続きます。
+次のコードはALIASESセクションの例です::
+
+    [ALIASES]
+    recentlog=log -r-3..-1
+    ll=log --line -r-10..-1
+    commit=commit --strict
+    diff=diff --diff-options -p
+
+上記の例の説明は次のとおりです:
+
+ * 最初のエイリアスは最新の3つのリビジョンに対するログを表示する新しい ``recentlog`` コマンドを作ります
+ *  ``ll`` エイリアスは行形式で最新の10件のログエントリを表示します。
+ *  ``commit`` エイリアスはツリーの中の新しいファイルが認知されない場合コミットを拒絶するデフォルトのcommitを設定します。
+ *  ``diff`` エイリアスは -pオプションをdiffに追加します
+
+定義したエイリアスを利用する
+-----------------------------
+
+上記で定義されたエイリアスは次のように使われます: ::
+
+   % bzr recentlog
+   % bzr ll
+   % bzr commit
+   % bzr diff
+
+エイリアスのためのルール
+-------------------------
+
+ * コマンドライン上で新しいオプションを指定することでエイリアスに渡されるオプションの一部をオーバーライドできます。
+   たとえば、 ``lastlog -r-5..`` を実行すると 10の代わりに行ベースのログエントリが5つだけ得られます。
+   すべての論理値型のオプションは暗黙的に逆のオプションがあるので、 ``commit --no-strict`` でcommitのエイリアスをオーバーライドできます。
+
+ * エイリアスの名前をオリジナルのコマンドと同じものにすることでエイリアスは既存のコマンドの標準のふるまいをオーバーライドできます。
+   たとえば、デフォルトのコミットは ``commit=commit --strict`` で変更されます。
+
+ * エイリアスは他のエイリアスを参照できません。言い換えると エイリアスの ``lastlog`` を作りそれを ``ll`` で参照しても動作しません。
+   これは標準のコマンドをオーバーライドするエイリアスを含みます。
+
+ * 　 ``--no-aliases`` オプションをbzrのコマンドに渡すと実行時にエイリアスは無視されます。
+   たとえば、 ``bzr --no-aliases commit`` を実行すると ``commit --strict`` ではなく標準のcomitコマンドが実行されます。
+

=== added file 'doc/ja/user-guide/using_checkouts.txt'
--- doc/ja/user-guide/using_checkouts.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/using_checkouts.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,97 @@
+チェックアウト機能を利用する
+============================
+
+ブランチをチェックアウトに変更する
+-----------------------------------
+
+ローカルのブランチを作りチェックアウトに変更したいのであれば、
+``bind`` コマンドを使います::
+
+  bzr bind sftp://centralhost/srv/bzr/PROJECT/trunk
+
+たとえば以前のセクションで説明されたように ``push`` を使って集中型の\
+ブランチを作った後でこれは必要です。
+
+これをした後は、コミットはローカルに適用される前にバインドした\
+ブランチに適用されます。
+
+チェックアウトをブランチに変更する
+----------------------------------
+
+チェックアウトを通常のブランチに変更したい場合、 ``unbind``
+コマンドを使います::
+
+  bzr unbind
+
+この後で、コミットはローカルのみに適用されます。
+
+チェックアウトを入手する
+-------------------------
+
+集中型のブランチを利用してチームで作業するとき、1人の人物が以前の\
+セクションで示される初期の内容を提供する必要があります。
+その後は、それぞれの個人が ローカルのチェックアウト、すなわち\
+彼らが変更を行うサンドボックス、を作るために ``checkout``
+コマンドを使用します。
+
+SubversionとCVSと異なり、Bazaarでは ``checkout`` コマンドは最新の内容を\
+保持している作業ツリーを作るのに加えて履歴のローカルな全コピーを作ります。
+``diff`` や ``log`` といったオペレーションは速く中心位置から接続していない\
+ときも利用できることを意味します。
+
+.. _getting-a-lightweight-checkout:
+
+軽量チェックアウトを入手する
+-----------------------------
+
+Bazaarはバージョン履歴を効率的に保存するために役立つ一方で、\
+履歴が望まれていないときがあります。
+たとえば、チームがBazaarを利用して集中型でウェブサイトの内容を\
+管理している場合、公開ウェブサーバー上の内容のチェックアウトを\
+更新するのと同じぐらいリリースプロセスは単純です。
+この場合、次の理由からその場所にダウンロードする履歴は望まないでしょう:
+
+ * 必要のない履歴を保有することでディスクスペースを無駄遣いする
+ * 秘密を維持したいBazaarブランチを公開する
+
+Bazaarで履歴のないチェックアウトを入手するには、
+``--lightweight`` オプションを使います::
+
+  bzr checkout --lightweight sftp://centralhost/srv/bzr/PROJECT/trunk
+
+もちろん、これによって通常のチェックアウトの多くの利点は失われますが、
+役に立つ場合と時を選ぶトレードオフです。
+``--lightweight`` オプションは、すべてのブランチではなくチェックアウト\
+のみに適用されます。
+
+注: コードベースが実際に大きくコンピュータ上のディスクスペースが限られている場合、
+`共用リポジトリ  <branching_a_project.html#a-reminder-about-shared-repositories>`_,
+`スタックブランチ <stacked.html>`_,
+`チェックアウトを再利用する <reusing_a_checkout.html>`_
+を含めたすべてのオプションを必ず考えてください。
+
+
+最新の内容に更新する
+---------------------
+
+ロックステップでの他の人との連携の重要な面の1つはあなたのチェックアウトを\
+集中型のブランチで行われた最新の変更に更新し続けることです。
+SubversionもしくはCVSで行うように、Bazaarでは ``update`` コマンドを使用して\
+次のように行います::
+
+  bzr update
+
+ブランチに結びつけられたブランチで利用可能な新しいリビジョンを入手して\
+もしあればローカルの変更をマージします。
+
+コミットの失敗を扱う
+---------------------
+
+``commit`` を実行する前にチェックアウトを最新にしなければならないことに注意してください。
+Bazaarはこの点でSubversionもしくはCVSよりも厳密です - 変更したファイルだけでなく\
+すべてのツリーを最新にする必要があります。
+Bazaarはあなたが最後に更新した後で中心位置にリビジョンが追加されたことを検出すると
+``update`` を実行するようにあなたに頼みます。
+
+バインドされたブランチへのネットワーク接続が失われると、コミットは失敗します。
+いくつかの代替の次善策は次のセクションで説明します。

=== added file 'doc/ja/user-guide/using_gatekeepers.txt'
--- doc/ja/user-guide/using_gatekeepers.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/using_gatekeepers.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,42 @@
+ゲートキーパーを利用する
+=========================
+
+分散型の人間のゲートキーパーのワークフロー
+-------------------------------------------
+
+このワークフローでは、1人の開発者(ゲートキーパー) がメインブランチへの\
+コミット権限を持つ一方で他の開発者はリードオンリーの権限のみを持ちます。
+すべての開発者はタスクブランチの中で変更を行います。
+
+.. image:: images/workflows_gatekeeper.png
+
+開発者は彼らの作業内容をマージしたいとき、ゲートキーパーに彼らの変更を\
+レビューして受け入れ可能であればマージするよう頼みます。
+変更がレビューを失敗するとき、準備ができるまで関連のタスクブランチで\
+さらなる開発が進みます。
+
+このアプローチの主要な面は含まれる制御の反転です:
+開発者は変更を中心ブランチに"コミット/プッシュ"するときを決めなくて済みます:
+コードベースはゲートキーパーの "マージ/プル" による統制された変更方法によって発展します。
+複数の中心ブランチとそれぞれ異なるゲートキーパーをを持つことはとてもよい方法で、
+よく採用されている方法です。。
+たとえば、現在の製品リリースと次のリリースのためにそれぞれ1つづつのブランチがあります。
+この場合、たいがいはバグ修正を保持するタスクブランチは両方のゲートキーパーによって\
+通知されます。
+
+このワークフローのすばらしい点の一つはスケーラブルであることです。
+大きなプロジェクトはチームになりそれぞれのチームはゲートキーパーによって管理される
+*ローカルマスターブランチ* を持つことができます。
+チームリーダーがリクエストするときにチームのマスターブランチからの変更を\
+プライマリマスターブランチにマージするために誰かを主席ゲートキーパーに任命できます。
+
+分散型の自動ゲートキーパーのワークフロー
+-----------------------------------------
+
+より高い品質を得るために、すべての開発者は変更を回帰テストスイートが通ったら\
+変更のマージとコミットだけを行う自動ゲートキーパーに投稿できることが求められます。
+このようなゲートキーパーの1つはPQMと呼ばれるソフトウェアツールです。
+
+.. image:: images/workflows_pqm.png
+
+PQMに関する詳細な情報に関しては、 https://launchpad.net/pqm を参照してください。

=== added file 'doc/ja/user-guide/version_info.txt'
--- doc/ja/user-guide/version_info.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/version_info.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,97 @@
+バージョンの情報をエクスポートする
+==================================
+
+最新のリビジョン番号を得る
+--------------------------
+
+ビルドスクリプトの中で最新のリビジョン番号だけが必要な場合、 ``revno`` コマンドを使用できます::
+
+  $ bzr revno
+  3104
+
+
+詳細なバージョン情報を得る
+---------------------------
+
+最新バージョンに関する詳細な情報を出力するには ``version-info`` コマンドを使用できます::
+
+  $ bzr version-info
+  revision-id: pqm@pqm.ubuntu.com-20071211175118-s94sizduj201hrs5
+  date: 2007-12-11 17:51:18 +0000
+  build-date: 2007-12-13 13:14:51 +1000
+  revno: 3104
+  branch-nick: bzr.dev
+
+オペレーティングシステムツールもしくはスクリプトを使用して出力を簡単にフィルタリングできます。
+例です(Linux/Unix)::
+
+  $ bzr version-info | grep ^date
+  date: 2007-12-11 17:51:18 +0000
+
+より高度な後処理のためにすべてのリビジョンに関するバージョン情報が必要であれば、
+``--all`` オプションはその情報を実際にダンプします。
+
+
+Pythonのプロジェクト
+--------------------
+
+.. TODO: Figure out how to attach into ``setup.py``
+
+
+プロジェクトファイルをビルドするためにMakefileを使う場合、
+次のようにバージョン情報用のファイルを簡単に生成できます::
+
+  library/_version.py:
+        bzr version-info --format python > library/_version.py
+
+これは3つのディレクトリを含むファイルを生成します:
+
+  * `version_info`: 現在の状態に関する基本情報を含むディレクトリ。
+
+  * `revisions`: コミット時間とコミットメッセージと一緒に、
+    ツリーの履歴の中のすべてのリビジョンのリストを表示するディクショナリ。
+    ``--all`` もしくは ``--include-history`` が提供されない限り、デフォルトではこれは空です。
+    リリースバージョンに含まれる、バグ修正などを追跡したい場合に便利です。
+    しかし多くのプロジェクトに対してこれは必要以上の情報です。
+
+  * `file_revisions`: プロジェクトのすべてのファイルに対する最終修正のリビジョンのリストを示すディクショナリ。
+    これは ``$Id$`` キーワードがCVSで管理されたファイルと同じように使われます。
+    最終修正の日付は ``revisions`` マップで探すことで決定されます。
+    デフォルトではこれは空で、 ``--all`` もしくは ``--include-file-revisions`` によってのみ有効になります
+
+
+別のフォーマットでバージョン情報を得る
+--------------------------------------
+
+任意のフォーマットのバージョン情報を取得するためにBazaarはテンプレートベースの方法をサポートします。
+``version-info`` への ``--custom`` オプションは作業ツリーのステータスに基づいて拡張された変数を含む
+``--template`` 引数を提供することで使用できます。
+
+たとえば、現在のリビジョン番号を含むフォーマットされた文字列を伴うCヘッダーファイルを生成するには::
+
+ bzr version-info --custom \
+      --template="#define VERSION_INFO \"Project 1.2.3 (r{revno})\"\n" \
+      > version_info.h
+
+``{revno}`` は作業ツリーのリビジョン番号に置き換えされます。
+(上記の例があなたのOSで動作しない場合、一行ですべてのコマンドを入力してみてください)
+テンプレートの中で利用できる変数の詳細な情報に関しては、
+Bazaarのユーザーリファレンスの `Version Info`_ を参照してください。
+
+.. _Version Info: ../user-reference/bzr_man.html#version-info
+
+特定の言語でバージョン情報をダンプするために予め定義されるフォーマットはは現在開発段階にあります。
+この領域の要求に関してはメーリングリストで私達開発者に連絡して下さるようお願いします。
+
+チェッククリーン
+-----------------
+
+プロジェクトの内容に関する大抵の情報はリビジョンエントリを読むだけで簡単に決定できます。
+しかしながら、作業ツリーがパッケージされたときにそれが最新であったこと、
+もしくはローカルな修正があったことを知るためには便利です。
+``--all`` もしくは ``--check-clean`` のどちらかを提供することで ``bzr`` は作業ツリーを検査して、
+``version_info`` ``clean`` を設定します。
+同様に ``modified`` が適切である場合に ``file_revisions`` でエントリを設定します。
+
+..
+   vim: tw=74 ft=rst spell spelllang=en_us

=== added file 'doc/ja/user-guide/web_browsing.txt'
--- doc/ja/user-guide/web_browsing.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/web_browsing.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,15 @@
+ウェブブラウジング
+==================
+
+概要
+-----
+
+BazaarのリポジトリをWeb上で閲覧するために利用できる選択肢は幅広くあり、\
+主要なものは Loggerhead です。
+Loggerhead のホームページは https://launchpad.net/loggerhead にあります。
+
+ダウンロードリンクを含めてこれらのパッケージの最新情報に関しては
+http://bazaar-vcs.org/WebInterface を参照してください。
+
+注: プロジェクトがホストされているもしくはLaunchpadでミラーリングされている場合、
+Loggerheadのコードブラウジング機能はサービスの一部として提供されます。

=== added file 'doc/ja/user-guide/working_offline_central.txt'
--- doc/ja/user-guide/working_offline_central.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/working_offline_central.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,50 @@
+オフラインで集中型のブランチに取り組む
+=======================================
+
+集中型のローカルコミットのワークフロー
+---------------------------------------
+
+旅行のためネットワーク接続できない場合、中心サーバーがダウンする、\
+もしくは今は中心位置に公開せずにローカルで変更のスナップショットを\
+記録したいだけなら、このワークフローはそんなあなたのためにあります。
+
+.. image:: images/workflows_localcommit.png
+
+ローカルでコミットする
+-----------------------
+
+チェックアウトで作業していてローカルだけでコミットする必要がある/したい場合、
+``--local`` オプションを ``commit`` コマンドに追加します::
+
+  bzr commit --local
+
+長期間切断する
+---------------
+
+しばらくの間バインドされたブランチから切断をする予定もしくはしたい場合、
+``--local`` をすべての ``commit`` コマンドを追加することを覚えるのは面倒でしょう。
+代わりの方法は チェックアウトを一時的に通常のブランチにするために ``unbind``
+コマンドを用い、後でロックステップの状態に戻りたくなったときに ``bind`` コマンド\
+を使うことです。
+
+``bind`` コマンドはこのブランチがチェックアウトされた最後の時間が結びつけられた\
+場所を覚えるので、前の ``unbind`` の後で ``bind`` を使うときにリモートブランチの\
+URLを入力する必要がないことに留意してください。
+
+ローカルコミットのシリーズをマージする
+---------------------------------------
+
+中心ブランチ上で進行中の開発から独立してローカルでコミットするとき、\
+次回 ``update`` が実行されるときBazaarはこれらを開発の2つのラインとして扱います。
+この場合、 ``update`` は次のことを行います:
+
+ * これはバインドされたブランチからの最新のリビジョンを取り込み、チェックアウトを\
+   メインラインの状態にします。
+
+ * これは最後に更新した以降のローカルな変更を論理的に並行ブランチに移動します
+
+ * これらを一緒にマージするのでローカルの変更は ``status`` によって未解決マージ
+   として報告されます
+
+常に、この後で作業内容を中心ブランチに送信するためには ``commit`` を実行する\
+必要があります。

=== added file 'doc/ja/user-guide/writing_a_plugin.txt'
--- doc/ja/user-guide/writing_a_plugin.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/writing_a_plugin.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,59 @@
+.. _writing-a-plugin:
+
+プラグインを書く
+================
+
+導入
+-----
+
+プラグインはbzrのコア機能ととてもよく似ています。
+これらはbzrlibから何でもインポートできます。
+プラグインは標準機能を上書きすることもできますが、大抵プラグインは\
+新しいコマンドを提供します。
+
+.. _creating-a-new-command:
+
+新しいコマンドを作る
+---------------------
+
+コマンドを書くには、
+``bzrlib.commands.Command`` を継承する新しいオブジェクトを作り、 ``cmd_foo`` と命名します。
+fooはコマンドの名前です。
+名前にアンダースコアが含まれるコマンドを作ると、UIではアンダースコアはハイフンとして表示されます。
+たとえば、 `cmd_baz_import` は `baz-import` として表示されます。
+コマンドの書き方の実例に関しては、 ``builtins.py`` を参照して頂くようお願いします。
+
+コマンドを作成したらファイルがインポートされるときに
+``bzrlib.commands.register_command(cmd_foo)`` でコマンドを登録しなければなりません。
+さもなければbzrはコマンドを見つけることはありません。
+
+.. _specifying-a-plugin-version-number:
+
+プラグインのバージョン番号を指定する
+-------------------------------------
+
+プラグインのバージョン番号を定義するにはタプルで ``version_info`` を定義します。例：
+``version_info = (0, 9, 0)``
+``version_info = (0, 9, 0, 'dev', 0)``
+
+.. _plugin-searching-rules:
+
+プラグインの検索ルール
+------------------------
+
+デフォルトではbzrはプラグインを見つけるために ``bzrlib/plugins`` と ``~/.bazaar/plugins`` をスキャンします。
+``BZR_PLUGIN_PATH`` でこれを上書きできます。
+プラグインはモジュールもしくはパッケージの形態をとることができます。
+プラグインが単独のファイルであれば、構造をモジュールにできます。
+プラグインが複数のファイルを持つ場合やbzrのブランチとして配布したい場合は、
+構造をパッケージ、すなわち、ディレクトリの中に ``__init__.py`` を含めます。
+
+
+詳しい情報
+-----------
+
+他の人にも役立つと考えましたら、プラグインをBzrToolsにお気軽に寄付してください。
+
+Bazaarの開発ガイドラインと方針の詳細に関しては `Bazaar開発者ガイド`_ を参照してください。
+
+.. _Bazaar開発者ガイド: ../developer-guide/HACKING.html

=== added file 'doc/ja/user-guide/zen.txt'
--- doc/ja/user-guide/zen.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-guide/zen.txt	2009-10-29 10:01:19 +0000
@@ -0,0 +1,195 @@
+Bazaarの哲学
+============
+
+Bazaarを完全に理解する
+-----------------------
+
+Bazaarは多くの点で他のVCSに似ていますが、最初見たときに必ずしも明らかではない大きな違いがいくつかあります。
+このセクションでは Bazaarを"grok"するため、すなわち深く理解するために、
+ユーザーが知る必要のあるいくつかの内容の説明を試みます。
+
+注: Bazaarを使うためにこのセクションを十分に理解する必要はありません。
+このセクションをさっと読んで後で戻るとよいでしょう。
+
+リビジョン番号を理解する
+------------------------
+
+ブランチのメインラインのすべてのリビジョンは単純に増加する整数を持ちます(最初のコミットは1、10番目のコミットは10などです)。
+これによって "私のブランチから10番目のリビジョンを獲得する"、もしくは "リビジョン3050で修正した" という言い方が自然になります。
+
+ブランチにマージされるリビジョンに関しては、ドットつきのバージョンが使われます(たとえば、3112.1.5)。
+ドットつきのリビジョン番号は3つの番号を持ちます [#]_.
+最初の番号はメインのリビジョンの変更の由来を示します。
+2番目の番号はブランチのカウンターです。
+同じリビジョンから多くのブランチが由来することがあり得るので、それらのブランチはユニークな番号を取得します。
+3番目の番号はブランチの開始以降のリビジョン番号です。
+たとえば、3112.1.5はリビジョン3112からの最初のブランチで、そのブランチ上の5番目のリビジョンです。
+
+.. [#] バージョン1.2以前のbzrでは少し異なるアルゴリズムが使われていました。
+   いくつかの入れ子のブランチはよりシンプルな3つの番号システムではなく追加の番号(たとえば1.1.1.1.1)を取得します。
+
+階層形式の履歴はよいものである
+-------------------------------
+
+多くの変更が一連のコミットで構成される状況で複数の開発者が変更を投稿するプロジェクトを想像してください。
+具体例を示すために、次の事例を考えてみましょう:
+
+ * プロジェクトのトランクのチップはリビジョン100です。
+ * Maryは機能Xを配信するために3つの変更を行う
+ * Billは機能Yを配信するために4つの変更を行う
+
+開発者が並行して作業して伝統的な集中型のVCSのアプローチを利用する場合、
+大抵の場合プロジェクトの履歴は次のようにMaryの変更とBillの変更が交互に混ざります::
+
+  107: Add documentation for Y
+  106: Fix bug found in testing Y
+  105: Fix bug found in testing X
+  104: Add code for Y
+  103: Add documentation for X
+  102: Add code and tests for X
+  101: Add tests for Y
+  100: ...
+
+多くのチームはこのアプローチを利用します。彼らのツールではブランチの作成とマージが難しいからです。
+結果として、開発者はトランクからの更新とコミットを頻繁に行い、すべてのコミットを通してそれを広げることで統合の苦痛を最小化します。
+望むのであれば、このようにBazaarを使うことができます。
+Bazaarは考慮すべき別の方法を提供します。
+
+分散型のVCSツールによって推奨される代替のアプローチは機能ブランチを作り、準備ができたらそれらを統合することです。
+この場合、Maryの機能ブランチは次のようになります::
+
+  103: Fix bug found in testing X
+  102: Add documentation for X
+  101: Add code and tests for X
+  100: ...
+
+そしてBillのものは次のようになります::
+
+  104: Add documentation for Y
+  103: Fix bug found in testing Y
+  102: Add code for Y
+  101: Add tests for Y
+  100: ...
+
+機能が独立していてリニアな履歴を維持したいのであれば、変更はバッチでトランクにpushされます。
+(技術的には、これを行う方法は無数にありますがこの検討内容の範囲を超えます。)
+結果の履歴は次のようになります::
+
+  107: Fix bug found in testing X
+  106: Add documentation for X
+  105: Add code and tests for X
+  104: Add documentation for Y
+  103: Fix bug found in testing Y
+  102: Add code for Y
+  101: Add tests for Y
+  100: ...
+
+これを実現するために少し努力が必要な一方で、リビジョンをランダムに織り交ぜるよりもいくつかの利点があります。
+よりベターですが、non-linearな履歴を形成してブランチは一緒にマージできます。
+結果は次のようになります::
+
+  102: Merge feature X
+       100.2.3: Fix bug found in testing X
+       100.2.2: Add documentation for X
+       100.2.1: Add code and tests for X
+  101: Merge feature Y
+       100.1.4: Add documentation for Y
+       100.1.3: Fix bug found in testing Y
+       100.1.2: Add code for Y
+       100.1.1: Add tests for Y
+  100: ...
+
+もしくは次のようになります::
+
+  102: Merge feature X
+       100.2.3: Fix bug
+       100.2.2: Add documentation
+       100.2.1: Add code and tests
+  101: Merge feature Y
+       100.1.4: Add documentation
+       100.1.3: Fix bug found in testing
+       100.1.2: Add code
+       100.1.1: Add tests
+  100: ...
+
+多くの理由からこれはよいものと考えられます:
+
+ * プロジェクトの履歴を理解するのが楽になります。
+   関連した変更はクラスターを形成し明確に区切られます。
+
+ * ブランチのメインライン上のコミットだけを見るために履歴を簡単に折りたたむことができます。
+   (このレベルでは興味のない膨大な数のコミットの代わりに)
+   このようなトランクの履歴を閲覧するとき、高いレベルのコミットだけ見えます。
+
+ * 必要であれば、より簡単に機能の変更を取り消します
+
+ * 継続的インテグレーション(Continuous integration: CI)ツールは
+   マージをメインラインにコミットするためにすべてのテストが合格することを保証するために使われます。
+   (多くの場合、すべての単独のコミットの後でCIツールの引き金を引くのは適切ではありません。
+   テストの中には開発の間に失敗するものがあるからです。
+   実際、テストファーストの追加 - テスト駆動開発(TDD)のスタイル - によってこれが保証されます！)
+
+要約すると、重要な点は次のとおりです:
+
+  *ブランチを利用してあなたの作業内容を編成する*
+
+  *マージ機能を利用して変更を統合する*
+
+  *順序つきの番号と階層によって履歴を追跡するのが楽になる*
+
+
+それぞれのブランチは履歴の独自のビューを持つ
+---------------------------------------------
+
+上述のように、Bazaarは次の内容を区別します:
+
+ * メインラインのリビジョン、すなわちブランチにコミットしたもの
+
+ * マージしたリビジョン、マージをコミットすることで祖先として追加されるもの
+
+それぞれのブランチは効率的に履歴の独自ビューを持ち、すなわち、
+異なるブランチは同じリビジョンに異なる"ローカルな"リビジョン番号を与えます。
+
+マージされたリビジョンは常にドットつきのリビジョン番号を入手するのに対して
+メインラインのリビジョンは常に単独の数字のリビジョン番号が割り当てられます。
+
+上記の例を拡張するためには、Maryが変更を完了させた後でプロジェクトのトランクにマージした後に
+Maryのブランチのリビジョンの履歴は次のようになります::
+
+  104: Merge mainline
+       100.2.1: Merge feature Y
+       100.1.4: Add documentation
+       100.1.3: Fix bug found in testing
+       100.1.2: Add code
+       100.1.1: Add tests
+  103: Fix bug found in testing X
+  102: Add documentation for X
+  101: Add code and tests for X
+  100: ...
+
+繰り返しますが、Maryはこの変更を開発するためにステップを見るために彼女の履歴のトップレベルを調べることが簡単になります。
+この文脈では、トランクのマージ(とそれを行うことによる衝突の解消)はこのブランチの履歴に関しては単なる1つのステップです。
+
+Bazaarは履歴を変更するのでなければグローバルなリビジョン識別子を変更するのでもないことを覚えておくのは大事です。
+本当に望むのであれば常に後者を使用できます。
+実際、ブランチのURLをコンテクストとして提供する *限り* コミュニケーションをするときに特定のリビジョン番号を使うことができます。
+(多くのBazaarのプロジェクトでは、開発者はブランチURLなしでリビジョン番号を交換するとき中心のトランクのブランチをほのめかします)
+
+マージはブランチのリビジョン番号を変更しません。それらはローカルのリビジョン番号を新しくマージしたリビジョンに割り当てるからです。
+Bazaarがブランチのリビジョン番号を変更する唯一のときはあなたが明示的に別のブランチをミラーリングするように頼むときです。
+
+注: リビジョンは安定した方法で番号づけされます: 2つのブランチがメインラインで同じリビジョン番号を持つとき、
+そのリビジョンの祖先のすべてのリビジョンは同じリビジョン番号を持ちます。
+たとえば、AliceとBobのブランチがリビジョン10に一致するのであれば、それらはそれ以前のすべてのリビジョンで一致します。
+
+要約
+-----
+
+一般的に、前に示されたアドバイスに従うのであれば - ブランチの中で作業し、\
+連携するためにマージを使う -
+Bazaarが一般的にあなたが期待することを行うことがわかります。
+
+次の章では、Bazaarを利用したさまざまな方法: もっとも単純なプロジェクト、個人プロジェクトなどを試します。
+
+..
+   vim: ft=rst tw=74 ai

=== added directory 'doc/ja/user-reference'
=== added file 'doc/ja/user-reference/index.txt'
--- doc/ja/user-reference/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ja/user-reference/index.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,3853 @@
+.. This file is autogenerated from the output of
+..     bzr help topics
+..     bzr help commands
+..     bzr help <cmd>
+..
+.. Generation time: 2009-01-09 07:03:09 +0000
+
+##########################
+Bazaarユーザーリファレンス
+##########################
+
+:Version:   1.11
+:Generated: 2009-01-09
+
+.. contents:: :depth: 2
+
+-----
+
+このチュートリアルについて
+##########################
+
+このマニュアルはBazaarのオンラインヘルプから生成されました。オンラインヘルプのシステムを
+利用するためには次のコマンドを試してください。
+
+    よく使われるコマンドの一覧を含めて紹介します::
+
+        bzr help
+
+    トピックの一覧とそれぞれの要約::
+
+        bzr help topics
+
+    コマンドの一覧とそれぞれの要約::
+
+        bzr help commands
+
+    特定のトピックもしくはコマンドに関する詳細な情報::
+
+        bzr help topic-or-command-name
+
+次のウェブサイトはBazaarに関する詳細な情報を提供します:
+
+:ホームページ:                     http://www.bazaar-vcs.org/
+:公式ドキュメント:                 http://doc.bazaar-vcs.org/
+:Launchpad:                     https://launchpad.net/bzr/
+
+概念
+####
+
+ブランチ
+=========
+
+ブランチは、すべての履歴を含む、プロジェクトの状態で構成されます。
+すべてのブランチは関連づけされたリポジトリ(ブランチの履歴が保存される場所)を持ちますが、
+複数のブランチは同じリポジトリを共有することもあります(共用リポジトリ)。
+ブランチはコピーしたりマージしたりできます。
+
+関連コマンド::
+
+  init    ディレクトリをバージョン管理されたブランチに変更する。
+  branch  ブランチの新しいコピーを作成する。
+  merge   3方向マージ (3-way merge) を実行する。
+
+
+チェックアウト
+==============
+
+チェックアウトはブランチに結びつけられたソースツリーなので、
+ソースツリーにコミットするときに、コミットの内容はブランチに格納されます。
+必要になるまでBazaarの分散型機能の一部を無視して、よりシンプルに、集中型のワークフローを利用できます。
+共用リポジトリでチェックアウトを利用することはSVNもしくはCVSでの作業とよく似ていますが、同じ制限を持ちません。
+そしてチェックアウトを利用することで望むワークフローがなんであれ他の人もプロジェクトに取り組むことができます。
+
+チェックアウトはbzr checkoutコマンド("help checkout"を参照)によって作成されます。
+これに別のブランチへのリファレンスを渡し、マスターブランチからのチェックアウトを作成したブランチへのリファレンスを
+まだ含むローカルコピーを作成します。
+
+何かコミットをすればこれらは他のブランチで最初に作成されます。
+これによって作業内容のインスタントミラーが作成されるもしくは
+それぞれの開発者が共同で作業して他の人の変更を継続的に統合するロックステップ開発を円滑にします。
+
+しかしながらチェックアウトはまだBazaarの第一級のブランチで、すべての履歴をローカルで保存できます。
+第一級のブランチがあるので、ローカルにコミットすることもできます。
+たとえば、ネットワーク接続による一時的な遅延を回避したいのであれば、ローカルでもコミットできます。
+これを行うには --local オプションを使います。
+次にローカルではないコミットを行うときにすべてのローカルコミットはマスターブランチに行われます。
+
+共用ブランチからのチェックアウトを使用しているとき、周期的に他の人による変更をすべてpullしたくなります。
+これは"update"コマンドによってできます。
+ローカルではないコミットの前に変更が適用される必要がありますが、
+Bazaarは変更が存在することを伝え必要なときにこのコマンドを使うように提示します。
+
+checkoutコマンドに--lightweightフラグを渡すことで"軽量"チェックアウトを作成することも可能です。
+第一級のブランチではなく、主に作業ツリーで構成されるという点で、軽量チェックアウトはSVNのチェックアウトにより近いです。
+履歴のオペレーションはマスターブランチに問い合わせをしなければならないので、
+ネットワーク接続が関わる場合遅くなる可能性があることを意味します。
+また、ローカルブランチを持たないので、ローカルでコミットできません。
+
+マスターブランチに高速で信頼性のあるアクセス権限があるときに軽量チェックアウトは最も良く動作します。
+マスターブランチが同じディスクもしくはLAN上にあれば、(ブランチのコピーの更新だけが必要なので)
+リビジョンを変更するどのコマンドでも軽量ブランチは重量ブランチよりも速くなることを意味します。
+一般的に重量チェックアウトは速いですが、マスターブランチが同じディスク上のあるときは、顕著な違いはありません。
+
+チェックアウトの別の使い方はブランチを格納するツリーなしのリポジトリで使うことです。
+ここでは異なるブランチに取り組むときチェックアウトが指定するマスターブランチを切り替えることで
+1つの作業ツリーだけを維持します。
+
+明確にチェックアウトにコミットするにはマスターブランチへの書き込み権限が必要です。
+マスターブランチはsftp://といった書き込み可能なプロトコルでアクセスしなければならないので、
+相手方で書き込み権限をもたなければならないことを意味します。
+チェックアウトはローカルファイルシステムでも機能するので、すべての問題はファイルのパーミッションです。
+
+"bind"コマンド("help bind"を参照)を使用することでチェックアウトのマスターを変更できます。
+これによってコミットが送信される位置が変更されます。
+bindコマンドはブランチをheavyチェックアウトに変換するためにも使用できます。
+すべてのコミットがローカルで行われるようにheavyチェックアウトを通常のブランチに変換したい場合、
+"unbind" コマンドを使用できます。
+
+関連コマンド::
+
+  checkout    チェックアウトを作成する。軽量チェックアウトを得るには --lightweight を渡す
+  update      マスターブランチの変更をあなたのチェックアウトにpullする
+  commit      マスターブランチに送信されるコミットを行う。
+              重量チェックアウトであれば --localオプションによって
+              マスターにコミットを送信せずにチェックアウトにコミットされます
+  bind        送信されるチェックアウトにコミットされるマスターブランチを変更する
+  unbind      コミットがローカルだけで行われるように重量チェックアウトをスタンドアロンのブランチに変換する
+
+
+クリスクロス
+============
+
+ブランチの履歴のクリスクロス(Criss-cross)は通常期待されるよりも多くのコンフリクトを出すデフォルトのマージテクニックを必要とします。
+
+複雑なマージの場合、 ``bzr merge --lca`` もしくは ``bzr merge --weave`` ではよりよい結果になるかもしれません。
+作業ツリーを ``bzr revert`` して再度マージしたいと願うかもしれません。
+代わりに、特定の衝突しているファイル上で ``bzr remerge`` を使います。
+
+2つのブランチが同じものをマージしてお互いにマージし合う場合、
+もしくは2つのブランチが同時にお互いをマージする場合、クリスクロスはブランチの中で発生します。
+それぞれのブランチが目的の集中型ブランチからもしくはそのブランチからのみマージすることでこれらを回避できます("star topology")。
+
+マージが動作する方法のためクリスクロスは問題を引き起こします。
+Bazaarのデフォルトマージは三方向マージです; OTHERをTHISにマージするには比較、BASE用の基本を見つけなければなりません。
+BASEを利用することで、THISとOTHERの違いが行を追加するワンサイドか、行を削除する別のサイドによるのかを決定できます。
+
+クリスクロスはベースに関してよい選択肢がないことを意味します。
+最近のマージポイントを選択することはワンサイドの変更を少し廃棄してしまう可能性があります。
+(Bazaarが行う)古いマージポイントを選択することは余分な衝突が発せられることを意味します。
+
+``weave`` マージタイプはこの問題の影響を受けません。
+このタイプは違いの原因を決定するためにベースのリビジョンの代わりに行を起点とする検出方法を利用するからです。
+
+
+ストレージフォーマット
+=======================
+
+古いクライアントが不正にデータにアクセスしないことを保証するために、
+Bazaarのポリシーでは新しい機能が新しいメタデータを追加する必要があるときに
+新しいフォーマットを導入することにしています。新しいストレージフォーマットは
+パフォーマンスとスケーラビリティを改善するために導入することもあります。
+
+フォーマットを選ぶために次のガイドラインを利用します(条件がtrueであると同時に停止):
+
+* 既存のプロジェクトに取り組んでいる場合、プロジェクトが利用しているものを使用します。
+  (デフォルトでBazaarはあなたの代わりにこれを行います)。
+
+* Subversionリポジトリと連携するbzr-svnを利用している場合は、
+  1.9-rich-rootを使用します。
+
+* 大きなツリー(5000以上のパス)もしくは深い履歴(5000以上のリビジョン)を持つ
+  プロジェクトに取り組んでいるのであれば、1.9を使用します。
+
+* さもなければ、デフォルトのフォーマットを使用します。大抵のプロジェクトはこれで十分です。
+
+(ディストロのパッケージを利用しているなどで)最新のBazaarを利用できない開発者がいるのであれば、
+それに応じてガイドラインを調整してください。
+たとえば、プロジェクトがBazaar 1.7を標準化している場合、1.9の代わりに1.6を選ぶことが必要です。
+
+注: 現在サポートされるフォーマットの多くは2つのバリアントを持ちます:
+plainのものとrich-rootのものです。
+後者はツリーのrootに関する追加フィールドを含みます。
+rich-rootフォーマットを利用する際にパフォーマンスコストはありませんが
+rich-rootフォーマットからの変更をplainフォーマットに簡単にマージできません。
+結果として、すべての投稿者がほぼ同時にリポジトリをアップグレードする必要があるので、
+プロジェクトをrich-rootフォーマットに移行させるには調整が必要です。
+(これまでのところrich-rootフォーマットをデフォルトにすることを遅らせてきた理由です。
+将来の適切な時期にこれを行います。)
+
+現在サポートされるフォーマットの完全なリストに関しては ``bzr help current-formats`` を参照してください。
+利用可能で実験上もしくは廃止されたフォーマットに関しては ``bzr help other-formats`` を参照してください。
+
+
+パターン
+========
+
+Bazaarはさまざまな時点でマッチするファイルを使用します。
+たとえば、 ``add`` コマンドは無視するパターンにマッチするファイルとスキップし
+プリファレンスはルールパターンを使用するファイルに関連づけできます。
+パターン構文は下記のとおりです。
+
+パターン上のトレーリングスラッシュは無視されます。
+パターンがスラッシュを含むもしくは正規表現である場合、ブランチのroot全体から比較されます。
+さもなければ、これはパスの最後のコンポーネントのみと比較されます。
+rootディレクトリの中のファイルのみにマッチさせるには'./'を用意します。
+絶対パスを指定するパターンは許可されていません。
+
+パターンは次のようなglobのワイルドカードを含むことができます::
+
+  ? - '/'以外の単独文字にマッチする
+  * - '/'以外の0かそれ以上の文字数にマッチする
+  /**/ - パスの中のゼロかそれ以上のディレクトリにマッチする
+  [a-z] - 文字のグループの範囲内からの単独の文字にマッチする
+
+パターンはPythonの正規表現にもなります。
+正規表現のパターンは 'RE:' の接頭辞で始まる正規表現で識別されます。
+正規表現のパターンは名前つきもしくは番号つきのグループを含むことはできません。
+
+
+リポジトリ
+===========
+
+Bazaarのリポジトリはコミットされた情報が保存される場所です。
+すべてのブランチと関連づけされたリポジトリが1つ存在します。
+
+リポジトリは一種のデータベースです。
+通常、パフォーマンスのためにBzrはこれを自動的に維持しますが、ある状況(たとえば短い期間にとても多くのコミットを行う)
+
+データベースのインデックスを最適化するようbzrに求めるとよいでしょう。
+これは'bzr pack' コマンドによって行われます。
+
+デフォルトでは 'bzr init' を実行するだけで新しいブランチの中でリポジトリが作成されますが、
+同じ位置で情報を共有するために複数のブランチを許可する共用リポジトリを作成することが可能です。
+新しいブランチが作成されたとき使用できる共用リポジトリが存在するかどうかを最初に確認します。
+
+同じプロジェクトのブランチが1つのリポジトリを共有するとき、一般的にスペースが大きく節約されます。
+(たとえばリポジトリの範囲内でブランチを作成するなどの)いくつかのコマンドに対してこれは大きな時間の節約になります。
+
+共用リポジトリを作るには、init-repositoryコマンド(もしくはエイリアスのinit-repo)を使います。
+このコマンドは作成するリポジトリの位置をとります。
+このことは'bzr init-repository repo'によって'repo'という名前のディレクトリが作成され
+その中に共用リポジトリが格納されることを意味します。
+このディレクトリの中に作成された新しいブランチはストレージ用にそれを使用します。
+
+1つ以上のプロジェクトのブランチを作成するときに1つのリポジトリを作成することはよい考えです。
+これは開発を行っている作業領域と、ホスティングプロジェクト用のサーバー領域の両方にあてはまります。
+後者の場合、作業ツリーなしのブランチが欲しいことは良くあります。
+ブランチのファイルは直接編集されないので作業ツリー用にディスクスペースを使い切る必要はありません。
+作業ブランチを持たないリポジトリを作成するには、 'init-repository'に'--no-trees'オプションを渡します。
+
+関連コマンド::
+
+  init-repository   共用リポジトリを作成する。
+                    新しいブランチが作業ツリーを作成しないものを作成するには--no-treesを使用する。
+
+
+ルール
+=======
+
+紹介
+-----
+
+ルールはiniファイルフォーマットで定義されます。
+セクションはファイルのglobパターンでそれぞれのセクションの内容は
+そのパターンにマッチするファイル用のプリファレンスです。例です::
+
+    [name *.bat]
+    eol = dos
+
+    [name *.html]
+    keywords = escape
+
+これらのようなプリファレンスは選択されたブランチの中で
+選択されたファイル用にカスタムのふるまいを提供したいコマンドとプラグインに役立ちます。
+
+
+ファイル
+---------
+
+すべてのブランチ用のデフォルトルールはオプションの ``BZR_HOME/rules`` ファイルで定義されます。
+
+ルールのパターン
+-----------------
+
+パターンは順序づけされ1つマッチすると共に検索は停止します。
+結果として、より明確なパターンをファイルのトップの方に置くべきです。
+ルールパターンは無視パターンとまったく同じ仕様を利用します。
+詳細は ``bzr help patterns`` を参照してください。
+
+注: 角かっこを含むパターンはそれらが正しく解析されるようにクォートで囲まなければなりません。
+
+
+スタンドアロンのツリー
+=======================
+
+スタンドアロンのツリーは関連リポジトリを持つ作業ツリーです。
+他に依存していないので、これは独立して利用できるブランチです。
+(bzr initを通して)スタンドアロンのツリーの作成は
+既存のプロジェクトをバージョン管理の元に置くための最も速い方法です。
+
+関連コマンド::
+
+  init    ディレクトリをバージョン管理下にあるブランチにする。
+
+
+同期化がずれているブランチ
+==========================
+
+チェックアウト、ツリーもしくはブランチを軽量ブランチに再設定するとき、
+ローカルのブランチを破壊しなければなりません。
+(チェックアウトに関して、これはキャッシュとして最初に提供するローカルブランチです。)
+破壊されるブランチが同じ最終リビジョンを持たなければ、
+軽量用チェックアウト用の新しい参照ブランチ、データが失われる可能性があるので、
+Bazaarは拒否します。
+
+この取り組み方は *なぜ* ブランチの同期がずれるのかによります。
+
+チェックアウトが手元にありローカルコミットを行う場合、
+"bzr update"(とおそらくは"bzr commit")を実行することで再び同期化できます。
+
+ブランチが手元にあり、リモートブランチが時代遅れになっている場合、
+"bzr push"を使用してローカルの変更をプッシュできます。
+ローカルブランチが時代遅れであれば、"bzr pull"をできます。
+両方のブランチに変更があれば、変更をマージ、コミットしてプッシュできます。
+変更の一部が便利でなければ、"push --overwrite"もしくは代わりに"pull --overwrite"できます。
+
+
+作業ツリー
+===========
+
+作業ツリーはディスク上に設置されたブランチのコンテンツなのでファイルを見て編集できます。
+作業ツリーはブランチに変更を行う場所なので、
+作業ツリーの現在の状態をコミットするとき、コミットに記録されるレコードです。
+
+ブランチをリモートシステムにプッシュするとき、作業ツリーは作成されません。
+ファイルがすでに存在すれば、ファイルは更新されません。
+ブランチの情報は更新され作業ツリーは時代遅れとしてマークされます。
+リモートの作業ツリーを更新するのは難しいです。
+アンコミットされた変更が存在するもしくは更新によってリモートで扱うのが難しい内容の衝突が引き起こされるからです。
+
+作業ツリーなしのブランチがあれば 作業ツリーを作成するために 'checkout' コマンドを使用できます。
+ブランチから 'bzr checkout .' を実行すると作業ツリーが作成されます。
+リモートでブランチが更新されると、そのディレクトリの中で'bzr update'を実行することで作業ツリーを更新できます。
+
+望まない作業ツリーを持つブランチがある場合、安全であれば'remove-tree'コマンドはツリーを除外します。
+ブランチにプッシュするとき更新されないリモート作業ツリーに関する警告を回避することでこれは可能です。
+これは'--no-trees'リポジトリ('bzr help repositories'を参照)に取り組むときにも便利です。
+
+プッシュするリモートマシン上で作業ブランチを持ちたい場合、
+pushするごとにリモートブランチで'bzr update'を実行するか、
+pushの間にツリーを更新する他の方法を使用できます。
+rsyncを使用してpushと同じように作業ツリーを更新する'rspush'プラグインが存在します。
+それぞれのプッシュの後で'bzr update'を自動的に実行する'push-and-update'プラグインも存在します。
+
+便利なコマンド::
+
+  checkout     ブランチが作業ツリーを持たないときにそれを作成する。
+  remove-tree  これを行うときに安全であるときにブランチから作業ツリーを除外する。
+  update       作業ツリーが関連ブランチから同期がずれているとき
+               このコマンドによってブランチにマッチするツリーが更新される。
+
+.. _formats: `ストレージフォーマット`_
+.. _standalone-trees: `スタンドアロンのツリー`_
+.. _sync-for-reconfigure: `同期化がずれているブランチ`_
+.. _working-trees: `作業ツリー`_
+
+
+
+リスト
+#######
+
+認証の設定
+===========
+
+
+Intent
+------
+
+``authentication.conf`` ファイルの中で多くの異なる認証ポリシーは記述できますが
+特定のユーザーはすべてのブランチ用のユーザーとパスワードを指定しなくても
+自分のニーズをカバーするわずかな定義だけが必要です。
+
+このファイルの中で見つかる定義は与えられたurl用のクレデンシャルを見つけるために使われます。
+一般的に同じクレデンシャルを必要とするリモートサーバーの周辺で宣言を分類することで可能な限り多くのブランチに対して
+クレデンシャルを使用できます。
+
+異なるサーバーによって使用されるクレデンシャルを宣言することも可能です。
+
+intentは維持を最少にするためにこのファイルを可能な限り小さくするものです。
+
+このファイルの中で関連のクレデンシャルが宣言されるとパスワード(セキュリティハザード)を埋め込まず
+もしくは(他の人とURLの共有を有効にする)ユーザーなしでブランチのURLを利用できます。
+
+次のURLよりも::
+
+  bzr branch ftp://joe:secret@host.com/path/to/my/branch
+
+シンプルになります::
+
+  bzr branch ftp://host.com/path/to/my/branch
+
+``authentication.conf`` ファイルを作成したことを前提とします::
+
+  [myprojects]
+  scheme=ftp
+  host=host.com
+  user=joe
+  password=secret
+
+
+認証の定義
+-----------
+
+bzrによってサポートされるさまざまなスキームによって使用される2種類の認証があります:
+
+1. ユーザーとパスワード
+
+``FTP`` は ``host`` 用に (``user`` 、 ``password``) を必要とします。
+``SFTP`` は認証用にパスワードもしくはホストキーを使用できます。
+しかしながら、sshエージェントはベターで、よりセキュアな解決方法です。
+独自のセキュアではない方法を提供しないことにします。
+
+2. ユーザー、領域とパスワード
+
+ホストに対して認証するために ``HTTP`` と ``HTTPS`` は(``user, realm, password``)を必要とします。
+``.htaccess`` ファイルを利用することで、たとえば、任意の ``host``
+に対して (``user, realm, password``) をいくつか定義することが可能です。
+ですので本当に必要なのは (``user``, ``password``, ``host``, ``path``)です。
+``realm`` は定義で考慮されませんが、bzrにパスワードを催促される場合表示されます。
+
+``HTTP proxy`` は適切なポートを指定することで ``HTTP`` (もしくは ``HTTPS``) として扱うことができます。
+
+すべてのスキームを考慮するには、パスワードは認証定義の一式 (``scheme``, ``host``, ``port``, ``path``, ``user``, ``password``) から推定されます。
+
+  * ``scheme``: 空にできます (定義の残りは任意のスキームに対して使用できることを意味する)、
+    ``SFTP`` と ``bzr+ssh`` はここでは使うべきではありません。
+    代わりに ``ssh`` が使われるべきです。これが認証に関して本当のスキームだからです。
+
+  * ``host``: 空にできます (ホスト用のデフォルトとして振る舞う),
+
+  * ``port`` は空にできます (ホストが同じスキームに対していくつかのサーバーを提供するときに便利)、
+    数値の値のみが許可され、サーバーがスキームの標準ポートとは異なるポートを使用するときのみにこれは使用されます。
+
+  * ``path``: 空にできます (FTPもしくはSFTPはこれを使用しません),
+
+  * ``user``: 空にできます (デフォルトでは ``bzr`` はpythonの ``getpass.get_user()`` を使用),
+
+  * ``password``: 常にパスワードをプロンプトで入力する方が望ましいのであれば空にできます。
+
+任意のURLに対して、複数の定義を提供できます。
+bzrは次のルールに従って (``user`` [, ``password``]) を選択します:
+
+ 1. 最初にマッチするものが優先される
+
+ 2. すべてにマッチする空のフィールド
+
+ 3. デコレータがリクエストされたURLに使用されていても ``scheme`` はマッチします。
+
+ 4. ``host`` は正確にマッチするか '.' で始まる場合、ドメインとしてふるまいます。
+    (``project.bzr.sf.net`` は ``.bzr.sf.net`` にマッチしますが ``projectbzr.sf.net`` は ``bzr.sf.net`` にマッチしない)。
+
+ 5. ``port`` はリクエストされたURLに含まれる場合(正確にマッチする場合のみ)マッチします。
+
+ 6. ``path`` はリクエストされたURLに含まれる場合マッチします (そして上記のルール #2 によって、
+    空のパスは任意の提供されたパスにマッチします)。
+
+
+
+ファイルのフォーマット
+----------------------
+
+`設定ファイル`_ 用の一般ルールは変数ポリシー意外に当てはまります。
+
+.. _設定ファイル: #configuration-settings
+
+それぞれのセクションで認証の定義を記述します。
+
+セクションの名前は任意の文字列で、 ``DEFAULT`` の値のみが保存され
+*最後* のセクションとして現れます。
+
+それぞれのセクションは次の内容を定義すべきです:
+
+* ``user``: 使用されるログイン名
+
+それぞれのセクションは次の内容を定義できます:
+
+* ``host``: リモートサーバー
+
+* ``port``: サーバーがリスンしているポート番号
+
+* ``path``: ブランチの位置
+
+* ``password``: パスワード
+
+
+例
+---
+
+
+外部でホストされた個人プロジェクト
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+すべての接続は同じ ``user`` で行われ
+(デフォルトのbzrのものが適切でない場合のためのリモートの接続)
+パスワードはいくつかの例外とともに常に催促されます::
+
+        # hobby.netのPetプロジェクト
+        [hobby]
+        host=r.hobby.net
+        user=jim
+        password=obvious1234
+
+        # ホームサーバー
+        [home]
+        scheme=https
+        host=home.net
+        user=joe
+        password=1essobV10us
+
+        [DEFAULT]
+        # ローカルユーザーがbarbazで、すべてのリモートサイト上ではfoobarとして
+        user=foobar
+
+
+ソースホスティングプロバイダ
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+shp.net(仮想)ドメインにおいて、それぞれのプロジェクトは独自のサイトを持ちます::
+
+        [shpnet domain]
+        # sftpを使用するが、sshは認証用に使用される
+        scheme=ssh
+        # '.' は 'shp.net' だけがマッチしないことを保証する
+        host=.shp.net
+        user=joe
+        # bzrはsftp用のパスワードの提供を保証しません
+        # パスワードをインタラクティブに入力したくなければ
+        # sshエージェントを使用することを考えてください(pageant, ssh-agent、など)
+
+HTTPS、SFTPサーバーとプロキシ
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+company.comにおいて、サーバーのホスティングリリースは統合ブランチの背後にはプロキシがあり、
+2つのブランチは異なる認証ポリシーを使用します::
+
+        [reference code]
+        scheme=https
+        host=dev.company.com
+        path=/dev
+        user=user1
+        password=pass1
+
+        # devサーバー上の開発ブランチ
+        [dev]
+        scheme=ssh # bzr+sshとsftpはここで利用可能
+        host=dev.company.com
+        path=/dev/integration
+        user=user2
+
+        # プロキシ
+        [proxy]
+        scheme=http
+        host=proxy.company.com
+        port=3128
+        user=proxyuser1
+        password=proxypass1
+
+
+計画的な強化
+-------------
+
+次の内容はまだ実装されていませんが進行中の作業の一部として計画されています:
+
+* ``password_encoding`` フィールドの追加は次のとおりです:
+
+  - さまざまな難読化のエンコーディング(たとえばbase64)でパスワードを保存する。
+
+  - パスワードの保存をプラグインに委譲する(たとえば.netrc)。
+
+* ユーザーがユーザー名もしくはパスワードの入力を催促されたらクレデンシャルを更新する。
+
+* ``HTTPS`` 用に ``verify_certificates`` フィールドを追加する。
+
+``password_encoding`` と ``verify_certificates`` フィールドは認識されますが
+実際の実装では無視されます。
+
+
+バグトラッカーの設定
+=====================
+
+コミットを行うとき、その変更によって修正されたバグに関するメタデータは --fixes オプションを使用することで記録されます。
+それぞれのバグが修正されたものとしてマークされるために、エントリーが '<url> <status>' を述べる 'bugs' リビジョンプロパティに含まれます。
+(現在サポートされる ``status`` の値は ``fixed.`` だけです)
+Launchpadの中心バグトラッカー用のサポートは組み込まれています。
+他のバグトラッカーに関して、正しいURLが記録されるように設定が予め要求されます。
+
+Launchpadに加えて、BazaarはBugzillaとTracに適切なURLの生成を直接サポートします。
+プロジェクトが異なるバグトラッカーを使用するのであれば、そのサポートを追加するのは簡単です。
+BugzillaもしくはTracを使用しているのであれば、
+バグトラッカーの基底URLを格納する設定変数を設定することだけが必要です。
+これらのオプションは ``bazaar.conf`` 、 ``branch.conf`` もしくは ``locations.conf`` のブランチ固有のセクションに入ります。
+取り組むプロジェクトごとにこれらの値をセットアップできます。
+
+注: それぞれのトラッカーに対して短縮名を提供するのであれば、望むのであればコミット時に1つもしくは複数のトラッカーで1つもしくは複数のバグを指定できます。
+
+Launchpad
+---------
+
+バグ2を修正するコミットを記録するには ``bzr commit --fixes lp:2`` を使用します。
+
+bugzilla_<tracker_abbreviation>_url
+-----------------------------------
+
+存在するのであれば、Bugzillaのバグトラッカーの位置は <tracker_abbreviation> によって参照されます。
+そのバグトラッカーのバグをそのコミットで修正されたものとしてマークするためにはこのオプションは ``bzr commit --fixes`` と一緒に使用できます::
+
+    bugzilla_squid_url = http://www.squid-cache.org/bugs
+
+上記の例はSquidのバグ 1234が修正されたものとしてマークするために ``bzr commit --fixes squid:1234`` を許可します。
+
+trac_<tracker_abbrevation>_url
+------------------------------
+
+存在するのであれば、Tracインスタンスの位置は <tracker_abbreviation> によって参照されます。
+そのコミットによってバグが修正されたものとしてそのトラッカーの中でマークするためにこのオプションは ``bzr commit --fixes`` と一緒に使用できます::
+
+    trac_twisted_url = http://www.twistedmatrix.com/trac
+
+上記の例はTwistedのバグ1234を修正したものとしてマークするために ``bzr commit --fixes twisted:1234`` を許可します。
+
+bugtracker_<tracker_abbrevation>_url
+------------------------------------
+
+存在するのであれば、一般的なバグトラッカーのインスタンスの位置は <tracker_abbreviation> によって参照されます。
+位置は ``{id}`` プレースホルダーを含まなければなりません。プレースホルダーは特定のバグIDに置き換えられます。
+そのコミットによってバグが修正されたものとしてそのトラッカーでマークするためにこのオプションを ``bzr commit --fixes`` と一緒に使用できます::
+
+    bugtracker_python_url = http://bugs.python.org/issue{id}
+
+上記の例はPythonのRoundupバグトラッカーのバグ1234を修正されたものとしてマークするために ``bzr commit --fixes python:1234`` を許可します::
+
+    bugtracker_cpan_url = http://rt.cpan.org/Public/Bug/Display.html?id={id}
+
+上記はCPANのRTバグトラッカー用です。
+
+
+構成設定
+=========
+
+.. TODO: Should have some explanation of why you'd want things in
+.. branch.conf.
+
+
+環境変数の設定
+---------------
+
+大抵の設定が設定ファイルによって取り扱われる一方で、
+半永久的ないくつかのオプションは環境変数を通して制御できます。
+
+BZR_EMAIL
+~~~~~~~~~
+
+Bazaarによって使用されるEメールのIDを上書きする。よくあるフォーマット::
+
+  "John Doe <jdoe@example.com>"
+
+``email`` の設定値も参照してください。
+
+BZR_PROGRESS_BAR
+~~~~~~~~~~~~~~~~
+
+進行状況の表示方法を上書きする。可能な値は "none"、 "dots"、 "tty"
+
+BZR_SIGQUIT_PDB
+~~~~~~~~~~~~~~~
+
+SIGQUITが通常とおりに振る舞うようにするかもしくはブレークインデバッガーを起動するかどうか制御する。
+
+* 0 = 標準のSIGQUITのふるまい(通常はコアダンプを伴ってexitする)
+* 1 = ブレークインデバッガーを起動する (デフォルト)
+
+BZR_HOME
+~~~~~~~~
+
+Bazaarによって使用されるホームディレクトリを上書きする
+
+BZR_SSH
+~~~~~~~
+
+異なるSSHの実装を選択する。
+
+BZR_PDB
+~~~~~~~
+
+デバッガもしくはエラーを立ち上げるか制御する。
+
+* 0 = Standard behavior
+* 1 = Launch debugger
+
+BZR_REMOTE_PATH
+~~~~~~~~~~~~~~~
+
+bzr+sshプロトコルを使用する際に使用するBazaar実行ファイルへのパス。
+
+設定値 ``bzr_remote_path`` も参照。
+
+BZR_EDITOR
+~~~~~~~~~~
+
+コミットメッセージなどの際にBazaarが使用するエディタへのパス。
+
+BZR_PLUGIN_PATH
+~~~~~~~~~~~~~~~
+
+Bazaarが使用するプラグインディレクトリへのパス。
+
+BZRPATH
+~~~~~~~
+
+Bazaarがシェルシェルプラグインの外部コマンドを探すパス。
+
+
+設定ファイル
+-------------
+
+設置場所
+~~~~~~~~~
+
+設定ファイルはLinux/Unixの場合 ``$HOME/.bazaar`` に
+Windowsの場合 ``C:\Documents and Settings\<username>\Application Data\Bazaar\2.0`` に設置されます。
+( ``bzr version`` を使用することでシステムに設置された位置をチェックできます)
+
+この位置に3つの主要な設定ファイルが存在します:
+
+* ``bazaar.conf`` はデフォルトの設定オプションを記述します
+
+* ``locations.conf`` は特定のブランチの位置用の設定情報を記述します。
+
+* ``authentication.conf`` はリモートサーバー用のクレデンシャル情報を記述します。
+
+それぞれのブランチはそのブランチに固有な値を設定する設定ファイルも格納します。
+このファイルはブランチの範囲内の ``.bzr/branch/branch.conf`` で見つかります。
+このファイルはブランチのすべてのユーザーに見えます。
+あなたのブランチ専用に設定値の1つを上書きしたいのであれば、 ``locations.conf`` で行うことができます。
+
+一般的なフォーマット
+~~~~~~~~~~~~~~~~~~~~
+
+iniファイルは3つの種類のコントラクト: セクションヘッダー、セクション変数とコメントを持ちます。
+
+コメント
+^^^^^^^^^
+
+コメント行は "#" で始まります("hash mark", "pound sign"  "number sign"とも呼ばれます)。
+コメント行はiniファイルを解析するときBazaarによって無視されます。
+
+セクションヘッダー
+^^^^^^^^^^^^^^^~~~~
+
+セクションヘッダーは行頭から始まり角かっこで囲まれた単語です。
+典型的なセクションヘッダーは次のとおりです::
+
+    [DEFAULT]
+
+bazaar.confに対して現時点で唯一有効なセクションヘッダーは[DEFAULT]と[ALIASES]です。
+セクションヘッダーは大文字と小文字を区別します。
+デフォルトのセクションが提供する設定変数はブランチの設定ファイルで上書きできます。
+
+``locations.conf`` に対して、
+セクションにマッチする最長のものを持つセクションからの変数は潜在的に有効な別のセクションヘッダーを除外するために使われます。
+セクションヘッダーはブランチ用のパスをセクションヘッダーとして使用します。次のような例があります::
+
+    [http://mybranches.isp.com/~jdoe/branchdir]
+    [/home/jdoe/branches/]
+
+
+セクション変数
+^^^^^^^^^^^^^^^
+
+セクション変数はセクションの範囲に属します。セクション変数は変数名、等号と値を格納します。例です::
+
+    email            = John Doe <jdoe@isp.com>
+    check_signatures = require
+
+
+変数のポリシー
+^^^^^^^^^^^^^^^
+
+セクションの中で定義された変数は名前つきのディレクトリもしくはURLに加えてそれらを格納する位置にも影響を与えます。
+ポリシーは可変変数が含まれる位置のために解釈される方法を変更するために使用できます。現在は3つのポリシーが利用できます:
+
+ none:
+   値は含まれる位置に対して同じように解釈されます。
+   これはデフォルトのふるまいです。
+ norecurse:
+   値はセクション名によって指定された正確な位置のみに対して使用されます。
+ appendpath:
+   for contained locations, 追加パスのコンポーネントは値に追加されます。
+
+ポリシーは "$var:policy" 形式の名前を持つキーによって指定されます。
+たとえば、ブランチのツリー用のpushの位置を定義するには、次の設定が使われます::
+
+  [/top/location]
+  push_location = sftp://example.com/location
+  push_location:policy = appendpath
+
+この設定によって、 ``/top/location/branch1`` 用のpush位置は ``sftp://example.com/location/branch1`` になります。
+
+
+主要な設定ファイルのbazaar.conf
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+``bazaar.conf`` は ``[DEFAULT]`` と呼ばれる1つのセクションだけを許可します。
+このデフォルトセクションはすべてのブランチ用のデフォルト設定オプションを格納します。
+デフォルトセクションは ``locations.conf`` にブランチ固有のセクションを提供することで上書きできます。
+
+典型的な ``bazaar.conf`` セクションは次のようになります::
+
+    [DEFAULT]
+    email             = John Doe <jdoe@isp.com>
+    editor            = /usr/bin/vim
+    check_signatures  = check-available
+    create_signatures = when-required
+
+
+ブランチの位置の設定ファイルのlocations.conf
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+``locations.conf`` によって特定のブランチ用に設定を上書きできます。
+フォーマットは1つの重大な変更を伴うbazaar.confのデフォルトセクションに対してほとんど理想的です:
+デフォルトを記述する代わりに、セクションヘッダーは値を上書きしたいブランチへのパスになります。
+ワイルドカードの '?' と '*' がサポートされます::
+
+    [/home/jdoe/branches/nethack]
+    email = Nethack Admin <nethack@nethack.com>
+
+    [http://hypothetical.site.com/branches/devel-branch]
+    create_signatures = always
+    check_signatures  = always
+
+    [http://bazaar-vcs.org/bzr/*]
+    check_signatures  = require
+
+認証用の設定ファイル、authentication.conf
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+``authentication.conf`` によってリモートサーバー用のクレデンシャルを指定できます。
+これはすべてのサポートされる転送と認証(たとえばsmtp)を必要とするbzrの一部に対して使用できます。
+
+ファイルの構文は適用しない変数ポリシー用の他の例外を除いて同じルールに従います。
+
+設定ファイルにおける認証の使い方の詳細な情報に関しては `認証の設定`_ を参照してください。
+
+
+変数の共通オプション
+---------------------
+
+email
+~~~~~
+
+Eメールアドレスはブランチをコミットする際に使われます。よく次のような形式をとります::
+
+    email = Full Name <account@hostname.tld>
+
+editor
+~~~~~~
+
+コミットメッセージなしで *bzr commit* が実行された場合に使用されるエディタのパスです。
+この設定は環境変数 ``BZR_EDITOR`` によって設定され、
+環境変数 ``VISUAL`` と ``EDITOR`` によって上書きされます。
+
+check_signatures
+~~~~~~~~~~~~~~~~
+
+署名用のふるまいを定義します。
+
+require
+    リビジョン用のgnupg署名が存在して有効でなければなりません。
+
+ignore
+    リビジョンのgnupgの署名をチェックしない。
+
+check-available
+    (デフォルト) リビジョン用のgnupgの署名が存在する場合、それらをチェックします。
+    わるい署名であることが分かるとBazaarは失敗しますが、署名が存在しない場合は失敗しません。
+
+create_signatures
+~~~~~~~~~~~~~~~~~
+
+リビジョン署名のふるまいを定義します。
+
+always
+    コミットされるすべての新しいリビジョンに署名する。
+
+when-required
+    (デフォルト) ブランチが署名つきのリビジョンを要求するときのみ新しくコミットされたリビジョンに署名する。
+
+never
+    ブランチが署名を要求する場合でも新しくコミットされたリビジョンに署名するのを拒否する。
+
+recurse
+~~~~~~~
+
+``locations.conf`` でのみ便利です。
+このセクション用の設定をサブディレクトリにも適用するかどうか定義します:
+
+true
+    (デフォルト このセクションはサブディレクトリにも適用される。
+
+false
+    このセクションはこのディレクトリのブランチのみに適用されその下のブランチには適用されない。
+
+gpg_signing_command
+~~~~~~~~~~~~~~~~~~~
+
+(デフォルト: "gpg"). リビジョンの署名とチェックのために使用されるプログラム。例です::
+
+    gpg_signing_command = /usr/bin/gnpg
+
+bzr_remote_path
+~~~~~~~~~~~~~~~
+
+(デフォルト: "bzr").  bzr用のスマートサーバーを稼働させるために使われるコマンドへのパス。
+この値はlocations.confでのみ指定が許可されます。理由は次のとおりです:
+
+- branch.confがアクセスできる前に必要だから
+- セキュリティリスクになるコマンドを指定するためにリモートのbranch.confファイルを許可するから
+
+これはBZR_REMOTE_PATH 環境変数によって上書きされます。
+
+smtp_server
+~~~~~~~~~~~
+
+(デフォルト: "localhost")。たとえば ``merge-directive --mail-to`` 、もしくはbzr-emailプラグインによって
+BazaarがEメールを送信する必要があるときに使用するSMTPサーバー、
+
+
+smtp_username, smtp_password
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+SMTPサーバーで認証するユーザーとパスワード。
+smtp_usernameが設定されていて、smtp_passwordが設定されていなければ、Bazaarはパスワードを催促します。
+Eメールを送信するためにSMTPサーバーが認証を必要とする場合のみこれらの設定が必要です。
+
+mail_client
+~~~~~~~~~~~
+
+マージリクエストを送信するために使うメールクライアント。
+デフォルトでは、Windowsではbzrは ``mapi`` を使うことを試みます。
+他のプラットフォームでは、 ``xdg-email`` を試みます。
+これらのどちらかが失敗すると、 ``editor`` に戻ります。
+
+特定のクライアント用のサポートされた値:
+
+:claws: Clawsを使用する。ファイル添付のダイアログはスキップする。
+:evolution: Evolutionを使用する
+:kmail: KMailを使用する
+:mutt: Muttを使用する
+:thunderbird: Mozilla ThunderbirdもしくはIcedoveを使用する。Thunderbird/Icedove 1.5に関して、
+    これはxdg-emailが扱えないいくつかのバグに対処します。
+
+サポートされる一般的な値は次のとおりです:
+
+:default: 上記を参照。
+:editor: マージリクエストを書くエディタを使用します。
+    これはコミットID( ``bzr whoami`` を参照),
+    smtp_serverと(オプションで)smtp_usernameとsmtp_passwordも使用します。
+:mapi: Windowsで好きなメールクライアントを使用します。
+:xdg-email: 好きなメールプラグラムを実行するためにxdg-emailを使用する
+
+submit_branch
+~~~~~~~~~~~~~
+
+現在の作業内容を投稿しようとしているブランチ。
+これは ``bzr send`` によって自動的に設定され ``submit:`` リビジョンスペックにも使用されます。
+通常、これはブランチ単位ロケーション単位で設定されます。
+
+public_branch
+~~~~~~~~~~~~~
+
+このブランチの公開されアクセス可能なバージョン
+(このブランチが公開されてアクセス可能ではないことを暗示する)。
+``bzr send`` によって使用されます(そして設定されます)。
+
+
+ブランチ特有のオプション
+-------------------------
+
+これらのオプションは ``dirstate-tags`` もしくは後のフォーマットを使用するブランチにのみ適用します。
+通常これらは自動的に ``.bzr/branch/branch.conf`` 設定される
+もしくは手動で ``locations.conf`` もしくは ``bazaar.conf`` に設定されます。
+
+append_revisions_only
+~~~~~~~~~~~~~~~~~~~~~
+
+"True"に設定されていればリビジョンはログにのみ追加され、削除されません。
+この設定が有効なブランチは、他のブランチのログがそれ自身のリビジョンより長い場合、別のブランチからのみpullできます。
+通常これは ``bzr init --append-revisions-only`` によって設定されます。
+
+parent_location
+~~~~~~~~~~~~~~~
+
+存在すれば、pullもしくはmerge用のデフォルトブランチの位置。
+通常このオプションは ``pull --remember`` もしくは ``merge --remember`` によって設定されます。
+
+push_location
+~~~~~~~~~~~~~
+
+存在すれば、push用のデフォルトブランチの位置。
+通常このオプションは ``push --remember`` によって設定されます。
+
+bound_location
+~~~~~~~~~~~~~~
+
+チェックアウトとして振る舞うときコミットが向かう位置。
+通常このオプションは ``bind`` によって設定されます。
+
+bound
+~~~~~
+
+"True"に設定されていると、ブランチはチェックアウトとしてふるまい、bound_locationにそれぞれのコミットをpushします。
+通常このオプションは ``bind``/``unbind`` に設定されます。
+
+
+衝突のタイプ
+=============
+
+オペレーションの中には、merge、revertとpullのように、作業ツリーの内容を修正するものがあります。
+これらの修正はプログラムで生成されるので、作業ツリーの現在の状態と衝突することがあります。
+多くの種類の変更はプログラムで結合できますが、 正しいことを行われているか時々人間だけしか判断できないことがあります。
+これが起きるとき Bazaarはあなたに衝突が存在するのでそれを解消するように伝えます。
+Bazaarに衝突が解消したことを伝えるコマンドは ``resolve`` ですが、
+これを実行できる前にいくつかのアクションを実行しなければなりません。
+
+それぞれの衝突は下記のセクションで説明され、衝突を解消するために行わなければならないアクションの概要が説明されています。
+
+
+テキストの衝突
+---------------
+
+典型的なメッセージは次のとおりです::
+
+  Text conflict in FILE
+
+テキストのマージが2つのセットのテキストの変更を完全に折り合いをつけられないときにこれらは生み出されます。
+BazaarはTHIS、OTHER、とBASEのエクステンションでそれぞれのバージョン用にファイルをemitします。
+THISはターゲットツリーからのファイルのバージョン、すなわち、変更をマージしようとしているツリーです。
+OTHERはターゲットにマージしようとしているバージョン、BASEは比較用のベースとして使われる古いバージョンです。
+
+ファイルのメインコピーにおいて、Bazaarは調整できるすべての変更を含み、
+未調整の衝突は ``<<<<<<<`` のように "herringbone" マーカーによって囲まれます。
+
+たとえば、初期のテキストが "The project leader released it."、でTHISはこれを "Martin Pool released it." に修正する一方で、
+OTHERは"The project leader released Bazaar."に修正します。衝突は次のようになります::
+
+  <<<<<<< TREE
+  Martin Pool released it.
+  =======
+  The project leader released Bazaar.
+  >>>>>>> MERGE-SOURCE
+
+正しい解消方法は"Martin Pool released Bazaar."になります。
+
+ファイルのメインコピーを編集する、もしくはTHIS、OTHERとBASEバージョン上で外部ツールを起動することのどちらかでテキストの衝突を扱うことができます。
+テキストの衝突の解消において他のものから変更のセットの1つの選別はめったにないことは言っておく価値があります。
+
+より頻繁に、2つのセットの変更はインテリジェントに結合しなければなりません。
+
+メインコピーを編集するとき、 herringbone マーカーを必ず削除してください。
+編集作業を終えたとき、ファイルは衝突がけっして起こらないようであれば、コミットする準備ができています。
+
+テキストの衝突を解消したとき、"bzr resolve"を実行するだけでBazaarは解消した衝突を自動検出します。
+
+内容の衝突
+----------
+
+典型的なメッセージ::
+
+  Contents conflict in FILE
+
+ターゲットツリーとマージソースの中の変更の衝突が存在するときにこの衝突は起こりますが、
+が衝突したアイテムはテキストファイルではありません。
+これらはバイナリファイルもしくはシンボリックリンクもしくはディレクトリになります。
+片方が削除され、もう一方が修正されたファイルでも起こり得ます。
+
+テキストの衝突のように、BazaarはTHIS、OTHER とBASEファイルをエミットしますが
+(これらは通常のファイル、シンボリックリンクもしくはディレクトリになります)、
+これはherringbone衝突マーカーを持つファイルの"メインコピー"を含みません。
+"メインコピー"がTHISもくはOTHERにリネームされたときにこれは現れます。
+
+これを解消するには、ファイルを通常の名前に戻すために "bzr mv" を使用し変更を手動で結合します。
+満足したときに、 "bzr resolve FILE" を実行します。この種の衝突が解消されたときにBazaarは自動検出できません。
+
+重複したパス
+-------------
+
+典型的なメッセージ::
+
+  Conflict adding file FILE.  Moved existing file to FILE.moved.
+
+時々Bazaarはすでに使用されているパス名を用いてファイルを作成しようとします。
+既存のファイルは "FILE.moved" にリネームされます。
+望むのであれば、これらのファイルの1つをリネームするか、それらの内容を結合できます。
+満足したら、衝突を解消したものとしてマークするために "bzr resolve FILE" を実行できます。
+
+バージョン管理下にない親
+-------------------------
+
+典型的なメッセージ::
+
+    Conflict because FILE is not versioned, but has versioned children.
+
+ときどきBazaarは親ディレクトリがバージョン管理されていないファイルを作成しようとします。
+ターゲットの中でディレクトリが削除されたときにこれが起こりますが、
+ソースの中の新しい子を持ちます。逆も同様です。
+この状況において、Bazaarは親ディレクトリも同様にバージョン管理します。
+この問題の解決方法は特定のシナリオに大きく依存します。
+ファイルもしくはディレクトリをリネームもしくは削除するとよいでしょう。
+満足したら、衝突を解消したものとして"bzr resolve FILE"を実行できます。
+
+見つからない親
+---------------
+
+典型的なメッセージ::
+
+  Conflict adding files to FILE.  Created directory.
+
+ターゲットの中でファイルを削除するときにこれが起こりますが、ソースの中に新しい子があります。
+これは "unversioned parent" の衝突と似ています。
+バージョン管理を解除される代わりに、親ディレクトリが *存在しない* ことを除いて、
+この状況において、Bazaarは見つからない親を作成します。
+この問題の解決方法は特定のシナリオに大いに依存します。
+ファイルもしくはディレクトリをリネームもしくは削除するとよいでしょう。
+満足したら、衝突を解消したものとして "bzr resolve FILE" を実行できます。
+
+親を削除する
+------------
+
+典型的なメッセージ::
+
+  Conflict: can't delete FILE because it is not empty.  Not deleting.
+
+これは"見つからない親"の反対です。ソースの中でディレクトリは削除されますが、
+ターゲットの中で新しい子はあります。Bazaarはディレクトリを保有し続けます。
+この問題の解消は特定のシナリオに大いに依存します。
+ファイルもしくはディレクトリをリネームもしくは削除するとよいでしょう。
+満足したら、衝突を解消したものとしてマークするために"bzr resolve FILE"を実行できます。
+
+パスの衝突
+-----------
+
+典型的なメッセージ::
+
+  Path conflict: PATH1 / PATH2
+
+ソースとターゲットがファイルの名前もしくは親ディレクトリを修正したときに起こります。
+Bazaarはソースからパス要素を使用します。
+ファイルをリネームできれば、衝突を解消したものとしてマークするために "bzr resolve FILE" を実行します。
+
+親のループ
+-----------
+
+典型的なメッセージ::
+
+  Conflict moving FILE into DIRECTORY.  Cancelled move.
+
+ソースとターゲットがそれぞれディレクトリを移動させたので、
+変更が適用可能であれば、ディレクトリはそれ自身を含むときにこれは起こります。
+例です::
+
+  $ bzr init
+  $ bzr mkdir a
+  $ bzr mkdir b
+  $ bzr commit -m "BASE"
+  $ bzr branch . ../other
+  $ bzr mv a b
+  $ bzr commit -m "THIS"
+  $ bzr mv ../other/b ../other/a
+  $ bzr commit ../other -m "OTHER"
+  $ bzr merge ../other
+
+この状況において、Bazaarは移動をキャンセルして、"a"を"b"の中に残しておきます。
+望むのであればディレクトリをリネームできれば
+衝突を解消したものとしてマークするために "bzr resolve FILE" を実行します。
+
+ディレクトリではない親
+-----------------------
+
+典型的なメッセージ::
+
+  Conflict: FILE.new is not a directory, but has files in it.
+  Created directory.
+
+片方がファイルをディレクトリを追加したとき、もう一方がディレクトリをファイルもしくはシンボリックリンクに変更したときにこれは起きます。
+例です::
+
+  $ bzr init
+  $ bzr mkdir a
+  $ bzr commit -m "BASE"
+  $ bzr branch . ../other
+  $ rmdir a
+  $ touch a
+  $ bzr commit -m "THIS"
+  $ bzr mkdir ../other/a/b
+  $ bzr commit ../other -m "OTHER"
+  $ bzr merge ../other
+
+
+MalformedTransform
+-------------------
+
+Bazaarに例外のMalformedTransformを起動させること可能です(非常にまれですが)。
+これはBazaarが解決できないファイルシステムの衝突に遭遇したことを意味します。
+通常これはバグを示します。これに遭遇したら教えて頂くようお願いします。
+バグトラッカーは https://launchpad.net/bzr/+bugs です。
+
+
+現在のストレージフォーマット
+============================
+
+:pack-0.92:
+    (ネイティブ) (デフォルト) 0.92で新しく導入:
+    dirstate-tagsフォーマットリポジトリと互換性のあるデータを持つパックベースのフォーマット。
+    0.92以前のbzrリポジトリと相互運用できますが0.92以前のbzrでは読めません。
+    以前はknitpack-experimentalと呼ばれていました。詳細な情報に関しては、
+    http://doc.bazaar-vcs.org/latest/developers/packrepo.html を参照。
+
+:1.6:
+    (ネイティブ) スタックをサポートするディレクトリに基づいたブランチとパック。
+
+:1.6.1-rich-root:
+    (ネイティブ) スタックとリッチrootデータをサポートするブランチとパックベースのリポジトリ(bzr-svnが必要)
+
+:1.9:
+    (ネイティブ) btreeインデックスを使用するブランチとパックベースのリポジトリ。
+
+:1.9-rich-root:
+    (ネイティブ) btreeインデックスとrich rootデータを使用する
+    ブランチとパックベースのリポジトリ(bzr-svnに必要)。
+
+
+ストレージフォーマットは ``bzr help formats`` を参照。
+
+
+環境変数
+========
+
+================ =================================================================
+BZRPATH          bzrがシェルプラグインコマンドを探すパス。
+BZR_EMAIL        ユーザーのEメールアドレス。EMAILを上書きする。
+EMAIL            ユーザーのEメールアドレス。
+BZR_EDITOR       コミットメッセージの編集用エディタ。EDITORを上書きする。
+EDITOR           コミットメッセージの編集用エディタ
+BZR_PLUGIN_PATH  bzrがプラグインを探すパス。
+BZR_HOME         .bazaarの設定ディレクトリを保持するディレクトリ。HOMEを上書きする。
+BZR_HOME (Win32) bazaar設定ディレクトリを保持するディレクトリ。APPDATAとHOMEを上書きする。
+BZR_REMOTE_PATH  リモート'bzr'コマンドのフルネーム(bzr+ssh:// URL用).
+BZR_SSH          SSHクライアント: paramiko (デフォルト), openssh, ssh, plink.
+BZR_LOG          .bzr.logの位置(ロギングを停止するには'/dev/null'を使う)。
+BZR_LOG (Win32)  .bzr.logの位置(ロギングを停止するには'NUL'を使う)。
+================ =================================================================
+
+
+ファイル
+========
+
+:On Linux:   ~/.bazaar/bazaar.conf
+:On Windows: C:\\Documents and Settings\\username\\Application Data\\bazaar\\2.0\\bazaar.conf
+
+ユーザーのデフォルト設定は上記のとおりです。
+``[DEFAULT]`` セクションすべての場所に適用される一般的な設定を定義するために使用できます。
+``[ALIASES]`` セクションは共通に使用されるオプション用のコマンドエイリアスを作成するために使用できます。
+
+典型的な設定ファイルは次のとおりです::
+
+  [DEFAULT]
+  email=John Doe <jdoe@isp.com>
+
+  [ALIASES]
+  commit = commit --strict
+  log10 = log --short -r -10..-1
+
+
+グローバルオプション
+=====================
+
+これらのオプションは任意のコマンドで使用可能で、コマンドの前で入力します(たとえば"bzr --profile help")。
+
+--version      バージョン番号を表示する。コマンドの前に入力しなければならない。
+--no-aliases   このコマンドを実行する際にコマンドエイリアスを処理しない。
+--builtin      プラグインのコマンドではなく、組み込みのコマンドを使用する。
+               このオプションは他のプラグインの効果を抑制しない。
+--no-plugins   プラグインを処理しない。
+
+--profile      ホットスポットプロファイラを使用するプロファイルの実行。
+--lsprof       lsprofプロファイラを使用したプロファイルの実行。
+--lsprof-file  lsprofプロファイラを使用するプロファイルを実行し、結果を指定ファイルに書き込む。
+               ファイル名が".txt"で終わる場合, テキストフォーマットが使用されます。
+               ファイル名が"callgrind.out"で始まる、もしくは".callgrind"で終わる場合、
+               KCacheGrind用に出力がフォーマットされる。
+               さもなければ、出力はpickleになる。
+--coverage     指定ディレクトリの行カバレージレポートを生成する。
+
+プロファイリングに関する詳細な情報はdoc/developers/profiling.txtを参照してください。
+トラブルシューティングと開発を手助けするためのたくさんのデバッグフラッグも利用可能です。
+
+-Dauth            使用される認証セクションをトレースする。
+-Derror           通常のエラーハンドリングの代わりに、常にエラー上のトラックバックを表示する。
+-Devil            割高なもしくはわるいスケーリングオペレーションを行うコールサイトをキャプチャする。
+-Dfetch           リポジトリ間のコピーの履歴をトレースする。
+-Dhashcache       ハッシュを決定するために作業ファイルが読み込まれるたびにログを記録する
+-Dhooks           フックの実行をトレースする。
+-Dhpss            スマートプロトコルリクエストとレスポンスをトレースする。
+-Dhttp            http接続、リクエストとレスポンスをトレースする。
+-Dindex           主要なindexオペレーションをトレースする。
+-Dknit            knitオペレーションをトレースする。
+-Dlock            lockdirロックがとられるもしくはリリースされるときをトレースする。
+-Dmerge           マージのデバッグ用の情報を表示する。
+-Dpack            packオペレーション用の情報を表示する。
+
+
+フック
+=======
+
+紹介
+-----
+
+*yyy* クラスの *xxx* タイプのフックを使用するには登録する必要があります::
+
+  yyy.hooks.install_named_hook("xxx", ...)
+
+例に関してはユーザーガイドの `フックを利用する`_ を参照してください。
+
+.. _フックを利用する: ../user-guide/index.html#id186
+
+それぞれのフックが含むクラスは下記のそれぞれのフックタイプの後で丸かっこの中で示されます。
+
+それぞれの説明ではクライアント(bzrが実行されるマシン)もしくはサーバー
+(ブランチURLで示されるマシン)で実行されるか示します。
+これらは必ずしも同じマシンではありません。
+
+以下の1つがtrueの場合(フックを含む)プラグインはサーバー上で実行されます:
+
+  * リモートブランチがクライアントと同じマシン上にあり、クライアントはプラグインを有効にしている。
+
+  * 接続はスマートサーバー経由で行われ("bzr://"、"bzr+ssh://"もしくは"bzr+http://"で
+    始まるURLでアクセスするもしくはスマートサーバーがHTTP経由で利用可能なときに
+    "http://"でアクセスする)、サーバーがプラグインを有効にしている。
+
+
+open (Branch)
+-------------
+
+Branchオブジェクトが開いた後で、Branchオブジェクトによって呼び出されます。
+クライアントとサーバーで実行します。
+
+post_push (Branch)
+------------------
+
+``push`` が完了した後で実行されます。
+クライアントで実行します。
+
+フックのシグネチャは (push_result) でメンバーを含みます。
+
+  source_branch
+    データがpushされる場所(読み込みはロックされる)。
+    これは最も低いレイテンシブランチになります。
+
+  target_branch
+    データが送信される直接の場所(書き込みがロックされる)。
+
+  master_branch
+    target_branch、もしくはターゲットがバインドされたブランチの場合、
+    これはマスターロケーションになります(書き込みはロックされる)。
+
+  local_branch
+    ターゲットがバインドされたブランチの場合、これがターゲットブランチになる、
+    そうでなければ、Noneになります。
+
+  old_revno
+    push以前のブランチのリビジョン番号(たとえば10)。
+
+  old_revid
+    push以前のリビジョンid (たとえば joe@foo.com-1234234-aoeua34)。
+
+  new_revno
+    push後のブランチのリビジョン番号(たとえば12)。
+
+  new_revid
+    push後のリビジョンid (たとえば joe@foo.com-5676566-boa234a)
+
+
+post_pull (Branch)
+------------------
+
+``pull`` が完了し後で実行されます。
+
+フックのシグネチャは (push_result) で次のメンバーを含みます:
+(source, local, master, old_revno, old_revid, new_revno, new_revid)。
+localはローカルのターゲットブランチもしくはNoneで、
+masterはターゲットのマスターブランチで、残りは見たとおりです。
+sourceでは読み込みがロックされターゲットブランチでは書き込みがロックされます。
+sourceはローカルの低レイテンシブランチになります。
+
+
+start_commit (MutableTree)
+--------------------------
+
+``commit`` が作業ツリーの処理を始める前に作業ツリー上で実行されます。
+クライアントで実行します。
+
+``pre_commit`` フック(下記を参照)とは異なり、
+``start_commit`` フックは作業ツリーを安全に変更できます。
+
+フックのシグネチャはツリーがMutableTreeオブジェクトである場所(ツリー)です
+
+
+pre_commit (Branch)
+-------------------
+
+``commit`` が完了する前に実行されます。
+クライアントで実行します。
+
+フックのシグネチャは
+(local, master, old_revno, old_revid, future_revno, future_revid, tree_delta, future_tree)です。
+old_revnoはブランチに最初にコミットするためのNULL_REVISIONで、
+tree_deltaは基底リビジョンからの変更を記述するTreeDeltaオブジェクトで、
+future_treeはインメモリツリーでCommitBuilder.revision_tree()から得られます。
+フックはtree_deltaとfuture_treeを修正する *必要はありません* 。
+
+
+post_commit (Branch)
+--------------------
+
+``commit`` が完了した後で実行されます。
+クライアントで実行します。
+
+フックのシグネチャは (local, master, old_revno, old_revid, new_revno, new_revid)です。
+old_revidはブランチへの最初のコミットのためのNULL_REVISIONです。
+
+
+post_uncommit (Branch)
+----------------------
+
+``uncommit`` が完了した後で実行されます。
+
+apiのシグネチャは (local, master, old_revno, old_revid, new_revno, new_revid)です。
+localはローカルブランチもしくはNoneで、masterはターゲットブランチで、
+空のブランチは0のnew_revno、Noneのnew_revidを受け取ります。
+
+
+pre_change_branch_tip (Branch)
+-------------------------------
+
+ブランチの書き込みがロックされている間に、ブランチチップが変更される前に実行されます。
+クライアントとサーバーで実行します。
+push、pull、commitとuncommitのすべてはこのフックを起動させることに注意してください。
+
+フックのシグネチャは (params) で、paramsはメンバーを含むオブジェクトです。
+
+  branch
+    チップが変更されるブランチ。
+
+  old_revno
+    変更前のブランチのリビジョン番号(たとえば10)。
+
+  old_revid
+    変更前のリビジョンid (たとえば joe@foo.com-1234234-aoeua34)。
+
+  new_revno
+    変更後のブランチのリビジョン番号(たとえば12)。
+
+  new_revid
+    変更後のリビジョンid (たとえば joe@foo.com-5676566-boa234a)。
+
+ヘッドリビジョンはドットつきのリビジョン番号をけっして持たないので、old_revnoとnew_revnoメンバーは整数です。
+
+
+post_change_branch_tip (Branch)
+-------------------------------
+
+ブランチの書き込みがまだロックされている間にブランチのチップが変更された後に実行されます。
+クライアントとサーバーで実行します。
+push、pull、commitとuncommitすべてがこのフックを起動させることに注意してください。
+
+フックシグネチャは(params)で、paramsは次のメンバーを含むオブジェクトです。
+
+  branch
+    チップが変更されるブランチ。
+
+  old_revno
+    変更前のブランチのリビジョン番号 (たとえば10)。
+
+  old_revid
+    変更前のリビジョンid(たとえば joe@foo.com-1234234-aoeua34)。
+
+  new_revno
+    変更後のブランチのリビジョン番号(たとえば12)。
+
+  new_revid
+    変更後のリビジョンid(たとえば joe@foo.com-5676566-boa234a)。
+
+ヘッドリビジョンはドットつきのリビジョン番号をけっして持たないのでold_revnoとnew_revnoメンバーは整数です。
+
+
+set_rh (Branch)
+---------------
+
+注意: このフックは廃止され近い将来の内に削除されます。
+代わりに ``post_change_branch_tip`` フックを使用してくださるようお願いします。
+
+
+transform_fallback_location (Branch)
+------------------------------------
+
+スタックドブランチとして起動させ、フォールバックロケーションをアクティベイトします。
+
+フックのシグネチャは(branch, url)です:
+
+  branch
+    開いたブランチ。まだフォールバックロケーションがアクティベイトされなければ、
+    ブランチは半分ビルドされたものとして扱われることに注意してください。
+
+  url
+    フォールバックロケーション用にブランチが指定されたURL。
+    フックはフォールバックロケーションを含むブランチのためにURLを返さなければなりません。
+    複数のフックが登録されていると、呼び出される順番は未定義で変更の影響を受けます。
+
+(1.9の新しい機能)
+
+
+server_started (SmartTCPServer)
+-------------------------------
+
+サーバーがディレクトリのサービスを提供始めるたびに起動します。
+サーバーで実行されます。
+フックのシグネチャは (backing urls, public url)です。
+
+  backing_url
+    サーバー固有のディレクトリの位置を渡す(string) URLのリスト。
+
+  public_url
+    ディレクトリ用の公開URL。
+
+
+server_stopped (SmartTCPServer)
+-------------------------------
+
+サーバーがディレクトリの提供を停止するときに常に起動します。
+サーバーで実行します。
+フックのシグネチャは ``server_started`` と同じです。
+
+
+lock_acquired (LockDir)
+----------------------------
+
+ロックの取得が成功したときにLockResultオブジェクトで呼び出されます(1.8で導入)。
+
+lock_released (LockDir)
+----------------------------
+
+ロックのリリースが成功したときにLockResultオブジェクトで呼び出されます(1.8で導入)。
+クライアントで実行します。
+
+
+commit_message_template (msgeditor)
+-----------------------------------
+
+コミットメッセージテンプレートを生成するためにコミットによって起動する。
+それぞれのフックはコミットメッセージテンプレートを修正できます。
+フックのシグネチャは (commit, start_message)です:
+
+  commit
+    進行中のコミットのための、コミットオブジェクト
+
+  start_message
+    オリジナルのコミットメッセージで、初期はNone。
+
+フックは新しいコミットメッセージテンプレートを返します。
+
+(1.10の新しい機能)
+
+
+その他のストレージフォーマット
+==============================
+
+実験的なフォーマットは次のとおりです。
+
+:1.12-preview:
+    (ネイティブ) ビューとコンテンツのフィルタリングをサポートする作業ツリーフォーマット。
+
+:1.12-preview-rich-root:
+    (ネイティブ) rich-rootデータをサポートする1.12-previewのバリアント(bzr-svnに必要)。
+
+:development:
+    (ネイティブ) 現在の開発フォーマット。
+    pack-0.92 (とpack-0.92と互換性のある)フォーマットリポジトリにデータを変換できます。
+    このフォーマットのリポジトリとブランチはbzr.devによってのみ読み込みできます。
+    使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html
+    をご覧下さるようお願いします。
+
+
+:development-subtree:
+    (ネイティブ) 現在の開発フォーマット。サブツリーのバリアント。
+    pack-0.92-subtree (pack-0.92-subtreeと互換性のあるものなら何でも)フォーマットリポジトリ
+    から/へのデータの変換ができる。このフォーマットのリポジトリとブランチは
+    bzr.devによってのみ読み込みできます。
+    使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html
+    をご覧下さるようお願いします。
+
+
+廃止されたフォーマットは下記のとおりです。
+
+:metaweave:
+    (ネイティブ) 0.8の暫定的なフォーマット。knitよりも遅い
+
+:weave:
+    (ネイティブ) 0.8以前のフォーマット。knitよりも遅くチェックアウトと共用リポジトリをサポートしない。
+
+:knit:
+    (ネイティブ) knitを使用するフォーマット。0.14とそれ以前のbzrとの相互運用に推奨される。
+
+:dirstate:
+    (ネイティブ) 0.15での新しいフォーマット: ローカルオペレーションが速い。
+    ネットワークを通してアクセスするときは0.8とそれ以降のbzrと互換性がある。
+
+:dirstate-tags:
+    (ネイティブ) 0.15での新しいフォーマット: 速いローカルオペレーションとネットワークオペレーションに関する改善されたスケーリング。
+    タグ用のサポートを追加。0.15以前のbzrとは互換性がない
+
+:rich-root:
+    (ネイティブ) 1.0での新しいフォーマット。ツリーrootの扱いを改善。1.0以前のbzrと互換性がない。
+
+
+詳細なストレージフォーマットは ``bzr help formats`` を参照してください。
+
+
+リビジョンの識別子
+====================
+
+リビジョンの識別子はブランチの履歴の特定の状態を参照します。
+これはリビジョン番号、もしくは ':' が後に続くキーワード、と他のパラメータになります。
+識別子の例として '3' 、 'last:1' 、 'before:yesterday' と 'submit:' などがあります。
+
+'REV1' と 'REV2' がリビジョンの識別子である場合、
+'REV1..REV2' はリビジョンの範囲を表示します。
+例: '3647..3649' 、 'date:yesterday..-1' と 'branch:/path/to/branch1/..branch:/branch2'
+('..'周辺にはクォートもしくはスペースが存在しません)。
+
+範囲は異なるコマンドによって異なる解釈がなされます。
+"log" コマンドに対して、範囲はログメッセージのシーケンスで、
+"diff" コマンドに対しては、範囲は(変更のシーケンスではなく)リビジョン間の変更を表示します。
+加えて、 "log" はclosed rangeを考慮するのに対して"diff"と"merge"はopen-endedとみなす、
+すなわち、これらは1つのendを含みますが他方は含みません。
+例です: "bzr log -r 3647..3649"はリビジョン3647、3648と3649のメッセージを表示するのに対して、
+"bzr diff -r 3647..3649"は3647と3648の間に行われた変更を含み、3649の変更は含みません。
+
+リビジョン選択方法として使用されるキーワードは次のとおりです:
+
+:revno:
+	番号を使用するリビジョンを選択する。
+:revid:
+	リビジョンidを使用するリビジョンを選択する。
+:last:
+	最後からn番目のリビジョンを選択する。
+:before:
+	指定されたリビジョンの親を選択する。
+:tag:
+	タグ名によって識別されるリビジョンを選択する。
+:date:
+	日付スタンプを基本とするリビジョンを選択する。
+:ancestor:
+	2番目のブランチで共通の祖先を選択する。
+:branch:
+	指定ブランチの最終リビジョンを選択する。
+:submit:
+	投稿ブランチで共通の祖先を選択する。
+
+加えて、プラグインは他のキーワードを提供できます。
+
+それぞれのキーワードの詳細な説明は下記のとおりです。
+
+:revno:
+
+    ブランチの履歴内のリビジョンを指定するために整数を使用する。
+    オプションとしてブランチを指定できます。接頭辞の 'revno:' はオプションです。
+    負の数はブランチの最後から数えます(-1は最後のリビジョン、-2はその前のリビジョン)。
+    負の数がブランチの履歴よりも大きい場合、最初のリビジョンが返されます。
+    例::
+
+      revno:1                   -> このブランチの最初のリビジョンを返す
+      revno:3:/path/to/branch   -> '/path/to/branch' ブランチの3番目のリビジョンを返す
+      revno:-1                  -> ブランチの最後のリビジョン。
+      -2:http://other/branch    -> リモートブランチの最後から2番目のリビジョン。
+      -1000000                  -> 履歴がとても長くなければ、おそらくは最初のリビジョン。
+
+:revid:
+
+    特定のリビジョンidを提供します。
+    ブランチの祖先のリビジョンidを指定するために使用できます。
+    マージと、マージの追加を含む。
+    例::
+
+      revid:aaaa@bbbb-123456789 -> リビジョン 'aaaa@bbbb-123456789' を選択する
+
+:last:
+
+    最後からn番目のリビジョンを取得するには正の数を提供する。
+    負の数の提供に関しては 'revno:' の仕様と同じです。
+    例::
+
+      last:1        -> 最後のバージョンを返す。
+      last:3        -> 最後の2つ前のリビジョンを返す。
+
+:before:
+
+    そのリビジョンの親を返すリビジョンスペックを提供する。
+    主にブランチのリビジョンの履歴の中に存在しないリビジョンを検査する際に便利です。
+
+    nullリビジョン(before:0)の親をリクエストするのは間違いです。
+
+    例::
+
+      before:1913    -> revno 1913の親を返す (revno 1912)
+      before:revid:aaaa@bbbb-1234567890  -> リビジョンaaaa@bbbb-1234567890の親を返す
+      bzr diff -r before:1913..1913
+            -> リビジョン1913とその親(1912)の間の変更を見つける
+               (リビジョン1913が導入する変更が行うこと)。
+               これは bzr diff -c 1913と同等です
+
+:tag:
+
+    タグはブランチに保存され、'tag'コマンドによって作成される。
+
+:date:
+
+    日付にマッチする最初のリビジョンを選択するためのデータスタンプを提供する。
+    日付は 'yesterday'、'today'、'tomorrow' もしくはYYYY-MM-DDの文字列です。
+    与えられた日付(深夜もしくは指定された時間のどちらか)の後の最初のエントリにマッチする。
+
+    昨日以降のすべての変更を表示する方法の1つは次のとおりです::
+
+        bzr log -r date:yesterday..
+
+    例::
+
+      date:yesterday            -> 昨日以降の最初のリビジョンを選択する
+      date:2006-08-14,17:10:14  -> August 14th, 2006 at 5:10pmの後の最初のリビジョンを選択する。
+
+:ancestor:
+
+    共通の祖先を選択するためにブランチへのパスを提供する。
+
+    共通の祖先は両方のブランチの中に存在する最後のリビジョンです。
+    通常これはブランチポイントですが、マージされたリビジョンにもなり得ます。
+
+    リモートブランチからマージしなかった変更を除外する一方で、
+    これはブランチが導入したすべての変更を返すために 'diff' でよく使用されます。
+
+    例::
+
+      ancestor:/path/to/branch
+      $ bzr diff -r ancestor:../../mainline/branch
+
+:branch:
+
+    最後のリビジョンを選択するためにブランチへのパスを提供する。
+
+    例::
+
+      branch:/path/to/branch
+
+:submit:
+
+    これに対する差分は、このブランチで行われたすべての変更を表示し、
+    マージされる予定のもののよい予測子です。
+    投稿ブランチはbundleとmergeコマンドによって使用されます。
+    投稿ブランチが指定されなければ、親ブランチが代わりに使用されます。
+
+    共通の祖先は両方のブランチ内に存在する最終リビジョンです。
+    通常これはブランチポイントですが、マージされたリビジョンにもなり得ます。
+
+    例::
+
+      $ bzr diff -r submit:
+
+
+標準オプション
+===============
+
+標準オプションはすべてのコマンドで有効です。
+
+--help, -h     ヘルプメッセージを表示する。
+--verbose, -v  詳細な情報を表示する。
+--quiet, -q    エラーと警告のみ表示する。
+
+グローバルオプションとは異なり、標準オプションはエイリアスで利用可能です。
+
+
+ステータスフラグ
+==================
+
+簡潔な方法で作業ツリーへの変更を要約するためにステータスフラグが使用されます。これらは次の形式をとります::
+
+   xxx   <filename>
+
+カラムの意味は次のとおりです。
+カラム 1 - バージョン管理/リネーム::
+
+  + バージョン管理されているファイル
+  - バージョン管理されていないファイル
+  R リネームされたファイル
+  ? 未知のファイル
+  C 衝突した内容を持つファイル
+  P マージを追加するためのエントリ(ファイルではない)
+
+カラム 2 - コンテンツ::
+
+  N 作成されたファイル
+  D 削除されたファイル
+  K 変更されたファイルの種類
+  M 修正されたファイル
+
+カラム 3 - 実行::
+
+  * 実行が少し変更された
+
+
+URLの識別子
+============
+
+サポートされるURLの接頭辞::
+
+  aftp://             アクティブFTPを利用したアクセス
+  bzr://              Bazaarスマートサーバーを利用したファーストアクセス
+  bzr+ssh://          SSHを通したBazaarスマートサーバーを利用したファーストアクセス
+  file://             標準ファイルシステムを利用したアクセス(デフォルト)
+  ftp://              パッシブFTPを利用したアクセス
+  http://             ウェブにエクスポートされたブランチへのリードオンリーのアクセス。
+  https://            SSLを利用したウェブにエクスポートされたブランチへのリードオンリーのアクセス。
+  sftp://             SFTPを利用したアクセス(大抵のSSHサーバーはSFTPを提供する)。
+
+
+.. _authentication: `認証の設定`_
+.. _bugs: `バグトラッカーの設定`_
+.. _configuration: `構成設定`_
+.. _conflicts: `衝突のタイプ`_
+.. _current-formats: `現在のストレージフォーマット`_
+.. _env-variables: `環境変数`_
+.. _global-options: `グローバルオプション`_
+.. _other-formats: `その他のストレージフォーマット`_
+.. _revisionspec: `リビジョンの識別子`_
+.. _standard-options: `標準オプション`_
+.. _status-flags: `ステータスフラグ`_
+.. _urlspec: `URLの識別子`_
+
+
+
+コマンド
+#########
+
+add
+===
+:目的: 指定したファイルもしくはディレクトリを追加する。
+:使い方:   bzr add [FILE...]
+
+:オプション:
+  --dry-run            何が行われるか表示するが、実際には行わない。
+  -v, --verbose        詳細な情報を表示する。
+  --no-recurse         ディレクトリの内容を再帰的に追加しない。
+  -h, --help           ヘルプメッセージを表示する。
+  -q, --quiet          エラーと警告だけ表示する。
+  --file-ids-from=ARG  このツリーからファイルのidを探索する。
+
+:説明:
+  non-recursiveモードでは、以前無視されたファイルであっても、
+  名前つきのすべてのアイテムが追加されます。
+  名前つきファイルがすでにバージョン管理されている場合は警告が表示されます。
+
+  recursiveモード(デフォルト)では、ファイルは同じ方法で扱われますが、
+  ディレクトリに対するふるまいは異なります。
+  すでにバージョン管理されているディレクトリであれば警告は表示されません。
+  すべてのディレクトリは、バージョン管理されているかいないかに関わらず、
+  ファイルもしくはバージョン管理も無視もされているサブディレクトリのための検索対象になり、
+  これらは追加されます。
+  この検索はバージョン管理されたディレクトリにも再帰的に進められます。
+  名前が渡されなければ、'.'が想定されます。
+
+  それゆえ単に 'bzr add' を実行すると現在未知であるファイルのすべてがバージョン管理されます。
+
+  親ディレクトリがバージョン管理されていないファイルを追加すると
+  親およびそのrootまでも暗黙の内に追加されます。
+  このことが意味するのはディレクトリを明示的に追加する必要はなく、
+  ディレクトリの中のファイルを1つ追加するときにそれらのディレクトリも追加されます。
+
+  --dry-runは追加されるファイルを表示しますが、それらを実際に追加しません。
+
+  --file-ids-fromは提供されたパスからファイルのidの使用を試みます。
+  これは同じファイル名を持ちマッチするディレクトリの発見をするためにidを探し、また純粋なパスによって行います。
+  このオプションが必要になるのはめったにありませんが、後でマージする2つのブランチに同じ論理ファイルを追加する
+  ときに便利です(2つの異なる追加を衝突として表示しません)。
+  別のプロジェクトをこのプロジェクトのサブディレクトリにマージする際にも便利です。
+
+:関連コマンド: `remove`_
+
+
+alias
+=====
+:目的: エイリアスの設定/設定解除と表示を行う。
+:使い方:   bzr alias [NAME]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  --remove       エイリアスを削除する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:例:
+    現在のエイリアスを表示するには::
+
+        bzr alias
+
+    'll'用に指定されたエイリアスを表示するには::
+
+        bzr alias ll
+
+    'll'のエイリアスを設定するには::
+
+        bzr alias ll="log --line -r-10..-1"
+
+    'll'のエイリアスを削除するには::
+
+        bzr alias --remove ll
+
+
+
+annotate
+========
+:目的: ファイルのそれぞれの行のoriginを表示する。
+:使い方:   bzr annotate FILENAME
+
+:オプション:
+  --all                 すべての行の注釈を表示する。
+  -v, --verbose         詳細な情報を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --long                注釈のコミット日時を表示する。
+  --show-ids            内部のオブジェクトidを表示する。
+  -r ARG, --revision=ARG
+                        "help revisionspec"の詳細を参照。
+
+:説明:
+  このコマンドは与えられたファイルの、変更によって導入されたリビジョン、
+  筆者と日付を示す注釈を左側で表示します。
+
+  連続した行の続きに関してoriginが同じ場合、
+  --allオプションが渡されない限り、これはトップでのみ表示されます。
+
+:エイリアス:  ann, blame, praise
+
+
+bind
+====
+:目的: 現在のブランチを提供されたブランチのチェックアウトに変換する。
+:使い方:   bzr bind [LOCATION]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  チェックアウトに変換されると、コミットはローカルブランチに適用される前に
+  コミットはマスターブランチを継承しなければなりません。
+
+  ローカルに設定されない限りバインドされたブランチは
+  マスターブランチのニックネームを使用します。
+  この場合、バインディングはローカルなニックネームをマスターのものに更新します。
+
+:関連コマンド: `checkout`_, `unbind`_
+
+
+branch
+======
+:目的: ブランチの新しいコピーを作成する。
+:使い方:   bzr branch FROM_LOCATION [TO_LOCATION]
+
+:オプション:
+  --stacked             ソースブランチを参照するスタックドブランチを作成する。
+                        すべてのオペレーションに関して
+                        新しいブランチはソースブランチの利用可能性に依存する。
+  -v, --verbose         詳細な情報を表示する。
+  --standalone          利用可能であっても共用リポジトリを使用しない。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --hardlink            可能な作業ツリーファイルをハードリンクする。
+  -r ARG, --revision=ARG
+                        詳細は "help revisionspec" を参照。
+
+:説明:
+  TO_LOCATIONが省略されると、FROM_LOCATIONの最終コンポーネントが使用されます。
+  言い換えると、 "branch ../foo/bar" は./bar を作成しようとします。
+  FROM_LOCATIONが/を持たない もしくは埋め込みのパスの区切り文字を持つ場合
+  冒頭のスキームもしくはドライブの識別子を剥ぎ取ることで、
+  FROM_LOCATIONからTO_LOCATIONが得られます。
+  たとえば、"branch lp:foo-bar"は./foo-barを作成しようとします。
+
+  ブランチの特定のリビジョンを読み取るには、
+  "branch foo/bar -r 5"のような、--revisionパラメータを提供します。
+
+:エイリアス:  get, clone
+:関連コマンド: `checkout`_
+
+
+break-lock
+==========
+:目的: リポジトリ、ブランチもしくは作業ディレクトリのデッドロックをブレークする。
+:使い方:   bzr break-lock [LOCATION]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  警告: ロックを保持するプロセスが停止したときにのみロックはブレークします。
+
+  'bzr info'コマンドを通して開いているロックに関する情報を得ることができます。
+
+:例:
+    bzr break-lock
+
+
+
+cat
+===
+:目的: 与えられたリビジョンのファイルの内容を標準出力に書き込む。
+:使い方:   bzr cat FILENAME
+
+:オプション:
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --name-from-revision  古いツリーのパス名。
+  -h, --help            ヘルプメッセージを表示する。
+
+:説明:
+  リビジョンが指定されなければ、最後のリビジョンが使用されます。
+
+  注意: バイナリファイルでこのコマンドを使用する際には
+        標準出力をリダイレクトするように気をつけてください。
+
+:関連コマンド: `ls`_
+
+
+check
+=====
+:目的: 作業ツリーの構造、ブランチの一貫性、とリポジトリの履歴をバリデートする。
+:使い方:   bzr check [PATH]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  --tree         現在のディレクトリに関連した作業ツリーをチェックする。
+  -q, --quiet    エラーと警告だけ表示する。
+  --repo         現在のディレクトリに関連したリポジトリをチェックする。
+  --branch       現在のディレクトリに関連したブランチをチェックする。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  このコマンドはデータの破損もしくはbzrのバグを検出するために
+  ブランチとリポジトリストレージに関するさまざまな不変量をチェックします・
+
+  問題が検出された場合のみ作業ツリーとブランチのチェックは出力をします。
+  リポジトリチェックの出力フィールドは次のとおりです:
+
+      revisions: これはチェックされるリビジョンの番号です。
+          これは問題を示しません。
+      versionedfiles: これはチェックされるバージョン管理されたファイルの数です。
+          これは問題を示しません。
+      unreferenced ancestors: 他のテキストの祖先であるテキストは、
+          リビジョンの祖先によって適切に参照されません。
+          これはBazaarが対処できるsubtleな問題です。
+      unique file texts: チェックされるリビジョンで見つかる
+          ファイルの内容の合計数です。これは問題を示しません。
+      repeated file texts: チェックされるリビジョンで見つかる、
+          繰り返されるテキストの合計数です。
+          テキストのエントリが修正されたときにテキストは繰り返しできますが、
+          ファイルの内容は繰り返しできません。
+          これは問題を示しません。
+
+  制限が指定されなければ、すべてのBazaarデータはチェックされる位置で見つかります。
+
+:例:
+    'foo' でのツリーとブランチをチェックする::
+
+        bzr check --tree --branch foo
+
+    'bar'でのリポジトリのみをチェックする::
+
+        bzr check --repo bar
+
+    'baz' ですべてをチェックする::
+
+        bzr check baz
+
+:関連コマンド: `reconcile`_
+
+
+checkout
+========
+:目的: 既存のブランチの新しいチェックアウトを作成する。
+:使い方:   bzr checkout [BRANCH_LOCATION] [TO_LOCATION]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  --files-from=ARG      このツリーからファイルの内容を取得する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --hardlink            利用可能な作業ツリーファイルをハードリンクする。
+  --lightweight         軽量チェックアウトを実行する。オペレーションに関して
+                        軽量チェックアウトはブランチへの権限に依存する。
+                        通常のチェックアウトはdiffやstatusのようなアクセスが
+                        不要な共通のオペレーションを実行可能で、
+                        ローカルコミットもサポートします。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  BRANCH_LOCATIONが省略されると、'.'で見つかるブランチ用に
+  チェックアウトは作業ツリーを再構成します。
+  作業ツリーを削除した場合もしくはこれがけっして作成されない場合
+  - すなわち、SFTPを使用してブランチを現在の位置にpushする場合、これは便利です。
+
+  TO_LOCATIONが省略されると、BRANCH_LOCATIONの最後のコンポーネントが使用されます。
+  言い換えると、"checkout ../foo/bar" は./barを作成しようとします。
+  BRANCH_LOCATIONが has no /を持たないもしくはパスの区切り文字が埋め込まれている場合、
+  先頭のスキームもしくはドライブの識別子を除去することでBRANCH_LOCATIONからTO_LOCATIONが
+  得られます。たとえば、"checkout lp:foo-bar"は./foo-barを作成しようとします。
+
+  特定のリビジョンのブランチを読み取るには、
+  "checkout foo/bar -r 5"のように--revisionパラメータを提供します。
+  これはすぐに時代遅れになりますが[なのでコミットできない]
+  役に立つことがあります(すなわち古いコードを検査するため)。
+
+:エイリアス:  co
+:関連コマンド: `branch`_, `チェックアウト`_
+
+
+commit
+======
+:目的: 変更を新しいリビジョンにコミットする。
+:使い方:   bzr commit [SELECTED...]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  --author=ARG          著者の名前がコミッターとは異なる場合、著者の名前を設定する。
+  --unchanged           何も変更されていなくてもコミットする。
+  --fixes=ARG           このリビジョンをバグが修正されたものとしてマークする。
+  -q, --quiet           エラーと警告のみを表示する。
+  --show-diff           メッセージが提供されないとき、
+                        メッセージエディタでステータスの要約と一緒に差分を表示する。
+  --strict              作業ツリーの中に未知のファイルが存在する場合コミットを拒否する。
+  -F MSGFILE, --file=MSGFILE
+                        このファイルからコミットメッセージを取得する。
+  -x ARG, --exclude=ARG
+                        与えられたパスへの変更を考慮しない。
+  -m ARG, --message=ARG
+                        新しいリビジョンの説明。
+  --local               バインドされたブランチにローカルコミットを実行する。
+                        通常のコミットが実行されるまで
+                        ローカルコミットはマスターブランチにpushされません。
+
+  -h, --help            ヘルプメッセージを表示する。
+
+:説明:
+  引数が渡されなければ、ツリー全体がコミットされます。
+
+  選択されたファイルが指定されると、これらのファイルへの変更のみがコミットされます。
+  ディレクトリが指定されるとディレクトリとその中のすべてがコミットされます。
+
+  excludesが渡されるとき、これらは選択されたファイルよりも優先されます。
+  たとえば、fooの範囲での変更のみコミットされますが、foo/barの範囲の変更はコミットされません::
+
+    bzr commit foo -x foo/bar
+
+  変更の著者がコミッターと同じ人物でなければ、
+  --authorオプションを使用して著者の名前を指定できます。
+  名前はコミッターidと同じフォーマットです。たとえば"John Doe <jdoe@example.com>"です。
+
+  コミットされるツリーが無効である場合選択されたファイルのコミットが失敗することがあります。
+  次の一連のコマンドを考えてみましょう::
+
+    bzr init foo
+    mkdir foo/bar
+    bzr add foo/bar
+    bzr commit foo -m "committing foo"
+    bzr mv foo/bar foo/baz
+    mkdir foo/bar
+    bzr add foo/bar
+    bzr commit foo/bar -m "committing bar but not baz"
+
+  上記の例において、最終コミットは故意に失敗します。
+  これによってユーザーは、同時に、最初に個別に、もしくはまったく
+  リネームしたくないかどうかを決める機会を得ます。
+  (一般的なルールとして、判断がつかないとき、Bazaarは安全に物事を行う方針を持ちます。)
+
+  注: マージの後の選択されたファイルのコミットはまだサポートされていません。
+
+:エイリアス:  ci, checkin
+:関連コマンド: `bugs`_, `uncommit`_
+
+
+conflicts
+=========
+:目的: 衝突を持つファイルの一覧を表示する。
+:使い方:   bzr conflicts
+
+:オプション:
+  --text         テキストの衝突を持つファイルのパスの一覧を表示する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  マージは2つのブランチの変更を結合するために最善を尽くしますが、
+  人間だけが修正できるある種の問題が存在します。
+  この問題に遭遇するとき、衝突がマークされます。
+  衝突はコミットする前に何かを修正する必要があることを意味します。
+
+  通常の衝突は短く人間が読めるメッセージとして一覧が示されます。
+  --textが提供される場合、代わりに、テキストの衝突を持つファイルのパスの一覧が表示されます。
+  (これはテキストの衝突を持つファイルをすべて編集するために便利です。)
+
+  問題を修正したらbzr resolveを使用します。
+
+:関連コマンド: `resolve`_
+
+
+
+deleted
+=======
+:目的: 作業ツリーの中で削除されたファイルの一覧を表示する。
+:使い方:   bzr deleted
+
+:オプション:
+  --show-ids     内部のオブジェクトidを表示する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:関連コマンド: `ls`_, `status`_
+
+
+diff
+====
+:目的: リビジョンもしくはブランチの間の、作業ツリーの中の違いを表示する。
+:使い方:   bzr diff [FILE...]
+
+:オプション:
+  --old=ARG             から比較するブランチ/ツリー。
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -p ARG, --prefix=ARG  コロンによって区切られた2つの値として
+                        新旧のファイル名に追加される接頭辞を設定する(たとえば"old/:new/")。
+  --using=ARG           ファイルを比較するためにこのコマンドを使用する。
+  --new=ARG             へ比較するブランチ/ツリー。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+  --diff-options=ARG    これらのオプションを外部diffプログラムに渡す。
+  -c ARG, --change=ARG  指定されたリビジョンによって導入された変更を選択する。
+                        "help revisionspec"も参照。
+  -h, --help            ヘルプメッセージを表示する。
+
+:説明:
+  引数が渡されなければ、現在のツリーに対するすべての変更の一覧が表示されます。
+  ファイルが渡されれば、これらのファイルの中の変更の一覧だけが表示されます。
+  リモートと複数のブランチは--oldと--newオプションを使用して比較できます。
+  これらのオプションが提供されなければ、両方のデフォルトは、存在すれば最初の引数、
+  引数が渡されなければ現在のツリーから得られます。
+
+  "bzr diff -p1" は "bzr diff --prefix old/:new/"と同等で、
+  "patch -p1"に最適なパッチが生成されます。
+
+:例:
+    作業ツリーと最終コミットの間の違いを表示する::
+
+        bzr diff
+
+    作業ツリーとリビジョン1の間の違い::
+
+        bzr diff -r1
+
+    リビジョン1とリビジョン2の間の違い::
+
+        bzr diff -r1..2
+
+    ブランチxxxのリビジョン1とリビジョン2の間の違い::
+
+        bzr diff -r1..2 xxx
+
+    NEWSファイルの違いだけ表示する::
+
+        bzr diff NEWS
+
+    NEWSファイルに対する作業ツリーの中の違いを表示する::
+
+        bzr diff xxx/NEWS
+
+    xxxブランチからこの作業ツリーの違いを表示する:
+
+        bzr diff --old xxx
+
+    NEWSファイルに対する2つのブランチの違いを表示する::
+
+        bzr diff --old xxx --new yyy NEWS
+
+    'bzr diff'と同じであるがold/とnew/でパスに接頭辞を追加する::
+
+        bzr diff --prefix old/:new/
+
+:Exitの値:
+    1 - 変更された
+    2 - 表現できない変更
+    3 - エラー
+    0 - 変更なし
+
+
+:エイリアス:  di, dif
+:関連コマンド: `status`_
+
+
+export
+======
+:目的: 現在のリビジョンを指定されたディレクトリもしくはアーカイブにエクスポートする。
+:使い方:   bzr export DEST [BRANCH_OR_SUBDIR]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  --format=ARG          Type of file to export to.
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --root=ARG            エクスポートされたファイル内部のrootディレクトリの名前。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  リビジョンが指定されなければこれは最終コミットのリビジョンをエクスポートします。
+
+  フォーマットはtar、tgz、tbz2のような"exporter"の名前になることができます。
+  何も渡されなければ、拡張子かｒフォーマットを見つけようとします。
+  拡張子が見つからなければディレクトリにエクスポートします(--format=dirと同等)。
+
+  rootが提供されると、これはコンテナフォーマット(tar、zip、その他)内部のrootディレクトリとして使用されます。
+  これが提供されなければエクスポートされるファイル名へのデフォルトになります。
+  rootオプションは'dir'フォーマットに対して効果がありません。
+
+  ブランチが省略されると現在の作業ディレクトリを含むブランチが使用されます。
+
+  注: ASCIIではないファイル名でのツリーのエクスポートはサポートされません。
+
+    ==========================       =========================
+    サポートされるフォーマット        拡張子で自動検出
+    ==========================       =========================
+       dir                              (none)
+       tar                               .tar
+       tbz2                              .tar.bz2, .tbz2
+       tgz                               .tar.gz, .tgz
+       zip                               .zip
+    ==========================       =========================
+
+
+
+help
+====
+:目的: コマンドもしくは他のトピックのヘルプを表示する。
+:使い方:   bzr help [TOPIC]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  --long         すべてのコマンドのヘルプを表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:エイリアス:  ?, --help, -?, -h
+:関連コマンド: topics
+
+
+ignore
+======
+:目的: 指定されたファイルもしくはパターンを無視する。
+:使い方:   bzr ignore [NAME_PATTERN...]
+
+:オプション:
+  --old-default-rules   bzr < 0.9で使用される無視ルールを書き出す。
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -h, --help            ヘルプメッセージを表示する。
+
+:説明:
+  パターンの構文の詳細は ``bzr help patterns`` を参照。
+
+  無視リストからパターンを除外するには、.bzrignoreファイルを編集します。
+  追加した後で、コマンドを使用して間接的に、もしくはエディタを使用して
+  直接そのファイルを編集もしくは削除した後で、そのコミットを確認してください。
+
+  注: シェルのワイルドカードを含む無視パターンはUnixのシェルからクォートされなければなりません。
+
+:例:
+    トップレベルのMakefileを無視する::
+
+        bzr ignore ./Makefile
+
+    すべてのディレクトリのクラスファイルを無視する::
+
+        bzr ignore "*.class"
+
+    libディレクトリ下の.oファイルを無視する::
+
+        bzr ignore "lib/**/*.o"
+
+    libディレクトリ下の.oファイルを無視する::
+
+        bzr ignore "RE:lib/.*\.o"
+
+    "debian"トップレベルディレクトリ以外のすべてを無視する::
+
+        bzr ignore "RE:(?!debian/).*"
+
+:関連コマンド: `ignored`_, `パターン`_, `status`_
+
+
+ignored
+=======
+:目的: 無視するファイルとそれらにマッチするパターンの一覧を表示する。
+:使い方:   bzr ignored
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  無視されるファイルと無視パターンのすべての一覧を表示します。
+
+  代わりにファイルの一覧だけを表示するには::
+
+      bzr ls --ignored
+
+:関連コマンド: `ignore`_, `ls`_
+
+
+info
+====
+:目的: 作業ツリー、ブランチもしくはリポジトリに関する情報を表示する。
+:使い方:   bzr info [LOCATION]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  このコマンドはツリー、ブランチもしくはリポジトリに関連する既知の位置とフォーマットのすべてを表示します。
+  統計情報はそれぞれのレポートに含まれます。
+
+  ブランチと作業ツリーは見つからないリビジョンもレポートします。
+
+:関連項目: `リポジトリ`_, `revno`_, `作業ツリー`_
+
+
+init
+====
+:目的: ディレクトリをバージョン管理下にあるブランチにする。
+:使い方:   bzr init [LOCATION]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  --create-prefix       ブランチに通じるパスがまだ存在していなければそれを作成する。
+  --append-revisions-only
+                        revnosもしくは既存のログを変更しない。
+                        リビジョンを追加するのみ。
+  -q, --quiet           エラーと警告のみを表示する。
+  -h, --help            ヘルプメッセージを表示する。
+
+  ブランチのフォーマット::
+
+    --format=ARG        このブランチのフォーマットを指定する。"help formats"を参照。
+    --1.12-preview      ビューとコンテンツのフィルタリングをサポートする作業ツリーフォーマット。
+    --1.12-preview-rich-root
+                        rich-rootデータをサポートする1.12-previewのバリアント(bzr-svnに必要)
+    --1.6               スタックをサポートするリポジトリに基づいたブランチとパック。
+    --1.6.1-rich-root   スタックとリッチなrootデータをサポートするリポジトリに基づいた
+                        ブランチとパック(bzr-svnに必要)。
+    --1.9               btreeインデックスを使用するリポジトリに基づいたブランチとパック
+    --1.9-rich-root     btreeインデックスとリッチrootデータを使用する
+                        リポジトリに基づいたブランチとパック(bzr-svnに必要)。
+    --default           0.92の新しい機能: dirstate-tagsフォーマットリポジトリと
+                        互換性のあるデータを持つパックベースのフォーマット。
+                        0.92以前のbzrリポジトリと相互運用しますが
+                        bzr < 0.92では読むことができません。
+                        以前はknitpack-experimentalと呼ばれていました。
+                        詳細な情報は http://doc.bazaar-vcs.org/latest/developers/packrepo.html を参照。
+    --development       現在の開発フォーマット。データをpack-0.92 (とpack-0.92と互換性のある)
+                        フォーマットリポジトリに変換できる。
+                        このフォーマットのリポジトリとブランチはbzr.devによってのみ読み込みできます。
+                        使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html を参照して頂くようお願いします。
+    --development-subtree
+                        現在の開発フォーマットで、subtreeバリアント。
+                        データをpack-0.92-subtree(とpack-0.92-subtreeと互換性のある)
+                        フォーマットリポジトリに変換できる。
+                        このフォーマットのリポジトリとブランチはbzr.devでのみ読み込みできる。
+                        使用する前に http://doc.bazaar-vcs.org/latest/developers/development-
+                        repo.html をご覧いただくようお願いします。
+    --dirstate          0.15の新しいフォーマット: 速いローカルオペレーション。
+                        ネットワークを通したアクセスのときbzr 0.8とそれ以降と互換性がある。
+    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで
+                        ネットワークオペレーションに関するスケーリングを改善。
+                        タグのサポートを追加。bzr < 0.15とは互換性がない。
+    --knit              knitsを使用するフォーマット。bzr <= 0.14との相互運用に推奨。
+    --metaweave         0.8での暫定フォーマット。knitよりも遅い。
+    --pack-0.92         0.92の新しいフォーマット: dirstate-tagsフォーマットリポジトリと
+                        互換性のあるデータを持つパックベースのフォーマット。
+                        0.92以前のbzrリポジトリと相互運用できるがbzr < 0.92.によって読み込みできない。
+                        以前はknitpack-experimentalと呼ばれていた。
+                        詳細な情報に関しては、 http://doc
+                        .bazaar-vcs.org/latest/developers/packrepo.html を参照。
+    --rich-root         1.0の新しいフォーマット。ツリーrootのベターな扱い。
+                        bzr < 1.0と互換性がない。
+    --rich-root-pack    1.0の新しいフォーマット: rich-rootデータをサポートする
+                        pack-0.92のバリアント(bzr-svnに必要)。
+    --weave             0.8以前のフォーマット。knitよりも遅く
+                        チェックアウトもしくは共用リポジトリをサポートしない。
+
+:説明:
+  空のブランチを作成するもしくは既存のプロジェクトをインポートする前に使用します。
+
+  親ディレクトリの位置にリポジトリが存在する場合、
+  ブランチの履歴はリポジトリに保存されます。
+  さもなければinitは.bzrのディレクトリに独自の履歴を運ぶスタンドアロンのブランチを作成します。
+
+  ロケーションにブランチがすでにあるが作業ツリーがない場合、ツリーは'bzr checkout'で投入できます。
+
+  ファイルのツリーをインポートする方法のレシピです::
+
+      cd ~/project
+      bzr init
+      bzr add .
+      bzr status
+      bzr commit -m "imported project"
+
+:関連コマンド: `branch`_, `checkout`_, `init-repository`_
+
+
+init-repository
+===============
+:目的: ブランチを保持する共用リポジトリを作成する。
+:使い方:   bzr init-repository LOCATION
+
+:オプション:
+  --no-trees            リポジトリのブランチはデフォルトで作業ツリーを持ちません。
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -h, --help            ヘルプメッセージを表示する。
+
+  ブランチのフォーマット::
+
+    --format=ARG        このブランチのフォーマットを指定する。"help formats"を参照。
+    --1.12-preview      ビューとコンテンツのフィルタリングをサポートする作業ツリーフォーマット。
+    --1.12-preview-rich-root
+                        rich-rootデータをサポートする1.12-previewのバリアント(bzr-svnに必要)
+    --1.6               スタックをサポートするリポジトリに基づいたブランチとパック。
+    --1.6.1-rich-root   スタックとリッチなrootデータをサポートするリポジトリに基づいた
+                        ブランチとパック(bzr-svnに必要)。
+    --1.9               btreeインデックスを使用するリポジトリに基づいたブランチとパック
+    --1.9-rich-root     btreeインデックスとリッチrootデータを使用する
+                        リポジトリに基づいたブランチとパック(bzr-svnに必要)。
+    --default           0.92の新しい機能: dirstate-tagsフォーマットリポジトリと
+                        互換性のあるデータを持つパックベースのフォーマット。
+                        0.92以前のbzrリポジトリと相互運用しますが
+                        bzr < 0.92では読むことができません。
+                        以前はknitpack-experimentalと呼ばれていました。
+                        詳細な情報は http://doc.bazaar-vcs.org/latest/developers/packrepo.html を参照。
+    --development       現在の開発フォーマット。データをpack-0.92 (とpack-0.92と互換性のある)
+                        フォーマットリポジトリに変換できる。
+                        このフォーマットのリポジトリとブランチはbzr.devによってのみ読み込みできます。
+                        使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html を参照して頂くようお願いします。
+    --development-subtree
+                        現在の開発フォーマットで、subtreeバリアント。
+                        データをpack-0.92-subtree(とpack-0.92-subtreeと互換性のある)
+                        フォーマットリポジトリに変換できる。
+                        このフォーマットのリポジトリとブランチはbzr.devでのみ読み込みできる。
+                        使用する前に http://doc.bazaar-vcs.org/latest/developers/development-
+                        repo.html をご覧いただくようお願いします。
+    --dirstate          0.15の新しいフォーマット: 速いローカルオペレーション。
+                        ネットワークを通したアクセスのときbzr 0.8とそれ以降と互換性がある。
+    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで
+                        ネットワークオペレーションに関するスケーリングを改善。
+                        タグのサポートを追加。bzr < 0.15とは互換性がない。
+    --knit              knitsを使用するフォーマット。bzr <= 0.14との相互運用に推奨。
+    --metaweave         0.8での暫定フォーマット。knitよりも遅い。
+    --pack-0.92         0.92の新しいフォーマット: dirstate-tagsフォーマットリポジトリと
+                        互換性のあるデータを持つパックベースのフォーマット。
+                        0.92以前のbzrリポジトリと相互運用できるがbzr < 0.92.によって読み込みできない。
+                        以前はknitpack-experimentalと呼ばれていた。
+                        詳細な情報に関しては、 http://doc
+                        .bazaar-vcs.org/latest/developers/packrepo.html を参照。
+    --rich-root         1.0の新しいフォーマット。ツリーrootのベターな扱い。
+                        bzr < 1.0と互換性がない。
+    --rich-root-pack    1.0の新しいフォーマット: rich-rootデータをサポートする
+                        pack-0.92のバリアント(bzr-svnに必要)。
+    --weave             0.8以前のフォーマット。knitよりも遅く
+                        チェックアウトもしくは共用リポジトリをサポートしない。
+
+:説明:
+  ブランチのディレクトリではなく、リポジトリにリビジョンを保存する
+  リポジトリディレクトリの元で作成された新しいブランチ。
+
+  --no-treesオプションが使用されるとリポジトリのブランチはデフォルトで作業ツリーを持ちません。
+
+:例:
+    ブランチだけを保有する共用リポジトリを作成する::
+
+        bzr init-repo --no-trees repo
+        bzr init repo/trunk
+
+    軽量チェックアウトを作成する::
+
+        bzr checkout --lightweight repo/trunk trunk-checkout
+        cd trunk-checkout
+        (add files here)
+
+:エイリアス:  init-repo
+:関連項目: `branch`_, `checkout`_, `init`_, `リポジトリ`_
+
+
+log
+===
+:目的: ブランチ、ファイル、もしくはディレクトリのログを表示する。
+:使い方:   bzr log [LOCATION]
+
+:オプション:
+  -v, --verbose         それぞれのリビジョンで変更されたファイルを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -l N, --limit=N       出力を最初のNのリビジョンに制限する。
+  --forward             最古から最新までを表示する。
+  --timezone=ARG        ローカル、オリジナル、utcのタイムゾーンを表示する。
+  --show-ids            内部オブジェクトidを表示する。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+  -m ARG, --message=ARG
+                        メッセージが正規表現にマッチするリビジョンを表示する。
+  -c ARG, --change=ARG  指定されたリビジョンだけを表示する。"help revisionspec"も参照。
+  -h, --help            ヘルプメッセージを表示する。
+
+  ログのフォーマット::
+    --log-format=ARG    指定されたログフォーマットを使用する。
+    --line              リビジョン単位の1行のログフォーマット
+    --long              詳細なログフォーマット
+    --short             適切に短いログフォーマット
+
+:説明:
+  デフォルトでは作業ディレクトリを含むブランチのログを表示する。
+
+  ログの範囲をリクエストするには、-r begin..endコマンドを使用できます。
+  -r revisionは指定したリビジョンをリクエストし、
+  -r ..end もしくは -r begin.. も有効です。
+
+:例:
+    現在のブランチのログ::
+
+        bzr log
+
+    ファイルのログ::
+
+        bzr log foo.c
+
+    ブランチの最後の10リビジョンのログ::
+
+        bzr log -r -10.. http://server/branch
+
+
+
+ls
+==
+:目的: ツリーのファイルの一覧を表示する。
+:使い方:   bzr ls [PATH]
+
+:オプション:
+  --from-root           ブランチのrootから相対的なパスを出力する。
+  --ignored             無視されたファイルを出力する。
+  --kind=ARG            特定の種類:file、directory、symlinkのエントリの一覧を表示する。
+  -v, --verbose         詳細な情報を表示する。
+  -V, --versioned       バージョン管理されたファイルを出力する。
+  --unknown             未知のファイルを出力する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --non-recursive       サブディレクトリで再帰的処理を行わない。
+  --show-ids            内部オブジェクトidを表示する。
+  --null                ファイルの間に改行の代わりに NUL (\0) 区切り文字を書く。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:関連項目: `cat`_, `status`_
+
+
+merge
+=====
+:目的: 三方向マージを実行する。
+:使い方:   bzr merge [LOCATION]
+
+:オプション:
+  --pull                すでに対象が完全にソースにマージされる場合、
+                        マージよりもソースからpullする。
+                        これが起きるとき、結果をコミットする必要はない。
+  --remember            指定されたロケーションをデフォルトとして記録する。
+  --force               目的のツリーがコミットされていない変更を持っていてもマージする。
+  -v, --verbose         詳細な情報を表示する。
+  --reprocess           誤った衝突を減らすために再処理する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --uncommitted         ブランチの変更の代わりに、作業ツリーからコミットされていない変更を適用する。
+
+  -d ARG, --directory=ARG
+                        作業ディレクトリを含むものよりも、マージするブランチ。
+  --show-base           衝突のベースリビジョンテキストを表示する。
+  --preview             マージする代わりに、マージの差分を表示する。
+  -c ARG, --change=ARG  指定されたリビジョンで導入された変更を選択する。
+                        "help revisionspec"も参照。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+  マージアルゴリズム::
+    --merge-type=ARG    特定のマージアルゴリズムを選択する。
+    --diff3             外部diff3を使用するマージ
+    --lca               新しいLCAマージ
+    --merge3            ネイティブのdiff3スタイルのマージ
+    --weave             weaveベースのマージ
+
+:説明:
+  マージのソースはブランチの形式、もしくはbzr sendで生成された
+  mergeディレクティブを含むファイルへのパスの形式で指定できます。
+  どちらも指定されなければ、デフォルトは上流ブランチもしくは
+  --rememberを使用して最近マージされたブランチです。
+
+  マージをブランチするとき、デフォルトではチップがマージされます。
+  異なるリビジョンをピックするには、--revisionを渡します。
+  2つの値を指定する場合、最初の値はBASEとして、2番目の値はOTHERとして使用されます。
+  個別のリビジョン、もしくはこのように利用可能なリビジョンのサブセットをマージすることは
+  一般的に"チェリーピック"として言及されます。
+
+  リビジョン番号はマージされるブランチに対して常に相対的です。
+
+  デフォルトでは、bzrは、自動的に適切なベースを検出して、
+  他のブランチからすべてのネットワークでマージしようとします。
+  これが失敗すると、明示的なベースを渡すことが必要になることがあります。
+
+  マージは2つのブランチの変更を結合するために最善を尽くしますが、
+  人間だけが修正できる種類の問題があります。
+  この問題に遭遇するとき、衝突マークがつけられます。
+  衝突はコミットする前に何かを修正する必要があることを意味します。
+
+  問題を修正したらbzr resolveを使用します。bzr conflictsも参照してください。
+
+  デフォルトのブランチセットが存在しない場合、最初のマージはそれを設定します。
+  その後で、デフォルトを使用するブランチを省略できます。
+  デフォルトを変更するには、--rememberを使用します。
+  リモートロケーションがアクセス可能場合のみ値は保存されます。
+
+  マージの結果は目的の作業ディレクトリに設置されます。
+  このディレクトリは(bzr diffで)閲覧、テスト、
+  とマージの結果を記録するためにコミット可能です。
+
+  --forceが渡されない限り、コミットされていない変更が存在すればマージの実行は拒否されます。
+
+:例:
+    bzr.devから最新のリビジョンをマージするには::
+
+        bzr merge ../bzr.dev
+
+    bzr.devからリビジョン82を含めて変更をマージするには::
+
+        bzr merge -r 82 ../bzr.dev
+
+    以前の変更なしに、82で導入された変更をマージするには::
+
+        bzr merge -r 81..82 ../bzr.dev
+
+    /tmp/mergeに含まれるmergeディレクトリを適用するには:
+
+        bzr merge /tmp/merge
+
+:関連項目: `remerge`_, `status-flags`_, `update`_
+
+
+missing
+=======
+:目的: 2つのブランチの間のmergeされていない/pullされていない リビジョンを表示する。
+:使い方:   bzr missing [OTHER_BRANCH]
+
+:オプション:
+  --reverse            リビジョンの順序をリバースする。
+  --this               --mine-onlyと同じ。
+  -h, --help           ヘルプメッセージを表示する。
+  -q, --quiet          エラーと警告だけ表示する。
+  --other              --theirs-onlyと同じ。
+  --include-merges     マージされたリビジョンを表示する。
+  --mine-only          ローカルブランチの変更のみを表示する。
+  --show-ids           内部オブジェクトidを表示する。
+  --theirs-only        リモートブランチの変更のみを表示する。
+  -v, --verbose        詳細な情報を表示する。
+
+  ログフォーマット::
+    --log-format=ARG   指定したログフォーマットを使用する。
+    --line             リビジョンごとの1行のログフォーマット
+    --long             詳細なログフォーマット
+    --short            適切に短いログフォーマット
+
+:説明:
+  OTHER_BRANCHはlocalもしくはremoteになります。
+
+:関連項目: `merge`_, `pull`_
+
+
+mkdir
+=====
+:目的: バージョン管理下にある新しいディレクトリを作成する。
+:使い方:   bzr mkdir DIR...
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  これはディレクトリの作成と追加と同等です。
+
+
+
+mv
+==
+:目的: ファイルを移動もしくはリネームする。
+:使い方:
+    bzr mv OLDNAME NEWNAME
+
+    bzr mv SOURCE... DESTINATION
+
+
+:オプション:
+  --after        ファイルがすでに移動しているので、ファイルのbzr識別子のみを移動させる。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  最後の引数がバージョン管理されているディレクトリの場合、
+  他のすべての名前はそこに移動します。
+  さもなければ、2つの引数だけにしなければならず
+  ファイルは新しい名前に変更されます。
+
+  OLDNAMEがファイルシステム上に存在しないがバージョン管理されていて
+  NEWNAMEはファイルシステム上に存在せずバージョン管理もされていない場合、
+  mvはファイルが手動で移動させられその変更を反映するために
+  内部インベントリだけを更新することを想定します。
+  多くのSOURCEファイルをDESTINATIONに移動させるときも同じです。
+
+  ブランチの間でファイルを移動させることはできません。
+
+:エイリアス:  move, rename
+
+
+nick
+====
+:目的: ブランチのニックネームを表示もしくは設定する。
+:使い方:   bzr nick [NICKNAME]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  設定が解除されると、ツリーのrootディレクトリの名前がニックネームとして使用されます。
+  現在のニックネームを表示するには、引数なしで実行します。
+
+  ローカルに設定されていない限りバインドされたブランチはマスターブランチのニックネームを使用します。
+
+:関連コマンド: `info`_
+
+
+pack
+====
+:目的: リポジトリ内のデータを圧縮する。
+:使い方:   bzr pack [BRANCH_OR_REPO]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:関連コマンド: `リポジトリ`_
+
+
+plugins
+=======
+:目的: インストールされたプラグインの一覧を表示する。
+:使い方:   bzr plugins
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  このコマンドはプラグインのバージョンとそれぞれの手短な説明を含めて
+  インストールされたプラグインの一覧を表示します
+
+  --verboseはそれぞれのプラグインが設置されたパスを表示します。
+
+  プラグインはコードを追加したり置き換えたりすることで
+  リビジョン管理システムを拡張する外部コンポーネントです。
+  コマンドの上書き、新しいコマンドの追加、追加のネットワーク転送の提供や
+  ログ出力のカスタマイズなどを含めて
+  プラグインはさまざまなことを行うことができます。
+
+  プラグインを見つけてインストール方法を含めた詳細な情報に関しては、
+  Bazaarのウェブサイト、http://bazaar-vcs.org を参照してください。
+  プログラミング言語のPyhonを利用して
+  新しいコマンドを作成する方法に関する手引きもあります。
+
+
+
+pull
+====
+:目的: このブランチを別のブランチのミラーにする。
+:使い方:   bzr pull [LOCATION]
+
+:オプション:
+  -v, --verbose         pullされたリビジョン用のログを表示する。
+  --remember            デフォルトとして指定されたロケーションを記録する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -d ARG, --directory=ARG
+                        作業ディレクトリを含むものよりもpullするブランチ。
+  --overwrite           ブランチの間の違いを無視して無条件で上書きする。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  このコマンドは分岐されていないブランチのみで動作します。
+  目的のブランチの最新の変更コミットが親にマージされなかった場合(直接もしくは間接)、
+  ブランチは分岐したものとして見なされます。
+
+  ブランチが分岐していれば、あるブランチからの変更を他のブランチに統合するために
+  'bzr merge'を使用できます。
+  一旦あるブランチがマージされると、他のブランチは再びそれをpullできるようになります。
+
+  ローカルの変更を忘れてリモートブランチを満たすようにブランチを更新したいだけなら、
+  pull --overwriteを使用します。
+
+  デフォルトのロケーションが存在しない場合、最初のpullはこれを設定します。
+  その後で、デフォルトを使用するロケーションを省略できます。
+  デフォルトを変更するには、--rememberを使用します。
+  リモートロケーションがアクセスできる場合のみ値は保存されます。
+
+  注: 位置がブランチのフォーマットもしくはbzr sendで生成されたmergeディレクトリを格納する
+      ファイルへのパスで指定できます。
+
+:関連項目: `push`_, `status-flags`_, `update`_
+
+
+push
+====
+:目的: このブランチのミラーを更新する。
+:使い方:   bzr push [LOCATION]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  --remember            指定された位置をデフォルトとして覚える。
+  --create-prefix       まだ存在しなればブランチへのパスを作成する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --stacked-on=ARG      コミットの履歴に関して別のブランチを参照するスタックドブランチを作成する。
+                        参照されるブランチに存在しない作業内容は作成されたブランチに格納される。
+  --use-existing-dir    デフォルトでは、ターゲットのディレクトリが存在するが
+                        まだコントロールディレクトリを持たない場合pushは失敗する。
+                        このフラグはpushの続行を可能にする。
+  -d ARG, --directory=ARG
+                        作業ディレクトリを含むブランチよりも、pushするブランチ
+  --stacked             親ブランチの公開位置を参照するスタックドブランチを作成する。
+  --overwrite           ブランチ間の違いを無視して無条件に上書きする。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  これは割高でリモートファイルシステムではサポートされないので、
+  ターゲットブランチは投入された作業ツリーを持ちません。
+
+  スマートサーバーもしくはプロトコルの中には将来作業ツリーを導入しないものがあります。
+
+  このコマンドは分岐されていないブランチでのみ動作します。
+  目的のブランチの最新のコミットがソースブランチによって(直接もしくは間接的に)マージされなければ
+  ブランチは分岐されたものとして見なされます。
+
+  ブランチが分岐されると、他のブランチを完全に置き換えるために
+  'bzr push --overwrite'を使用できます。この場合、マージされていない変更は廃棄されます。
+
+  他のブランチに異なる変更があることを保証したい場合は、
+  他のブランチからマージを行い(bzr help mergeを参照)、それをコミットします。
+  その後で'--overwrite'なしでpushを行うことができるようになります。
+
+  デフォルトのpush位置の設定がなければ、最初のpushはこれを設定します。
+  その後では、デフォルトを省略できます。
+  デフォルトを変更するには、--rememberを使用します。
+  リモート位置がアクセスできる場合のみ値は保存されます。
+
+:関連項目: `pull`_, `update`_, `working-trees`_
+
+
+reconcile
+=========
+:目的: ブランチのメタデータを調整する。
+:使い方:   bzr reconcile [BRANCH]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  これは以前の実在しないオペレーションもしくはbzrの更新によって
+  引き起こされるデータのミスマッチを訂正できます。
+  'bzr check'もしくはbzrの開発者がそのコマンドを実行するようにアドバイスするのであれば、
+  このコマンドを実行することだけが必要になります。
+
+  2番目のブランチが提供されると、
+  ブランチをまたがる調整も行われます。これによってbzrの初期のバージョンでは存在しなかった
+  ツリーのroot idのようなデータがチェックされ、両方のブランチで正しく表示されます。
+
+  同時にデータが再圧縮されるのでディスクスペースの節約やパフォーマンスのゲインにつながります。
+
+  ブランチはローカルディスクもしくはsftpのようにリスト可能なシステム上になければなりません。
+
+:関連項目: `check`_
+
+
+reconfigure
+===========
+:目的: bzrディレクトリのタイプを再設定する。
+:使い方:   bzr reconfigure [LOCATION]
+
+:オプション:
+  --force               ローカルの変更が失われていた場合でも再設定を実行する。
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --bind-to=ARG         チェックアウトをバインドするブランチ。
+  -h, --help            ヘルプメッセージを表示する。
+
+  Target type:
+    --branch            作業ツリーを持たないバインドされていないブランチに再設定する。
+    --checkout          作業ツリーを持つバインドされたブランチに再設定する。
+    --lightweight-checkout
+                        軽量チェックアウトに再設定する(ローカルの履歴はなし)。
+    --standalone        スタンドアロンブランチに再設定する(すなわち共用リポジトリの使用を停止する)。
+    --tree              作業ツリーを持つバインドされていないブランチに再設定する。
+    --use-shared        共用リポジトリを使用するように再設定する。
+
+:説明:
+  ターゲットの設定を指定しなければなりません。
+
+  チェックアウトに関しては指定されていなければ、bind-toのロケーションは自動検出されます。
+  優先順位は
+  1. 軽量チェックアウトに関しては、現在バインドされているロケーション。
+  2. チェックアウトに使用されるブランチに関しては、以前バインドされたロケーション。
+  3. pushのロケーション。
+  4. 親のロケーション。
+  これらが利用できなければ、--bind-toを指定しなければなりません。
+
+:関連項目: `ブランチ`_, `チェックアウト`_, `スタンドアロンのツリー`_, `作業ツリー`_
+
+
+remerge
+=======
+:目的: マージを再び行う。
+:使い方:   bzr remerge [FILE...]
+
+:オプション:
+  -v, --verbose       詳細な情報を表示する。
+  --reprocess         誤った衝突を減らすために再処理する。
+  -q, --quiet         エラーと警告のみ表示する。
+  --show-base         衝突内のベースリビジョンのテキストを表示する。
+  -h, --help          ヘルプメッセージを表示する。
+
+  マージアルゴリズム:
+    --merge-type=ARG  特定のマージアルゴリズムを指定する。
+    --diff3           外部diff3を使用するマージ
+    --lca             新しいLCAマージ
+    --merge3          ネイティブのdiff3スタイルのマージ
+    --weave           weaveベースのマージ
+
+:説明:
+  衝突を解消している間に異なるマージテクニックを試したい場合はこれを使用します。
+  マージテクニックの中には他のものよりもすぐれたものがあり、
+  remergeによって異なるファイルで異なるテクニックを試すことができます。
+  remergeのオプションはmergeのものと同じ意味とデフォルトを持ちます。
+  違いは未解決のマージが存在するときのみremergeは実行できて
+  特定のファイルを指定できることです。
+
+:例:
+    すべてのファイルのマージを再実行し、通常のTHISとOTHERテキストに加えて、
+    衝突領域のベーステキストを表示する::
+
+        bzr remerge --show-base
+
+    weaveマージアルゴリズムを使用して"foobar"のマージを再実行して、
+    衝突領域のサイズを減らすために追加処理を行う::
+
+        bzr remerge --merge-type weave --reprocess foobar
+
+
+
+remove
+======
+:目的: ファイルもしくはディレクトリを除外する。
+:使い方:   bzr remove [FILE...]
+
+:オプション:
+  --new         けっしてコミットされなかったファイルのみを除外する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+  削除戦略:
+    --force      指定されたファイルがリカバーできないまたは空のディレクトリではなくても
+                 これらすべてを削除する。
+    --keep       ファイルを削除しない。
+    --safe       ファイルを安全にリカバーできるのであればファイルを削除することだけ行う(デフォルト)。
+
+:説明:
+  このコマンドによってbzrは指定されたファイルへの変更の追跡を止めます。
+  rebertコマンドで容易に復元できるのであればbzrはこれらのファイルを削除します。
+  オプションもしくはパラメータが与えられなければbzrは追跡されているファイルをスキャンしますが
+  ツリーの中で見つからなければそれらの追跡を停止します。
+
+:エイリアス:  rm, del
+
+
+remove-tree
+===========
+:目的: 与えられたブランチ/チェックアウトから作業ツリーを除外する。
+:使い方:   bzr remove-tree [LOCATION]
+
+:オプション:
+  --force        コミットされていない変更があっても作業ツリーを除外する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  軽量チェックアウトは作業ツリーと大差ないので、これはそれに対する実行を拒絶します。
+
+  作業ツリーを再現するには、"bzr checkout"を使用します。
+
+:関連項目: `checkout`_, `working-trees`_
+
+
+renames
+=======
+:目的: リネームされたファイルの一覧を表示する。
+:使い方:   bzr renames [DIR]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:関連項目: `status`_
+
+
+resolve
+=======
+:目的: 衝突を解消されたものとしてマークする。
+:使い方:   bzr resolve [FILE...]
+
+:オプション:
+  --all          このツリーのすべての衝突を解消する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  2つのブランチの間の変更を結合するためにマージは最善を尽くしますが、
+  人間だけが修正できる種類の問題があります。
+  この問題に遭遇するとき、衝突がマークされます。
+  衝突はコミットする前に何かを修正する必要があることを意味します。
+
+  一旦問題を修正すれば、自動的にテキストの衝突を修正したものとしてマークするために"bzr resolve"を使用し、
+  特定の衝突を解消したものとしてマークするためにFILEをresolveします。
+  すべての衝突が解消されたものとしてマークするにはor "bzr resolve --all"を行います。
+
+:関連コマンド: `bzr conflicts`
+
+:エイリアス:  resolved
+
+
+revert
+======
+:目的: ファイルを以前のリビジョンに差し戻す。
+:使い方:   bzr revert [FILE...]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --forget-merges       ファイルを変更せずに、未解決のマージマーカーを取り除く。
+  --no-backup           差し戻しされたファイルのバックアップを保存しない。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  指定されたテキストだけを差し戻すファイルのリストを渡します。
+  さもなければ、すべてのファイルが差し戻されます。
+  '--revision'でリビジョンが指定されなければ、最後にコミットされたリビジョンが使用されます。
+
+  以前のリビジョンに差し戻さずに、いくつかの変更を除外するには、代わりにmergeを使用します。
+  たとえば、"merge . --revision -2..-3"は-2で導入された変更を除外しますが、
+  -1で導入された変更には影響を与えません。
+  hunk-by-hunkベースである変更を除外するには、Shelfプラグインを参照してください。
+
+  デフォルトでは、手動で変更されてきたファイルは最初にバックアップされます。
+  (マージのみで変更されたファイルはバックアップされません。)
+  バックアップファイルの名前には '.~#~' が追加されます。#は番号です。
+
+  ファイルを提供する場合、現在のパス名もしくはターゲットリビジョンからのパス名を使用できます。
+  名前でファイルを"undelete"するためにrevertを使用できます。
+  ディレクトリに名前をつけると、そのディレクトリのすべての内容が差し戻されます。
+
+  そのリビジョン以降に新しく追加されたファイルは削除されます。適切であればバックアップは維持されます。
+  未知のファイルを持つディレクトリは削除されません。
+
+  作業ツリーは未解決のマージされたリビジョンのリストを含みます。
+  これは次のコミットで親として含まれます。
+  通常は、ファイルを差し戻すのと同様にrevertはそのリストをクリーンにします。
+  ファイルが指定されていれば、revertは未解決のマージリストをそのままにしてファイルだけを差し戻します。
+  すべてのファイルを差し戻すがマージの記録を維持するにはツリーのrootで"bzr revert ."を使用し、
+  ファイルの差し戻しを行わずに未解決のマージリストをクリアするには"bzr revert --forget-merges"を使用します。
+
+:関連項目: `cat`_, `export`_
+
+
+revno
+=====
+:目的: 現在のリビジョン番号を表示する。
+:使い方:   bzr revno [LOCATION]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  これはこのブランチのリビジョン番号と等しいです。
+
+:関連項目: `info`_
+
+
+root
+====
+:目的: ツリーのrootディレクトリを表示する。
+:使い方:   bzr root [FILENAME]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  The rootは.bzrコントロールディレクトリを持つもっとも近い同封ディレクトリです。
+
+send
+====
+:目的: 変更を投稿するためにメールを送るもしくはmergeディレクティブを作成する。
+:使い方:   bzr send [SUBMIT_BRANCH] [PUBLIC_BRANCH]
+
+:オプション:
+  -f ARG, --from=ARG    作業ディレクトリを含むブランチよりも、投稿フォームを生成するブランチ。
+  --remember            投稿と公開ブランチを覚える。
+  --mail-to=ARG         このアドレスにリクエストメールを送信する。
+  --format=ARG          指定されたフォーマットを使用する。
+                        "0.9": バンドルフォーマット 0.9、マージディレクティブ 1。
+                        "4": バンドルフォーマット 4、マージディレクティブ 2 (デフォルト)。
+  --no-bundle           バンドルをmergeディレクティブに含めない。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -o ARG, --output=ARG  mergeディレクティブをこのファイルに書き込む; stdout用に-を使用する。
+  -m ARG, --message=ARG
+                        メッセージの文字列。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+  --no-patch            mergeディレクティブにプレビューパッチを含めない。
+  -v, --verbose         詳細な情報を表示する。
+
+:説明:
+  mergeディレクティブはmergeリクエストを行うために必要な多くのものを提供します:
+
+  * 実行するマージのマシンが理解できる説明
+
+  * リクエストされた変更のプレビューであるオプションのパッチ
+
+  * リビジョンデータのオプションバンドル、
+    ブランチからデータを読み込まずに、mergeディレクトリからの変更を直接適用できるようになります。
+
+  --no-bundleが指定されると、public_branchが必要です(また最新でなければなりません)、
+  受け取り手がpublic_branchを使用するマージを実行できるように
+  後で他の人がチェックできるように、知っているのであればpublic_branchを常に含まれていなければなりません。
+
+  投稿ブランチのデフォルトは親ですが、上書きできます。
+  提供されれば投稿ブランチと公開ブランチの両方が記録されます。
+
+  public_branchがsubmit_branchに知られていれば、
+  その公開と投稿ブランチはマージのインストラクションで使用されます。
+  これはそのローカルミラーに対してpublic_branchを設定すれば、
+  そのミラーは実際の投稿ブランチとして使用できることを意味します。
+
+  メールは好きなプログラムで送信されます。
+  Windowsではこれは透過的です(MAPIが使用される)。
+  Linuxでは、xdg-emailユーティリティを必要とします。
+  望ましいクライアントが見つからなければ(もしくは使用できなければ)、エディタが使用されます。
+
+  特定のメールプログラムを使用するには、mail_client設定オプションを設定します。
+  (Thunderbird 1.5に関して、これはいくつかのバグに対処します。)
+  特定のクライアント用にサポートされる値は"claws"、"evolution"、"kmail"、"mutt"、と"thunderbird";
+  一般的なオプションは"default"、"editor"、"emacsclient"、"mapi"、と"xdg-email"です。
+  プラグインがサポートされるクライアントを追加することもあります。
+
+  メールが送信されている場合、to addressが必要になります。
+  これはコマンドライン、submit_to設定オプションをブランチ自身に設定するか、
+  投稿ブランチでchild_submit_to設定オプションを設定することで提供できます。
+
+  現在2つのフォーマットがサポートされています: "4"はリビジョンバンドルフォーマット4
+  とマージディレクトリフォーマット2です。
+  これは古いフォーマットよりも顕著に速く小さいです。
+  これはBazaar 0.19とそれ以降で互換性があります。
+  これはデフォルトです。
+  "0.9"はリビジョンバンドルフォーマット0.9とマージディレクティブフォーマット1を使用します。
+  これは0.12 - 0.18と互換性があります。
+
+  mergeもしくはpullコマンドを使用することでmergeディレクトリが適用されます。
+
+:関連項目: `merge`_, `pull`_
+
+
+serve
+=====
+:目的: bzrサーバーを稼働させる。
+:使い方:   bzr serve
+
+:オプション:
+  --allow-writes     デフォルトではサーバーはリードオンリーのサーバーです。
+                     --allow-writesを提供すると提供されるディレクトリと
+                     その下の内容への書き込み権限を有効にできる。
+  -v, --verbose      詳細な情報を表示する。
+  -q, --quiet        エラーと警告のみを表示する。
+  --directory=ARG    このディレクトリの内容をサーブする。
+  --port=ARG         [hostname:]portnumber形式で指名されたポート上で接続するためにリスンする。
+                     0をポート番号として割り当てるとポートは動的な割り当てになります。
+                     デフォルトのポートは4155です。
+  --inet             inetdもしくはsshdからの使用のためにstdin/outでserveする。
+  -h, --help         ヘルプメッセージを表示する。
+
+:エイリアス:  server
+
+
+shelve
+======
+:目的: いくつかの変更を現在のツリーから一時的に退避する。
+:使い方:   bzr shelve [FILE...]
+
+:オプション:
+  --all                 すべての変更を退避する。
+  -v, --verbose         詳細な情報を表示する。
+  --list                退避された変更の一覧を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告だけ表示する。
+  -m ARG, --message=ARG
+                        メッセージの文字列。
+  -r ARG, --revision=ARG
+                        詳細に関しては"help revisionspec"を参照。
+
+  writer:
+    --plain             プレーンテキスト形式での差分の出力。
+
+:説明:
+  shelveによって変更を一時的に"棚に上げる"、すなわち邪魔にならない場所に置くことができます。
+  'unshelve'コマンドで後で元に戻すことができます。
+
+  shelve --listが指定されると、以前退避された変更の一覧が表示されます。
+
+  shelveは不適切に混ぜられた変更のいくつかのセットの分離を手助けすることを目的としています。
+  すべての変更を除去したいだけで後で退避する必要がなければ、revertを使用します。
+  一度にすべてのテキストの変更をshelveするには、shelve --allを使用します。
+
+  ファイル名が指定されると、それらのファイルの変更のみ退避されます。
+  他のファイルは手つかずのままです。
+
+  リビジョンが指定されれば、そのリビジョン以降の変更は退避されます。
+
+  複数のアイテムを退避することができ、デフォルトでは、
+  'unshelve'は最近shelveされた変更を復元します。
+
+:関連項目: `unshelve`_
+
+sign-my-commits
+===============
+:目的: 与えられたコミッターですべてのコミットに署名する。
+:使い方:   bzr sign-my-commits [LOCATION] [COMMITTER]
+
+:オプション:
+  --dry-run      実際に署名しない。
+                 署名されるリビジョンを表示するだけ。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  位置が指定されなければローカルツリーが使用されます。
+  コミッターが指定されなければデフォルトのコミッターが使用されます。
+
+  これはすでにシグネチャを持つコミットには署名しません。
+
+
+
+split
+=====
+:目的: ツリーのサブディレクトリを個別のツリーに分割する。
+:使い方:   bzr split TREE
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  このコマンドは'rich-root' もしくは 'rich-root-pack'のように
+  リッチrootをサポートするフォーマットでターゲットツリーを生み出します。
+  これらのフォーマットは'dirstate-tags'のような初期のフォーマットに変換できません。
+
+  TREEの引数は作業ツリーのサブディレクトリになります。
+  そのサブディレクトリは独自のブランチを持つ独立したツリーに変換されます。
+  トップレベルツリーのコミットは新しいサブツリーに適用されません。
+
+
+
+status
+======
+:目的: ステータスの要約を表示する。
+:使い方:   bzr status [FILE...]
+
+:オプション:
+  -S, --short           短いステータスインジケーターを表示する。
+  -v, --verbose         詳細な情報を表示する。
+  -V, --versioned       バージョン管理されたファイルだけを表示する。
+  --no-pending          未解決のマージを表示しない。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --show-ids            内部オブジェクトidを表示する。
+  -c ARG, --change=ARG  指定されたリビジョンで導入された変更を選択する。
+                        "help revisionspec"を参照。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  これはバージョン管理されたファイルと未知のファイルを状態で
+  分類してレポートします。利用可能な状態は次のとおりです:
+
+  added
+      作業ツリーでバージョン管理されているが以前のリビジョンではない。
+
+  removed
+      以前のリビジョンでバージョン管理されているが作業コピーでは移動もしくは削除されている。
+
+  renamed
+      以前のリビジョンから変更されたファイルのパス;
+      テキストも変更されていることがある。
+      これは親ディレクトリがリネームされたファイルを含む。
+
+  modified
+      以前のリビジョン以降変更されたテキスト。
+
+  kind changed
+      変更されたファイルの種類(たとえばファイルからディレクトリへ)。
+
+  unknown
+      バージョン管理されていないかつ無視パターンにマッチしない。
+
+  無視されるファイルを見るには'bzr ignored'を使用します。
+  ファイルテキストへの詳細な変更に関しては、'bzr diff'を使用します。
+
+  --shortもしくは-Sは、Subversionのstatusコマンドに似た、
+  それぞれのアイテムに対するステータスフラグを提供することに注意してください。
+  svn -qと似たような出力を得るには、bzr status -SVを使用します。
+
+  引数が指定されなければ、作業ディレクトリ全体のステータスが示されます。
+  さもなければ、指定されたファイルもしくはディレクトリのステータスのみが報告されます。
+  ディレクトリが渡されれば、そのディレクトリ内部のすべてに関するステータスが報告されます。
+
+  1つのリビジョンの引数が渡されれば、ステータスはそのリビジョンに対して
+  2つの引数の場合は2つのリビジョンの間で算出されます。
+
+:エイリアス:  st, stat
+:関連項目: `diff`_, `revert`_, `status-flags`_
+
+
+switch
+======
+:目的: チェックアウトのブランチを設定してupdateする。
+:使い方:   bzr switch TO_LOCATION
+
+:オプション:
+  --force        ローカルコミットが失われていても切り替える。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  軽量チェックアウトに対して、これは参照されているブランチを変更します。
+  重量チェックアウトに対して、これはローカルコミットがなく、
+  バインドされたブランチがないことを確認して、
+  ローカルブランチを新しいロケーションのミラーにしてそれにバインドします。
+
+  両方の場合において、作業ツリーはupdateされコミットされてない変更はマージされます。
+  ユーザーは望むのであればcommitもしくはrevertできます。
+
+  マージの追加にはswithを使用する前にcommitもしくはrevertする必要があります。
+
+  swithするブランチへのパスは現在のブランチの親ディレクトリに対して相対的に指定できます。
+  たとえば、現在/path/to/branchのチェックアウトの中にいるのであれば
+  'newbranch'を指定すれば/path/to/newbranchでのブランチが発見されます。
+
+  ローカルに設定されていない限りバインドされたブランチはマスターブランチのニックネームを使用します。
+  この場合、switchを行うとローカルのニックネームはマスターのものに更新されます。
+
+
+tag
+===
+:目的: リビジョンを名づけっるタグを作成、削除もしくは修正する。
+:使い方:   bzr tag TAG_NAME
+
+:オプション:
+  --force               既存のタグを置き換える。
+  -v, --verbose         詳細な情報を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -d ARG, --directory=ARG
+                        タグを設置するブランチ
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+  --delete              置き換えるよりもタグを削除する。
+
+:説明:
+  タグはリビジョンに人間が理解できる名前を与えます。
+  -r (--revision)オプションをとるコマンドは-rtag:Xに渡されます。
+  Xは以前作成されたタグです。
+
+  タグはブランチに保存されます。
+  branch、push、pullもしくはmergeを行うときタグはあるブランチから他のブランチにコピーされます。
+
+  --forceを渡さない限り、既存のタグ名を与えるとエラーになります。
+  この場合新しいリビジョンを示すようにタグは移動します。
+
+  タグをリネームする(名前を変更するが同じリビジョンで維持する)には、
+  ``bzr tag new-name -r tag:old-name`` と ``bzr tag --delete oldname`` を実行します。
+
+:関連項目: `commit`_, `tags`_
+
+
+tags
+====
+:目的: タグの一覧を表示する。
+:使い方:   bzr tags
+
+:オプション:
+  --sort=ARG            異なる基準でタグをソートする。
+                        "alpha": 辞書式でタグをソートする(デフォルト)。
+                        "time": 年代順でタグをソートする。
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -d ARG, --directory=ARG
+                        タグが表示されるブランチ。
+  --show-ids            内部オブジェクトidを表示する。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+  -h, --help            ヘルプメッセージを表示する。
+
+:説明:
+  このコマンドはこれらが参照するタグ名とリビジョンのテーブルを表示します。
+
+:関連項目: `tag`_
+
+
+testament
+=========
+:目的: リビジョンのtestament(署名のフォーム)を表示する。
+:使い方:   bzr testament [BRANCH]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --long                長いフォーマットのtestamentを生成する。
+  --strict              厳密なフォーマットのtestamentを生成する。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+
+
+unbind
+======
+:目的: 現在のチェックアウトを通常のブランチに変換する。
+:使い方:   bzr unbind
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  unbindした後で、ローカルブランチは独立したものとして見なされ
+  その後のコミットはローカルのみで行われます。
+
+:関連項目: `bind`_, `チェックアウト`_
+
+
+uncommit
+========
+:目的: 最後にコミットされたリビジョンを削除する。
+:使い方:   bzr uncommit [LOCATION]
+
+:オプション:
+  --dry-run             実際には変更しない。
+  -v, --verbose         詳細な情報を表示する。
+  -h, --help            ヘルプメッセージを表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  --force               すべての質問にyesと答える。
+  --local               チェックアウトのときローカルブランチからコミットのみを削除する。
+  -r ARG, --revision=ARG
+                        詳細は"help revisionspec"を参照。
+
+:説明:
+  --verboseは削除されているものを表示します。
+  --dry-runはすべてのモーションを経験しますが、実際には何も削除しません。
+
+  --revisionが指定されると、指定されたリビジョンでブランチをそのままにするために
+  リビジョンをuncommitします。たとえば、"bzr uncommit -r 15"はリビジョン15でのブランチを
+  そのままにします。
+
+  uncommitは新しいコミットの準備ができている作業ツリーをそのままにします。
+  唯一行われる変更はコミット以前に存在していた追加マージをリストアすることです。
+
+:関連項目: `commit`_
+
+unshelve
+========
+:目的: shelveされた変更を復元する。
+:使い方Usage:   bzr unshelve [SHELF_ID]
+
+:オプション:
+  -v, --verbose    詳細な情報を表示する。
+  -q, --quiet      エラーと警告だけ表示する。
+  -h, --help       ヘルプメッセージを表示する。
+
+  アクション:
+    --apply        変更を適用してshelfから削除する。
+    --delete-only  変更を適用せずにそれらを削除する。
+    --dry-run      編子を表示するがそれらを適用もしくは除外しない。
+
+:説明:
+  デフォルトでは、最近shelveされた変更が復元されます。
+  んまでパッチを指定したとしてもそれらの変更が代わりに復元されます。
+  変更がお互いに依存しないときにこれはもっとも良く機能します。
+
+:関連項目: `shelve`_
+
+
+update
+======
+:目的: ブランチにコミットした最新コードにツリーを更新する。
+:使い方:   bzr update [DIR]
+
+:オプション:
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:説明:
+  このコマンドは作業ツリーでマージを実行し、衝突を生成することがあります。
+  ローカルの変更がある場合、updateを完了させるために
+  updateの後でそれらをコミットする必要があります。
+
+  ローカルの変更を破棄したい場合、updateの後で'bzr commit'の代わりに
+  'bzr revert'を使用できます。
+
+:エイリアス:  up
+:関連項目: `pull`_, `status-flags`_, `working-trees`_
+
+
+upgrade
+=======
+:目的: ブランチのストレージを現在のフォーマットにアップグレードする。
+:使い方:   bzr upgrade [URL]
+
+:オプション:
+  -v, --verbose         詳細な情報を表示する。
+  -q, --quiet           エラーと警告のみを表示する。
+  -h, --help            ヘルプメッセージを表示する。
+
+  ブランチのフォーマット::
+
+    --format=ARG        このブランチのフォーマットを指定する。"help formats"を参照。
+    --1.12-preview      ビューとコンテンツのフィルタリングをサポートする作業ツリーフォーマット。
+    --1.12-preview-rich-root
+                        rich-rootデータをサポートする1.12-previewのバリアント(bzr-svnに必要)
+    --1.6               スタックをサポートするリポジトリに基づいたブランチとパック。
+    --1.6.1-rich-root   スタックとリッチなrootデータをサポートするリポジトリに基づいた
+                        ブランチとパック(bzr-svnに必要)。
+    --1.9               btreeインデックスを使用するリポジトリに基づいたブランチとパック
+    --1.9-rich-root     btreeインデックスとリッチrootデータを使用する
+                        リポジトリに基づいたブランチとパック(bzr-svnに必要)。
+    --default           0.92の新しい機能: dirstate-tagsフォーマットリポジトリと
+                        互換性のあるデータを持つパックベースのフォーマット。
+                        0.92以前のbzrリポジトリと相互運用しますが
+                        bzr < 0.92では読むことができません。
+                        以前はknitpack-experimentalと呼ばれていました。
+                        詳細な情報は http://doc.bazaar-vcs.org/latest/developers/packrepo.html を参照。
+    --development       現在の開発フォーマット。データをpack-0.92 (とpack-0.92と互換性のある)
+                        フォーマットリポジトリに変換できる。
+                        このフォーマットのリポジトリとブランチはbzr.devによってのみ読み込みできます。
+                        使用する前に http://doc.bazaar-vcs.org/latest/developers/development-repo.html を参照して頂くようお願いします。
+    --development-subtree
+                        現在の開発フォーマットで、subtreeバリアント。
+                        データをpack-0.92-subtree(とpack-0.92-subtreeと互換性のある)
+                        フォーマットリポジトリに変換できる。
+                        このフォーマットのリポジトリとブランチはbzr.devでのみ読み込みできる。
+                        使用する前に http://doc.bazaar-vcs.org/latest/developers/development-
+                        repo.html をご覧いただくようお願いします。
+    --dirstate          0.15の新しいフォーマット: 速いローカルオペレーション。
+                        ネットワークを通したアクセスのときbzr 0.8とそれ以降と互換性がある。
+    --dirstate-tags     0.15の新しいフォーマット: 速いローカルオペレーションで
+                        ネットワークオペレーションに関するスケーリングを改善。
+                        タグのサポートを追加。bzr < 0.15とは互換性がない。
+    --knit              knitsを使用するフォーマット。bzr <= 0.14との相互運用に推奨。
+    --metaweave         0.8での暫定フォーマット。knitよりも遅い。
+    --pack-0.92         0.92の新しいフォーマット: dirstate-tagsフォーマットリポジトリと
+                        互換性のあるデータを持つパックベースのフォーマット。
+                        0.92以前のbzrリポジトリと相互運用できるがbzr < 0.92.によって読み込みできない。
+                        以前はknitpack-experimentalと呼ばれていた。
+                        詳細な情報に関しては、 http://doc
+                        .bazaar-vcs.org/latest/developers/packrepo.html を参照。
+    --rich-root         1.0の新しいフォーマット。ツリーrootのベターな扱い。
+                        bzr < 1.0と互換性がない。
+    --rich-root-pack    1.0の新しいフォーマット: rich-rootデータをサポートする
+                        pack-0.92のバリアント(bzr-svnに必要)。
+    --weave             0.8以前のフォーマット。knitよりも遅く
+                        チェックアウトもしくは共用リポジトリをサポートしない。
+
+:説明:
+  ときどきこのコマンドを実行するにcheckコマンドもしくはbzrの開発者がアドバイスすることがあります。
+  デフォルトフォーマットが変更されたときアップグレードする他のオペレーションの実行中に警告されることもあります。
+
+:関連コマンド: `check`_
+
+
+version
+=======
+:目的: bzrのバージョンを表示する
+:使い方:   bzr version
+
+:オプション:
+  --short        バージョン番号だけを表示する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告だけ表示する。
+  -h, --help     ヘルプメッセージを表示する。
+
+
+
+version-info
+============
+:目的: このツリーに関するバージョン情報を表示する。
+:使い方:   bzr version-info [LOCATION]
+
+:オプション:
+  --all                 すべての入手可能な情報を含める。
+  -v, --verbose         詳細な情報を表示する。
+  --check-clean         ツリーがクリーンであるかチェックする。
+  --include-history     リビジョンの履歴を含める。
+  -q, --quiet           エラーと警告のみを表示する。
+  --template=ARG        出力用のテンプレート。
+  --include-file-revisions
+                        それぞれのファイルに対する最終リビジョンを含める。
+  -h, --help            ヘルプメッセージを表示する。
+
+  フォーマット::
+    --format=ARG        出力フォーマットを選択する。
+    --custom            カスタムテンプレートベースのフォーマットでのバージョン情報。
+    --python            Pythonフォーマットでのバージョン情報。
+    --rio               RIOフォーマット(シンプルなテキスト)でのバージョン情報(デフォルト)。
+
+:説明:
+  バージョンに関する情報をアプリケーションのソースコードに追加するために
+  このコマンドを使用できます。出力のフォーマットはサポートされているもの1つか
+  テンプレートに基づいてカスタマイズされたものです。
+
+  例::
+
+    bzr version-info --custom \
+      --template="#define VERSION_INFO \"Project 1.2.3 (r{revno})\"\n"
+
+  現在のリビジョン番号を含むフォーマットされた文字列でCヘッダファイルを生成します。
+  テンプレートでのサポートされた他の変数は次のとおりです:
+
+    * {date} - 最終リビジョンの日付
+    * {build_date} - 現在の日付
+    * {revno} - リビジョン番号
+    * {revision_id} - リビジョンid
+    * {branch_nick} - ブランチのニックネーム
+    * {clean} - ソースコードがコミットされていない変更を含むときは0でそれ以外は1
+
+
+
+whoami
+======
+:目的: bzrのユーザーidを表示もしくは設定する。
+:使い方:   bzr whoami [NAME]
+
+:オプション:
+  --email        Eメールアドレスのみ表示する。
+  -v, --verbose  詳細な情報を表示する。
+  -q, --quiet    エラーと警告のみを表示する。
+  --branch       グローバルの代わりに現在のブランチ用のIDを設定する。
+  -h, --help     ヘルプメッセージを表示する。
+
+:例:
+    現在のユーザーのEメールを表示する::
+
+        bzr whoami --email
+
+    現在のユーザーを設定する::
+
+        bzr whoami "Frank Chu <fchu@example.com>"
+
+
+
+

=== added directory 'doc/ru/_static'
=== added file 'doc/ru/_static/bzr icon 16.png'
Binary files doc/ru/_static/bzr icon 16.png and doc/ru/_static/bzr icon 16.png differ
=== added file 'doc/ru/_static/bzr.ico'
Binary files doc/ru/_static/bzr.ico and doc/ru/_static/bzr.ico differ
=== added directory 'doc/ru/_static/ru'
=== renamed file 'doc/ru/quick-reference/Makefile' => 'doc/ru/_static/ru/Makefile'
--- doc/ru/quick-reference/Makefile	2008-08-19 06:29:48 +0000
+++ doc/ru/_static/ru/Makefile	2009-09-07 05:26:43 +0000
@@ -1,5 +1,5 @@
-TARGETS=quick-start-summary.png quick-start-summary.pdf
-OBJECTS=quick-start-summary.svg Makefile
+TARGETS=bzr-quick-reference.png bzr-quick-reference.pdf
+OBJECTS=bzr-quick-reference.svg Makefile
 
 all: $(TARGETS)
 
@@ -11,9 +11,9 @@
 .svg.png:
 	rsvg-convert -d 300 -p 300 -z 3.3346 -f png -o $@ $<
 
-bzr-quickref.png: $(OBJECTS)
+bzr-quick-reference.png: $(OBJECTS)
 
-bzr-quickref.pdf: $(OBJECTS)
+bzr-quick-reference.pdf: $(OBJECTS)
 
 clean:
 	rm -f $(TARGETS)

=== renamed file 'doc/ru/quick-reference/quick-start-summary.pdf' => 'doc/ru/_static/ru/bzr-ru-quick-reference.pdf'
=== renamed file 'doc/ru/quick-reference/quick-start-summary.png' => 'doc/ru/_static/ru/bzr-ru-quick-reference.png'
=== renamed file 'doc/ru/quick-reference/quick-start-summary.svg' => 'doc/ru/_static/ru/bzr-ru-quick-reference.svg'
=== added directory 'doc/ru/_templates'
=== added file 'doc/ru/_templates/layout.html'
--- doc/ru/_templates/layout.html	1970-01-01 00:00:00 +0000
+++ doc/ru/_templates/layout.html	2009-10-30 07:51:16 +0000
@@ -0,0 +1,27 @@
+{% extends "!layout.html" %}
+
+{% block rootrellink %}
+<li><a href="http://bazaar-vcs.org/">
+    <img src="{{ pathto("_static/bzr icon 16.png", 1) }}" /> Главная</a>&nbsp;|&nbsp;</li>
+<a href="http://doc.bazaar-vcs.org/ru/">Документация</a>&nbsp;|&nbsp;</li>
+{{ super() }}
+{% endblock %}
+
+{% block document %}
+ <script type="text/javascript">
+  var gaJsHost = (("https:" == document.location.protocol) ?  "https://ssl." : "http://www.");
+  document.write(unescape("%3Cscript src='" + gaJsHost + "google-analytics.com/ga.js' type='text/javascript'%3E%3C/script%3E"));
+  </script>
+  <script type="text/javascript">
+  try{
+  var pageTracker = _gat._getTracker("UA-1018242-1");
+  pageTracker._trackPageview();
+  } catch(err) {}
+  try {
+    /* bazaar team tracker */
+    var pageTracker = _gat._getTracker("UA-11329411-2");
+    pageTracker._trackPageview();
+  } catch(err) {}
+</script>
+{{ super() }}
+{% endblock %}

=== added file 'doc/ru/conf.py'
--- doc/ru/conf.py	1970-01-01 00:00:00 +0000
+++ doc/ru/conf.py	2009-09-09 15:51:18 +0000
@@ -0,0 +1,94 @@
+# -*- coding: utf-8 -*-
+#
+# Bazaar documentation build configuration file, created by
+# sphinx-quickstart on Tue Jul 21 17:04:52 2009.
+#
+# This file is execfile()d with the current directory set to its containing dir.
+
+import sys, os
+
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path = [os.path.abspath('../..')] + sys.path
+
+# Most of the configuration for Bazaar docs is defined here ...
+from bzrlib.doc_generate.sphinx_conf import *
+
+
+## Configuration specific to this site ##
+
+# The locale code for this documentation set
+bzr_locale = 'ru'
+
+# Translations & supporting helper function
+bzr_titles = {
+        u'Table of Contents (%s)': u'Содержание (%s)',
+        u'Bazaar User Guide': None,
+        u'Bazaar User Reference': None,
+        u'Bazaar Release Notes': None,
+        u'Bazaar Upgrade Guide': None,
+        u'Bazaar in five minutes': u'Базар за пять минут',
+        u'Bazaar Tutorial': u'Большой учебник',
+        u'Using Bazaar With Launchpad': u'Использование Bazaar с Launchpad',
+        u'Centralized Workflow Tutorial': u'Работа в централизованном стиле',
+    }
+def bzr_title(s):
+    return bzr_titles.get(s) or s
+
+# The language for content autogenerated by Sphinx. Refer to documentation
+# for a list of supported languages.
+language = bzr_locale
+
+# A shorter title for the navigation bar.  Default is the same as html_title.
+html_short_title = bzr_title(u"Table of Contents (%s)") % (release,)
+
+# Additional templates that should be rendered to pages, maps page names to
+# template names.
+#html_additional_pages = {'index': 'index.html'}
+
+# Output file base name for HTML help builder.
+htmlhelp_basename = 'bzr-%s' % (bzr_locale,)
+
+# Grouping the document tree into LaTeX files. List of tuples
+# (source start file, target name, title, author, documentclass [howto/manual]).
+latex_documents = [
+  # Manuals
+  #('user-guide/index', 'bzr-%s-user-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar User Guide'), bzr_team, 'manual'),
+  #('user-reference/bzr_man', 'bzr-%s-user-reference.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar User Reference'), bzr_team, 'manual'),
+  #('release-notes/NEWS', 'bzr-%s-release-notes.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Release Notes'), bzr_team, 'manual'),
+  #('upgrade-guide/index', 'bzr-%s-upgrade-guide.tex' % (bzr_locale,),
+  #  bzr_title(u'Bazaar Upgrade Guide'), bzr_team, 'manual'),
+  # Tutorials
+  ('mini-tutorial/index', 'bzr-%s-tutorial-mini.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar in five minutes'), bzr_team, 'howto'),
+  ('tutorials/tutorial', 'bzr-%s-tutorial.tex' % (bzr_locale,),
+    bzr_title(u'Bazaar Tutorial'), bzr_team, 'howto'),
+  #('tutorials/using_bazaar_with_launchpad',
+  #  'bzr-%s-tutorial-with-launchpad.tex' % (bzr_locale,),
+  #  bzr_title(u'Using Bazaar With Launchpad'), bzr_team, 'howto'),
+  #('tutorials/centralized_workflow',
+  #  'bzr-%s-tutorial-centralized.tex' % (bzr_locale,),
+  #  bzr_title(u'Centralized Workflow Tutorial'), bzr_team, 'howto'),
+]
+
+# List of documents that shouldn't be included in the build.
+unused_docs = [
+    # Subtopics that get included
+    'upgrade-guide/overview',
+    'upgrade-guide/data_migration',
+    'upgrade-guide/tips_and_tricks',
+    'user-guide/branching_a_project',
+    'user-guide/core_concepts',
+    'user-guide/introducing_bazaar',
+    'user-guide/specifying_revisions',
+    'user-guide/stacked',
+    'user-guide/using_checkouts',
+    'user-guide/zen',
+    # Plain-style documentation generation stuff
+    'user-guide/index-plain',
+]
+

=== renamed file 'doc/index.ru.txt' => 'doc/ru/index.txt'
--- doc/index.ru.txt	2009-06-02 18:07:12 +0000
+++ doc/ru/index.txt	2009-12-02 20:34:07 +0000
@@ -2,60 +2,36 @@
 Главный каталог документов Bazaar
 =================================
 
-Последняя версия этих документов доступа со страницы документации 
-на сайте Bazaar, <http://doc.bazaar-vcs.org/>. Еще больше информации 
-можно получить по адресу <http://bazaar-vcs.org/Documentation>.
+Последняя версия этих документов доступа со страницы документации
+на сайте Bazaar, <http://doc.bazaar-vcs.org/ru/>.
 
 Основная документация
 =====================
 
-* `Руководство пользователя <ru/user-guide/index.html>`_
-
-* `Справочник пользователя <en/user-reference/bzr_man.html>`_ (англ.)
-
-* `Карточка быстрого старта <ru/quick-reference/quick-start-summary.svg>`_
-  (`PDF <ru/quick-reference/quick-start-summary.pdf>`_,
-  `PNG <ru/quick-reference/quick-start-summary.png>`_)
-
-* `Список изменений <en/release-notes/NEWS.html>`_ (англ.)
-
-* `Каталог информации для разработчиков <developers/index.html>`_ (англ.) |--| 
-  для разработчиков Bazaar и плагинов
-
-Учебники
-========
-
-* `Базар за пять минут <ru/mini-tutorial/index.html>`_
-
-* `Большой учебник <ru/tutorials/tutorial.html>`_
-
-* `Использование Bazaar с Launchpad 
-  <ru/tutorials/using_bazaar_with_launchpad.html>`_
-
-* `Работа в централизованном стиле
-  <ru/tutorials/centralized_workflow.html>`_
+.. toctree::
+   :maxdepth: 1
+
+   user-guide/index
+   quick-reference/index
+   mini-tutorial/index
+   tutorials/tutorial
+   tutorials/using_bazaar_with_launchpad
+   tutorials/centralized_workflow
+
 
 Ссылки в сети
 =============
 
-* `Руководства по переходу <http://bazaar-vcs.org/BzrSwitching>`_
-  |--| для пользователей переходящих с других систем контроля версий
-
-* `Руководство по миграции <http://bazaar-vcs.org/BzrMigration>`_
+* `Руководство по миграции <http://doc.bazaar-vcs.org/migration/en/>`_
   |--| для команд переносящих историю с других систем контроля версий
 
-* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.), 
-  см. также `русскую версию`__ 
-  
+* `Словарь терминов <http://bazaar-vcs.org/BzrGlossary>`_ (англ.),
+  см. также `русскую версию`__
+
 __  http://groups.google.com/group/ru_bzr/web/%D0%B3%D0%BB%D0%BE%D1%81%D1%81%D0%B0%D1%80%D0%B8%D0%B9
 
-* `Часто задаваемые вопросы <http://bazaar-vcs.org/FAQ>`_ (англ.)
-
-Другие языки
-============
-
-* `Документация на английском <index.html>`_ |--| English Documentation
-* `Документация на испанском <index.es.html>`_
+* `Часто задаваемые вопросы <https://answers.launchpad.net/bzr>`_ (англ.)
+
 
 .. |--| unicode:: U+2014
 

=== modified file 'doc/ru/mini-tutorial/index.txt'
--- doc/ru/mini-tutorial/index.txt	2009-05-05 21:16:12 +0000
+++ doc/ru/mini-tutorial/index.txt	2009-12-02 20:34:07 +0000
@@ -15,20 +15,20 @@
 ваших файлов, как вносить изменения, проверять вашу работу, публиковать её и
 отправлять для объединения с главной веткой проекта.
 
-Если вы предпочитаете более подробное введение, обратитесь к разделу 
+Если вы предпочитаете более подробное введение, обратитесь к разделу
 `Узнать больше`_.
 
 Установка
 =========
 
-Это руководство не описывает как установить Bazaar, потому что обычно 
+Это руководство не описывает как установить Bazaar, потому что обычно
 это очень легко. Инструкции по установке вы найдете тут:
 
 - **GNU/Linux:** скорее всего Bazaar уже присутствует в вашем дистрибутиве GNU/Linux.
 - **Windows:** `инструкции по установке для Windows`_.
 - **Mac OS X:** `инструкции по установке для Mac OS X`_.
 
-Для других платформ и для установки из исходных кодов, обратитесь к страницам 
+Для других платформ и для установки из исходных кодов, обратитесь к страницам
 Загрузка_ и Установка_.
 
 .. _инструкции по установке для Windows: http://bazaar-vcs.org/WindowsDownloads
@@ -39,7 +39,7 @@
 Представьтесь
 =============
 
-Прежде чем начать работать, было бы неплохо сообщить Bazaar кто вы такой. 
+Прежде чем начать работать, было бы неплохо сообщить Bazaar кто вы такой.
 В этом случае ваша работа будет корректно идентифицирована в истории ревизий.
 
 Используя ваше имя и адрес электронной почты, вместо данных Васи Пупкина,
@@ -66,8 +66,8 @@
     $ mkdir subdirectory
     $ touch test1.txt test2.txt test3.txt subdirectory/test4.txt
 
-**Замечание для пользователей Windows:** используйте Windows Explorer 
-для создания ваших каталогов, затем нажимайте правую кнопку мыши 
+**Замечание для пользователей Windows:** используйте Windows Explorer
+для создания ваших каталогов, затем нажимайте правую кнопку мыши
 в этих каталогах и выбирайте ``Новый файл``, чтобы создать ваши файлы.
 
 Теперь дадим Bazaar возможность инициализировать свои данные в каталоге вашего
@@ -182,8 +182,8 @@
 свободного программного обеспечения. Вы можете использовать его для публикации
 своей ветки.
 
-Если у вас нет учетной записи Launchpad, следуйте 
-`руководству по получению учетной записи`_ и `зарегистрируйте SSH ключ`_ 
+Если у вас нет учетной записи Launchpad, следуйте
+`руководству по получению учетной записи`_ и `зарегистрируйте SSH ключ`_
 в своей новой учетной записи.
 
 .. _руководству по получению учетной записи: https://help.launchpad.net/CreatingYourLaunchpadAccount
@@ -264,14 +264,14 @@
     Using saved parent location: http://bazaar.launchpad.net/~bzr/bzr-gtk/trunk
 
 Теперь вы можете отправить директиву объединения по электронной почте
-в проект bzr-gtk. Если разработчики bzr-gtk захотят, то смогут использовать 
+в проект bzr-gtk. Если разработчики bzr-gtk захотят, то смогут использовать
 эту директиву для включения вашей работы в основную ветку.
 
 
 Узнать больше
 =============
 
-Больше информации о Bazaar вы найдете в 
+Больше информации о Bazaar вы найдете в
 `Руководстве пользователя Bazaar <../user-guide/index.html>`_.
 
 Чтобы узнать больше о Bazaar из командой строки::

=== added file 'doc/ru/quick-reference/index.txt'
--- doc/ru/quick-reference/index.txt	1970-01-01 00:00:00 +0000
+++ doc/ru/quick-reference/index.txt	2009-09-09 02:32:10 +0000
@@ -0,0 +1,6 @@
+Карточка быстрого старта
+========================
+
+* `PDF <../_static/ru/bzr-ru-quick-reference.pdf>`_
+* `PNG <../_static/ru/bzr-ru-quick-reference.png>`_
+* `SVG <../_static/ru/bzr-ru-quick-reference.svg>`_

=== modified file 'doc/ru/tutorials/centralized_workflow.txt'
--- doc/ru/tutorials/centralized_workflow.txt	2009-06-05 18:59:14 +0000
+++ doc/ru/tutorials/centralized_workflow.txt	2009-12-02 20:34:07 +0000
@@ -45,7 +45,7 @@
 использоваться в сообщениях журнала и аннотациях, таким образом лучше что
 бы она была похожа на что-то реальное.
 
-::  
+::
 
    % bzr whoami "Иван Пупкин <ivan@pupkin.ru>"
 
@@ -109,7 +109,7 @@
 
 .. _Отслеживание изменений на основной ветке: http://bazaar-vcs.org/TrackingUpstream
 
-.. 
+..
    TODO: На самом деле нам нужен другой документ для описания
    конвертирования проекта. Но пока ссылка выше - это лучшее.
 
@@ -288,7 +288,7 @@
 ::
 
   % bzr branch sftp://centralhost/srv/bzr/sigil/user-a \
-               sftp://centralhost/srv/bzr/sigil/user-a/feature 
+               sftp://centralhost/srv/bzr/sigil/user-a/feature
   % cd ~/work/sigil
   % bzr checkout sftp://centralhost/srv/bzr/sigil/user-a/feature myfeature
 
@@ -315,5 +315,5 @@
 ветки разделяют историю и они могут так же разделять и хранилище истории.
 
 
-.. 
+..
    vim: tw=74 ft=rst spell spelllang=en_us

=== modified file 'doc/ru/tutorials/tutorial.txt'
--- doc/ru/tutorials/tutorial.txt	2009-06-05 18:59:14 +0000
+++ doc/ru/tutorials/tutorial.txt	2009-12-02 20:34:07 +0000
@@ -482,7 +482,7 @@
 готовой ветки. Так как эта копия может быть потенциальной новой веткой эта
 команда называется **branch**::
 
-    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev 
+    % bzr branch http://bazaar-vcs.org/bzr/bzr.dev
     % cd bzr.dev
 
 Эта команда копирует полную историю ветки и после этого вы можете делать все
@@ -553,7 +553,7 @@
 
   ::
 
-    % bzr push sftp://servername.com/path/to/directory 
+    % bzr push sftp://servername.com/path/to/directory
 
   (Каталог назначения должна быть создан заранее, если только не указана
   опция ``--create-prefix``)

=== modified file 'doc/ru/tutorials/using_bazaar_with_launchpad.txt'
--- doc/ru/tutorials/using_bazaar_with_launchpad.txt	2009-05-31 11:46:02 +0000
+++ doc/ru/tutorials/using_bazaar_with_launchpad.txt	2009-12-02 20:34:07 +0000
@@ -301,7 +301,7 @@
 Как поясняется далее, функция отслеживания объединений веток на Launchpad в
 настоящее время находится в стадии разработки. Как только эта функция будет
 готова более подходящим поведением станет автоматическое изменение состояния
-ошибки на *Fix Committed* (исправление зафиксировано). 
+ошибки на *Fix Committed* (исправление зафиксировано).
 
 
 Связь ветки с планом

=== modified file 'doc/ru/user-guide/branching_a_project.txt'
--- doc/ru/user-guide/branching_a_project.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/branching_a_project.txt	2009-12-02 20:34:07 +0000
@@ -93,7 +93,7 @@
 the latest version.
 
 As explained in later chapters, Bazaar also has support for
-`lightweight checkouts <#getting-a-lightweight-checkout>`_ 
+`lightweight checkouts <#getting-a-lightweight-checkout>`_
 of a branch, i.e. working trees with
 no local storage of history. Of course, disconnected usage
 is not available then but that's a tradeoff you can decide

=== added file 'doc/ru/user-guide/index-plain.txt'
--- doc/ru/user-guide/index-plain.txt	1970-01-01 00:00:00 +0000
+++ doc/ru/user-guide/index-plain.txt	2009-12-02 20:34:07 +0000
@@ -0,0 +1,121 @@
+###############################
+Руководство пользователя Bazaar
+###############################
+
+.. Пожалуйста отмечайте секции в подключаемых файлах следующим образом:
+..   уровень 1 ========
+..   уровень 2 --------
+..   уровень 3 ~~~~~~~~
+..   уровень 4 ^^^^^^^^ (лучше не использовать вложенность больше 3-х уровней)
+
+.. contents::
+   Содержание
+   :depth: 2
+.. sectnum::
+
+
+Введение
+########
+
+.. include:: introducing_bazaar.txt
+.. include:: core_concepts.txt
+.. include:: ../../en/user-guide/bazaar_workflows.txt
+
+
+Начинаем работать
+#################
+
+.. include:: ../../en/user-guide/installing_bazaar.txt
+.. include:: ../../en/user-guide/entering_commands.txt
+.. include:: ../../en/user-guide/getting_help.txt
+.. include:: ../../en/user-guide/configuring_bazaar.txt
+.. include:: ../../en/user-guide/using_aliases.txt
+.. include:: ../../en/user-guide/plugins.txt
+.. include:: zen.txt
+
+
+Личный контроль версий
+######################
+
+.. include:: ../../en/user-guide/solo_intro.txt
+.. include:: ../../en/user-guide/starting_a_project.txt
+.. include:: ../../en/user-guide/controlling_registration.txt
+.. include:: ../../en/user-guide/reviewing_changes.txt
+.. include:: ../../en/user-guide/recording_changes.txt
+.. include:: ../../en/user-guide/browsing_history.txt
+.. include:: ../../en/user-guide/releasing_a_project.txt
+.. include:: ../../en/user-guide/undoing_mistakes.txt
+
+
+Делимся с другими
+#################
+
+.. include:: ../../en/user-guide/partner_intro.txt
+.. include:: branching_a_project.txt
+.. include:: ../../en/user-guide/merging_changes.txt
+.. include:: ../../en/user-guide/resolving_conflicts.txt
+.. include:: ../../en/user-guide/annotating_changes.txt
+
+
+Сотрудничество в команде, централизованный стиль
+################################################
+
+.. include:: ../../en/user-guide/central_intro.txt
+.. include:: ../../en/user-guide/publishing_a_branch.txt
+.. include:: using_checkouts.txt
+.. include:: ../../en/user-guide/working_offline_central.txt
+.. include:: ../../en/user-guide/reusing_a_checkout.txt
+
+
+Сотрудничество в команде, распределенный стиль
+##############################################
+
+.. include:: ../../en/user-guide/distributed_intro.txt
+.. include:: ../../en/user-guide/organizing_branches.txt
+.. include:: ../../en/user-guide/using_gatekeepers.txt
+.. include:: ../../en/user-guide/sending_changes.txt
+
+
+Различные темы
+##############
+
+.. include:: ../../en/user-guide/part2_intro.txt
+.. include:: ../../en/user-guide/adv_merging.txt
+.. include:: ../../en/user-guide/shelving_changes.txt
+.. include:: ../../en/user-guide/filtered_views.txt
+.. include:: stacked.txt
+.. include:: ../../en/user-guide/server.txt
+.. include:: ../../en/user-guide/hooks.txt
+.. include:: ../../en/user-guide/version_info.txt
+
+
+Краткое описание некоторых популярных плагинов
+##############################################
+
+.. include:: ../../en/user-guide/bzrtools_plugin.txt
+.. include:: ../../en/user-guide/svn_plugin.txt
+.. include later looms_plugin.txt
+
+
+Интегрируем Bazaar в нашу среду
+###############################
+
+.. include:: ../../en/user-guide/web_browsing.txt
+.. include later - file_explorers.txt
+.. include later - desktop_integration.txt
+.. include later - editors_and_ides.txt
+.. include later - email.txt
+.. include:: ../../en/user-guide/bug_trackers.txt
+
+
+Приложения
+##########
+
+.. include:: specifying_revisions.txt
+.. include:: ../../en/user-guide/organizing_your_workspace.txt
+.. include:: ../../en/user-guide/shared_repository_layouts.txt
+.. include:: ../../en/user-guide/setting_up_email.txt
+.. include:: ../../en/user-guide/http_smart_server.txt
+.. include:: ../../en/user-guide/writing_a_plugin.txt
+
+.. |--| unicode:: U+2014

=== modified file 'doc/ru/user-guide/index.txt'
--- doc/ru/user-guide/index.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/index.txt	2009-12-02 20:34:07 +0000
@@ -87,7 +87,7 @@
 .. include:: ../../en/user-guide/server.txt
 .. include:: ../../en/user-guide/hooks.txt
 .. include:: ../../en/user-guide/version_info.txt
- 
+
 
 Краткое описание некоторых популярных плагинов
 ##############################################

=== modified file 'doc/ru/user-guide/introducing_bazaar.txt'
--- doc/ru/user-guide/introducing_bazaar.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/introducing_bazaar.txt	2009-12-02 20:34:07 +0000
@@ -86,10 +86,10 @@
 
  * для сообществ с открытым исходным кодом:
 
-   * более легкое создание и поддержка изменений для сторонних разработчиков 
+   * более легкое создание и поддержка изменений для сторонних разработчиков
 
    * упрощение взаимодействия основных разработчиков со сторонними
-     разработчиками и более простая миграция сторонних разработчиков в основные 
+     разработчиками и более простая миграция сторонних разработчиков в основные
 
  * для компаний - упрощение работы с распределенными и внешними командами.
 

=== modified file 'doc/ru/user-guide/specifying_revisions.txt'
--- doc/ru/user-guide/specifying_revisions.txt	2009-06-02 11:14:10 +0000
+++ doc/ru/user-guide/specifying_revisions.txt	2009-12-02 20:34:07 +0000
@@ -128,7 +128,7 @@
 ~~~~~~~~
 
 **ancestor**:*path*
-    specifies the common ancestor between the current branch and a 
+    specifies the common ancestor between the current branch and a
     different branch. This is the same ancestor that would be used for
     merging purposes.
 

=== modified file 'doc/ru/user-guide/zen.txt'
--- doc/ru/user-guide/zen.txt	2009-06-05 20:06:14 +0000
+++ doc/ru/user-guide/zen.txt	2009-12-02 20:34:07 +0000
@@ -4,13 +4,13 @@
 Глубокое понимание Bazaar
 -------------------------
 
-Хотя Bazaar во многом похож на другие инструменты контроля версий, есть 
+Хотя Bazaar во многом похож на другие инструменты контроля версий, есть
 некоторые важные различия, которые не всегда очевидны на первый взгляд. Этот
 раздел пытается объяснить некоторые вещи, который пользователь должен знать
 чтобы разбираться в Bazaar, т.е. глубоко его понимать.
 
-Заметьте: чтобы использовать Bazaar совсем необязательно полностью понимать 
-этот раздел. Вы можете просмотреть этот раздел сейчас и вернуться к нему позже. 
+Заметьте: чтобы использовать Bazaar совсем необязательно полностью понимать
+этот раздел. Вы можете просмотреть этот раздел сейчас и вернуться к нему позже.
 
 Понимание номеров ревизий
 -------------------------
@@ -55,7 +55,7 @@
   102: Add code and tests for X
   101: Add tests for Y
   100: ...
-  
+
 Many teams use this approach because their tools make branching and merging
 difficult. As a consequence, developers update from and commit to the trunk
 frequently, minimizing integration pain by spreading it over every commit.
@@ -205,10 +205,10 @@
 ------
 
 Обычно, если вы следовали ранее полученным советам - организовать вашу работу
-в ветках и использовать объединение для сотрудничества - вы обнаружите что 
+в ветках и использовать объединение для сотрудничества - вы обнаружите что
 чаще всего Bazaar делает то что вы ожидаете.
 
-В следующих главах, мы проверим различный способы использования Bazaar, начиная 
+В следующих главах, мы проверим различный способы использования Bazaar, начиная
 с самого простого: использование Bazaar для личных проектов.
 
 ..

=== modified file 'setup.py'
--- setup.py	2009-08-14 14:34:35 +0000
+++ setup.py	2009-11-02 21:51:25 +0000
@@ -40,7 +40,7 @@
     'url':          'http://www.bazaar-vcs.org/',
     'description':  'Friendly distributed version control system',
     'license':      'GNU GPL v2',
-    'download_url': 'http://bazaar-vcs.org/Download',
+    'download_url': 'https://launchpad.net/bzr/+download',
     'long_description': get_long_description(),
     'classifiers': [
         'Development Status :: 6 - Mature',
@@ -167,7 +167,13 @@
 from distutils.extension import Extension
 ext_modules = []
 try:
-    from Pyrex.Distutils import build_ext
+    try:
+        from Pyrex.Distutils import build_ext
+        from Pyrex.Compiler.Version import version as pyrex_version
+    except ImportError:
+        print "No Pyrex, trying Cython..."
+        from Cython.Distutils import build_ext
+        from Cython.Compiler.Version import version as pyrex_version
 except ImportError:
     have_pyrex = False
     # try to build the extension from the prior generated source.
@@ -180,7 +186,6 @@
     from distutils.command.build_ext import build_ext
 else:
     have_pyrex = True
-    from Pyrex.Compiler.Version import version as pyrex_version
 
 
 class build_ext_if_possible(build_ext):
@@ -265,7 +270,6 @@
 
 add_pyrex_extension('bzrlib._annotator_pyx')
 add_pyrex_extension('bzrlib._bencode_pyx')
-add_pyrex_extension('bzrlib._btree_serializer_pyx')
 add_pyrex_extension('bzrlib._chunks_to_lines_pyx')
 add_pyrex_extension('bzrlib._groupcompress_pyx',
                     extra_source=['bzrlib/diff-delta.c'])
@@ -295,6 +299,10 @@
 add_pyrex_extension('bzrlib._chk_map_pyx', libraries=[z_lib])
 ext_modules.append(Extension('bzrlib._patiencediff_c',
                              ['bzrlib/_patiencediff_c.c']))
+add_pyrex_extension('bzrlib._simple_set_pyx')
+ext_modules.append(Extension('bzrlib._static_tuple_c',
+                             ['bzrlib/_static_tuple_c.c']))
+add_pyrex_extension('bzrlib._btree_serializer_pyx')
 
 
 if unavailable_files:
@@ -327,9 +335,6 @@
     # Ensure tbzrlib itself is on sys.path
     sys.path.append(tbzr_root)
 
-    # Ensure our COM "entry-point" is on sys.path
-    sys.path.append(os.path.join(tbzr_root, "shellext", "python"))
-
     packages.append("tbzrlib")
 
     # collect up our icons.
@@ -357,17 +362,6 @@
     excludes.extend("""pywin pywin.dialogs pywin.dialogs.list
                        win32ui crawler.Crawler""".split())
 
-    # NOTE: We still create a DLL version of the Python implemented shell
-    # extension for testing purposes - but it is *not* registered by
-    # default - our C++ one is instead.  To discourage people thinking
-    # this DLL is still necessary, its called 'tbzr_old.dll'
-    tbzr = dict(
-        modules=["tbzr"],
-        create_exe = False, # we only want a .dll
-        dest_base = 'tbzr_old',
-    )
-    com_targets.append(tbzr)
-
     # tbzrcache executables - a "console" version for debugging and a
     # GUI version that is generally used.
     tbzrcache = dict(
@@ -398,8 +392,7 @@
     console_targets.append(tracer)
 
     # The C++ implemented shell extensions.
-    dist_dir = os.path.join(tbzr_root, "shellext", "cpp", "tbzrshellext",
-                            "build", "dist")
+    dist_dir = os.path.join(tbzr_root, "shellext", "build")
     data_files.append(('', [os.path.join(dist_dir, 'tbzrshellext_x86.dll')]))
     data_files.append(('', [os.path.join(dist_dir, 'tbzrshellext_x64.dll')]))
 
@@ -411,6 +404,7 @@
     includes.append('sip') # extension module required for Qt.
     packages.append('pygments') # colorizer for qbzr
     packages.append('docutils') # html formatting
+    includes.append('win32event')  # for qsubprocess stuff
     # but we can avoid many Qt4 Dlls.
     dll_excludes.extend(
         """QtAssistantClient4.dll QtCLucene4.dll QtDesigner4.dll
@@ -544,7 +538,7 @@
                                      version = version_str,
                                      description = META_INFO['description'],
                                      author = META_INFO['author'],
-                                     copyright = "(c) Canonical Ltd, 2005-2007",
+                                     copyright = "(c) Canonical Ltd, 2005-2009",
                                      company_name = "Canonical Ltd.",
                                      comments = META_INFO['description'],
                                     )
@@ -635,7 +629,6 @@
                        'tools/win32/bzr_postinstall.py',
                        ]
     gui_targets = []
-    com_targets = []
     data_files = topics_files + plugins_files
 
     if 'qbzr' in plugins:
@@ -686,7 +679,6 @@
     setup(options=options_list,
           console=console_targets,
           windows=gui_targets,
-          com_server=com_targets,
           zipfile='lib/library.zip',
           data_files=data_files,
           cmdclass={'install_data': install_data_with_bytecompile},

=== added file 'tools/generate_release_notes.py'
--- tools/generate_release_notes.py	1970-01-01 00:00:00 +0000
+++ tools/generate_release_notes.py	2009-09-03 05:09:22 +0000
@@ -0,0 +1,86 @@
+#!/usr/bin/python
+
+# Copyright 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+import os
+import sys
+from optparse import OptionParser
+
+sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
+
+
+def split_into_topics(lines, out_file, out_dir):
+    """Split a large NEWS file into topics, one per release.
+
+    Releases are detected by matching headings that look like
+    release names. Topics are created with matching names
+    replacing spaces with dashes.
+    """
+    topic_file = None
+    for index, line in enumerate(lines):
+        maybe_new_topic = line[:4] in ['bzr ', 'bzr-0',]
+        if maybe_new_topic and lines[index + 1].startswith('####'):
+            release = line.strip()
+            if topic_file is None:
+                # First topic found
+                out_file.write(".. toctree::\n   :maxdepth: 1\n\n")
+            else:
+                # close the current topic
+                topic_file.close()
+            topic_file = open_topic_file(out_file, out_dir, release)
+        elif topic_file:
+            topic_file.write(line)
+        else:
+            # Still in the header - dump content straight to output
+            out_file.write(line)
+
+
+def open_topic_file(out_file, out_dir, release):
+    topic_name = release.replace(' ', '-')
+    out_file.write("   %s\n" % (topic_name,))
+    topic_path = os.path.join(out_dir, "%s.txt" % (topic_name,))
+    result = open(topic_path, 'w')
+    result.write("%s\n" % (release,))
+    return result
+
+
+def main(argv):
+    # Check usage
+    parser = OptionParser(usage="%prog SOURCE DESTINATION")
+    (options, args) = parser.parse_args(argv)
+    if len(args) != 2:
+        parser.print_help()
+        sys.exit(1)
+
+    # Open the files and do the work
+    infile_name = args[0]
+    outfile_name = args[1]
+    outdir = os.path.dirname(outfile_name)
+    infile = open(infile_name, 'r')
+    try:
+        lines = infile.readlines()
+    finally:
+        infile.close()
+    outfile = open(outfile_name, 'w')
+    try:
+        split_into_topics(lines, outfile, outdir)
+    finally:
+        outfile.close()
+
+
+if __name__ == '__main__':
+    main(sys.argv[1:])

=== added file 'tools/package_docs.py'
--- tools/package_docs.py	1970-01-01 00:00:00 +0000
+++ tools/package_docs.py	2009-09-09 00:49:50 +0000
@@ -0,0 +1,109 @@
+#!/usr/bin/python
+
+# Copyright 2009 Canonical Ltd.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+import os
+import sys
+import tarfile
+from optparse import OptionParser
+from shutil import copy2, copytree, rmtree
+
+sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
+
+
+def package_docs(section, src_build, dest_html, dest_downloads):
+    """Package docs from a Sphinx _build directory into target directories.
+
+    :param section: section in the website being built
+    :param src_build: the _build directory
+    :param dest_html: the directory where html should go
+    :param downloads: the directory where downloads should go
+    """
+    # Copy across the HTML. Explicitly delete the html destination
+    # directory first though because copytree insists on it not existing.
+    src_html = os.path.join(src_build, 'html')
+    if os.path.exists(dest_html):
+        rmtree(dest_html)
+    copytree(src_html, dest_html)
+
+    # Package the html as a downloadable archive
+    archive_root = "bzr-%s-html" % (section,)
+    archive_basename = "%s.tar.bz2" % (archive_root,)
+    archive_name = os.path.join(dest_downloads, archive_basename)
+    build_archive(src_html, archive_name, archive_root, 'bz2')
+
+    # Copy across the PDF docs, if any, including the quick ref card
+    pdf_files = []
+    quick_ref = os.path.join(src_html,
+        '_static/%s/bzr-%s-quick-reference.pdf' % (section, section))
+    if os.path.exists(quick_ref):
+        pdf_files.append(quick_ref)
+    src_pdf = os.path.join(src_build, 'latex')
+    if os.path.exists(src_pdf):
+        for name in os.listdir(src_pdf):
+            if name.endswith('.pdf'):
+                pdf_files.append(os.path.join(src_pdf, name))
+    if pdf_files:
+        dest_pdf = os.path.join(dest_downloads, 'pdf-%s' % (section,))
+        if not os.path.exists(dest_pdf):
+            os.mkdir(dest_pdf)
+        for pdf in pdf_files:
+            copy2(pdf, dest_pdf)
+
+    # TODO: copy across the CHM files, if any
+
+
+def build_archive(src_dir, archive_name, archive_root, format):
+    print "creating %s ..." % (archive_name,)
+    tar = tarfile.open(archive_name, "w:%s" % (format,))
+    for relpath in os.listdir(src_dir):
+        src_path = os.path.join(src_dir, relpath)
+        archive_path = os.path.join(archive_root, relpath)
+        tar.add(src_path, arcname=archive_path)
+    tar.close()
+
+
+def main(argv):
+    # Check usage. The first argument is the parent directory of
+    # the Sphinx _build directory. It will typically be 'doc/xx'.
+    # The second argument is the website build directory.
+    parser = OptionParser(usage="%prog SOURCE-DIR WEBSITE-BUILD-DIR")
+    (options, args) = parser.parse_args(argv)
+    if len(args) != 2:
+        parser.print_help()
+        sys.exit(1)
+
+    # Get the section - locale code or 'developers'
+    src_dir = args[0]
+    section = os.path.basename(src_dir)
+    src_build = os.path.join(src_dir, '_build')
+
+    # Create the destination directories if they doesn't exist.
+    dest_dir = args[1]
+    dest_html = os.path.join(dest_dir, section)
+    dest_downloads = os.path.join(dest_dir, 'downloads')
+    for d in [dest_dir, dest_downloads]:
+        if not os.path.exists(d):
+            print "creating directory %s ..." % (d,)
+            os.mkdir(d)
+
+    # Package and copy the files across
+    package_docs(section, src_build, dest_html, dest_downloads)
+
+
+if __name__ == '__main__':
+    main(sys.argv[1:])

=== modified file 'tools/packaging/build-packages.sh'
--- tools/packaging/build-packages.sh	2009-02-16 10:13:56 +0000
+++ tools/packaging/build-packages.sh	2009-05-25 10:59:42 +0000
@@ -9,5 +9,5 @@
 fi
 
 for DISTRO in $UBUNTU_RELEASES; do
-    (cd "packaging-$DISTRO" && bzr builddeb -S)
+    (cd "$PACKAGE-$DISTRO" && bzr builddeb -S)
 done

=== modified file 'tools/packaging/update-changelogs.sh'
--- tools/packaging/update-changelogs.sh	2009-02-16 10:13:56 +0000
+++ tools/packaging/update-changelogs.sh	2009-06-03 10:26:06 +0000
@@ -7,22 +7,27 @@
     exit 1
 fi
 
-if [ "x$1" = "x" ]; then
+if [ "x$VERSION" = "x" ]; then
     echo "Missing version"
     echo "You want something like:"
-    echo "  update-changelogs.sh 1.6~rc1-1~bazaar1"
+    echo "  VERSION=1.6~rc1-1~bazaar1 update-changelogs.sh"
     echo "or"
-    echo "  update-changelogs.sh 1.6-1~bazaar1"
+    echo "  VERSION=1.6-1~bazaar1 update-changelogs.sh"
     exit
 fi
-VERSION=$1
+
+if [ -z "$1" ]; then
+    MSG="New upstream release"
+else
+    MSG=$1
+fi
 
 for DISTRO in $UBUNTU_RELEASES; do
     PPAVERSION="$VERSION~${DISTRO}1"
     (
         echo "Updating changelog for $DISTRO"
-	cd "packaging-$DISTRO" &&
-	dch -v $PPAVERSION -D $DISTRO -c changelog 'New upstream release.' &&
-	bzr commit -m "New upstream release: $PPAVERSION"
+        cd "$PACKAGE-$DISTRO" &&
+            dch -v $PPAVERSION -D $DISTRO -c changelog "$MSG." &&
+            bzr commit -m "$MSG: $PPAVERSION"
     )
 done

=== added file 'tools/packaging/update-control.sh'
--- tools/packaging/update-control.sh	1970-01-01 00:00:00 +0000
+++ tools/packaging/update-control.sh	2009-09-02 04:08:08 +0000
@@ -0,0 +1,31 @@
+#!/bin/bash
+
+if [ -z "$UBUNTU_RELEASES" ]; then
+    echo "Configure the distro platforms that you want to"
+    echo "build with a line like:"
+    echo '  export UBUNTU_RELEASES="dapper feisty gutsy hardy intrepid jaunty"'
+    exit 1
+fi
+
+OLD_VERSION=$1
+NEW_VERSION=$2
+NEXT_VERSION=$3
+if [ -z "$OLD_VERSION" -o -z "$NEW_VERSION" -o -z "$NEXT_VERSION" ]; then
+    echo "Missing version"
+    echo "You want something like:"
+    echo "  update-control.sh 1.5 1.6 1.7"
+    exit
+fi
+
+if [ "$PACKAGE" = "bzr" ]; then
+    continue
+fi
+for DISTRO in $UBUNTU_RELEASES; do
+    PPAVERSION="$VERSION~${DISTRO}1"
+    (
+        echo "Updating control for $DISTRO"
+        cd "$PACKAGE-$DISTRO" &&
+            sed -i -e "s/$NEW_VERSION~/$NEXT_VERSION~/;s/$OLD_VERSION~/$NEW_VERSION~/" control &&
+            bzr commit -m "New upstream release: $PPAVERSION, update control"
+    )
+done

=== modified file 'tools/packaging/update-packaging-branches.sh'
--- tools/packaging/update-packaging-branches.sh	2009-02-16 10:13:56 +0000
+++ tools/packaging/update-packaging-branches.sh	2009-06-03 10:20:19 +0000
@@ -9,12 +9,20 @@
 fi
 
 for DISTRO in $UBUNTU_RELEASES; do
-    if [ -d "packaging-$DISTRO" ] ; then
-        echo "Updating packaging-$DISTRO"
-        bzr update packaging-$DISTRO
+    if [ -d "$PACKAGE-$DISTRO" ] ; then
+        echo "Updating $PACKAGE-$DISTRO"
+        bzr update $PACKAGE-$DISTRO
+        if [ "$PACKAGE" = "bzr-svn" ] ; then
+            cd $PACKAGE-$DISTRO
+            bzr merge http://bzr.debian.org/pkg-bazaar/bzr-svn/unstable/
+            cd ..
+        fi
     else
-        echo "Checking out lp:~bzr/bzr/packaging-$DISTRO"
-        bzr co lp:~bzr/bzr/packaging-$DISTRO
+        SRC="lp:~bzr/$PACKAGE/packaging-$DISTRO"
+        if [ "$PACKAGE" = "bzr-svn" ] ; then
+            SRC="lp:~bzr/$PACKAGE/beta-ppa-$DISTRO"
+        fi
+        echo "Checking out $SRC"
+        bzr co $SRC $PACKAGE-$DISTRO
     fi
 done
-

